Class: Google::Apis::RunV2::GoogleCloudRunV2BuildpacksBuild

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Build the source using Buildpacks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2BuildpacksBuild

Returns a new instance of GoogleCloudRunV2BuildpacksBuild.



214
215
216
# File 'lib/google/apis/run_v2/classes.rb', line 214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_imageString

Optional. The base image to use for the build. Corresponds to the JSON property baseImage

Returns:

  • (String)


173
174
175
# File 'lib/google/apis/run_v2/classes.rb', line 173

def base_image
  @base_image
end

#cache_image_uriString

Optional. cache_image_uri is the GCR/AR URL where the cache image will be stored. cache_image_uri is optional and omitting it will disable caching. This URL must be stable across builds. It is used to derive a build-specific temporary URL by substituting the tag with the build ID. The build will clean up the temporary image on a best-effort basis. Corresponds to the JSON property cacheImageUri

Returns:

  • (String)


182
183
184
# File 'lib/google/apis/run_v2/classes.rb', line 182

def cache_image_uri
  @cache_image_uri
end

#enable_automatic_updatesBoolean Also known as: enable_automatic_updates?

Optional. Whether or not the application container will be enrolled in automatic base image updates. When true, the application will be built on a scratch base image, so the base layers can be appended at run time. Corresponds to the JSON property enableAutomaticUpdates

Returns:

  • (Boolean)


189
190
191
# File 'lib/google/apis/run_v2/classes.rb', line 189

def enable_automatic_updates
  @enable_automatic_updates
end

#environment_variablesHash<String,String>

Optional. User-provided build-time environment variables. Corresponds to the JSON property environmentVariables

Returns:

  • (Hash<String,String>)


195
196
197
# File 'lib/google/apis/run_v2/classes.rb', line 195

def environment_variables
  @environment_variables
end

#function_targetString

Optional. Name of the function target if the source is a function source. Required for function builds. Corresponds to the JSON property functionTarget

Returns:

  • (String)


201
202
203
# File 'lib/google/apis/run_v2/classes.rb', line 201

def function_target
  @function_target
end

#project_descriptorString

Optional. project_descriptor stores the path to the project descriptor file. When empty, it means that there is no project descriptor file in the source. Corresponds to the JSON property projectDescriptor

Returns:

  • (String)


207
208
209
# File 'lib/google/apis/run_v2/classes.rb', line 207

def project_descriptor
  @project_descriptor
end

#runtimeString

The runtime name, e.g. 'go113'. Leave blank for generic builds. Corresponds to the JSON property runtime

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/run_v2/classes.rb', line 212

def runtime
  @runtime
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



219
220
221
222
223
224
225
226
227
# File 'lib/google/apis/run_v2/classes.rb', line 219

def update!(**args)
  @base_image = args[:base_image] if args.key?(:base_image)
  @cache_image_uri = args[:cache_image_uri] if args.key?(:cache_image_uri)
  @enable_automatic_updates = args[:enable_automatic_updates] if args.key?(:enable_automatic_updates)
  @environment_variables = args[:environment_variables] if args.key?(:environment_variables)
  @function_target = args[:function_target] if args.key?(:function_target)
  @project_descriptor = args[:project_descriptor] if args.key?(:project_descriptor)
  @runtime = args[:runtime] if args.key?(:runtime)
end