Class: Google::Apis::RunV2::GoogleCloudRunV2Condition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Defines a status condition for a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Condition

Returns a new instance of GoogleCloudRunV2Condition.



366
367
368
# File 'lib/google/apis/run_v2/classes.rb', line 366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execution_reasonString

Output only. A reason for the execution condition. Corresponds to the JSON property executionReason

Returns:

  • (String)


326
327
328
# File 'lib/google/apis/run_v2/classes.rb', line 326

def execution_reason
  @execution_reason
end

#last_transition_timeString

Last time the condition transitioned from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


331
332
333
# File 'lib/google/apis/run_v2/classes.rb', line 331

def last_transition_time
  @last_transition_time
end

#messageString

Human readable message indicating details about the current status. Corresponds to the JSON property message

Returns:

  • (String)


336
337
338
# File 'lib/google/apis/run_v2/classes.rb', line 336

def message
  @message
end

#reasonString

Output only. A common (service-level) reason for this condition. Corresponds to the JSON property reason

Returns:

  • (String)


341
342
343
# File 'lib/google/apis/run_v2/classes.rb', line 341

def reason
  @reason
end

#revision_reasonString

Output only. A reason for the revision condition. Corresponds to the JSON property revisionReason

Returns:

  • (String)


346
347
348
# File 'lib/google/apis/run_v2/classes.rb', line 346

def revision_reason
  @revision_reason
end

#severityString

How to interpret failures of this condition, one of Error, Warning, Info Corresponds to the JSON property severity

Returns:

  • (String)


351
352
353
# File 'lib/google/apis/run_v2/classes.rb', line 351

def severity
  @severity
end

#stateString

State of the condition. Corresponds to the JSON property state

Returns:

  • (String)


356
357
358
# File 'lib/google/apis/run_v2/classes.rb', line 356

def state
  @state
end

#typeString

type is used to communicate the status of the reconciliation process. See also: https://github.com/knative/serving/blob/main/docs/spec/errors.md#error- conditions-and-reporting Types common to all resources include: * "Ready": True when the Resource is ready. Corresponds to the JSON property type

Returns:

  • (String)


364
365
366
# File 'lib/google/apis/run_v2/classes.rb', line 364

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



371
372
373
374
375
376
377
378
379
380
# File 'lib/google/apis/run_v2/classes.rb', line 371

def update!(**args)
  @execution_reason = args[:execution_reason] if args.key?(:execution_reason)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @revision_reason = args[:revision_reason] if args.key?(:revision_reason)
  @severity = args[:severity] if args.key?(:severity)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end