Class: Google::Apis::RunV2::GoogleCloudRunV2ContainerStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

ContainerStatus holds the information of container name and image digest value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2ContainerStatus

Returns a new instance of GoogleCloudRunV2ContainerStatus.



589
590
591
# File 'lib/google/apis/run_v2/classes.rb', line 589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_digestString

ImageDigest holds the resolved digest for the image specified and resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object. Corresponds to the JSON property imageDigest

Returns:

  • (String)


582
583
584
# File 'lib/google/apis/run_v2/classes.rb', line 582

def image_digest
  @image_digest
end

#nameString

The name of the container, if specified. Corresponds to the JSON property name

Returns:

  • (String)


587
588
589
# File 'lib/google/apis/run_v2/classes.rb', line 587

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



594
595
596
597
# File 'lib/google/apis/run_v2/classes.rb', line 594

def update!(**args)
  @image_digest = args[:image_digest] if args.key?(:image_digest)
  @name = args[:name] if args.key?(:name)
end