Class: Google::Apis::RunV2::GoogleCloudRunV2EmptyDirVolumeSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when the sandbox is taken down, the data is destroyed with it (it does not persist across sandbox runs).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2EmptyDirVolumeSource

Returns a new instance of GoogleCloudRunV2EmptyDirVolumeSource.



651
652
653
# File 'lib/google/apis/run_v2/classes.rb', line 651

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mediumString

The medium on which the data is stored. Acceptable values today is only MEMORY or none. When none, the default will currently be backed by memory but could change over time. +optional Corresponds to the JSON property medium

Returns:

  • (String)


638
639
640
# File 'lib/google/apis/run_v2/classes.rb', line 638

def medium
  @medium
end

#size_limitString

Limit on the storage usable by this EmptyDir volume. The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers. The default is nil which means that the limit is undefined. More info: https://cloud.google.com/run/docs/configuring/in- memory-volumes#configure-volume. Info in Kubernetes: https://kubernetes.io/ docs/concepts/storage/volumes/#emptydir Corresponds to the JSON property sizeLimit

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/run_v2/classes.rb', line 649

def size_limit
  @size_limit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



656
657
658
659
# File 'lib/google/apis/run_v2/classes.rb', line 656

def update!(**args)
  @medium = args[:medium] if args.key?(:medium)
  @size_limit = args[:size_limit] if args.key?(:size_limit)
end