Class: Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
ExecutionTemplate describes the data an execution should have when created from a template.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
-
#client ⇒ String
Optional.
-
#client_version ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Unstructured key value map that can be used to organize and categorize objects.
-
#parallelism ⇒ Fixnum
Optional.
-
#task_count ⇒ Fixnum
Specifies the desired number of tasks the execution should run.
-
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskTemplate
TaskTemplate describes the data a task should have when created from a template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ExecutionTemplate
constructor
A new instance of GoogleCloudRunV2ExecutionTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ExecutionTemplate
Returns a new instance of GoogleCloudRunV2ExecutionTemplate.
1050 1051 1052 |
# File 'lib/google/apis/run_v2/classes.rb', line 1050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Unstructured key value map that may be set by external tools to store and
arbitrary metadata. They are not queryable and should be preserved when
modifying objects. Cloud Run API v2 does not support annotations with run.
googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected. All system
annotations in v1 now have a corresponding field in v2 ExecutionTemplate. This
field follows Kubernetes annotations' namespacing, limits, and rules.
Corresponds to the JSON property annotations
1002 1003 1004 |
# File 'lib/google/apis/run_v2/classes.rb', line 1002 def annotations @annotations end |
#client ⇒ String
Optional. Arbitrary identifier for the API client.
Corresponds to the JSON property client
1007 1008 1009 |
# File 'lib/google/apis/run_v2/classes.rb', line 1007 def client @client end |
#client_version ⇒ String
Optional. Arbitrary version identifier for the API client.
Corresponds to the JSON property clientVersion
1012 1013 1014 |
# File 'lib/google/apis/run_v2/classes.rb', line 1012 def client_version @client_version end |
#labels ⇒ Hash<String,String>
Unstructured key value map that can be used to organize and categorize objects.
User-provided labels are shared with Google's billing system, so they can be
used to filter, or break down billing charges by team, component, environment,
state, etc. For more information, visit https://cloud.google.com/resource-
manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/
configuring/labels. Cloud Run API v2 does not support labels with run.
googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected. All system
labels in v1 now have a corresponding field in v2 ExecutionTemplate.
Corresponds to the JSON property labels
1025 1026 1027 |
# File 'lib/google/apis/run_v2/classes.rb', line 1025 def labels @labels end |
#parallelism ⇒ Fixnum
Optional. Specifies the maximum desired number of tasks the execution should
run at given time. When the job is run, if this field is 0 or unset, the
maximum possible value will be used for that execution. The actual number of
tasks running in steady state will be less than this number when there are
fewer tasks waiting to be completed remaining, i.e. when the work left to do
is less than max parallelism.
Corresponds to the JSON property parallelism
1035 1036 1037 |
# File 'lib/google/apis/run_v2/classes.rb', line 1035 def parallelism @parallelism end |
#task_count ⇒ Fixnum
Specifies the desired number of tasks the execution should run. Setting to 1
means that parallelism is limited to 1 and the success of that task signals
the success of the execution. Defaults to 1.
Corresponds to the JSON property taskCount
1042 1043 1044 |
# File 'lib/google/apis/run_v2/classes.rb', line 1042 def task_count @task_count end |
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskTemplate
TaskTemplate describes the data a task should have when created from a
template.
Corresponds to the JSON property template
1048 1049 1050 |
# File 'lib/google/apis/run_v2/classes.rb', line 1048 def template @template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1055 1056 1057 1058 1059 1060 1061 1062 1063 |
# File 'lib/google/apis/run_v2/classes.rb', line 1055 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @client = args[:client] if args.key?(:client) @client_version = args[:client_version] if args.key?(:client_version) @labels = args[:labels] if args.key?(:labels) @parallelism = args[:parallelism] if args.key?(:parallelism) @task_count = args[:task_count] if args.key?(:task_count) @template = args[:template] if args.key?(:template) end |