Class: Google::Apis::RunV2::GoogleCloudRunV2HttpGetAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

HTTPGetAction describes an action based on HTTP Get requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2HttpGetAction

Returns a new instance of GoogleCloudRunV2HttpGetAction.



1208
1209
1210
# File 'lib/google/apis/run_v2/classes.rb', line 1208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_headersArray<Google::Apis::RunV2::GoogleCloudRunV2HttpHeader>

Optional. Custom headers to set in the request. HTTP allows repeated headers. Corresponds to the JSON property httpHeaders



1194
1195
1196
# File 'lib/google/apis/run_v2/classes.rb', line 1194

def http_headers
  @http_headers
end

#pathString

Optional. Path to access on the HTTP server. Defaults to '/'. Corresponds to the JSON property path

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/run_v2/classes.rb', line 1199

def path
  @path
end

#portFixnum

Optional. Port number to access on the container. Must be in the range 1 to

  1. If not specified, defaults to the exposed port of the container, which is the value of container.ports[0].containerPort. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1206
1207
1208
# File 'lib/google/apis/run_v2/classes.rb', line 1206

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1213
1214
1215
1216
1217
# File 'lib/google/apis/run_v2/classes.rb', line 1213

def update!(**args)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @path = args[:path] if args.key?(:path)
  @port = args[:port] if args.key?(:port)
end