Class: Google::Apis::RunV2::GoogleCloudRunV2InstanceSplitStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2InstanceSplitStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Represents the observed state of a single InstanceSplit entry.
Instance Attribute Summary collapse
-
#percent ⇒ Fixnum
Specifies percent of the instance split to this Revision.
-
#revision ⇒ String
Revision to which this instance split is assigned.
-
#type ⇒ String
The allocation type for this instance split.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2InstanceSplitStatus
constructor
A new instance of GoogleCloudRunV2InstanceSplitStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2InstanceSplitStatus
Returns a new instance of GoogleCloudRunV2InstanceSplitStatus.
1272 1273 1274 |
# File 'lib/google/apis/run_v2/classes.rb', line 1272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percent ⇒ Fixnum
Specifies percent of the instance split to this Revision.
Corresponds to the JSON property percent
1260 1261 1262 |
# File 'lib/google/apis/run_v2/classes.rb', line 1260 def percent @percent end |
#revision ⇒ String
Revision to which this instance split is assigned.
Corresponds to the JSON property revision
1265 1266 1267 |
# File 'lib/google/apis/run_v2/classes.rb', line 1265 def revision @revision end |
#type ⇒ String
The allocation type for this instance split.
Corresponds to the JSON property type
1270 1271 1272 |
# File 'lib/google/apis/run_v2/classes.rb', line 1270 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1277 1278 1279 1280 1281 |
# File 'lib/google/apis/run_v2/classes.rb', line 1277 def update!(**args) @percent = args[:percent] if args.key?(:percent) @revision = args[:revision] if args.key?(:revision) @type = args[:type] if args.key?(:type) end |