Class: Google::Apis::RunV2::GoogleCloudRunV2ListInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ListInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Response message containing a list of Instances.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Instance>
The resulting list of Instances.
-
#next_page_token ⇒ String
A token indicating there are more items than page_size.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ListInstancesResponse
constructor
A new instance of GoogleCloudRunV2ListInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ListInstancesResponse
Returns a new instance of GoogleCloudRunV2ListInstancesResponse.
1922 1923 1924 |
# File 'lib/google/apis/run_v2/classes.rb', line 1922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Instance>
The resulting list of Instances.
Corresponds to the JSON property instances
1914 1915 1916 |
# File 'lib/google/apis/run_v2/classes.rb', line 1914 def instances @instances end |
#next_page_token ⇒ String
A token indicating there are more items than page_size. Use it in the next
ListInstances request to continue.
Corresponds to the JSON property nextPageToken
1920 1921 1922 |
# File 'lib/google/apis/run_v2/classes.rb', line 1920 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1927 1928 1929 1930 |
# File 'lib/google/apis/run_v2/classes.rb', line 1927 def update!(**args) @instances = args[:instances] if args.key?(:instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |