Class: Google::Apis::RunV2::GoogleCloudRunV2ListServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ListServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Response message containing a list of Services.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token indicating there are more items than page_size.
-
#services ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Service>
The resulting list of Services.
-
#unreachable ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ListServicesResponse
constructor
A new instance of GoogleCloudRunV2ListServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ListServicesResponse
Returns a new instance of GoogleCloudRunV2ListServicesResponse.
2020 2021 2022 |
# File 'lib/google/apis/run_v2/classes.rb', line 2020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token indicating there are more items than page_size. Use it in the next
ListServices request to continue.
Corresponds to the JSON property nextPageToken
2007 2008 2009 |
# File 'lib/google/apis/run_v2/classes.rb', line 2007 def next_page_token @next_page_token end |
#services ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Service>
The resulting list of Services.
Corresponds to the JSON property services
2012 2013 2014 |
# File 'lib/google/apis/run_v2/classes.rb', line 2012 def services @services end |
#unreachable ⇒ Array<String>
Output only. For global requests, returns the list of regions that could not
be reached within the deadline.
Corresponds to the JSON property unreachable
2018 2019 2020 |
# File 'lib/google/apis/run_v2/classes.rb', line 2018 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2025 2026 2027 2028 2029 |
# File 'lib/google/apis/run_v2/classes.rb', line 2025 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @services = args[:services] if args.key?(:services) @unreachable = args[:unreachable] if args.key?(:unreachable) end |