Class: Google::Apis::RunV2::GoogleCloudRunV2ListWorkerPoolsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ListWorkerPoolsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Response message containing a list of WorkerPools.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token indicating there are more items than page_size.
-
#worker_pools ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2WorkerPool>
The resulting list of WorkerPools.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ListWorkerPoolsResponse
constructor
A new instance of GoogleCloudRunV2ListWorkerPoolsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ListWorkerPoolsResponse
Returns a new instance of GoogleCloudRunV2ListWorkerPoolsResponse.
1660 1661 1662 |
# File 'lib/google/apis/run_v2/classes.rb', line 1660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token indicating there are more items than page_size. Use it in the next
ListWorkerPools request to continue.
Corresponds to the JSON property nextPageToken
1653 1654 1655 |
# File 'lib/google/apis/run_v2/classes.rb', line 1653 def next_page_token @next_page_token end |
#worker_pools ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2WorkerPool>
The resulting list of WorkerPools.
Corresponds to the JSON property workerPools
1658 1659 1660 |
# File 'lib/google/apis/run_v2/classes.rb', line 1658 def worker_pools @worker_pools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1665 1666 1667 1668 |
# File 'lib/google/apis/run_v2/classes.rb', line 1665 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @worker_pools = args[:worker_pools] if args.key?(:worker_pools) end |