Class: Google::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Represents an NFS mount.
Instance Attribute Summary collapse
-
#path ⇒ String
Path that is exported by the NFS server.
-
#read_only ⇒ Boolean
(also: #read_only?)
If true, the volume will be mounted as read only for all mounts.
-
#server ⇒ String
Hostname or IP address of the NFS server Corresponds to the JSON property
server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2NfsVolumeSource
constructor
A new instance of GoogleCloudRunV2NfsVolumeSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2NfsVolumeSource
Returns a new instance of GoogleCloudRunV2NfsVolumeSource.
2141 2142 2143 |
# File 'lib/google/apis/run_v2/classes.rb', line 2141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path ⇒ String
Path that is exported by the NFS server.
Corresponds to the JSON property path
2128 2129 2130 |
# File 'lib/google/apis/run_v2/classes.rb', line 2128 def path @path end |
#read_only ⇒ Boolean Also known as: read_only?
If true, the volume will be mounted as read only for all mounts.
Corresponds to the JSON property readOnly
2133 2134 2135 |
# File 'lib/google/apis/run_v2/classes.rb', line 2133 def read_only @read_only end |
#server ⇒ String
Hostname or IP address of the NFS server
Corresponds to the JSON property server
2139 2140 2141 |
# File 'lib/google/apis/run_v2/classes.rb', line 2139 def server @server end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2146 2147 2148 2149 2150 |
# File 'lib/google/apis/run_v2/classes.rb', line 2146 def update!(**args) @path = args[:path] if args.key?(:path) @read_only = args[:read_only] if args.key?(:read_only) @server = args[:server] if args.key?(:server) end |