Class: Google::Apis::RunV2::GoogleCloudRunV2Overrides

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

RunJob Overrides that contains Execution fields to be overridden.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Overrides

Returns a new instance of GoogleCloudRunV2Overrides.



2245
2246
2247
# File 'lib/google/apis/run_v2/classes.rb', line 2245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_overridesArray<Google::Apis::RunV2::GoogleCloudRunV2ContainerOverride>

Per container override specification. Corresponds to the JSON property containerOverrides



2230
2231
2232
# File 'lib/google/apis/run_v2/classes.rb', line 2230

def container_overrides
  @container_overrides
end

#task_countFixnum

Optional. The desired number of tasks the execution should run. Will replace existing task_count value. Corresponds to the JSON property taskCount

Returns:

  • (Fixnum)


2236
2237
2238
# File 'lib/google/apis/run_v2/classes.rb', line 2236

def task_count
  @task_count
end

#timeoutString

Duration in seconds the task may be active before the system will actively try to mark it failed and kill associated containers. Will replace existing timeout_seconds value. Corresponds to the JSON property timeout

Returns:

  • (String)


2243
2244
2245
# File 'lib/google/apis/run_v2/classes.rb', line 2243

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2250
2251
2252
2253
2254
# File 'lib/google/apis/run_v2/classes.rb', line 2250

def update!(**args)
  @container_overrides = args[:container_overrides] if args.key?(:container_overrides)
  @task_count = args[:task_count] if args.key?(:task_count)
  @timeout = args[:timeout] if args.key?(:timeout)
end