Class: Google::Apis::RunV2::GoogleCloudRunV2Revision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Revision is an immutable snapshot of code and configuration. A Revision references a container image. Revisions are only created by updates to its parent Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Revision

Returns a new instance of GoogleCloudRunV2Revision.



2577
2578
2579
# File 'lib/google/apis/run_v2/classes.rb', line 2577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Output only. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2367
2368
2369
# File 'lib/google/apis/run_v2/classes.rb', line 2367

def annotations
  @annotations
end

#clientString

Output only. Arbitrary identifier for the API client. Corresponds to the JSON property client

Returns:

  • (String)


2372
2373
2374
# File 'lib/google/apis/run_v2/classes.rb', line 2372

def client
  @client
end

#client_versionString

Output only. Arbitrary version identifier for the API client. Corresponds to the JSON property clientVersion

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/run_v2/classes.rb', line 2377

def client_version
  @client_version
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Condition of this Revision, containing its readiness status, and detailed error information in case it did not reach a serving state. Corresponds to the JSON property conditions



2383
2384
2385
# File 'lib/google/apis/run_v2/classes.rb', line 2383

def conditions
  @conditions
end

#containersArray<Google::Apis::RunV2::GoogleCloudRunV2Container>

Holds the list which define the units of execution for this Revision. Corresponds to the JSON property containers



2388
2389
2390
# File 'lib/google/apis/run_v2/classes.rb', line 2388

def containers
  @containers
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


2393
2394
2395
# File 'lib/google/apis/run_v2/classes.rb', line 2393

def create_time
  @create_time
end

#creatorString

Output only. Email address of the authenticated creator. Corresponds to the JSON property creator

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/run_v2/classes.rb', line 2398

def creator
  @creator
end

#delete_timeString

Output only. For a deleted resource, the deletion time. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


2404
2405
2406
# File 'lib/google/apis/run_v2/classes.rb', line 2404

def delete_time
  @delete_time
end

#encryption_keyString

A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google.com/run/docs/ securing/using-cmek Corresponds to the JSON property encryptionKey

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/run_v2/classes.rb', line 2411

def encryption_key
  @encryption_key
end

#encryption_key_revocation_actionString

The action to take if the encryption key is revoked. Corresponds to the JSON property encryptionKeyRevocationAction

Returns:

  • (String)


2416
2417
2418
# File 'lib/google/apis/run_v2/classes.rb', line 2416

def encryption_key_revocation_action
  @encryption_key_revocation_action
end

#encryption_key_shutdown_durationString

If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances. The minimum increment is 1 hour. Corresponds to the JSON property encryptionKeyShutdownDuration

Returns:

  • (String)


2422
2423
2424
# File 'lib/google/apis/run_v2/classes.rb', line 2422

def encryption_key_shutdown_duration
  @encryption_key_shutdown_duration
end

#etagString

Output only. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


2428
2429
2430
# File 'lib/google/apis/run_v2/classes.rb', line 2428

def etag
  @etag
end

#execution_environmentString

The execution environment being used to host this Revision. Corresponds to the JSON property executionEnvironment

Returns:

  • (String)


2433
2434
2435
# File 'lib/google/apis/run_v2/classes.rb', line 2433

def execution_environment
  @execution_environment
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permamently deleted. It is only populated as a response to a Delete request. Corresponds to the JSON property expireTime

Returns:

  • (String)


2439
2440
2441
# File 'lib/google/apis/run_v2/classes.rb', line 2439

def expire_time
  @expire_time
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


2445
2446
2447
# File 'lib/google/apis/run_v2/classes.rb', line 2445

def generation
  @generation
end

#gpu_zonal_redundancy_disabledBoolean Also known as: gpu_zonal_redundancy_disabled?

Optional. Output only. True if GPU zonal redundancy is disabled on this revision. Corresponds to the JSON property gpuZonalRedundancyDisabled

Returns:

  • (Boolean)


2451
2452
2453
# File 'lib/google/apis/run_v2/classes.rb', line 2451

def gpu_zonal_redundancy_disabled
  @gpu_zonal_redundancy_disabled
end

#labelsHash<String,String>

Output only. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2462
2463
2464
# File 'lib/google/apis/run_v2/classes.rb', line 2462

def labels
  @labels
end

#launch_stageString

The least stable launch stage needed to create this resource, as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and GA. Note that this value might not be what was used as input. For example, if ALPHA was provided as input in the parent resource, but only BETA and GA-level features are used, this field will be BETA. Corresponds to the JSON property launchStage

Returns:

  • (String)


2472
2473
2474
# File 'lib/google/apis/run_v2/classes.rb', line 2472

def launch_stage
  @launch_stage
end

#log_uriString

Output only. The Google Console URI to obtain logs for the Revision. Corresponds to the JSON property logUri

Returns:

  • (String)


2477
2478
2479
# File 'lib/google/apis/run_v2/classes.rb', line 2477

def log_uri
  @log_uri
end

#max_instance_request_concurrencyFixnum

Sets the maximum number of requests that each serving instance can receive. Corresponds to the JSON property maxInstanceRequestConcurrency

Returns:

  • (Fixnum)


2482
2483
2484
# File 'lib/google/apis/run_v2/classes.rb', line 2482

def max_instance_request_concurrency
  @max_instance_request_concurrency
end

#nameString

Output only. The unique name of this Revision. Corresponds to the JSON property name

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/run_v2/classes.rb', line 2487

def name
  @name
end

#node_selectorGoogle::Apis::RunV2::GoogleCloudRunV2NodeSelector

Hardware constraints configuration. Corresponds to the JSON property nodeSelector



2492
2493
2494
# File 'lib/google/apis/run_v2/classes.rb', line 2492

def node_selector
  @node_selector
end

#observed_generationFixnum

Output only. The generation of this Revision currently serving traffic. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


2499
2500
2501
# File 'lib/google/apis/run_v2/classes.rb', line 2499

def observed_generation
  @observed_generation
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether the resource's reconciliation is still in progress. See comments in Service.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2506
2507
2508
# File 'lib/google/apis/run_v2/classes.rb', line 2506

def reconciling
  @reconciling
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2512
2513
2514
# File 'lib/google/apis/run_v2/classes.rb', line 2512

def satisfies_pzs
  @satisfies_pzs
end

#scalingGoogle::Apis::RunV2::GoogleCloudRunV2RevisionScaling

Settings for revision-level scaling settings. Corresponds to the JSON property scaling



2518
2519
2520
# File 'lib/google/apis/run_v2/classes.rb', line 2518

def scaling
  @scaling
end

#scaling_statusGoogle::Apis::RunV2::GoogleCloudRunV2RevisionScalingStatus

Effective settings for the current revision Corresponds to the JSON property scalingStatus



2523
2524
2525
# File 'lib/google/apis/run_v2/classes.rb', line 2523

def scaling_status
  @scaling_status
end

#serviceString

Output only. The name of the parent service. Corresponds to the JSON property service

Returns:

  • (String)


2528
2529
2530
# File 'lib/google/apis/run_v2/classes.rb', line 2528

def service
  @service
end

#service_accountString

Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2535
2536
2537
# File 'lib/google/apis/run_v2/classes.rb', line 2535

def 
  @service_account
end

#service_meshGoogle::Apis::RunV2::GoogleCloudRunV2ServiceMesh

Settings for Cloud Service Mesh. For more information see https://cloud.google. com/service-mesh/docs/overview. Corresponds to the JSON property serviceMesh



2541
2542
2543
# File 'lib/google/apis/run_v2/classes.rb', line 2541

def service_mesh
  @service_mesh
end

#session_affinityBoolean Also known as: session_affinity?

Enable session affinity. Corresponds to the JSON property sessionAffinity

Returns:

  • (Boolean)


2546
2547
2548
# File 'lib/google/apis/run_v2/classes.rb', line 2546

def session_affinity
  @session_affinity
end

#timeoutString

Max allowed time for an instance to respond to a request. Corresponds to the JSON property timeout

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/run_v2/classes.rb', line 2552

def timeout
  @timeout
end

#uidString

Output only. Server assigned unique identifier for the Revision. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


2559
2560
2561
# File 'lib/google/apis/run_v2/classes.rb', line 2559

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/run_v2/classes.rb', line 2564

def update_time
  @update_time
end

#volumesArray<Google::Apis::RunV2::GoogleCloudRunV2Volume>

A list of Volumes to make available to containers. Corresponds to the JSON property volumes



2569
2570
2571
# File 'lib/google/apis/run_v2/classes.rb', line 2569

def volumes
  @volumes
end

#vpc_accessGoogle::Apis::RunV2::GoogleCloudRunV2VpcAccess

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc. Corresponds to the JSON property vpcAccess



2575
2576
2577
# File 'lib/google/apis/run_v2/classes.rb', line 2575

def vpc_access
  @vpc_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
# File 'lib/google/apis/run_v2/classes.rb', line 2582

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client = args[:client] if args.key?(:client)
  @client_version = args[:client_version] if args.key?(:client_version)
  @conditions = args[:conditions] if args.key?(:conditions)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action)
  @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration)
  @etag = args[:etag] if args.key?(:etag)
  @execution_environment = args[:execution_environment] if args.key?(:execution_environment)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency)
  @name = args[:name] if args.key?(:name)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scaling = args[:scaling] if args.key?(:scaling)
  @scaling_status = args[:scaling_status] if args.key?(:scaling_status)
  @service = args[:service] if args.key?(:service)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_mesh = args[:service_mesh] if args.key?(:service_mesh)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @timeout = args[:timeout] if args.key?(:timeout)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volumes = args[:volumes] if args.key?(:volumes)
  @vpc_access = args[:vpc_access] if args.key?(:vpc_access)
end