Class: Google::Apis::RunV2::GoogleCloudRunV2RevisionScaling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Settings for revision-level scaling settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2RevisionScaling

Returns a new instance of GoogleCloudRunV2RevisionScaling.



2216
2217
2218
# File 'lib/google/apis/run_v2/classes.rb', line 2216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_instance_countFixnum

Optional. Maximum number of serving instances that this resource should have. When unspecified, the field is set to the server default value of 100. For more information see https://cloud.google.com/run/docs/configuring/max- instances Corresponds to the JSON property maxInstanceCount

Returns:

  • (Fixnum)


2209
2210
2211
# File 'lib/google/apis/run_v2/classes.rb', line 2209

def max_instance_count
  @max_instance_count
end

#min_instance_countFixnum

Optional. Minimum number of serving instances that this resource should have. Corresponds to the JSON property minInstanceCount

Returns:

  • (Fixnum)


2214
2215
2216
# File 'lib/google/apis/run_v2/classes.rb', line 2214

def min_instance_count
  @min_instance_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2221
2222
2223
2224
# File 'lib/google/apis/run_v2/classes.rb', line 2221

def update!(**args)
  @max_instance_count = args[:max_instance_count] if args.key?(:max_instance_count)
  @min_instance_count = args[:min_instance_count] if args.key?(:min_instance_count)
end