Class: Google::Apis::RunV2::GoogleCloudRunV2RunJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Request message to create a new Execution of a Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2RunJobRequest

Returns a new instance of GoogleCloudRunV2RunJobRequest.



2890
2891
2892
# File 'lib/google/apis/run_v2/classes.rb', line 2890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


2876
2877
2878
# File 'lib/google/apis/run_v2/classes.rb', line 2876

def etag
  @etag
end

#overridesGoogle::Apis::RunV2::GoogleCloudRunV2Overrides

RunJob Overrides that contains Execution fields to be overridden. Corresponds to the JSON property overrides



2881
2882
2883
# File 'lib/google/apis/run_v2/classes.rb', line 2881

def overrides
  @overrides
end

#validate_onlyBoolean Also known as: validate_only?

Indicates that the request should be validated without actually deleting any resources. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2887
2888
2889
# File 'lib/google/apis/run_v2/classes.rb', line 2887

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2895
2896
2897
2898
2899
# File 'lib/google/apis/run_v2/classes.rb', line 2895

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @overrides = args[:overrides] if args.key?(:overrides)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end