Class: Google::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
The secret's value will be presented as the content of a file whose name is defined in the item path. If no items are defined, the name of the file is the secret.
Instance Attribute Summary collapse
-
#default_mode ⇒ Fixnum
Integer representation of mode bits to use on created files by default.
-
#items ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2VersionToPath>
If unspecified, the volume will expose a file whose name is the secret, relative to VolumeMount.mount_path + VolumeMount.sub_path.
-
#secret ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2SecretVolumeSource
constructor
A new instance of GoogleCloudRunV2SecretVolumeSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2SecretVolumeSource
Returns a new instance of GoogleCloudRunV2SecretVolumeSource.
2961 2962 2963 |
# File 'lib/google/apis/run_v2/classes.rb', line 2961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_mode ⇒ Fixnum
Integer representation of mode bits to use on created files by default. Must
be a value between 0000 and 0777 (octal), defaulting to 0444. Directories
within the path are not affected by this setting. Notes * Internally, a umask
of 0222 will be applied to any non-zero value. * This is an integer
representation of the mode bits. So, the octal integer value should look
exactly as the chmod numeric notation with a leading zero. Some examples: for
chmod 640 (u=rw,g=r), set to 0640 (octal) or 416 (base-10). For chmod 755 (u=
rwx,g=rx,o=rx), set to 0755 (octal) or 493 (base-10). * This might be in
conflict with other options that affect the file mode, like fsGroup, and the
result can be other mode bits set. This might be in conflict with other
options that affect the file mode, like fsGroup, and as a result, other mode
bits could be set.
Corresponds to the JSON property defaultMode
2943 2944 2945 |
# File 'lib/google/apis/run_v2/classes.rb', line 2943 def default_mode @default_mode end |
#items ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2VersionToPath>
If unspecified, the volume will expose a file whose name is the secret,
relative to VolumeMount.mount_path + VolumeMount.sub_path. If specified, the
key will be used as the version to fetch from Cloud Secret Manager and the
path will be the name of the file exposed in the volume. When items are
defined, they must specify a path and a version.
Corresponds to the JSON property items
2952 2953 2954 |
# File 'lib/google/apis/run_v2/classes.rb', line 2952 def items @items end |
#secret ⇒ String
Required. The name of the secret in Cloud Secret Manager. Format: secret if
the secret is in the same project. projects/project/secrets/secret if the
secret is in a different project.
Corresponds to the JSON property secret
2959 2960 2961 |
# File 'lib/google/apis/run_v2/classes.rb', line 2959 def secret @secret end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2966 2967 2968 2969 2970 |
# File 'lib/google/apis/run_v2/classes.rb', line 2966 def update!(**args) @default_mode = args[:default_mode] if args.key?(:default_mode) @items = args[:items] if args.key?(:items) @secret = args[:secret] if args.key?(:secret) end |