Class: Google::Apis::RunV2::GoogleCloudRunV2StopInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Request message for deleting an Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2StopInstanceRequest

Returns a new instance of GoogleCloudRunV2StopInstanceRequest.



3452
3453
3454
# File 'lib/google/apis/run_v2/classes.rb', line 3452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. A system-generated fingerprint for this version of the resource. This may be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


3443
3444
3445
# File 'lib/google/apis/run_v2/classes.rb', line 3443

def etag
  @etag
end

#validate_onlyBoolean Also known as: validate_only?

Optional. Indicates that the request should be validated without actually stopping any resources. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


3449
3450
3451
# File 'lib/google/apis/run_v2/classes.rb', line 3449

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3457
3458
3459
3460
# File 'lib/google/apis/run_v2/classes.rb', line 3457

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end