Class: Google::Apis::RunV2::GoogleCloudRunV2StorageSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Location of the source in an archive file in Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2StorageSource

Returns a new instance of GoogleCloudRunV2StorageSource.



3524
3525
3526
# File 'lib/google/apis/run_v2/classes.rb', line 3524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

Required. Google Cloud Storage bucket containing the source (see Bucket Name Requirements ). Corresponds to the JSON property bucket

Returns:

  • (String)


3510
3511
3512
# File 'lib/google/apis/run_v2/classes.rb', line 3510

def bucket
  @bucket
end

#generationFixnum

Optional. Google Cloud Storage generation for the object. If the generation is omitted, the latest generation will be used. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


3516
3517
3518
# File 'lib/google/apis/run_v2/classes.rb', line 3516

def generation
  @generation
end

#objectString

Required. Google Cloud Storage object containing the source. This object must be a gzipped archive file (.tar.gz) containing source to build. Corresponds to the JSON property object

Returns:

  • (String)


3522
3523
3524
# File 'lib/google/apis/run_v2/classes.rb', line 3522

def object
  @object
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3529
3530
3531
3532
3533
# File 'lib/google/apis/run_v2/classes.rb', line 3529

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @generation = args[:generation] if args.key?(:generation)
  @object = args[:object] if args.key?(:object)
end