Class: Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Response message for submitting a Build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildResponse

Returns a new instance of GoogleCloudRunV2SubmitBuildResponse.



3618
3619
3620
# File 'lib/google/apis/run_v2/classes.rb', line 3618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_image_uriString

URI of the base builder image in Artifact Registry being used in the build. Used to opt into automatic base image updates. Corresponds to the JSON property baseImageUri

Returns:

  • (String)


3605
3606
3607
# File 'lib/google/apis/run_v2/classes.rb', line 3605

def base_image_uri
  @base_image_uri
end

#base_image_warningString

Warning message for the base image. Corresponds to the JSON property baseImageWarning

Returns:

  • (String)


3610
3611
3612
# File 'lib/google/apis/run_v2/classes.rb', line 3610

def base_image_warning
  @base_image_warning
end

#build_operationGoogle::Apis::RunV2::GoogleLongrunningOperation

This resource represents a long-running operation that is the result of a network API call. Corresponds to the JSON property buildOperation



3616
3617
3618
# File 'lib/google/apis/run_v2/classes.rb', line 3616

def build_operation
  @build_operation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3623
3624
3625
3626
3627
# File 'lib/google/apis/run_v2/classes.rb', line 3623

def update!(**args)
  @base_image_uri = args[:base_image_uri] if args.key?(:base_image_uri)
  @base_image_warning = args[:base_image_warning] if args.key?(:base_image_warning)
  @build_operation = args[:build_operation] if args.key?(:build_operation)
end