Class: Google::Apis::RunV2::GoogleCloudRunV2Task

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Task represents a single run of a container to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Task

Returns a new instance of GoogleCloudRunV2Task.



3853
3854
3855
# File 'lib/google/apis/run_v2/classes.rb', line 3853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Output only. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


3660
3661
3662
# File 'lib/google/apis/run_v2/classes.rb', line 3660

def annotations
  @annotations
end

#completion_timeString

Output only. Represents time when the Task was completed. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property completionTime

Returns:

  • (String)


3666
3667
3668
# File 'lib/google/apis/run_v2/classes.rb', line 3666

def completion_time
  @completion_time
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Condition of this Task, containing its readiness status, and detailed error information in case it did not reach the desired state. Corresponds to the JSON property conditions



3672
3673
3674
# File 'lib/google/apis/run_v2/classes.rb', line 3672

def conditions
  @conditions
end

#containersArray<Google::Apis::RunV2::GoogleCloudRunV2Container>

Holds the single container that defines the unit of execution for this task. Corresponds to the JSON property containers



3677
3678
3679
# File 'lib/google/apis/run_v2/classes.rb', line 3677

def containers
  @containers
end

#create_timeString

Output only. Represents time when the task was created by the system. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property createTime

Returns:

  • (String)


3683
3684
3685
# File 'lib/google/apis/run_v2/classes.rb', line 3683

def create_time
  @create_time
end

#delete_timeString

Output only. For a deleted resource, the deletion time. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3689
3690
3691
# File 'lib/google/apis/run_v2/classes.rb', line 3689

def delete_time
  @delete_time
end

#encryption_keyString

Output only. A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google. com/run/docs/securing/using-cmek Corresponds to the JSON property encryptionKey

Returns:

  • (String)


3696
3697
3698
# File 'lib/google/apis/run_v2/classes.rb', line 3696

def encryption_key
  @encryption_key
end

#etagString

Output only. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


3702
3703
3704
# File 'lib/google/apis/run_v2/classes.rb', line 3702

def etag
  @etag
end

#executionString

Output only. The name of the parent Execution. Corresponds to the JSON property execution

Returns:

  • (String)


3707
3708
3709
# File 'lib/google/apis/run_v2/classes.rb', line 3707

def execution
  @execution
end

#execution_environmentString

The execution environment being used to host this Task. Corresponds to the JSON property executionEnvironment

Returns:

  • (String)


3712
3713
3714
# File 'lib/google/apis/run_v2/classes.rb', line 3712

def execution_environment
  @execution_environment
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permamently deleted. It is only populated as a response to a Delete request. Corresponds to the JSON property expireTime

Returns:

  • (String)


3718
3719
3720
# File 'lib/google/apis/run_v2/classes.rb', line 3718

def expire_time
  @expire_time
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


3724
3725
3726
# File 'lib/google/apis/run_v2/classes.rb', line 3724

def generation
  @generation
end

#gpu_zonal_redundancy_disabledBoolean Also known as: gpu_zonal_redundancy_disabled?

Optional. Output only. True if GPU zonal redundancy is disabled on this task. Corresponds to the JSON property gpuZonalRedundancyDisabled

Returns:

  • (Boolean)


3729
3730
3731
# File 'lib/google/apis/run_v2/classes.rb', line 3729

def gpu_zonal_redundancy_disabled
  @gpu_zonal_redundancy_disabled
end

#indexFixnum

Output only. Index of the Task, unique per execution, and beginning at 0. Corresponds to the JSON property index

Returns:

  • (Fixnum)


3735
3736
3737
# File 'lib/google/apis/run_v2/classes.rb', line 3735

def index
  @index
end

#jobString

Output only. The name of the parent Job. Corresponds to the JSON property job

Returns:

  • (String)


3740
3741
3742
# File 'lib/google/apis/run_v2/classes.rb', line 3740

def job
  @job
end

#labelsHash<String,String>

Output only. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3750
3751
3752
# File 'lib/google/apis/run_v2/classes.rb', line 3750

def labels
  @labels
end

#last_attempt_resultGoogle::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult

Result of a task attempt. Corresponds to the JSON property lastAttemptResult



3755
3756
3757
# File 'lib/google/apis/run_v2/classes.rb', line 3755

def last_attempt_result
  @last_attempt_result
end

#log_uriString

Output only. URI where logs for this execution can be found in Cloud Console. Corresponds to the JSON property logUri

Returns:

  • (String)


3760
3761
3762
# File 'lib/google/apis/run_v2/classes.rb', line 3760

def log_uri
  @log_uri
end

#max_retriesFixnum

Number of retries allowed per Task, before marking this Task failed. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


3765
3766
3767
# File 'lib/google/apis/run_v2/classes.rb', line 3765

def max_retries
  @max_retries
end

#nameString

Output only. The unique name of this Task. Corresponds to the JSON property name

Returns:

  • (String)


3770
3771
3772
# File 'lib/google/apis/run_v2/classes.rb', line 3770

def name
  @name
end

#node_selectorGoogle::Apis::RunV2::GoogleCloudRunV2NodeSelector

Hardware constraints configuration. Corresponds to the JSON property nodeSelector



3775
3776
3777
# File 'lib/google/apis/run_v2/classes.rb', line 3775

def node_selector
  @node_selector
end

#observed_generationFixnum

Output only. The generation of this Task. See comments in Job.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


3781
3782
3783
# File 'lib/google/apis/run_v2/classes.rb', line 3781

def observed_generation
  @observed_generation
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether the resource's reconciliation is still in progress. See comments in Job.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3788
3789
3790
# File 'lib/google/apis/run_v2/classes.rb', line 3788

def reconciling
  @reconciling
end

#retriedFixnum

Output only. The number of times this Task was retried. Tasks are retried when they fail up to the maxRetries limit. Corresponds to the JSON property retried

Returns:

  • (Fixnum)


3795
3796
3797
# File 'lib/google/apis/run_v2/classes.rb', line 3795

def retried
  @retried
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


3800
3801
3802
# File 'lib/google/apis/run_v2/classes.rb', line 3800

def satisfies_pzs
  @satisfies_pzs
end

#scheduled_timeString

Output only. Represents time when the task was scheduled to run by the system. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property scheduledTime

Returns:

  • (String)


3808
3809
3810
# File 'lib/google/apis/run_v2/classes.rb', line 3808

def scheduled_time
  @scheduled_time
end

#service_accountString

Email address of the IAM service account associated with the Task of a Job. The service account represents the identity of the running task, and determines what permissions the task has. If not provided, the task will use the project's default service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3816
3817
3818
# File 'lib/google/apis/run_v2/classes.rb', line 3816

def 
  @service_account
end

#start_timeString

Output only. Represents time when the task started to run. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property startTime

Returns:

  • (String)


3822
3823
3824
# File 'lib/google/apis/run_v2/classes.rb', line 3822

def start_time
  @start_time
end

#timeoutString

Max allowed time duration the Task may be active before the system will actively try to mark it failed and kill associated containers. This applies per attempt of a task, meaning each retry can run for the full timeout. Corresponds to the JSON property timeout

Returns:

  • (String)


3829
3830
3831
# File 'lib/google/apis/run_v2/classes.rb', line 3829

def timeout
  @timeout
end

#uidString

Output only. Server assigned unique identifier for the Task. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


3835
3836
3837
# File 'lib/google/apis/run_v2/classes.rb', line 3835

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


3840
3841
3842
# File 'lib/google/apis/run_v2/classes.rb', line 3840

def update_time
  @update_time
end

#volumesArray<Google::Apis::RunV2::GoogleCloudRunV2Volume>

A list of Volumes to make available to containers. Corresponds to the JSON property volumes



3845
3846
3847
# File 'lib/google/apis/run_v2/classes.rb', line 3845

def volumes
  @volumes
end

#vpc_accessGoogle::Apis::RunV2::GoogleCloudRunV2VpcAccess

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc. Corresponds to the JSON property vpcAccess



3851
3852
3853
# File 'lib/google/apis/run_v2/classes.rb', line 3851

def vpc_access
  @vpc_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
# File 'lib/google/apis/run_v2/classes.rb', line 3858

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @conditions = args[:conditions] if args.key?(:conditions)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @etag = args[:etag] if args.key?(:etag)
  @execution = args[:execution] if args.key?(:execution)
  @execution_environment = args[:execution_environment] if args.key?(:execution_environment)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled)
  @index = args[:index] if args.key?(:index)
  @job = args[:job] if args.key?(:job)
  @labels = args[:labels] if args.key?(:labels)
  @last_attempt_result = args[:last_attempt_result] if args.key?(:last_attempt_result)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
  @name = args[:name] if args.key?(:name)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @retried = args[:retried] if args.key?(:retried)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @timeout = args[:timeout] if args.key?(:timeout)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volumes = args[:volumes] if args.key?(:volumes)
  @vpc_access = args[:vpc_access] if args.key?(:vpc_access)
end