Class: Google::Apis::RunV2::GoogleCloudRunV2UploadSourceRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2UploadSourceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
The request message for the UploadSource method.
Instance Attribute Summary collapse
-
#service ⇒ String
The name of Cloud Run Service upload source archive will be used for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2UploadSourceRequest
constructor
A new instance of GoogleCloudRunV2UploadSourceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2UploadSourceRequest
Returns a new instance of GoogleCloudRunV2UploadSourceRequest.
4113 4114 4115 |
# File 'lib/google/apis/run_v2/classes.rb', line 4113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
The name of Cloud Run Service upload source archive will be used for.
Corresponds to the JSON property service
4111 4112 4113 |
# File 'lib/google/apis/run_v2/classes.rb', line 4111 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4118 4119 4120 |
# File 'lib/google/apis/run_v2/classes.rb', line 4118 def update!(**args) @service = args[:service] if args.key?(:service) end |