Class: Google::Apis::RunV2::GoogleCloudRunV2VersionToPath
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2VersionToPath
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
VersionToPath maps a specific version of a secret to a relative file to mount to, relative to VolumeMount's mount_path.
Instance Attribute Summary collapse
-
#mode ⇒ Fixnum
Integer octal mode bits to use on this file, must be a value between 01 and 0777 (octal).
-
#path ⇒ String
Required.
-
#version ⇒ String
The Cloud Secret Manager secret version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2VersionToPath
constructor
A new instance of GoogleCloudRunV2VersionToPath.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2VersionToPath
Returns a new instance of GoogleCloudRunV2VersionToPath.
4171 4172 4173 |
# File 'lib/google/apis/run_v2/classes.rb', line 4171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ Fixnum
Integer octal mode bits to use on this file, must be a value between 01 and
0777 (octal). If 0 or not set, the Volume's default mode will be used. Notes *
Internally, a umask of 0222 will be applied to any non-zero value. * This is
an integer representation of the mode bits. So, the octal integer value should
look exactly as the chmod numeric notation with a leading zero. Some examples:
for chmod 640 (u=rw,g=r), set to 0640 (octal) or 416 (base-10). For chmod 755 (
u=rwx,g=rx,o=rx), set to 0755 (octal) or 493 (base-10). * This might be in
conflict with other options that affect the file mode, like fsGroup, and the
result can be other mode bits set.
Corresponds to the JSON property mode
4158 4159 4160 |
# File 'lib/google/apis/run_v2/classes.rb', line 4158 def mode @mode end |
#path ⇒ String
Required. The relative path of the secret in the container.
Corresponds to the JSON property path
4163 4164 4165 |
# File 'lib/google/apis/run_v2/classes.rb', line 4163 def path @path end |
#version ⇒ String
The Cloud Secret Manager secret version. Can be 'latest' for the latest value,
or an integer or a secret alias for a specific version.
Corresponds to the JSON property version
4169 4170 4171 |
# File 'lib/google/apis/run_v2/classes.rb', line 4169 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4176 4177 4178 4179 4180 |
# File 'lib/google/apis/run_v2/classes.rb', line 4176 def update!(**args) @mode = args[:mode] if args.key?(:mode) @path = args[:path] if args.key?(:path) @version = args[:version] if args.key?(:version) end |