Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

ApprovalResult describes the decision and associated metadata of a manual approval of a build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ApprovalResult

Returns a new instance of GoogleDevtoolsCloudbuildV1ApprovalResult.



4744
4745
4746
# File 'lib/google/apis/run_v2/classes.rb', line 4744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_timeString

Output only. The time when the approval decision was made. Corresponds to the JSON property approvalTime

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/run_v2/classes.rb', line 4718

def approval_time
  @approval_time
end

#approver_accountString

Output only. Email of the user that called the ApproveBuild API to approve or reject a build at the time that the API was called. Corresponds to the JSON property approverAccount

Returns:

  • (String)


4724
4725
4726
# File 'lib/google/apis/run_v2/classes.rb', line 4724

def 
  @approver_account
end

#commentString

Optional. An optional comment for this manual approval result. Corresponds to the JSON property comment

Returns:

  • (String)


4729
4730
4731
# File 'lib/google/apis/run_v2/classes.rb', line 4729

def comment
  @comment
end

#decisionString

Required. The decision of this manual approval. Corresponds to the JSON property decision

Returns:

  • (String)


4734
4735
4736
# File 'lib/google/apis/run_v2/classes.rb', line 4734

def decision
  @decision
end

#urlString

Optional. An optional URL tied to this manual approval result. This field is essentially the same as comment, except that it will be rendered by the UI differently. An example use case is a link to an external job that approved this Build. Corresponds to the JSON property url

Returns:

  • (String)


4742
4743
4744
# File 'lib/google/apis/run_v2/classes.rb', line 4742

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4749
4750
4751
4752
4753
4754
4755
# File 'lib/google/apis/run_v2/classes.rb', line 4749

def update!(**args)
  @approval_time = args[:approval_time] if args.key?(:approval_time)
  @approver_account = args[:approver_account] if args.key?(:approver_account)
  @comment = args[:comment] if args.key?(:comment)
  @decision = args[:decision] if args.key?(:decision)
  @url = args[:url] if args.key?(:url)
end