Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildApproval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

BuildApproval describes a build's approval configuration, state, and result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildApproval

Returns a new instance of GoogleDevtoolsCloudbuildV1BuildApproval.



5118
5119
5120
# File 'lib/google/apis/run_v2/classes.rb', line 5118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalConfig

ApprovalConfig describes configuration for manual approval of a build. Corresponds to the JSON property config



5105
5106
5107
# File 'lib/google/apis/run_v2/classes.rb', line 5105

def config
  @config
end

#resultGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalResult

ApprovalResult describes the decision and associated metadata of a manual approval of a build. Corresponds to the JSON property result



5111
5112
5113
# File 'lib/google/apis/run_v2/classes.rb', line 5111

def result
  @result
end

#stateString

Output only. The state of this build's approval. Corresponds to the JSON property state

Returns:

  • (String)


5116
5117
5118
# File 'lib/google/apis/run_v2/classes.rb', line 5116

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5123
5124
5125
5126
5127
# File 'lib/google/apis/run_v2/classes.rb', line 5123

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @result = args[:result] if args.key?(:result)
  @state = args[:state] if args.key?(:state)
end