Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A step in the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildStep

Returns a new instance of GoogleDevtoolsCloudbuildV1BuildStep.



5454
5455
5456
# File 'lib/google/apis/run_v2/classes.rb', line 5454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_exit_codesArray<Fixnum>

Allow this build step to fail without failing the entire build if and only if the exit code is one of the specified codes. If allow_failure is also specified, this field will take precedence. Corresponds to the JSON property allowExitCodes

Returns:

  • (Array<Fixnum>)


5318
5319
5320
# File 'lib/google/apis/run_v2/classes.rb', line 5318

def allow_exit_codes
  @allow_exit_codes
end

#allow_failureBoolean Also known as: allow_failure?

Allow this build step to fail without failing the entire build. If false, the entire build will fail if this step fails. Otherwise, the build will succeed, but this step will still have a failure status. Error information will be reported in the failure_detail field. Corresponds to the JSON property allowFailure

Returns:

  • (Boolean)


5326
5327
5328
# File 'lib/google/apis/run_v2/classes.rb', line 5326

def allow_failure
  @allow_failure
end

#argsArray<String>

A list of arguments that will be presented to the step when it is started. If the image used to run the step's container has an entrypoint, the args are used as arguments to that entrypoint. If the image does not define an entrypoint, the first element in args is used as the entrypoint, and the remainder will be used as arguments. Corresponds to the JSON property args

Returns:

  • (Array<String>)


5336
5337
5338
# File 'lib/google/apis/run_v2/classes.rb', line 5336

def args
  @args
end

#automap_substitutionsBoolean Also known as: automap_substitutions?

Option to include built-in and custom substitutions as env variables for this build step. This option will override the global option in BuildOption. Corresponds to the JSON property automapSubstitutions

Returns:

  • (Boolean)


5342
5343
5344
# File 'lib/google/apis/run_v2/classes.rb', line 5342

def automap_substitutions
  @automap_substitutions
end

#dirString

Working directory to use when running this step's container. If this value is a relative path, it is relative to the build's working directory. If this value is absolute, it may be outside the build's working directory, in which case the contents of the path may not be persisted across build step executions, unless a volume for that path is specified. If the build specifies a RepoSource with dir and a step with a dir, which specifies an absolute path, the RepoSource dir is ignored for the step's execution. Corresponds to the JSON property dir

Returns:

  • (String)


5354
5355
5356
# File 'lib/google/apis/run_v2/classes.rb', line 5354

def dir
  @dir
end

#entrypointString

Entrypoint to be used instead of the build step image's default entrypoint. If unset, the image's default entrypoint is used. Corresponds to the JSON property entrypoint

Returns:

  • (String)


5360
5361
5362
# File 'lib/google/apis/run_v2/classes.rb', line 5360

def entrypoint
  @entrypoint
end

#envArray<String>

A list of environment variable definitions to be used when running a step. The elements are of the form "KEY=VALUE" for the environment variable "KEY" being given the value "VALUE". Corresponds to the JSON property env

Returns:

  • (Array<String>)


5367
5368
5369
# File 'lib/google/apis/run_v2/classes.rb', line 5367

def env
  @env
end

#exit_codeFixnum

Output only. Return code from running the step. Corresponds to the JSON property exitCode

Returns:

  • (Fixnum)


5372
5373
5374
# File 'lib/google/apis/run_v2/classes.rb', line 5372

def exit_code
  @exit_code
end

#idString

Unique identifier for this build step, used in wait_for to reference this build step as a dependency. Corresponds to the JSON property id

Returns:

  • (String)


5378
5379
5380
# File 'lib/google/apis/run_v2/classes.rb', line 5378

def id
  @id
end

#nameString

Required. The name of the container image that will run this particular build step. If the image is available in the host's Docker daemon's cache, it will be run directly. If not, the host will attempt to pull the image first, using the builder service account's credentials if necessary. The Docker daemon's cache will already have the latest versions of all of the officially supported build steps (https://github.com/GoogleCloudPlatform/cloud-builders). The Docker daemon will also have cached many of the layers for some popular images, like "ubuntu", "debian" , but they will be refreshed at the time you attempt to use them. If you built an image in a previous build step, it will be stored in the host's Docker daemon's cache and is available to use as the name for a later build step. Corresponds to the JSON property name

Returns:

  • (String)


5393
5394
5395
# File 'lib/google/apis/run_v2/classes.rb', line 5393

def name
  @name
end

#pull_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pullTiming



5398
5399
5400
# File 'lib/google/apis/run_v2/classes.rb', line 5398

def pull_timing
  @pull_timing
end

#resultsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StepResult>

Declaration of results for this build step. Corresponds to the JSON property results



5403
5404
5405
# File 'lib/google/apis/run_v2/classes.rb', line 5403

def results
  @results
end

#scriptString

A shell script to be executed in the step. When script is provided, the user cannot specify the entrypoint or args. Corresponds to the JSON property script

Returns:

  • (String)


5409
5410
5411
# File 'lib/google/apis/run_v2/classes.rb', line 5409

def script
  @script
end

#secret_envArray<String>

A list of environment variables which are encrypted using a Cloud Key Management Service crypto key. These values must be specified in the build's Secret. Corresponds to the JSON property secretEnv

Returns:

  • (Array<String>)


5416
5417
5418
# File 'lib/google/apis/run_v2/classes.rb', line 5416

def secret_env
  @secret_env
end

#statusString

Output only. Status of the build step. At this time, build step status is only updated on build completion; step status is not updated in real-time as the build progresses. Corresponds to the JSON property status

Returns:

  • (String)


5423
5424
5425
# File 'lib/google/apis/run_v2/classes.rb', line 5423

def status
  @status
end

#timeoutString

Time limit for executing this build step. If not defined, the step has no time limit and will be allowed to continue to run until either it completes or the build itself times out. Corresponds to the JSON property timeout

Returns:

  • (String)


5430
5431
5432
# File 'lib/google/apis/run_v2/classes.rb', line 5430

def timeout
  @timeout
end

#timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property timing



5435
5436
5437
# File 'lib/google/apis/run_v2/classes.rb', line 5435

def timing
  @timing
end

#volumesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Volume>

List of volumes to mount into the build step. Each volume is created as an empty volume prior to execution of the build step. Upon completion of the build, volumes and their contents are discarded. Using a named volume in only one step is not valid as it is indicative of a build request with an incorrect configuration. Corresponds to the JSON property volumes



5444
5445
5446
# File 'lib/google/apis/run_v2/classes.rb', line 5444

def volumes
  @volumes
end

#wait_forArray<String>

The ID(s) of the step(s) that this build step depends on. This build step will not start until all the build steps in wait_for have completed successfully. If wait_for is empty, this build step will start when all previous build steps in the Build.Steps list have completed successfully. Corresponds to the JSON property waitFor

Returns:

  • (Array<String>)


5452
5453
5454
# File 'lib/google/apis/run_v2/classes.rb', line 5452

def wait_for
  @wait_for
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5459
5460
5461
5462
5463
5464
5465
5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
5477
5478
5479
# File 'lib/google/apis/run_v2/classes.rb', line 5459

def update!(**args)
  @allow_exit_codes = args[:allow_exit_codes] if args.key?(:allow_exit_codes)
  @allow_failure = args[:allow_failure] if args.key?(:allow_failure)
  @args = args[:args] if args.key?(:args)
  @automap_substitutions = args[:automap_substitutions] if args.key?(:automap_substitutions)
  @dir = args[:dir] if args.key?(:dir)
  @entrypoint = args[:entrypoint] if args.key?(:entrypoint)
  @env = args[:env] if args.key?(:env)
  @exit_code = args[:exit_code] if args.key?(:exit_code)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @pull_timing = args[:pull_timing] if args.key?(:pull_timing)
  @results = args[:results] if args.key?(:results)
  @script = args[:script] if args.key?(:script)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
  @status = args[:status] if args.key?(:status)
  @timeout = args[:timeout] if args.key?(:timeout)
  @timing = args[:timing] if args.key?(:timing)
  @volumes = args[:volumes] if args.key?(:volumes)
  @wait_for = args[:wait_for] if args.key?(:wait_for)
end