Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
An image built by the pipeline.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#digest ⇒ String
Docker Registry 2.0 digest.
-
#name ⇒ String
Name used to push the container image to Google Container Registry, as presented to
docker push. -
#oci_media_type ⇒ String
Output only.
-
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuiltImage
constructor
A new instance of GoogleDevtoolsCloudbuildV1BuiltImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuiltImage
Returns a new instance of GoogleDevtoolsCloudbuildV1BuiltImage.
5564 5565 5566 |
# File 'lib/google/apis/run_v2/classes.rb', line 5564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
5540 5541 5542 |
# File 'lib/google/apis/run_v2/classes.rb', line 5540 def artifact_registry_package @artifact_registry_package end |
#digest ⇒ String
Docker Registry 2.0 digest.
Corresponds to the JSON property digest
5545 5546 5547 |
# File 'lib/google/apis/run_v2/classes.rb', line 5545 def digest @digest end |
#name ⇒ String
Name used to push the container image to Google Container Registry, as
presented to docker push.
Corresponds to the JSON property name
5551 5552 5553 |
# File 'lib/google/apis/run_v2/classes.rb', line 5551 def name @name end |
#oci_media_type ⇒ String
Output only. The OCI media type of the artifact. Non-OCI images, such as
Docker images, will have an unspecified value.
Corresponds to the JSON property ociMediaType
5557 5558 5559 |
# File 'lib/google/apis/run_v2/classes.rb', line 5557 def oci_media_type @oci_media_type end |
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
5562 5563 5564 |
# File 'lib/google/apis/run_v2/classes.rb', line 5562 def push_timing @push_timing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5569 5570 5571 5572 5573 5574 5575 |
# File 'lib/google/apis/run_v2/classes.rb', line 5569 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @digest = args[:digest] if args.key?(:digest) @name = args[:name] if args.key?(:name) @oci_media_type = args[:oci_media_type] if args.key?(:oci_media_type) @push_timing = args[:push_timing] if args.key?(:push_timing) end |