Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Location of the source in a 2nd-gen Google Cloud Build repository resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ConnectedRepository

Returns a new instance of GoogleDevtoolsCloudbuildV1ConnectedRepository.



5599
5600
5601
# File 'lib/google/apis/run_v2/classes.rb', line 5599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Optional. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


5585
5586
5587
# File 'lib/google/apis/run_v2/classes.rb', line 5585

def dir
  @dir
end

#repositoryString

Required. Name of the Google Cloud Build repository, formatted as projects/*/ locations/*/connections/*/repositories/*. Corresponds to the JSON property repository

Returns:

  • (String)


5591
5592
5593
# File 'lib/google/apis/run_v2/classes.rb', line 5591

def repository
  @repository
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


5597
5598
5599
# File 'lib/google/apis/run_v2/classes.rb', line 5597

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5604
5605
5606
5607
5608
# File 'lib/google/apis/run_v2/classes.rb', line 5604

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end