Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.



5652
5653
5654
# File 'lib/google/apis/run_v2/classes.rb', line 5652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


5639
5640
5641
# File 'lib/google/apis/run_v2/classes.rb', line 5639

def empty
  @empty
end

#generic_artifactGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifactDependency

Represents a generic artifact as a build dependency. Corresponds to the JSON property genericArtifact



5645
5646
5647
# File 'lib/google/apis/run_v2/classes.rb', line 5645

def generic_artifact
  @generic_artifact
end

#git_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



5650
5651
5652
# File 'lib/google/apis/run_v2/classes.rb', line 5650

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5657
5658
5659
5660
5661
# File 'lib/google/apis/run_v2/classes.rb', line 5657

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact)
  @git_source = args[:git_source] if args.key?(:git_source)
end