Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

This config defines the location of a source through Developer Connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

Returns a new instance of GoogleDevtoolsCloudbuildV1DeveloperConnectConfig.



5647
5648
5649
# File 'lib/google/apis/run_v2/classes.rb', line 5647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dirString

Required. Directory, relative to the source root, in which to run the build. Corresponds to the JSON property dir

Returns:

  • (String)


5633
5634
5635
# File 'lib/google/apis/run_v2/classes.rb', line 5633

def dir
  @dir
end

Required. The Developer Connect Git repository link, formatted as projects/*/ locations/*/connections/*/gitRepositoryLink/*. Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


5639
5640
5641
# File 'lib/google/apis/run_v2/classes.rb', line 5639

def git_repository_link
  @git_repository_link
end

#revisionString

Required. The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref. Corresponds to the JSON property revision

Returns:

  • (String)


5645
5646
5647
# File 'lib/google/apis/run_v2/classes.rb', line 5645

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5652
5653
5654
5655
5656
# File 'lib/google/apis/run_v2/classes.rb', line 5652

def update!(**args)
  @dir = args[:dir] if args.key?(:dir)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @revision = args[:revision] if args.key?(:revision)
end