Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FailureInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FailureInfo

Returns a new instance of GoogleDevtoolsCloudbuildV1FailureInfo.



5692
5693
5694
# File 'lib/google/apis/run_v2/classes.rb', line 5692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


5685
5686
5687
# File 'lib/google/apis/run_v2/classes.rb', line 5685

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


5690
5691
5692
# File 'lib/google/apis/run_v2/classes.rb', line 5690

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5697
5698
5699
5700
# File 'lib/google/apis/run_v2/classes.rb', line 5697

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end