Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FileHashes

Returns a new instance of GoogleDevtoolsCloudbuildV1FileHashes.



5732
5733
5734
# File 'lib/google/apis/run_v2/classes.rb', line 5732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Hash>

Collection of file hashes. Corresponds to the JSON property fileHash



5730
5731
5732
# File 'lib/google/apis/run_v2/classes.rb', line 5730

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5737
5738
5739
# File 'lib/google/apis/run_v2/classes.rb', line 5737

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end