Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency

Returns a new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.



5887
5888
5889
# File 'lib/google/apis/run_v2/classes.rb', line 5887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


5864
5865
5866
# File 'lib/google/apis/run_v2/classes.rb', line 5864

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


5869
5870
5871
# File 'lib/google/apis/run_v2/classes.rb', line 5869

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


5874
5875
5876
# File 'lib/google/apis/run_v2/classes.rb', line 5874

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



5880
5881
5882
# File 'lib/google/apis/run_v2/classes.rb', line 5880

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


5885
5886
5887
# File 'lib/google/apis/run_v2/classes.rb', line 5885

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5892
5893
5894
5895
5896
5897
5898
# File 'lib/google/apis/run_v2/classes.rb', line 5892

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end