Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1MavenArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1MavenArtifact.



6106
6107
6108
# File 'lib/google/apis/run_v2/classes.rb', line 6106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Maven artifactId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property artifactId

Returns:

  • (String)


6071
6072
6073
# File 'lib/google/apis/run_v2/classes.rb', line 6071

def artifact_id
  @artifact_id
end

#deploy_folderString

Optional. Path to a folder containing the files to upload to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/target/, or a relative path from /workspace, e.g. my-app/target/. This field is mutually exclusive with the path field. Corresponds to the JSON property deployFolder

Returns:

  • (String)


6079
6080
6081
# File 'lib/google/apis/run_v2/classes.rb', line 6079

def deploy_folder
  @deploy_folder
end

#group_idString

Maven groupId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property groupId

Returns:

  • (String)


6084
6085
6086
# File 'lib/google/apis/run_v2/classes.rb', line 6084

def group_id
  @group_id
end

#pathString

Optional. Path to an artifact in the build's workspace to be uploaded to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/ target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/ target/my-app-1.0.SNAPSHOT.jar. Corresponds to the JSON property path

Returns:

  • (String)


6092
6093
6094
# File 'lib/google/apis/run_v2/classes.rb', line 6092

def path
  @path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


6099
6100
6101
# File 'lib/google/apis/run_v2/classes.rb', line 6099

def repository
  @repository
end

#versionString

Maven version value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property version

Returns:

  • (String)


6104
6105
6106
# File 'lib/google/apis/run_v2/classes.rb', line 6104

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6111
6112
6113
6114
6115
6116
6117
6118
# File 'lib/google/apis/run_v2/classes.rb', line 6111

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder)
  @group_id = args[:group_id] if args.key?(:group_id)
  @path = args[:path] if args.key?(:path)
  @repository = args[:repository] if args.key?(:repository)
  @version = args[:version] if args.key?(:version)
end