Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Npm package to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#package_path ⇒ String
Optional.
-
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-npm.pkg.dev/$ PROJECT/$REPOSITORY" Npm package in the workspace specified by path will be zipped and uploaded to Artifact Registry with this location as a prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1NpmPackage
constructor
A new instance of GoogleDevtoolsCloudbuildV1NpmPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1NpmPackage
Returns a new instance of GoogleDevtoolsCloudbuildV1NpmPackage.
5418 5419 5420 |
# File 'lib/google/apis/run_v2/classes.rb', line 5418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#package_path ⇒ String
Optional. Path to the package.json. e.g. workspace/path/to/package Only one of
archive or package_path can be specified.
Corresponds to the JSON property packagePath
5409 5410 5411 |
# File 'lib/google/apis/run_v2/classes.rb', line 5409 def package_path @package_path end |
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-npm.pkg.dev/$
PROJECT/$REPOSITORY" Npm package in the workspace specified by path will be
zipped and uploaded to Artifact Registry with this location as a prefix.
Corresponds to the JSON property repository
5416 5417 5418 |
# File 'lib/google/apis/run_v2/classes.rb', line 5416 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5423 5424 5425 5426 |
# File 'lib/google/apis/run_v2/classes.rb', line 5423 def update!(**args) @package_path = args[:package_path] if args.key?(:package_path) @repository = args[:repository] if args.key?(:repository) end |