Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Oci

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

OCI image to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Oci

Returns a new instance of GoogleDevtoolsCloudbuildV1Oci.



6108
6109
6110
# File 'lib/google/apis/run_v2/classes.rb', line 6108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fileString

Required. Path on the local file system where to find the container to upload. e.g. /workspace/my-image.tar Corresponds to the JSON property file

Returns:

  • (String)


6095
6096
6097
# File 'lib/google/apis/run_v2/classes.rb', line 6095

def file
  @file
end

#registry_pathString

Required. Registry path to upload the container to. e.g. us-east1-docker.pkg. dev/my-project/my-repo/my-image Corresponds to the JSON property registryPath

Returns:

  • (String)


6101
6102
6103
# File 'lib/google/apis/run_v2/classes.rb', line 6101

def registry_path
  @registry_path
end

#tagsArray<String>

Optional. Tags to apply to the uploaded image. e.g. latest, 1.0.0 Corresponds to the JSON property tags

Returns:

  • (Array<String>)


6106
6107
6108
# File 'lib/google/apis/run_v2/classes.rb', line 6106

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6113
6114
6115
6116
6117
# File 'lib/google/apis/run_v2/classes.rb', line 6113

def update!(**args)
  @file = args[:file] if args.key?(:file)
  @registry_path = args[:registry_path] if args.key?(:registry_path)
  @tags = args[:tags] if args.key?(:tags)
end