Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#build_step_results ⇒ Hash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps.
-
#generic_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only.
-
#go_modules ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
constructor
A new instance of GoogleDevtoolsCloudbuildV1Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
Returns a new instance of GoogleDevtoolsCloudbuildV1Results.
6380 6381 6382 |
# File 'lib/google/apis/run_v2/classes.rb', line 6380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
6316 6317 6318 |
# File 'lib/google/apis/run_v2/classes.rb', line 6316 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
6321 6322 6323 |
# File 'lib/google/apis/run_v2/classes.rb', line 6321 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
6326 6327 6328 |
# File 'lib/google/apis/run_v2/classes.rb', line 6326 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
6335 6336 6337 |
# File 'lib/google/apis/run_v2/classes.rb', line 6335 def build_step_outputs @build_step_outputs end |
#build_step_results ⇒ Hash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStepResults>
Results for build steps. step_id ->
Corresponds to the JSON property buildStepResults
6340 6341 6342 |
# File 'lib/google/apis/run_v2/classes.rb', line 6340 def build_step_results @build_step_results end |
#generic_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>
Output only. Generic artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property genericArtifacts
6346 6347 6348 |
# File 'lib/google/apis/run_v2/classes.rb', line 6346 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
6352 6353 6354 |
# File 'lib/google/apis/run_v2/classes.rb', line 6352 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
6357 6358 6359 |
# File 'lib/google/apis/run_v2/classes.rb', line 6357 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
6362 6363 6364 |
# File 'lib/google/apis/run_v2/classes.rb', line 6362 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
6367 6368 6369 |
# File 'lib/google/apis/run_v2/classes.rb', line 6367 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
6373 6374 6375 |
# File 'lib/google/apis/run_v2/classes.rb', line 6373 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
6378 6379 6380 |
# File 'lib/google/apis/run_v2/classes.rb', line 6378 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 |
# File 'lib/google/apis/run_v2/classes.rb', line 6385 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @build_step_results = args[:build_step_results] if args.key?(:build_step_results) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |