Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Location of the source in an archive file in Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1StorageSource

Returns a new instance of GoogleDevtoolsCloudbuildV1StorageSource.



6588
6589
6590
# File 'lib/google/apis/run_v2/classes.rb', line 6588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

Cloud Storage bucket containing the source (see Bucket Name Requirements). Corresponds to the JSON property bucket

Returns:

  • (String)


6569
6570
6571
# File 'lib/google/apis/run_v2/classes.rb', line 6569

def bucket
  @bucket
end

#generationFixnum

Optional. Cloud Storage generation for the object. If the generation is omitted, the latest generation will be used. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


6575
6576
6577
# File 'lib/google/apis/run_v2/classes.rb', line 6575

def generation
  @generation
end

#objectString

Required. Cloud Storage object containing the source. This object must be a zipped (.zip) or gzipped archive file (.tar.gz) containing source to build. Corresponds to the JSON property object

Returns:

  • (String)


6581
6582
6583
# File 'lib/google/apis/run_v2/classes.rb', line 6581

def object
  @object
end

#source_fetcherString

Optional. Option to specify the tool to fetch the source file for the build. Corresponds to the JSON property sourceFetcher

Returns:

  • (String)


6586
6587
6588
# File 'lib/google/apis/run_v2/classes.rb', line 6586

def source_fetcher
  @source_fetcher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6593
6594
6595
6596
6597
6598
# File 'lib/google/apis/run_v2/classes.rb', line 6593

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @generation = args[:generation] if args.key?(:generation)
  @object = args[:object] if args.key?(:object)
  @source_fetcher = args[:source_fetcher] if args.key?(:source_fetcher)
end