Class: Google::Apis::RunV2::GoogleLongrunningWaitOperationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

The request message for Operations.WaitOperation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningWaitOperationRequest

Returns a new instance of GoogleLongrunningWaitOperationRequest.



6603
6604
6605
# File 'lib/google/apis/run_v2/classes.rb', line 6603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#timeoutString

The maximum duration to wait before timing out. If left blank, the wait will be at most the time permitted by the underlying HTTP/RPC protocol. If RPC context deadline is also specified, the shorter one will be used. Corresponds to the JSON property timeout

Returns:

  • (String)


6601
6602
6603
# File 'lib/google/apis/run_v2/classes.rb', line 6601

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6608
6609
6610
# File 'lib/google/apis/run_v2/classes.rb', line 6608

def update!(**args)
  @timeout = args[:timeout] if args.key?(:timeout)
end