Class: Google::Apis::RunV2::Proto2BridgeMessageSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS. If you are using editions or proto2, please make your own extendable messages for your use case. If you are using proto3, please use Any instead. MessageSet was the implementation of extensions for proto1. When proto2 was introduced, extensions were implemented as a first-class feature. This schema for MessageSet was meant to be a "bridge" solution to migrate MessageSet- bearing messages from proto1 to proto2. This schema has been open-sourced only to facilitate the migration of Google products with MessageSet-bearing messages to open-source environments.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Proto2BridgeMessageSet

Returns a new instance of Proto2BridgeMessageSet.



6734
6735
6736
# File 'lib/google/apis/run_v2/classes.rb', line 6734

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6739
6740
# File 'lib/google/apis/run_v2/classes.rb', line 6739

def update!(**args)
end