Class: Google::Apis::RunV2::GoogleCloudRunV2Condition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Defines a status condition for a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Condition

Returns a new instance of GoogleCloudRunV2Condition.



360
361
362
# File 'lib/google/apis/run_v2/classes.rb', line 360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execution_reasonString

Output only. A reason for the execution condition. Corresponds to the JSON property executionReason

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/run_v2/classes.rb', line 320

def execution_reason
  @execution_reason
end

#last_transition_timeString

Last time the condition transitioned from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


325
326
327
# File 'lib/google/apis/run_v2/classes.rb', line 325

def last_transition_time
  @last_transition_time
end

#messageString

Human readable message indicating details about the current status. Corresponds to the JSON property message

Returns:

  • (String)


330
331
332
# File 'lib/google/apis/run_v2/classes.rb', line 330

def message
  @message
end

#reasonString

Output only. A common (service-level) reason for this condition. Corresponds to the JSON property reason

Returns:

  • (String)


335
336
337
# File 'lib/google/apis/run_v2/classes.rb', line 335

def reason
  @reason
end

#revision_reasonString

Output only. A reason for the revision condition. Corresponds to the JSON property revisionReason

Returns:

  • (String)


340
341
342
# File 'lib/google/apis/run_v2/classes.rb', line 340

def revision_reason
  @revision_reason
end

#severityString

How to interpret failures of this condition, one of Error, Warning, Info Corresponds to the JSON property severity

Returns:

  • (String)


345
346
347
# File 'lib/google/apis/run_v2/classes.rb', line 345

def severity
  @severity
end

#stateString

State of the condition. Corresponds to the JSON property state

Returns:

  • (String)


350
351
352
# File 'lib/google/apis/run_v2/classes.rb', line 350

def state
  @state
end

#typeString

type is used to communicate the status of the reconciliation process. See also: https://github.com/knative/serving/blob/main/docs/spec/errors.md#error- conditions-and-reporting Types common to all resources include: * "Ready": True when the Resource is ready. Corresponds to the JSON property type

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/run_v2/classes.rb', line 358

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



365
366
367
368
369
370
371
372
373
374
# File 'lib/google/apis/run_v2/classes.rb', line 365

def update!(**args)
  @execution_reason = args[:execution_reason] if args.key?(:execution_reason)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @revision_reason = args[:revision_reason] if args.key?(:revision_reason)
  @severity = args[:severity] if args.key?(:severity)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end