Class: Google::Apis::RunV2::GoogleCloudRunV2Container
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Container
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A single application container. This specifies both the container to run, the command to run in the container and the arguments to supply to it. Note that additional arguments can be supplied by the system to the container at runtime.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Arguments to the entrypoint.
-
#base_image_uri ⇒ String
Base image for this container.
-
#build_info ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildInfo
Build information of the image.
-
#command ⇒ Array<String>
Entrypoint array.
-
#depends_on ⇒ Array<String>
Names of the containers that must start before this container.
-
#env ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>
List of environment variables to set in the container.
-
#image ⇒ String
Required.
-
#liveness_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
-
#name ⇒ String
Name of the container specified as a DNS_LABEL (RFC 1123).
-
#ports ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerPort>
List of ports to expose from the container.
-
#readiness_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
-
#resources ⇒ Google::Apis::RunV2::GoogleCloudRunV2ResourceRequirements
ResourceRequirements describes the compute resource requirements.
-
#source_code ⇒ Google::Apis::RunV2::GoogleCloudRunV2SourceCode
Source type for the container.
-
#startup_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
-
#volume_mounts ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2VolumeMount>
Volume to mount into the container's filesystem.
-
#working_dir ⇒ String
Container's working directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Container
constructor
A new instance of GoogleCloudRunV2Container.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Container
Returns a new instance of GoogleCloudRunV2Container.
482 483 484 |
# File 'lib/google/apis/run_v2/classes.rb', line 482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Arguments to the entrypoint. The docker image's CMD is used if this is not
provided.
Corresponds to the JSON property args
393 394 395 |
# File 'lib/google/apis/run_v2/classes.rb', line 393 def args @args end |
#base_image_uri ⇒ String
Base image for this container. Only supported for services. If set, it
indicates that the service is enrolled into automatic base image update.
Corresponds to the JSON property baseImageUri
399 400 401 |
# File 'lib/google/apis/run_v2/classes.rb', line 399 def base_image_uri @base_image_uri end |
#build_info ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildInfo
Build information of the image.
Corresponds to the JSON property buildInfo
404 405 406 |
# File 'lib/google/apis/run_v2/classes.rb', line 404 def build_info @build_info end |
#command ⇒ Array<String>
Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT
is used if this is not provided.
Corresponds to the JSON property command
410 411 412 |
# File 'lib/google/apis/run_v2/classes.rb', line 410 def command @command end |
#depends_on ⇒ Array<String>
Names of the containers that must start before this container.
Corresponds to the JSON property dependsOn
415 416 417 |
# File 'lib/google/apis/run_v2/classes.rb', line 415 def depends_on @depends_on end |
#env ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>
List of environment variables to set in the container.
Corresponds to the JSON property env
420 421 422 |
# File 'lib/google/apis/run_v2/classes.rb', line 420 def env @env end |
#image ⇒ String
Required. Name of the container image in Dockerhub, Google Artifact Registry,
or Google Container Registry. If the host is not provided, Dockerhub is
assumed.
Corresponds to the JSON property image
427 428 429 |
# File 'lib/google/apis/run_v2/classes.rb', line 427 def image @image end |
#liveness_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to
determine whether it is alive or ready to receive traffic.
Corresponds to the JSON property livenessProbe
433 434 435 |
# File 'lib/google/apis/run_v2/classes.rb', line 433 def liveness_probe @liveness_probe end |
#name ⇒ String
Name of the container specified as a DNS_LABEL (RFC 1123).
Corresponds to the JSON property name
438 439 440 |
# File 'lib/google/apis/run_v2/classes.rb', line 438 def name @name end |
#ports ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerPort>
List of ports to expose from the container. Only a single port can be
specified. The specified ports must be listening on all interfaces (0.0.0.0)
within the container to be accessible. If omitted, a port number will be
chosen and passed to the container through the PORT environment variable for
the container to listen on.
Corresponds to the JSON property ports
447 448 449 |
# File 'lib/google/apis/run_v2/classes.rb', line 447 def ports @ports end |
#readiness_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to
determine whether it is alive or ready to receive traffic.
Corresponds to the JSON property readinessProbe
453 454 455 |
# File 'lib/google/apis/run_v2/classes.rb', line 453 def readiness_probe @readiness_probe end |
#resources ⇒ Google::Apis::RunV2::GoogleCloudRunV2ResourceRequirements
ResourceRequirements describes the compute resource requirements.
Corresponds to the JSON property resources
458 459 460 |
# File 'lib/google/apis/run_v2/classes.rb', line 458 def resources @resources end |
#source_code ⇒ Google::Apis::RunV2::GoogleCloudRunV2SourceCode
Source type for the container.
Corresponds to the JSON property sourceCode
463 464 465 |
# File 'lib/google/apis/run_v2/classes.rb', line 463 def source_code @source_code end |
#startup_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to
determine whether it is alive or ready to receive traffic.
Corresponds to the JSON property startupProbe
469 470 471 |
# File 'lib/google/apis/run_v2/classes.rb', line 469 def startup_probe @startup_probe end |
#volume_mounts ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2VolumeMount>
Volume to mount into the container's filesystem.
Corresponds to the JSON property volumeMounts
474 475 476 |
# File 'lib/google/apis/run_v2/classes.rb', line 474 def volume_mounts @volume_mounts end |
#working_dir ⇒ String
Container's working directory. If not specified, the container runtime's
default will be used, which might be configured in the container image.
Corresponds to the JSON property workingDir
480 481 482 |
# File 'lib/google/apis/run_v2/classes.rb', line 480 def working_dir @working_dir end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/google/apis/run_v2/classes.rb', line 487 def update!(**args) @args = args[:args] if args.key?(:args) @base_image_uri = args[:base_image_uri] if args.key?(:base_image_uri) @build_info = args[:build_info] if args.key?(:build_info) @command = args[:command] if args.key?(:command) @depends_on = args[:depends_on] if args.key?(:depends_on) @env = args[:env] if args.key?(:env) @image = args[:image] if args.key?(:image) @liveness_probe = args[:liveness_probe] if args.key?(:liveness_probe) @name = args[:name] if args.key?(:name) @ports = args[:ports] if args.key?(:ports) @readiness_probe = args[:readiness_probe] if args.key?(:readiness_probe) @resources = args[:resources] if args.key?(:resources) @source_code = args[:source_code] if args.key?(:source_code) @startup_probe = args[:startup_probe] if args.key?(:startup_probe) @volume_mounts = args[:volume_mounts] if args.key?(:volume_mounts) @working_dir = args[:working_dir] if args.key?(:working_dir) end |