Class: Google::Apis::RunV2::GoogleCloudRunV2Container
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Container
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A single application container. This specifies both the container to run, the command to run in the container and the arguments to supply to it. Note that additional arguments can be supplied by the system to the container at runtime.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Arguments to the entrypoint.
-
#base_image_uri ⇒ String
Base image for this container.
-
#build_info ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildInfo
Build information of the image.
-
#command ⇒ Array<String>
Entrypoint array.
-
#depends_on ⇒ Array<String>
Names of the containers that must start before this container.
-
#env ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>
List of environment variables to set in the container.
-
#image ⇒ String
Required.
-
#liveness_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
-
#name ⇒ String
Name of the container specified as a DNS_LABEL (RFC 1123).
-
#ports ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerPort>
List of ports to expose from the container.
-
#resources ⇒ Google::Apis::RunV2::GoogleCloudRunV2ResourceRequirements
ResourceRequirements describes the compute resource requirements.
-
#source_code ⇒ Google::Apis::RunV2::GoogleCloudRunV2SourceCode
Source type for the container.
-
#startup_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
-
#volume_mounts ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2VolumeMount>
Volume to mount into the container's filesystem.
-
#working_dir ⇒ String
Container's working directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Container
constructor
A new instance of GoogleCloudRunV2Container.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Container
Returns a new instance of GoogleCloudRunV2Container.
470 471 472 |
# File 'lib/google/apis/run_v2/classes.rb', line 470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Arguments to the entrypoint. The docker image's CMD is used if this is not
provided.
Corresponds to the JSON property args
387 388 389 |
# File 'lib/google/apis/run_v2/classes.rb', line 387 def args @args end |
#base_image_uri ⇒ String
Base image for this container. Only supported for services. If set, it
indicates that the service is enrolled into automatic base image update.
Corresponds to the JSON property baseImageUri
393 394 395 |
# File 'lib/google/apis/run_v2/classes.rb', line 393 def base_image_uri @base_image_uri end |
#build_info ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildInfo
Build information of the image.
Corresponds to the JSON property buildInfo
398 399 400 |
# File 'lib/google/apis/run_v2/classes.rb', line 398 def build_info @build_info end |
#command ⇒ Array<String>
Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT
is used if this is not provided.
Corresponds to the JSON property command
404 405 406 |
# File 'lib/google/apis/run_v2/classes.rb', line 404 def command @command end |
#depends_on ⇒ Array<String>
Names of the containers that must start before this container.
Corresponds to the JSON property dependsOn
409 410 411 |
# File 'lib/google/apis/run_v2/classes.rb', line 409 def depends_on @depends_on end |
#env ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>
List of environment variables to set in the container.
Corresponds to the JSON property env
414 415 416 |
# File 'lib/google/apis/run_v2/classes.rb', line 414 def env @env end |
#image ⇒ String
Required. Name of the container image in Dockerhub, Google Artifact Registry,
or Google Container Registry. If the host is not provided, Dockerhub is
assumed.
Corresponds to the JSON property image
421 422 423 |
# File 'lib/google/apis/run_v2/classes.rb', line 421 def image @image end |
#liveness_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to
determine whether it is alive or ready to receive traffic.
Corresponds to the JSON property livenessProbe
427 428 429 |
# File 'lib/google/apis/run_v2/classes.rb', line 427 def liveness_probe @liveness_probe end |
#name ⇒ String
Name of the container specified as a DNS_LABEL (RFC 1123).
Corresponds to the JSON property name
432 433 434 |
# File 'lib/google/apis/run_v2/classes.rb', line 432 def name @name end |
#ports ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerPort>
List of ports to expose from the container. Only a single port can be
specified. The specified ports must be listening on all interfaces (0.0.0.0)
within the container to be accessible. If omitted, a port number will be
chosen and passed to the container through the PORT environment variable for
the container to listen on.
Corresponds to the JSON property ports
441 442 443 |
# File 'lib/google/apis/run_v2/classes.rb', line 441 def ports @ports end |
#resources ⇒ Google::Apis::RunV2::GoogleCloudRunV2ResourceRequirements
ResourceRequirements describes the compute resource requirements.
Corresponds to the JSON property resources
446 447 448 |
# File 'lib/google/apis/run_v2/classes.rb', line 446 def resources @resources end |
#source_code ⇒ Google::Apis::RunV2::GoogleCloudRunV2SourceCode
Source type for the container.
Corresponds to the JSON property sourceCode
451 452 453 |
# File 'lib/google/apis/run_v2/classes.rb', line 451 def source_code @source_code end |
#startup_probe ⇒ Google::Apis::RunV2::GoogleCloudRunV2Probe
Probe describes a health check to be performed against a container to
determine whether it is alive or ready to receive traffic.
Corresponds to the JSON property startupProbe
457 458 459 |
# File 'lib/google/apis/run_v2/classes.rb', line 457 def startup_probe @startup_probe end |
#volume_mounts ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2VolumeMount>
Volume to mount into the container's filesystem.
Corresponds to the JSON property volumeMounts
462 463 464 |
# File 'lib/google/apis/run_v2/classes.rb', line 462 def volume_mounts @volume_mounts end |
#working_dir ⇒ String
Container's working directory. If not specified, the container runtime's
default will be used, which might be configured in the container image.
Corresponds to the JSON property workingDir
468 469 470 |
# File 'lib/google/apis/run_v2/classes.rb', line 468 def working_dir @working_dir end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/google/apis/run_v2/classes.rb', line 475 def update!(**args) @args = args[:args] if args.key?(:args) @base_image_uri = args[:base_image_uri] if args.key?(:base_image_uri) @build_info = args[:build_info] if args.key?(:build_info) @command = args[:command] if args.key?(:command) @depends_on = args[:depends_on] if args.key?(:depends_on) @env = args[:env] if args.key?(:env) @image = args[:image] if args.key?(:image) @liveness_probe = args[:liveness_probe] if args.key?(:liveness_probe) @name = args[:name] if args.key?(:name) @ports = args[:ports] if args.key?(:ports) @resources = args[:resources] if args.key?(:resources) @source_code = args[:source_code] if args.key?(:source_code) @startup_probe = args[:startup_probe] if args.key?(:startup_probe) @volume_mounts = args[:volume_mounts] if args.key?(:volume_mounts) @working_dir = args[:working_dir] if args.key?(:working_dir) end |