Class: Google::Apis::RunV2::GoogleCloudRunV2ContainerOverride
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ContainerOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Per-container override specification.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Optional.
-
#clear_args ⇒ Boolean
(also: #clear_args?)
Optional.
-
#env ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>
List of environment variables to set in the container.
-
#name ⇒ String
The name of the container specified as a DNS_LABEL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ContainerOverride
constructor
A new instance of GoogleCloudRunV2ContainerOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ContainerOverride
Returns a new instance of GoogleCloudRunV2ContainerOverride.
533 534 535 |
# File 'lib/google/apis/run_v2/classes.rb', line 533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Optional. Arguments to the entrypoint. Will replace existing args for override.
Corresponds to the JSON property args
514 515 516 |
# File 'lib/google/apis/run_v2/classes.rb', line 514 def args @args end |
#clear_args ⇒ Boolean Also known as: clear_args?
Optional. True if the intention is to clear out existing args list.
Corresponds to the JSON property clearArgs
519 520 521 |
# File 'lib/google/apis/run_v2/classes.rb', line 519 def clear_args @clear_args end |
#env ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>
List of environment variables to set in the container. Will be merged with
existing env for override.
Corresponds to the JSON property env
526 527 528 |
# File 'lib/google/apis/run_v2/classes.rb', line 526 def env @env end |
#name ⇒ String
The name of the container specified as a DNS_LABEL.
Corresponds to the JSON property name
531 532 533 |
# File 'lib/google/apis/run_v2/classes.rb', line 531 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
538 539 540 541 542 543 |
# File 'lib/google/apis/run_v2/classes.rb', line 538 def update!(**args) @args = args[:args] if args.key?(:args) @clear_args = args[:clear_args] if args.key?(:clear_args) @env = args[:env] if args.key?(:env) @name = args[:name] if args.key?(:name) end |