Class: Google::Apis::RunV2::GoogleCloudRunV2ContainerOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Per-container override specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2ContainerOverride

Returns a new instance of GoogleCloudRunV2ContainerOverride.



520
521
522
# File 'lib/google/apis/run_v2/classes.rb', line 520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Optional. Arguments to the entrypoint. Will replace existing args for override. Corresponds to the JSON property args

Returns:

  • (Array<String>)


501
502
503
# File 'lib/google/apis/run_v2/classes.rb', line 501

def args
  @args
end

#clear_argsBoolean Also known as: clear_args?

Optional. True if the intention is to clear out existing args list. Corresponds to the JSON property clearArgs

Returns:

  • (Boolean)


506
507
508
# File 'lib/google/apis/run_v2/classes.rb', line 506

def clear_args
  @clear_args
end

#envArray<Google::Apis::RunV2::GoogleCloudRunV2EnvVar>

List of environment variables to set in the container. Will be merged with existing env for override. Corresponds to the JSON property env



513
514
515
# File 'lib/google/apis/run_v2/classes.rb', line 513

def env
  @env
end

#nameString

The name of the container specified as a DNS_LABEL. Corresponds to the JSON property name

Returns:

  • (String)


518
519
520
# File 'lib/google/apis/run_v2/classes.rb', line 518

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



525
526
527
528
529
530
# File 'lib/google/apis/run_v2/classes.rb', line 525

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @clear_args = args[:clear_args] if args.key?(:clear_args)
  @env = args[:env] if args.key?(:env)
  @name = args[:name] if args.key?(:name)
end