Class: Google::Apis::RunV2::GoogleCloudRunV2EnvVar

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

EnvVar represents an environment variable present in a Container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2EnvVar

Returns a new instance of GoogleCloudRunV2EnvVar.



676
677
678
# File 'lib/google/apis/run_v2/classes.rb', line 676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. Name of the environment variable. Must not exceed 32768 characters. Corresponds to the JSON property name

Returns:

  • (String)


663
664
665
# File 'lib/google/apis/run_v2/classes.rb', line 663

def name
  @name
end

#valueString

Literal value of the environment variable. Defaults to "", and the maximum length is 32768 bytes. Variable references are not supported in Cloud Run. Corresponds to the JSON property value

Returns:

  • (String)


669
670
671
# File 'lib/google/apis/run_v2/classes.rb', line 669

def value
  @value
end

#value_sourceGoogle::Apis::RunV2::GoogleCloudRunV2EnvVarSource

EnvVarSource represents a source for the value of an EnvVar. Corresponds to the JSON property valueSource



674
675
676
# File 'lib/google/apis/run_v2/classes.rb', line 674

def value_source
  @value_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



681
682
683
684
685
# File 'lib/google/apis/run_v2/classes.rb', line 681

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
  @value_source = args[:value_source] if args.key?(:value_source)
end