Class: Google::Apis::RunV2::GoogleCloudRunV2EnvVar

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

EnvVar represents an environment variable present in a Container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2EnvVar

Returns a new instance of GoogleCloudRunV2EnvVar.



628
629
630
# File 'lib/google/apis/run_v2/classes.rb', line 628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. Name of the environment variable. Must not exceed 32768 characters. Corresponds to the JSON property name

Returns:

  • (String)


615
616
617
# File 'lib/google/apis/run_v2/classes.rb', line 615

def name
  @name
end

#valueString

Literal value of the environment variable. Defaults to "", and the maximum length is 32768 bytes. Variable references are not supported in Cloud Run. Corresponds to the JSON property value

Returns:

  • (String)


621
622
623
# File 'lib/google/apis/run_v2/classes.rb', line 621

def value
  @value
end

#value_sourceGoogle::Apis::RunV2::GoogleCloudRunV2EnvVarSource

EnvVarSource represents a source for the value of an EnvVar. Corresponds to the JSON property valueSource



626
627
628
# File 'lib/google/apis/run_v2/classes.rb', line 626

def value_source
  @value_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



633
634
635
636
637
# File 'lib/google/apis/run_v2/classes.rb', line 633

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
  @value_source = args[:value_source] if args.key?(:value_source)
end