Class: Google::Apis::RunV2::GoogleCloudRunV2Execution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Execution represents the configuration of a single execution. A execution an immutable resource that references a container image which is run to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Execution

Returns a new instance of GoogleCloudRunV2Execution.



840
841
842
# File 'lib/google/apis/run_v2/classes.rb', line 840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Output only. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


670
671
672
# File 'lib/google/apis/run_v2/classes.rb', line 670

def annotations
  @annotations
end

#cancelled_countFixnum

Output only. The number of tasks which reached phase Cancelled. Corresponds to the JSON property cancelledCount

Returns:

  • (Fixnum)


675
676
677
# File 'lib/google/apis/run_v2/classes.rb', line 675

def cancelled_count
  @cancelled_count
end

#completion_timeString

Output only. Represents time when the execution was completed. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property completionTime

Returns:

  • (String)


681
682
683
# File 'lib/google/apis/run_v2/classes.rb', line 681

def completion_time
  @completion_time
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Condition of this Execution, containing its readiness status, and detailed error information in case it did not reach the desired state. Corresponds to the JSON property conditions



687
688
689
# File 'lib/google/apis/run_v2/classes.rb', line 687

def conditions
  @conditions
end

#create_timeString

Output only. Represents time when the execution was acknowledged by the execution controller. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property createTime

Returns:

  • (String)


694
695
696
# File 'lib/google/apis/run_v2/classes.rb', line 694

def create_time
  @create_time
end

#creatorString

Output only. Email address of the authenticated creator. Corresponds to the JSON property creator

Returns:

  • (String)


699
700
701
# File 'lib/google/apis/run_v2/classes.rb', line 699

def creator
  @creator
end

#delete_timeString

Output only. For a deleted resource, the deletion time. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


705
706
707
# File 'lib/google/apis/run_v2/classes.rb', line 705

def delete_time
  @delete_time
end

#etagString

Output only. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


711
712
713
# File 'lib/google/apis/run_v2/classes.rb', line 711

def etag
  @etag
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permamently deleted. It is only populated as a response to a Delete request. Corresponds to the JSON property expireTime

Returns:

  • (String)


717
718
719
# File 'lib/google/apis/run_v2/classes.rb', line 717

def expire_time
  @expire_time
end

#failed_countFixnum

Output only. The number of tasks which reached phase Failed. Corresponds to the JSON property failedCount

Returns:

  • (Fixnum)


722
723
724
# File 'lib/google/apis/run_v2/classes.rb', line 722

def failed_count
  @failed_count
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


728
729
730
# File 'lib/google/apis/run_v2/classes.rb', line 728

def generation
  @generation
end

#jobString

Output only. The name of the parent Job. Corresponds to the JSON property job

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/run_v2/classes.rb', line 733

def job
  @job
end

#labelsHash<String,String>

Output only. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


743
744
745
# File 'lib/google/apis/run_v2/classes.rb', line 743

def labels
  @labels
end

#launch_stageString

The least stable launch stage needed to create this resource, as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and GA. Note that this value might not be what was used as input. For example, if ALPHA was provided as input in the parent resource, but only BETA and GA-level features are were, this field will be BETA. Corresponds to the JSON property launchStage

Returns:

  • (String)


753
754
755
# File 'lib/google/apis/run_v2/classes.rb', line 753

def launch_stage
  @launch_stage
end

#log_uriString

Output only. URI where logs for this execution can be found in Cloud Console. Corresponds to the JSON property logUri

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/run_v2/classes.rb', line 758

def log_uri
  @log_uri
end

#nameString

Output only. The unique name of this Execution. Corresponds to the JSON property name

Returns:

  • (String)


763
764
765
# File 'lib/google/apis/run_v2/classes.rb', line 763

def name
  @name
end

#observed_generationFixnum

Output only. The generation of this Execution. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


769
770
771
# File 'lib/google/apis/run_v2/classes.rb', line 769

def observed_generation
  @observed_generation
end

#parallelismFixnum

Output only. Specifies the maximum desired number of tasks the execution should run at any given time. Must be <= task_count. The actual number of tasks running in steady state will be less than this number when ((.spec. task_count - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


778
779
780
# File 'lib/google/apis/run_v2/classes.rb', line 778

def parallelism
  @parallelism
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether the resource's reconciliation is still in progress. See comments in Job.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


785
786
787
# File 'lib/google/apis/run_v2/classes.rb', line 785

def reconciling
  @reconciling
end

#retried_countFixnum

Output only. The number of tasks which have retried at least once. Corresponds to the JSON property retriedCount

Returns:

  • (Fixnum)


791
792
793
# File 'lib/google/apis/run_v2/classes.rb', line 791

def retried_count
  @retried_count
end

#running_countFixnum

Output only. The number of actively running tasks. Corresponds to the JSON property runningCount

Returns:

  • (Fixnum)


796
797
798
# File 'lib/google/apis/run_v2/classes.rb', line 796

def running_count
  @running_count
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


801
802
803
# File 'lib/google/apis/run_v2/classes.rb', line 801

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Represents time when the execution started to run. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property startTime

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/run_v2/classes.rb', line 808

def start_time
  @start_time
end

#succeeded_countFixnum

Output only. The number of tasks which reached phase Succeeded. Corresponds to the JSON property succeededCount

Returns:

  • (Fixnum)


813
814
815
# File 'lib/google/apis/run_v2/classes.rb', line 813

def succeeded_count
  @succeeded_count
end

#task_countFixnum

Output only. Specifies the desired number of tasks the execution should run. Setting to 1 means that parallelism is limited to 1 and the success of that task signals the success of the execution. Corresponds to the JSON property taskCount

Returns:

  • (Fixnum)


820
821
822
# File 'lib/google/apis/run_v2/classes.rb', line 820

def task_count
  @task_count
end

#templateGoogle::Apis::RunV2::GoogleCloudRunV2TaskTemplate

TaskTemplate describes the data a task should have when created from a template. Corresponds to the JSON property template



826
827
828
# File 'lib/google/apis/run_v2/classes.rb', line 826

def template
  @template
end

#uidString

Output only. Server assigned unique identifier for the Execution. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


833
834
835
# File 'lib/google/apis/run_v2/classes.rb', line 833

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


838
839
840
# File 'lib/google/apis/run_v2/classes.rb', line 838

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
# File 'lib/google/apis/run_v2/classes.rb', line 845

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @cancelled_count = args[:cancelled_count] if args.key?(:cancelled_count)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @failed_count = args[:failed_count] if args.key?(:failed_count)
  @generation = args[:generation] if args.key?(:generation)
  @job = args[:job] if args.key?(:job)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @name = args[:name] if args.key?(:name)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @retried_count = args[:retried_count] if args.key?(:retried_count)
  @running_count = args[:running_count] if args.key?(:running_count)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @succeeded_count = args[:succeeded_count] if args.key?(:succeeded_count)
  @task_count = args[:task_count] if args.key?(:task_count)
  @template = args[:template] if args.key?(:template)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end