Class: Google::Apis::RunV2::GoogleCloudRunV2ExecutionReference
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ExecutionReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Reference to an Execution. Use /Executions.GetExecution with the given name to get full execution including the latest status.
Instance Attribute Summary collapse
-
#completion_status ⇒ String
Status for the execution completion.
-
#completion_time ⇒ String
Creation timestamp of the execution.
-
#create_time ⇒ String
Creation timestamp of the execution.
-
#delete_time ⇒ String
The deletion time of the execution.
-
#name ⇒ String
Name of the execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ExecutionReference
constructor
A new instance of GoogleCloudRunV2ExecutionReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ExecutionReference
Returns a new instance of GoogleCloudRunV2ExecutionReference.
974 975 976 |
# File 'lib/google/apis/run_v2/classes.rb', line 974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_status ⇒ String
Status for the execution completion.
Corresponds to the JSON property completionStatus
951 952 953 |
# File 'lib/google/apis/run_v2/classes.rb', line 951 def completion_status @completion_status end |
#completion_time ⇒ String
Creation timestamp of the execution.
Corresponds to the JSON property completionTime
956 957 958 |
# File 'lib/google/apis/run_v2/classes.rb', line 956 def completion_time @completion_time end |
#create_time ⇒ String
Creation timestamp of the execution.
Corresponds to the JSON property createTime
961 962 963 |
# File 'lib/google/apis/run_v2/classes.rb', line 961 def create_time @create_time end |
#delete_time ⇒ String
The deletion time of the execution. It is only populated as a response to a
Delete request.
Corresponds to the JSON property deleteTime
967 968 969 |
# File 'lib/google/apis/run_v2/classes.rb', line 967 def delete_time @delete_time end |
#name ⇒ String
Name of the execution.
Corresponds to the JSON property name
972 973 974 |
# File 'lib/google/apis/run_v2/classes.rb', line 972 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
979 980 981 982 983 984 985 |
# File 'lib/google/apis/run_v2/classes.rb', line 979 def update!(**args) @completion_status = args[:completion_status] if args.key?(:completion_status) @completion_time = args[:completion_time] if args.key?(:completion_time) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @name = args[:name] if args.key?(:name) end |