Class: Google::Apis::RunV2::GoogleCloudRunV2ExecutionReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Reference to an Execution. Use /Executions.GetExecution with the given name to get full execution including the latest status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2ExecutionReference

Returns a new instance of GoogleCloudRunV2ExecutionReference.



960
961
962
# File 'lib/google/apis/run_v2/classes.rb', line 960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_statusString

Status for the execution completion. Corresponds to the JSON property completionStatus

Returns:

  • (String)


937
938
939
# File 'lib/google/apis/run_v2/classes.rb', line 937

def completion_status
  @completion_status
end

#completion_timeString

Creation timestamp of the execution. Corresponds to the JSON property completionTime

Returns:

  • (String)


942
943
944
# File 'lib/google/apis/run_v2/classes.rb', line 942

def completion_time
  @completion_time
end

#create_timeString

Creation timestamp of the execution. Corresponds to the JSON property createTime

Returns:

  • (String)


947
948
949
# File 'lib/google/apis/run_v2/classes.rb', line 947

def create_time
  @create_time
end

#delete_timeString

The deletion time of the execution. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


953
954
955
# File 'lib/google/apis/run_v2/classes.rb', line 953

def delete_time
  @delete_time
end

#nameString

Name of the execution. Corresponds to the JSON property name

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/run_v2/classes.rb', line 958

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



965
966
967
968
969
970
971
# File 'lib/google/apis/run_v2/classes.rb', line 965

def update!(**args)
  @completion_status = args[:completion_status] if args.key?(:completion_status)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @name = args[:name] if args.key?(:name)
end