Class: Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

ExecutionTemplate describes the data an execution should have when created from a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2ExecutionTemplate

Returns a new instance of GoogleCloudRunV2ExecutionTemplate.



1036
1037
1038
# File 'lib/google/apis/run_v2/classes.rb', line 1036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Cloud Run API v2 does not support annotations with run. googleapis.com, cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev namespaces, and they will be rejected. All system annotations in v1 now have a corresponding field in v2 ExecutionTemplate. This field follows Kubernetes annotations' namespacing, limits, and rules. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


988
989
990
# File 'lib/google/apis/run_v2/classes.rb', line 988

def annotations
  @annotations
end

#clientString

Optional. Arbitrary identifier for the API client. Corresponds to the JSON property client

Returns:

  • (String)


993
994
995
# File 'lib/google/apis/run_v2/classes.rb', line 993

def client
  @client
end

#client_versionString

Optional. Arbitrary version identifier for the API client. Corresponds to the JSON property clientVersion

Returns:

  • (String)


998
999
1000
# File 'lib/google/apis/run_v2/classes.rb', line 998

def client_version
  @client_version
end

#labelsHash<String,String>

Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud.google.com/resource- manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/ configuring/labels. Cloud Run API v2 does not support labels with run. googleapis.com, cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev namespaces, and they will be rejected. All system labels in v1 now have a corresponding field in v2 ExecutionTemplate. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1011
1012
1013
# File 'lib/google/apis/run_v2/classes.rb', line 1011

def labels
  @labels
end

#parallelismFixnum

Optional. Specifies the maximum desired number of tasks the execution should run at given time. When the job is run, if this field is 0 or unset, the maximum possible value will be used for that execution. The actual number of tasks running in steady state will be less than this number when there are fewer tasks waiting to be completed remaining, i.e. when the work left to do is less than max parallelism. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


1021
1022
1023
# File 'lib/google/apis/run_v2/classes.rb', line 1021

def parallelism
  @parallelism
end

#task_countFixnum

Specifies the desired number of tasks the execution should run. Setting to 1 means that parallelism is limited to 1 and the success of that task signals the success of the execution. Defaults to 1. Corresponds to the JSON property taskCount

Returns:

  • (Fixnum)


1028
1029
1030
# File 'lib/google/apis/run_v2/classes.rb', line 1028

def task_count
  @task_count
end

#templateGoogle::Apis::RunV2::GoogleCloudRunV2TaskTemplate

TaskTemplate describes the data a task should have when created from a template. Corresponds to the JSON property template



1034
1035
1036
# File 'lib/google/apis/run_v2/classes.rb', line 1034

def template
  @template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'lib/google/apis/run_v2/classes.rb', line 1041

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client = args[:client] if args.key?(:client)
  @client_version = args[:client_version] if args.key?(:client_version)
  @labels = args[:labels] if args.key?(:labels)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
  @task_count = args[:task_count] if args.key?(:task_count)
  @template = args[:template] if args.key?(:template)
end