Class: Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
ExecutionTemplate describes the data an execution should have when created from a template.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
-
#labels ⇒ Hash<String,String>
Unstructured key value map that can be used to organize and categorize objects.
-
#parallelism ⇒ Fixnum
Optional.
-
#task_count ⇒ Fixnum
Specifies the desired number of tasks the execution should run.
-
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskTemplate
TaskTemplate describes the data a task should have when created from a template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ExecutionTemplate
constructor
A new instance of GoogleCloudRunV2ExecutionTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ExecutionTemplate
Returns a new instance of GoogleCloudRunV2ExecutionTemplate.
974 975 976 |
# File 'lib/google/apis/run_v2/classes.rb', line 974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Unstructured key value map that may be set by external tools to store and
arbitrary metadata. They are not queryable and should be preserved when
modifying objects. Cloud Run API v2 does not support annotations with run.
googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected. All system
annotations in v1 now have a corresponding field in v2 ExecutionTemplate. This
field follows Kubernetes annotations' namespacing, limits, and rules.
Corresponds to the JSON property annotations
936 937 938 |
# File 'lib/google/apis/run_v2/classes.rb', line 936 def annotations @annotations end |
#labels ⇒ Hash<String,String>
Unstructured key value map that can be used to organize and categorize objects.
User-provided labels are shared with Google's billing system, so they can be
used to filter, or break down billing charges by team, component, environment,
state, etc. For more information, visit https://cloud.google.com/resource-
manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/
configuring/labels. Cloud Run API v2 does not support labels with run.
googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected. All system
labels in v1 now have a corresponding field in v2 ExecutionTemplate.
Corresponds to the JSON property labels
949 950 951 |
# File 'lib/google/apis/run_v2/classes.rb', line 949 def labels @labels end |
#parallelism ⇒ Fixnum
Optional. Specifies the maximum desired number of tasks the execution should
run at given time. When the job is run, if this field is 0 or unset, the
maximum possible value will be used for that execution. The actual number of
tasks running in steady state will be less than this number when there are
fewer tasks waiting to be completed remaining, i.e. when the work left to do
is less than max parallelism.
Corresponds to the JSON property parallelism
959 960 961 |
# File 'lib/google/apis/run_v2/classes.rb', line 959 def parallelism @parallelism end |
#task_count ⇒ Fixnum
Specifies the desired number of tasks the execution should run. Setting to 1
means that parallelism is limited to 1 and the success of that task signals
the success of the execution. Defaults to 1.
Corresponds to the JSON property taskCount
966 967 968 |
# File 'lib/google/apis/run_v2/classes.rb', line 966 def task_count @task_count end |
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskTemplate
TaskTemplate describes the data a task should have when created from a
template.
Corresponds to the JSON property template
972 973 974 |
# File 'lib/google/apis/run_v2/classes.rb', line 972 def template @template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
979 980 981 982 983 984 985 |
# File 'lib/google/apis/run_v2/classes.rb', line 979 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @labels = args[:labels] if args.key?(:labels) @parallelism = args[:parallelism] if args.key?(:parallelism) @task_count = args[:task_count] if args.key?(:task_count) @template = args[:template] if args.key?(:template) end |