Class: Google::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2GcsVolumeSource

Returns a new instance of GoogleCloudRunV2GcsVolumeSource.



1145
1146
1147
# File 'lib/google/apis/run_v2/classes.rb', line 1145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

Cloud Storage Bucket name. Corresponds to the JSON property bucket

Returns:

  • (String)


1131
1132
1133
# File 'lib/google/apis/run_v2/classes.rb', line 1131

def bucket
  @bucket
end

#mount_optionsArray<String>

A list of additional flags to pass to the gcsfuse CLI. Options should be specified without the leading "--". Corresponds to the JSON property mountOptions

Returns:

  • (Array<String>)


1137
1138
1139
# File 'lib/google/apis/run_v2/classes.rb', line 1137

def mount_options
  @mount_options
end

#read_onlyBoolean Also known as: read_only?

If true, the volume will be mounted as read only for all mounts. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


1142
1143
1144
# File 'lib/google/apis/run_v2/classes.rb', line 1142

def read_only
  @read_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1150
1151
1152
1153
1154
# File 'lib/google/apis/run_v2/classes.rb', line 1150

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @mount_options = args[:mount_options] if args.key?(:mount_options)
  @read_only = args[:read_only] if args.key?(:read_only)
end