Class: Google::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE.
Instance Attribute Summary collapse
-
#bucket ⇒ String
Cloud Storage Bucket name.
-
#mount_options ⇒ Array<String>
A list of additional flags to pass to the gcsfuse CLI.
-
#read_only ⇒ Boolean
(also: #read_only?)
If true, the volume will be mounted as read only for all mounts.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2GcsVolumeSource
constructor
A new instance of GoogleCloudRunV2GcsVolumeSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2GcsVolumeSource
Returns a new instance of GoogleCloudRunV2GcsVolumeSource.
1081 1082 1083 |
# File 'lib/google/apis/run_v2/classes.rb', line 1081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ String
Cloud Storage Bucket name.
Corresponds to the JSON property bucket
1067 1068 1069 |
# File 'lib/google/apis/run_v2/classes.rb', line 1067 def bucket @bucket end |
#mount_options ⇒ Array<String>
A list of additional flags to pass to the gcsfuse CLI. Options should be
specified without the leading "--".
Corresponds to the JSON property mountOptions
1073 1074 1075 |
# File 'lib/google/apis/run_v2/classes.rb', line 1073 def @mount_options end |
#read_only ⇒ Boolean Also known as: read_only?
If true, the volume will be mounted as read only for all mounts.
Corresponds to the JSON property readOnly
1078 1079 1080 |
# File 'lib/google/apis/run_v2/classes.rb', line 1078 def read_only @read_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1086 1087 1088 1089 1090 |
# File 'lib/google/apis/run_v2/classes.rb', line 1086 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @mount_options = args[:mount_options] if args.key?(:mount_options) @read_only = args[:read_only] if args.key?(:read_only) end |