Class: Google::Apis::RunV2::GoogleCloudRunV2HttpGetAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

HTTPGetAction describes an action based on HTTP Get requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2HttpGetAction

Returns a new instance of GoogleCloudRunV2HttpGetAction.



1144
1145
1146
# File 'lib/google/apis/run_v2/classes.rb', line 1144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_headersArray<Google::Apis::RunV2::GoogleCloudRunV2HttpHeader>

Optional. Custom headers to set in the request. HTTP allows repeated headers. Corresponds to the JSON property httpHeaders



1130
1131
1132
# File 'lib/google/apis/run_v2/classes.rb', line 1130

def http_headers
  @http_headers
end

#pathString

Optional. Path to access on the HTTP server. Defaults to '/'. Corresponds to the JSON property path

Returns:

  • (String)


1135
1136
1137
# File 'lib/google/apis/run_v2/classes.rb', line 1135

def path
  @path
end

#portFixnum

Optional. Port number to access on the container. Must be in the range 1 to

  1. If not specified, defaults to the exposed port of the container, which is the value of container.ports[0].containerPort. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1142
1143
1144
# File 'lib/google/apis/run_v2/classes.rb', line 1142

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1149
1150
1151
1152
1153
# File 'lib/google/apis/run_v2/classes.rb', line 1149

def update!(**args)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @path = args[:path] if args.key?(:path)
  @port = args[:port] if args.key?(:port)
end