Class: Google::Apis::RunV2::GoogleCloudRunV2ImageExportStatus
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ImageExportStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
The status of an image export job.
Instance Attribute Summary collapse
-
#export_job_state ⇒ String
Output only.
-
#exported_image_digest ⇒ String
The exported image ID as it will appear in Artifact Registry.
-
#status ⇒ Google::Apis::RunV2::UtilStatusProto
Wire-format for a Status object Corresponds to the JSON property
status. -
#tag ⇒ String
The image tag as it will appear in Artifact Registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ImageExportStatus
constructor
A new instance of GoogleCloudRunV2ImageExportStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ImageExportStatus
Returns a new instance of GoogleCloudRunV2ImageExportStatus.
1270 1271 1272 |
# File 'lib/google/apis/run_v2/classes.rb', line 1270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_job_state ⇒ String
Output only. Has the image export job finished (regardless of successful or
failure).
Corresponds to the JSON property exportJobState
1253 1254 1255 |
# File 'lib/google/apis/run_v2/classes.rb', line 1253 def export_job_state @export_job_state end |
#exported_image_digest ⇒ String
The exported image ID as it will appear in Artifact Registry.
Corresponds to the JSON property exportedImageDigest
1258 1259 1260 |
# File 'lib/google/apis/run_v2/classes.rb', line 1258 def exported_image_digest @exported_image_digest end |
#status ⇒ Google::Apis::RunV2::UtilStatusProto
Wire-format for a Status object
Corresponds to the JSON property status
1263 1264 1265 |
# File 'lib/google/apis/run_v2/classes.rb', line 1263 def status @status end |
#tag ⇒ String
The image tag as it will appear in Artifact Registry.
Corresponds to the JSON property tag
1268 1269 1270 |
# File 'lib/google/apis/run_v2/classes.rb', line 1268 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1275 1276 1277 1278 1279 1280 |
# File 'lib/google/apis/run_v2/classes.rb', line 1275 def update!(**args) @export_job_state = args[:export_job_state] if args.key?(:export_job_state) @exported_image_digest = args[:exported_image_digest] if args.key?(:exported_image_digest) @status = args[:status] if args.key?(:status) @tag = args[:tag] if args.key?(:tag) end |