Class: Google::Apis::RunV2::GoogleCloudRunV2ImageExportStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

The status of an image export job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2ImageExportStatus

Returns a new instance of GoogleCloudRunV2ImageExportStatus.



1206
1207
1208
# File 'lib/google/apis/run_v2/classes.rb', line 1206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_job_stateString

Output only. Has the image export job finished (regardless of successful or failure). Corresponds to the JSON property exportJobState

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/run_v2/classes.rb', line 1189

def export_job_state
  @export_job_state
end

#exported_image_digestString

The exported image ID as it will appear in Artifact Registry. Corresponds to the JSON property exportedImageDigest

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/run_v2/classes.rb', line 1194

def exported_image_digest
  @exported_image_digest
end

#statusGoogle::Apis::RunV2::UtilStatusProto

Wire-format for a Status object Corresponds to the JSON property status



1199
1200
1201
# File 'lib/google/apis/run_v2/classes.rb', line 1199

def status
  @status
end

#tagString

The image tag as it will appear in Artifact Registry. Corresponds to the JSON property tag

Returns:

  • (String)


1204
1205
1206
# File 'lib/google/apis/run_v2/classes.rb', line 1204

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1211
1212
1213
1214
1215
1216
# File 'lib/google/apis/run_v2/classes.rb', line 1211

def update!(**args)
  @export_job_state = args[:export_job_state] if args.key?(:export_job_state)
  @exported_image_digest = args[:exported_image_digest] if args.key?(:exported_image_digest)
  @status = args[:status] if args.key?(:status)
  @tag = args[:tag] if args.key?(:tag)
end