Class: Google::Apis::RunV2::GoogleCloudRunV2Instance
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A Cloud Run Instance represents a single group of containers running in a region.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Corresponds to the JSON property
annotations. -
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
-
#client ⇒ String
Arbitrary identifier for the API client.
-
#client_version ⇒ String
Arbitrary version identifier for the API client.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#container_statuses ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerStatus>
Output only.
-
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Required.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#default_uri_disabled ⇒ Boolean
(also: #default_uri_disabled?)
Optional.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description of the Instance.
-
#encryption_key ⇒ String
A reference to a customer managed encryption key (CMEK) to use to encrypt this container image.
-
#encryption_key_revocation_action ⇒ String
The action to take if the encryption key is revoked.
-
#encryption_key_shutdown_duration ⇒ String
If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances.
-
#etag ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#gpu_zonal_redundancy_disabled ⇒ Boolean
(also: #gpu_zonal_redundancy_disabled?)
Optional.
-
#iap_enabled ⇒ Boolean
(also: #iap_enabled?)
Optional.
-
#ingress ⇒ String
Optional.
-
#invoker_iam_disabled ⇒ Boolean
(also: #invoker_iam_disabled?)
Optional.
-
#labels ⇒ Hash<String,String>
Corresponds to the JSON property
labels. -
#last_modifier ⇒ String
Output only.
-
#launch_stage ⇒ String
The launch stage as defined by Google Cloud Platform Launch Stages.
-
#log_uri ⇒ String
Output only.
-
#name ⇒ String
The fully qualified name of this Instance.
-
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#restart_policy ⇒ String
Optional.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
Corresponds to the JSON property
serviceAccount. -
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#urls ⇒ Array<String>
Output only.
-
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
-
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Instance
constructor
A new instance of GoogleCloudRunV2Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Instance
Returns a new instance of GoogleCloudRunV2Instance.
1558 1559 1560 |
# File 'lib/google/apis/run_v2/classes.rb', line 1558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Corresponds to the JSON property annotations
1318 1319 1320 |
# File 'lib/google/apis/run_v2/classes.rb', line 1318 def annotations @annotations end |
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
Corresponds to the JSON property binaryAuthorization
1323 1324 1325 |
# File 'lib/google/apis/run_v2/classes.rb', line 1323 def @binary_authorization end |
#client ⇒ String
Arbitrary identifier for the API client.
Corresponds to the JSON property client
1328 1329 1330 |
# File 'lib/google/apis/run_v2/classes.rb', line 1328 def client @client end |
#client_version ⇒ String
Arbitrary version identifier for the API client.
Corresponds to the JSON property clientVersion
1333 1334 1335 |
# File 'lib/google/apis/run_v2/classes.rb', line 1333 def client_version @client_version end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Conditions of all other associated sub-resources. They
contain additional diagnostics information in case the Instance does not reach
its Serving state. See comments in reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property conditions
1341 1342 1343 |
# File 'lib/google/apis/run_v2/classes.rb', line 1341 def conditions @conditions end |
#container_statuses ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerStatus>
Output only. Status information for each of the specified containers. The
status includes the resolved digest for specified images.
Corresponds to the JSON property containerStatuses
1347 1348 1349 |
# File 'lib/google/apis/run_v2/classes.rb', line 1347 def container_statuses @container_statuses end |
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Required. Holds the single container that defines the unit of execution for
this Instance.
Corresponds to the JSON property containers
1353 1354 1355 |
# File 'lib/google/apis/run_v2/classes.rb', line 1353 def containers @containers end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
1358 1359 1360 |
# File 'lib/google/apis/run_v2/classes.rb', line 1358 def create_time @create_time end |
#creator ⇒ String
Output only. Email address of the authenticated creator.
Corresponds to the JSON property creator
1363 1364 1365 |
# File 'lib/google/apis/run_v2/classes.rb', line 1363 def creator @creator end |
#default_uri_disabled ⇒ Boolean Also known as: default_uri_disabled?
Optional. Disables public resolution of the default URI of this Instance.
Corresponds to the JSON property defaultUriDisabled
1368 1369 1370 |
# File 'lib/google/apis/run_v2/classes.rb', line 1368 def default_uri_disabled @default_uri_disabled end |
#delete_time ⇒ String
Output only. The deletion time.
Corresponds to the JSON property deleteTime
1374 1375 1376 |
# File 'lib/google/apis/run_v2/classes.rb', line 1374 def delete_time @delete_time end |
#description ⇒ String
User-provided description of the Instance. This field currently has a 512-
character limit.
Corresponds to the JSON property description
1380 1381 1382 |
# File 'lib/google/apis/run_v2/classes.rb', line 1380 def description @description end |
#encryption_key ⇒ String
A reference to a customer managed encryption key (CMEK) to use to encrypt this
container image. For more information, go to https://cloud.google.com/run/docs/
securing/using-cmek
Corresponds to the JSON property encryptionKey
1387 1388 1389 |
# File 'lib/google/apis/run_v2/classes.rb', line 1387 def encryption_key @encryption_key end |
#encryption_key_revocation_action ⇒ String
The action to take if the encryption key is revoked.
Corresponds to the JSON property encryptionKeyRevocationAction
1392 1393 1394 |
# File 'lib/google/apis/run_v2/classes.rb', line 1392 def encryption_key_revocation_action @encryption_key_revocation_action end |
#encryption_key_shutdown_duration ⇒ String
If encryption_key_revocation_action is SHUTDOWN, the duration before shutting
down all instances. The minimum increment is 1 hour.
Corresponds to the JSON property encryptionKeyShutdownDuration
1398 1399 1400 |
# File 'lib/google/apis/run_v2/classes.rb', line 1398 def encryption_key_shutdown_duration @encryption_key_shutdown_duration end |
#etag ⇒ String
Optional. A system-generated fingerprint for this version of the resource. May
be used to detect modification conflict during updates.
Corresponds to the JSON property etag
1404 1405 1406 |
# File 'lib/google/apis/run_v2/classes.rb', line 1404 def etag @etag end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permamently deleted.
Corresponds to the JSON property expireTime
1410 1411 1412 |
# File 'lib/google/apis/run_v2/classes.rb', line 1410 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state. Please note that unlike v1, this is an int64 value.
As with most Google APIs, its JSON representation will be a string instead
of an integer.
Corresponds to the JSON property generation
1418 1419 1420 |
# File 'lib/google/apis/run_v2/classes.rb', line 1418 def generation @generation end |
#gpu_zonal_redundancy_disabled ⇒ Boolean Also known as: gpu_zonal_redundancy_disabled?
Optional. True if GPU zonal redundancy is disabled on this instance.
Corresponds to the JSON property gpuZonalRedundancyDisabled
1423 1424 1425 |
# File 'lib/google/apis/run_v2/classes.rb', line 1423 def gpu_zonal_redundancy_disabled @gpu_zonal_redundancy_disabled end |
#iap_enabled ⇒ Boolean Also known as: iap_enabled?
Optional. IAP settings on the Instance.
Corresponds to the JSON property iapEnabled
1429 1430 1431 |
# File 'lib/google/apis/run_v2/classes.rb', line 1429 def iap_enabled @iap_enabled end |
#ingress ⇒ String
Optional. Provides the ingress settings for this Instance. On output, returns
the currently observed ingress settings, or INGRESS_TRAFFIC_UNSPECIFIED if no
revision is active.
Corresponds to the JSON property ingress
1437 1438 1439 |
# File 'lib/google/apis/run_v2/classes.rb', line 1437 def ingress @ingress end |
#invoker_iam_disabled ⇒ Boolean Also known as: invoker_iam_disabled?
Optional. Disables IAM permission check for run.routes.invoke for callers of
this Instance. For more information, visit https://cloud.google.com/run/docs/
securing/managing-access#invoker_check.
Corresponds to the JSON property invokerIamDisabled
1444 1445 1446 |
# File 'lib/google/apis/run_v2/classes.rb', line 1444 def invoker_iam_disabled @invoker_iam_disabled end |
#labels ⇒ Hash<String,String>
Corresponds to the JSON property labels
1450 1451 1452 |
# File 'lib/google/apis/run_v2/classes.rb', line 1450 def labels @labels end |
#last_modifier ⇒ String
Output only. Email address of the last authenticated modifier.
Corresponds to the JSON property lastModifier
1455 1456 1457 |
# File 'lib/google/apis/run_v2/classes.rb', line 1455 def last_modifier @last_modifier end |
#launch_stage ⇒ String
The launch stage as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and
GA. If no value is specified, GA is assumed. Set the launch stage to a
preview stage on input to allow use of preview features in that stage. On read
(or output), describes whether the resource uses preview features. For example,
if ALPHA is provided as input, but only BETA and GA-level features are used,
this field will be BETA on output.
Corresponds to the JSON property launchStage
1466 1467 1468 |
# File 'lib/google/apis/run_v2/classes.rb', line 1466 def launch_stage @launch_stage end |
#log_uri ⇒ String
Output only. The Google Console URI to obtain logs for the Instance.
Corresponds to the JSON property logUri
1471 1472 1473 |
# File 'lib/google/apis/run_v2/classes.rb', line 1471 def log_uri @log_uri end |
#name ⇒ String
The fully qualified name of this Instance. In CreateInstanceRequest, this
field is ignored, and instead composed from CreateInstanceRequest.parent and
CreateInstanceRequest.instance_id. Format: projects/project/locations/
location/instances/instance_id
Corresponds to the JSON property name
1479 1480 1481 |
# File 'lib/google/apis/run_v2/classes.rb', line 1479 def name @name end |
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
Corresponds to the JSON property nodeSelector
1484 1485 1486 |
# File 'lib/google/apis/run_v2/classes.rb', line 1484 def node_selector @node_selector end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Instance currently serving traffic. See
comments in reconciling for additional information on reconciliation process
in Cloud Run. Please note that unlike v1, this is an int64 value. As with most
Google APIs, its JSON representation will be a string instead of an integer
.
Corresponds to the JSON property observedGeneration
1493 1494 1495 |
# File 'lib/google/apis/run_v2/classes.rb', line 1493 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Returns true if the Instance is currently being acted upon by the
system to bring it into the desired state. When a new Instance is created, or
an existing one is updated, Cloud Run will asynchronously perform all
necessary steps to bring the Instance to the desired serving state. This
process is called reconciliation. While reconciliation is in process,
observed_generation will have a transient value that might mismatch the
intended state. Once reconciliation is over (and this field is false), there
are two possible outcomes: reconciliation succeeded and the serving state
matches the Instance, or there was an error, and reconciliation failed. This
state can be found in terminal_condition.state.
Corresponds to the JSON property reconciling
1507 1508 1509 |
# File 'lib/google/apis/run_v2/classes.rb', line 1507 def reconciling @reconciling end |
#restart_policy ⇒ String
Optional. Restart policy for the Instance.
Corresponds to the JSON property restartPolicy
1513 1514 1515 |
# File 'lib/google/apis/run_v2/classes.rb', line 1513 def restart_policy @restart_policy end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1518 1519 1520 |
# File 'lib/google/apis/run_v2/classes.rb', line 1518 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
Corresponds to the JSON property serviceAccount
1524 1525 1526 |
# File 'lib/google/apis/run_v2/classes.rb', line 1524 def service_account @service_account end |
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
Corresponds to the JSON property terminalCondition
1529 1530 1531 |
# File 'lib/google/apis/run_v2/classes.rb', line 1529 def terminal_condition @terminal_condition end |
#uid ⇒ String
Output only. Server assigned unique identifier for the trigger. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
1535 1536 1537 |
# File 'lib/google/apis/run_v2/classes.rb', line 1535 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
1540 1541 1542 |
# File 'lib/google/apis/run_v2/classes.rb', line 1540 def update_time @update_time end |
#urls ⇒ Array<String>
Output only. All URLs serving traffic for this Instance.
Corresponds to the JSON property urls
1545 1546 1547 |
# File 'lib/google/apis/run_v2/classes.rb', line 1545 def urls @urls end |
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
Corresponds to the JSON property volumes
1550 1551 1552 |
# File 'lib/google/apis/run_v2/classes.rb', line 1550 def volumes @volumes end |
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings. For more information on sending traffic to a VPC network,
visit https://cloud.google.com/run/docs/configuring/connecting-vpc.
Corresponds to the JSON property vpcAccess
1556 1557 1558 |
# File 'lib/google/apis/run_v2/classes.rb', line 1556 def vpc_access @vpc_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 |
# File 'lib/google/apis/run_v2/classes.rb', line 1563 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization) @client = args[:client] if args.key?(:client) @client_version = args[:client_version] if args.key?(:client_version) @conditions = args[:conditions] if args.key?(:conditions) @container_statuses = args[:container_statuses] if args.key?(:container_statuses) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @default_uri_disabled = args[:default_uri_disabled] if args.key?(:default_uri_disabled) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action) @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled) @iap_enabled = args[:iap_enabled] if args.key?(:iap_enabled) @ingress = args[:ingress] if args.key?(:ingress) @invoker_iam_disabled = args[:invoker_iam_disabled] if args.key?(:invoker_iam_disabled) @labels = args[:labels] if args.key?(:labels) @last_modifier = args[:last_modifier] if args.key?(:last_modifier) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @log_uri = args[:log_uri] if args.key?(:log_uri) @name = args[:name] if args.key?(:name) @node_selector = args[:node_selector] if args.key?(:node_selector) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @restart_policy = args[:restart_policy] if args.key?(:restart_policy) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @terminal_condition = args[:terminal_condition] if args.key?(:terminal_condition) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @urls = args[:urls] if args.key?(:urls) @volumes = args[:volumes] if args.key?(:volumes) @vpc_access = args[:vpc_access] if args.key?(:vpc_access) end |