Class: Google::Apis::RunV2::GoogleCloudRunV2Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Cloud Run Instance represents a single group of containers running in a region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Instance

Returns a new instance of GoogleCloudRunV2Instance.



1551
1552
1553
# File 'lib/google/apis/run_v2/classes.rb', line 1551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1310
1311
1312
# File 'lib/google/apis/run_v2/classes.rb', line 1310

def annotations
  @annotations
end

#binary_authorizationGoogle::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization

Settings for Binary Authorization feature. Corresponds to the JSON property binaryAuthorization



1315
1316
1317
# File 'lib/google/apis/run_v2/classes.rb', line 1315

def binary_authorization
  @binary_authorization
end

#clientString

Arbitrary identifier for the API client. Corresponds to the JSON property client

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/run_v2/classes.rb', line 1320

def client
  @client
end

#client_versionString

Arbitrary version identifier for the API client. Corresponds to the JSON property clientVersion

Returns:

  • (String)


1325
1326
1327
# File 'lib/google/apis/run_v2/classes.rb', line 1325

def client_version
  @client_version
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Conditions of all other associated sub-resources. They contain additional diagnostics information in case the Instance does not reach its Serving state. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property conditions



1333
1334
1335
# File 'lib/google/apis/run_v2/classes.rb', line 1333

def conditions
  @conditions
end

#container_statusesArray<Google::Apis::RunV2::GoogleCloudRunV2ContainerStatus>

Output only. Status information for each of the specified containers. The status includes the resolved digest for specified images. Corresponds to the JSON property containerStatuses



1339
1340
1341
# File 'lib/google/apis/run_v2/classes.rb', line 1339

def container_statuses
  @container_statuses
end

#containersArray<Google::Apis::RunV2::GoogleCloudRunV2Container>

Required. Holds the single container that defines the unit of execution for this Instance. Corresponds to the JSON property containers



1345
1346
1347
# File 'lib/google/apis/run_v2/classes.rb', line 1345

def containers
  @containers
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


1350
1351
1352
# File 'lib/google/apis/run_v2/classes.rb', line 1350

def create_time
  @create_time
end

#creatorString

Output only. Email address of the authenticated creator. Corresponds to the JSON property creator

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/run_v2/classes.rb', line 1355

def creator
  @creator
end

#default_uri_disabledBoolean Also known as: default_uri_disabled?

Optional. Disables public resolution of the default URI of this Instance. Corresponds to the JSON property defaultUriDisabled

Returns:

  • (Boolean)


1360
1361
1362
# File 'lib/google/apis/run_v2/classes.rb', line 1360

def default_uri_disabled
  @default_uri_disabled
end

#delete_timeString

Output only. The deletion time. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/run_v2/classes.rb', line 1366

def delete_time
  @delete_time
end

#descriptionString

User-provided description of the Instance. This field currently has a 512- character limit. Corresponds to the JSON property description

Returns:

  • (String)


1372
1373
1374
# File 'lib/google/apis/run_v2/classes.rb', line 1372

def description
  @description
end

#encryption_keyString

A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google.com/run/docs/ securing/using-cmek Corresponds to the JSON property encryptionKey

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/run_v2/classes.rb', line 1379

def encryption_key
  @encryption_key
end

#encryption_key_revocation_actionString

The action to take if the encryption key is revoked. Corresponds to the JSON property encryptionKeyRevocationAction

Returns:

  • (String)


1384
1385
1386
# File 'lib/google/apis/run_v2/classes.rb', line 1384

def encryption_key_revocation_action
  @encryption_key_revocation_action
end

#encryption_key_shutdown_durationString

If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances. The minimum increment is 1 hour. Corresponds to the JSON property encryptionKeyShutdownDuration

Returns:

  • (String)


1390
1391
1392
# File 'lib/google/apis/run_v2/classes.rb', line 1390

def encryption_key_shutdown_duration
  @encryption_key_shutdown_duration
end

#etagString

Optional. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


1396
1397
1398
# File 'lib/google/apis/run_v2/classes.rb', line 1396

def etag
  @etag
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permamently deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


1402
1403
1404
# File 'lib/google/apis/run_v2/classes.rb', line 1402

def expire_time
  @expire_time
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Please note that unlike v1, this is an int64 value. As with most Google APIs, its JSON representation will be a string instead of an integer. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


1410
1411
1412
# File 'lib/google/apis/run_v2/classes.rb', line 1410

def generation
  @generation
end

#gpu_zonal_redundancy_disabledBoolean Also known as: gpu_zonal_redundancy_disabled?

Optional. True if GPU zonal redundancy is disabled on this instance. Corresponds to the JSON property gpuZonalRedundancyDisabled

Returns:

  • (Boolean)


1415
1416
1417
# File 'lib/google/apis/run_v2/classes.rb', line 1415

def gpu_zonal_redundancy_disabled
  @gpu_zonal_redundancy_disabled
end

#iap_enabledBoolean Also known as: iap_enabled?

Optional. IAP settings on the Instance. Corresponds to the JSON property iapEnabled

Returns:

  • (Boolean)


1421
1422
1423
# File 'lib/google/apis/run_v2/classes.rb', line 1421

def iap_enabled
  @iap_enabled
end

#ingressString

Optional. Provides the ingress settings for this Instance. On output, returns the currently observed ingress settings, or INGRESS_TRAFFIC_UNSPECIFIED if no revision is active. Corresponds to the JSON property ingress

Returns:

  • (String)


1429
1430
1431
# File 'lib/google/apis/run_v2/classes.rb', line 1429

def ingress
  @ingress
end

#invoker_iam_disabledBoolean Also known as: invoker_iam_disabled?

Optional. Disables IAM permission check for run.routes.invoke for callers of this Instance. For more information, visit https://cloud.google.com/run/docs/ securing/managing-access#invoker_check. Corresponds to the JSON property invokerIamDisabled

Returns:

  • (Boolean)


1436
1437
1438
# File 'lib/google/apis/run_v2/classes.rb', line 1436

def invoker_iam_disabled
  @invoker_iam_disabled
end

#labelsHash<String,String>

Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1442
1443
1444
# File 'lib/google/apis/run_v2/classes.rb', line 1442

def labels
  @labels
end

#last_modifierString

Output only. Email address of the last authenticated modifier. Corresponds to the JSON property lastModifier

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/run_v2/classes.rb', line 1447

def last_modifier
  @last_modifier
end

#launch_stageString

The launch stage as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and GA. If no value is specified, GA is assumed. Set the launch stage to a preview stage on input to allow use of preview features in that stage. On read (or output), describes whether the resource uses preview features. For example, if ALPHA is provided as input, but only BETA and GA-level features are used, this field will be BETA on output. Corresponds to the JSON property launchStage

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/run_v2/classes.rb', line 1458

def launch_stage
  @launch_stage
end

#log_uriString

Output only. The Google Console URI to obtain logs for the Instance. Corresponds to the JSON property logUri

Returns:

  • (String)


1463
1464
1465
# File 'lib/google/apis/run_v2/classes.rb', line 1463

def log_uri
  @log_uri
end

#nameString

The fully qualified name of this Instance. In CreateInstanceRequest, this field is ignored, and instead composed from CreateInstanceRequest.parent and CreateInstanceRequest.instance_id. Format: projects/project/locations/ location/instances/instance_id Corresponds to the JSON property name

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/run_v2/classes.rb', line 1471

def name
  @name
end

#node_selectorGoogle::Apis::RunV2::GoogleCloudRunV2NodeSelector

Hardware constraints configuration. Corresponds to the JSON property nodeSelector



1476
1477
1478
# File 'lib/google/apis/run_v2/classes.rb', line 1476

def node_selector
  @node_selector
end

#observed_generationFixnum

Output only. The generation of this Instance currently serving traffic. See comments in reconciling for additional information on reconciliation process in Cloud Run. Please note that unlike v1, this is an int64 value. As with most Google APIs, its JSON representation will be a string instead of an integer . Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


1485
1486
1487
# File 'lib/google/apis/run_v2/classes.rb', line 1485

def observed_generation
  @observed_generation
end

#reconcilingBoolean Also known as: reconciling?

Output only. Returns true if the Instance is currently being acted upon by the system to bring it into the desired state. When a new Instance is created, or an existing one is updated, Cloud Run will asynchronously perform all necessary steps to bring the Instance to the desired serving state. This process is called reconciliation. While reconciliation is in process, observed_generation will have a transient value that might mismatch the intended state. Once reconciliation is over (and this field is false), there are two possible outcomes: reconciliation succeeded and the serving state matches the Instance, or there was an error, and reconciliation failed. This state can be found in terminal_condition.state. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1499
1500
1501
# File 'lib/google/apis/run_v2/classes.rb', line 1499

def reconciling
  @reconciling
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1505
1506
1507
# File 'lib/google/apis/run_v2/classes.rb', line 1505

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1511
1512
1513
# File 'lib/google/apis/run_v2/classes.rb', line 1511

def 
  @service_account
end

#terminal_conditionGoogle::Apis::RunV2::GoogleCloudRunV2Condition

Defines a status condition for a resource. Corresponds to the JSON property terminalCondition



1516
1517
1518
# File 'lib/google/apis/run_v2/classes.rb', line 1516

def terminal_condition
  @terminal_condition
end

#timeoutString

Optional. Duration the instance may be active before the system will shut it down. Corresponds to the JSON property timeout

Returns:

  • (String)


1522
1523
1524
# File 'lib/google/apis/run_v2/classes.rb', line 1522

def timeout
  @timeout
end

#uidString

Output only. Server assigned unique identifier for the trigger. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


1528
1529
1530
# File 'lib/google/apis/run_v2/classes.rb', line 1528

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1533
1534
1535
# File 'lib/google/apis/run_v2/classes.rb', line 1533

def update_time
  @update_time
end

#urlsArray<String>

Output only. All URLs serving traffic for this Instance. Corresponds to the JSON property urls

Returns:

  • (Array<String>)


1538
1539
1540
# File 'lib/google/apis/run_v2/classes.rb', line 1538

def urls
  @urls
end

#volumesArray<Google::Apis::RunV2::GoogleCloudRunV2Volume>

A list of Volumes to make available to containers. Corresponds to the JSON property volumes



1543
1544
1545
# File 'lib/google/apis/run_v2/classes.rb', line 1543

def volumes
  @volumes
end

#vpc_accessGoogle::Apis::RunV2::GoogleCloudRunV2VpcAccess

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc. Corresponds to the JSON property vpcAccess



1549
1550
1551
# File 'lib/google/apis/run_v2/classes.rb', line 1549

def vpc_access
  @vpc_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
# File 'lib/google/apis/run_v2/classes.rb', line 1556

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization)
  @client = args[:client] if args.key?(:client)
  @client_version = args[:client_version] if args.key?(:client_version)
  @conditions = args[:conditions] if args.key?(:conditions)
  @container_statuses = args[:container_statuses] if args.key?(:container_statuses)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @default_uri_disabled = args[:default_uri_disabled] if args.key?(:default_uri_disabled)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @description = args[:description] if args.key?(:description)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action)
  @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled)
  @iap_enabled = args[:iap_enabled] if args.key?(:iap_enabled)
  @ingress = args[:ingress] if args.key?(:ingress)
  @invoker_iam_disabled = args[:invoker_iam_disabled] if args.key?(:invoker_iam_disabled)
  @labels = args[:labels] if args.key?(:labels)
  @last_modifier = args[:last_modifier] if args.key?(:last_modifier)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @name = args[:name] if args.key?(:name)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @terminal_condition = args[:terminal_condition] if args.key?(:terminal_condition)
  @timeout = args[:timeout] if args.key?(:timeout)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @urls = args[:urls] if args.key?(:urls)
  @volumes = args[:volumes] if args.key?(:volumes)
  @vpc_access = args[:vpc_access] if args.key?(:vpc_access)
end