Class: Google::Apis::RunV2::GoogleCloudRunV2Instance
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A Cloud Run Instance represents a single group of containers running in a region.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Corresponds to the JSON property
annotations. -
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
-
#client ⇒ String
Arbitrary identifier for the API client.
-
#client_version ⇒ String
Arbitrary version identifier for the API client.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#container_statuses ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerStatus>
Output only.
-
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Required.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description of the Instance.
-
#encryption_key ⇒ String
A reference to a customer managed encryption key (CMEK) to use to encrypt this container image.
-
#encryption_key_revocation_action ⇒ String
The action to take if the encryption key is revoked.
-
#encryption_key_shutdown_duration ⇒ String
If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances.
-
#etag ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#gpu_zonal_redundancy_disabled ⇒ Boolean
(also: #gpu_zonal_redundancy_disabled?)
Optional.
-
#iap_enabled ⇒ Boolean
(also: #iap_enabled?)
Optional.
-
#ingress ⇒ String
Optional.
-
#invoker_iam_disabled ⇒ Boolean
(also: #invoker_iam_disabled?)
Optional.
-
#labels ⇒ Hash<String,String>
Corresponds to the JSON property
labels. -
#last_modifier ⇒ String
Output only.
-
#launch_stage ⇒ String
The launch stage as defined by Google Cloud Platform Launch Stages.
-
#log_uri ⇒ String
Output only.
-
#name ⇒ String
The fully qualified name of this Instance.
-
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
Corresponds to the JSON property
serviceAccount. -
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
-
#timeout ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#urls ⇒ Array<String>
Output only.
-
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
-
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Instance
constructor
A new instance of GoogleCloudRunV2Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Instance
Returns a new instance of GoogleCloudRunV2Instance.
1545 1546 1547 |
# File 'lib/google/apis/run_v2/classes.rb', line 1545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Corresponds to the JSON property annotations
1310 1311 1312 |
# File 'lib/google/apis/run_v2/classes.rb', line 1310 def annotations @annotations end |
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
Corresponds to the JSON property binaryAuthorization
1315 1316 1317 |
# File 'lib/google/apis/run_v2/classes.rb', line 1315 def @binary_authorization end |
#client ⇒ String
Arbitrary identifier for the API client.
Corresponds to the JSON property client
1320 1321 1322 |
# File 'lib/google/apis/run_v2/classes.rb', line 1320 def client @client end |
#client_version ⇒ String
Arbitrary version identifier for the API client.
Corresponds to the JSON property clientVersion
1325 1326 1327 |
# File 'lib/google/apis/run_v2/classes.rb', line 1325 def client_version @client_version end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Conditions of all other associated sub-resources. They
contain additional diagnostics information in case the Instance does not reach
its Serving state. See comments in reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property conditions
1333 1334 1335 |
# File 'lib/google/apis/run_v2/classes.rb', line 1333 def conditions @conditions end |
#container_statuses ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerStatus>
Output only. Status information for each of the specified containers. The
status includes the resolved digest for specified images.
Corresponds to the JSON property containerStatuses
1339 1340 1341 |
# File 'lib/google/apis/run_v2/classes.rb', line 1339 def container_statuses @container_statuses end |
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Required. Holds the single container that defines the unit of execution for
this Instance.
Corresponds to the JSON property containers
1345 1346 1347 |
# File 'lib/google/apis/run_v2/classes.rb', line 1345 def containers @containers end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
1350 1351 1352 |
# File 'lib/google/apis/run_v2/classes.rb', line 1350 def create_time @create_time end |
#creator ⇒ String
Output only. Email address of the authenticated creator.
Corresponds to the JSON property creator
1355 1356 1357 |
# File 'lib/google/apis/run_v2/classes.rb', line 1355 def creator @creator end |
#delete_time ⇒ String
Output only. The deletion time.
Corresponds to the JSON property deleteTime
1360 1361 1362 |
# File 'lib/google/apis/run_v2/classes.rb', line 1360 def delete_time @delete_time end |
#description ⇒ String
User-provided description of the Instance. This field currently has a 512-
character limit.
Corresponds to the JSON property description
1366 1367 1368 |
# File 'lib/google/apis/run_v2/classes.rb', line 1366 def description @description end |
#encryption_key ⇒ String
A reference to a customer managed encryption key (CMEK) to use to encrypt this
container image. For more information, go to https://cloud.google.com/run/docs/
securing/using-cmek
Corresponds to the JSON property encryptionKey
1373 1374 1375 |
# File 'lib/google/apis/run_v2/classes.rb', line 1373 def encryption_key @encryption_key end |
#encryption_key_revocation_action ⇒ String
The action to take if the encryption key is revoked.
Corresponds to the JSON property encryptionKeyRevocationAction
1378 1379 1380 |
# File 'lib/google/apis/run_v2/classes.rb', line 1378 def encryption_key_revocation_action @encryption_key_revocation_action end |
#encryption_key_shutdown_duration ⇒ String
If encryption_key_revocation_action is SHUTDOWN, the duration before shutting
down all instances. The minimum increment is 1 hour.
Corresponds to the JSON property encryptionKeyShutdownDuration
1384 1385 1386 |
# File 'lib/google/apis/run_v2/classes.rb', line 1384 def encryption_key_shutdown_duration @encryption_key_shutdown_duration end |
#etag ⇒ String
Optional. A system-generated fingerprint for this version of the resource. May
be used to detect modification conflict during updates.
Corresponds to the JSON property etag
1390 1391 1392 |
# File 'lib/google/apis/run_v2/classes.rb', line 1390 def etag @etag end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permamently deleted.
Corresponds to the JSON property expireTime
1396 1397 1398 |
# File 'lib/google/apis/run_v2/classes.rb', line 1396 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state. Please note that unlike v1, this is an int64 value.
As with most Google APIs, its JSON representation will be a string instead
of an integer.
Corresponds to the JSON property generation
1404 1405 1406 |
# File 'lib/google/apis/run_v2/classes.rb', line 1404 def generation @generation end |
#gpu_zonal_redundancy_disabled ⇒ Boolean Also known as: gpu_zonal_redundancy_disabled?
Optional. True if GPU zonal redundancy is disabled on this instance.
Corresponds to the JSON property gpuZonalRedundancyDisabled
1409 1410 1411 |
# File 'lib/google/apis/run_v2/classes.rb', line 1409 def gpu_zonal_redundancy_disabled @gpu_zonal_redundancy_disabled end |
#iap_enabled ⇒ Boolean Also known as: iap_enabled?
Optional. IAP settings on the Instance.
Corresponds to the JSON property iapEnabled
1415 1416 1417 |
# File 'lib/google/apis/run_v2/classes.rb', line 1415 def iap_enabled @iap_enabled end |
#ingress ⇒ String
Optional. Provides the ingress settings for this Instance. On output, returns
the currently observed ingress settings, or INGRESS_TRAFFIC_UNSPECIFIED if no
revision is active.
Corresponds to the JSON property ingress
1423 1424 1425 |
# File 'lib/google/apis/run_v2/classes.rb', line 1423 def ingress @ingress end |
#invoker_iam_disabled ⇒ Boolean Also known as: invoker_iam_disabled?
Optional. Disables IAM permission check for run.routes.invoke for callers of
this Instance. For more information, visit https://cloud.google.com/run/docs/
securing/managing-access#invoker_check.
Corresponds to the JSON property invokerIamDisabled
1430 1431 1432 |
# File 'lib/google/apis/run_v2/classes.rb', line 1430 def invoker_iam_disabled @invoker_iam_disabled end |
#labels ⇒ Hash<String,String>
Corresponds to the JSON property labels
1436 1437 1438 |
# File 'lib/google/apis/run_v2/classes.rb', line 1436 def labels @labels end |
#last_modifier ⇒ String
Output only. Email address of the last authenticated modifier.
Corresponds to the JSON property lastModifier
1441 1442 1443 |
# File 'lib/google/apis/run_v2/classes.rb', line 1441 def last_modifier @last_modifier end |
#launch_stage ⇒ String
The launch stage as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and
GA. If no value is specified, GA is assumed. Set the launch stage to a
preview stage on input to allow use of preview features in that stage. On read
(or output), describes whether the resource uses preview features. For example,
if ALPHA is provided as input, but only BETA and GA-level features are used,
this field will be BETA on output.
Corresponds to the JSON property launchStage
1452 1453 1454 |
# File 'lib/google/apis/run_v2/classes.rb', line 1452 def launch_stage @launch_stage end |
#log_uri ⇒ String
Output only. The Google Console URI to obtain logs for the Instance.
Corresponds to the JSON property logUri
1457 1458 1459 |
# File 'lib/google/apis/run_v2/classes.rb', line 1457 def log_uri @log_uri end |
#name ⇒ String
The fully qualified name of this Instance. In CreateInstanceRequest, this
field is ignored, and instead composed from CreateInstanceRequest.parent and
CreateInstanceRequest.instance_id. Format: projects/project/locations/
location/instances/instance_id
Corresponds to the JSON property name
1465 1466 1467 |
# File 'lib/google/apis/run_v2/classes.rb', line 1465 def name @name end |
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
Corresponds to the JSON property nodeSelector
1470 1471 1472 |
# File 'lib/google/apis/run_v2/classes.rb', line 1470 def node_selector @node_selector end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Instance currently serving traffic. See
comments in reconciling for additional information on reconciliation process
in Cloud Run. Please note that unlike v1, this is an int64 value. As with most
Google APIs, its JSON representation will be a string instead of an integer
.
Corresponds to the JSON property observedGeneration
1479 1480 1481 |
# File 'lib/google/apis/run_v2/classes.rb', line 1479 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Returns true if the Instance is currently being acted upon by the
system to bring it into the desired state. When a new Instance is created, or
an existing one is updated, Cloud Run will asynchronously perform all
necessary steps to bring the Instance to the desired serving state. This
process is called reconciliation. While reconciliation is in process,
observed_generation will have a transient value that might mismatch the
intended state. Once reconciliation is over (and this field is false), there
are two possible outcomes: reconciliation succeeded and the serving state
matches the Instance, or there was an error, and reconciliation failed. This
state can be found in terminal_condition.state.
Corresponds to the JSON property reconciling
1493 1494 1495 |
# File 'lib/google/apis/run_v2/classes.rb', line 1493 def reconciling @reconciling end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1499 1500 1501 |
# File 'lib/google/apis/run_v2/classes.rb', line 1499 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
Corresponds to the JSON property serviceAccount
1505 1506 1507 |
# File 'lib/google/apis/run_v2/classes.rb', line 1505 def service_account @service_account end |
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
Corresponds to the JSON property terminalCondition
1510 1511 1512 |
# File 'lib/google/apis/run_v2/classes.rb', line 1510 def terminal_condition @terminal_condition end |
#timeout ⇒ String
Optional. Duration the instance may be active before the system will shut it
down.
Corresponds to the JSON property timeout
1516 1517 1518 |
# File 'lib/google/apis/run_v2/classes.rb', line 1516 def timeout @timeout end |
#uid ⇒ String
Output only. Server assigned unique identifier for the trigger. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
1522 1523 1524 |
# File 'lib/google/apis/run_v2/classes.rb', line 1522 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
1527 1528 1529 |
# File 'lib/google/apis/run_v2/classes.rb', line 1527 def update_time @update_time end |
#urls ⇒ Array<String>
Output only. All URLs serving traffic for this Instance.
Corresponds to the JSON property urls
1532 1533 1534 |
# File 'lib/google/apis/run_v2/classes.rb', line 1532 def urls @urls end |
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
Corresponds to the JSON property volumes
1537 1538 1539 |
# File 'lib/google/apis/run_v2/classes.rb', line 1537 def volumes @volumes end |
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings. For more information on sending traffic to a VPC network,
visit https://cloud.google.com/run/docs/configuring/connecting-vpc.
Corresponds to the JSON property vpcAccess
1543 1544 1545 |
# File 'lib/google/apis/run_v2/classes.rb', line 1543 def vpc_access @vpc_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 |
# File 'lib/google/apis/run_v2/classes.rb', line 1550 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization) @client = args[:client] if args.key?(:client) @client_version = args[:client_version] if args.key?(:client_version) @conditions = args[:conditions] if args.key?(:conditions) @container_statuses = args[:container_statuses] if args.key?(:container_statuses) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action) @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled) @iap_enabled = args[:iap_enabled] if args.key?(:iap_enabled) @ingress = args[:ingress] if args.key?(:ingress) @invoker_iam_disabled = args[:invoker_iam_disabled] if args.key?(:invoker_iam_disabled) @labels = args[:labels] if args.key?(:labels) @last_modifier = args[:last_modifier] if args.key?(:last_modifier) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @log_uri = args[:log_uri] if args.key?(:log_uri) @name = args[:name] if args.key?(:name) @node_selector = args[:node_selector] if args.key?(:node_selector) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @terminal_condition = args[:terminal_condition] if args.key?(:terminal_condition) @timeout = args[:timeout] if args.key?(:timeout) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @urls = args[:urls] if args.key?(:urls) @volumes = args[:volumes] if args.key?(:volumes) @vpc_access = args[:vpc_access] if args.key?(:vpc_access) end |