Class: Google::Apis::RunV2::GoogleCloudRunV2Job
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Job represents the configuration of a single job, which references a container image that is run to completion.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
-
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
-
#client ⇒ String
Arbitrary identifier for the API client.
-
#client_version ⇒ String
Arbitrary version identifier for the API client.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#execution_count ⇒ Fixnum
Output only.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
Unstructured key value map that can be used to organize and categorize objects.
-
#last_modifier ⇒ String
Output only.
-
#latest_created_execution ⇒ Google::Apis::RunV2::GoogleCloudRunV2ExecutionReference
Reference to an Execution.
-
#launch_stage ⇒ String
The launch stage as defined by Google Cloud Platform Launch Stages.
-
#name ⇒ String
The fully qualified name of this Job.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#run_execution_token ⇒ String
A unique string used as a suffix for creating a new execution.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_execution_token ⇒ String
A unique string used as a suffix creating a new execution.
-
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate
ExecutionTemplate describes the data an execution should have when created from a template.
-
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Job
constructor
A new instance of GoogleCloudRunV2Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Job
Returns a new instance of GoogleCloudRunV2Job.
1853 1854 1855 |
# File 'lib/google/apis/run_v2/classes.rb', line 1853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Unstructured key value map that may be set by external tools to store and
arbitrary metadata. They are not queryable and should be preserved when
modifying objects. Cloud Run API v2 does not support annotations with run.
googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected on new
resources. All system annotations in v1 now have a corresponding field in v2
Job. This field follows Kubernetes annotations' namespacing, limits, and rules.
Corresponds to the JSON property annotations
1678 1679 1680 |
# File 'lib/google/apis/run_v2/classes.rb', line 1678 def annotations @annotations end |
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
Corresponds to the JSON property binaryAuthorization
1683 1684 1685 |
# File 'lib/google/apis/run_v2/classes.rb', line 1683 def @binary_authorization end |
#client ⇒ String
Arbitrary identifier for the API client.
Corresponds to the JSON property client
1688 1689 1690 |
# File 'lib/google/apis/run_v2/classes.rb', line 1688 def client @client end |
#client_version ⇒ String
Arbitrary version identifier for the API client.
Corresponds to the JSON property clientVersion
1693 1694 1695 |
# File 'lib/google/apis/run_v2/classes.rb', line 1693 def client_version @client_version end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Conditions of all other associated sub-resources. They
contain additional diagnostics information in case the Job does not reach its
desired state. See comments in reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property conditions
1701 1702 1703 |
# File 'lib/google/apis/run_v2/classes.rb', line 1701 def conditions @conditions end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
1706 1707 1708 |
# File 'lib/google/apis/run_v2/classes.rb', line 1706 def create_time @create_time end |
#creator ⇒ String
Output only. Email address of the authenticated creator.
Corresponds to the JSON property creator
1711 1712 1713 |
# File 'lib/google/apis/run_v2/classes.rb', line 1711 def creator @creator end |
#delete_time ⇒ String
Output only. The deletion time. It is only populated as a response to a Delete
request.
Corresponds to the JSON property deleteTime
1717 1718 1719 |
# File 'lib/google/apis/run_v2/classes.rb', line 1717 def delete_time @delete_time end |
#etag ⇒ String
Optional. A system-generated fingerprint for this version of the resource. May
be used to detect modification conflict during updates.
Corresponds to the JSON property etag
1723 1724 1725 |
# File 'lib/google/apis/run_v2/classes.rb', line 1723 def etag @etag end |
#execution_count ⇒ Fixnum
Output only. Number of executions created for this job.
Corresponds to the JSON property executionCount
1728 1729 1730 |
# File 'lib/google/apis/run_v2/classes.rb', line 1728 def execution_count @execution_count end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permamently deleted.
Corresponds to the JSON property expireTime
1734 1735 1736 |
# File 'lib/google/apis/run_v2/classes.rb', line 1734 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state.
Corresponds to the JSON property generation
1740 1741 1742 |
# File 'lib/google/apis/run_v2/classes.rb', line 1740 def generation @generation end |
#labels ⇒ Hash<String,String>
Unstructured key value map that can be used to organize and categorize objects.
User-provided labels are shared with Google's billing system, so they can be
used to filter, or break down billing charges by team, component, environment,
state, etc. For more information, visit https://cloud.google.com/resource-
manager/docs/creating-managing-labels or https://cloud.google.com/run/docs/
configuring/labels. Cloud Run API v2 does not support labels with run.
googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected. All system
labels in v1 now have a corresponding field in v2 Job.
Corresponds to the JSON property labels
1753 1754 1755 |
# File 'lib/google/apis/run_v2/classes.rb', line 1753 def labels @labels end |
#last_modifier ⇒ String
Output only. Email address of the last authenticated modifier.
Corresponds to the JSON property lastModifier
1758 1759 1760 |
# File 'lib/google/apis/run_v2/classes.rb', line 1758 def last_modifier @last_modifier end |
#latest_created_execution ⇒ Google::Apis::RunV2::GoogleCloudRunV2ExecutionReference
Reference to an Execution. Use /Executions.GetExecution with the given name to
get full execution including the latest status.
Corresponds to the JSON property latestCreatedExecution
1764 1765 1766 |
# File 'lib/google/apis/run_v2/classes.rb', line 1764 def latest_created_execution @latest_created_execution end |
#launch_stage ⇒ String
The launch stage as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and
GA. If no value is specified, GA is assumed. Set the launch stage to a
preview stage on input to allow use of preview features in that stage. On read
(or output), describes whether the resource uses preview features. For example,
if ALPHA is provided as input, but only BETA and GA-level features are used,
this field will be BETA on output.
Corresponds to the JSON property launchStage
1775 1776 1777 |
# File 'lib/google/apis/run_v2/classes.rb', line 1775 def launch_stage @launch_stage end |
#name ⇒ String
The fully qualified name of this Job. Format: projects/project/locations/
location/jobs/job
Corresponds to the JSON property name
1781 1782 1783 |
# File 'lib/google/apis/run_v2/classes.rb', line 1781 def name @name end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Job. See comments in reconciling for
additional information on reconciliation process in Cloud Run.
Corresponds to the JSON property observedGeneration
1787 1788 1789 |
# File 'lib/google/apis/run_v2/classes.rb', line 1787 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Returns true if the Job is currently being acted upon by the
system to bring it into the desired state. When a new Job is created, or an
existing one is updated, Cloud Run will asynchronously perform all necessary
steps to bring the Job to the desired state. This process is called
reconciliation. While reconciliation is in process, observed_generation and
latest_succeeded_execution, will have transient values that might mismatch
the intended state: Once reconciliation is over (and this field is false),
there are two possible outcomes: reconciliation succeeded and the state
matches the Job, or there was an error, and reconciliation failed. This state
can be found in terminal_condition.state. If reconciliation succeeded, the
following fields will match: observed_generation and generation,
latest_succeeded_execution and latest_created_execution. If reconciliation
failed, observed_generation and latest_succeeded_execution will have the
state of the last succeeded execution or empty for newly created Job.
Additional information on the failure can be found in terminal_condition and
conditions.
Corresponds to the JSON property reconciling
1807 1808 1809 |
# File 'lib/google/apis/run_v2/classes.rb', line 1807 def reconciling @reconciling end |
#run_execution_token ⇒ String
A unique string used as a suffix for creating a new execution. The Job will
become ready when the execution is successfully completed. The sum of job name
and token length must be fewer than 63 characters.
Corresponds to the JSON property runExecutionToken
1815 1816 1817 |
# File 'lib/google/apis/run_v2/classes.rb', line 1815 def run_execution_token @run_execution_token end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1820 1821 1822 |
# File 'lib/google/apis/run_v2/classes.rb', line 1820 def satisfies_pzs @satisfies_pzs end |
#start_execution_token ⇒ String
A unique string used as a suffix creating a new execution. The Job will become
ready when the execution is successfully started. The sum of job name and
token length must be fewer than 63 characters.
Corresponds to the JSON property startExecutionToken
1828 1829 1830 |
# File 'lib/google/apis/run_v2/classes.rb', line 1828 def start_execution_token @start_execution_token end |
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2ExecutionTemplate
ExecutionTemplate describes the data an execution should have when created
from a template.
Corresponds to the JSON property template
1834 1835 1836 |
# File 'lib/google/apis/run_v2/classes.rb', line 1834 def template @template end |
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
Corresponds to the JSON property terminalCondition
1839 1840 1841 |
# File 'lib/google/apis/run_v2/classes.rb', line 1839 def terminal_condition @terminal_condition end |
#uid ⇒ String
Output only. Server assigned unique identifier for the Execution. The value is
a UUID4 string and guaranteed to remain unchanged until the resource is
deleted.
Corresponds to the JSON property uid
1846 1847 1848 |
# File 'lib/google/apis/run_v2/classes.rb', line 1846 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
1851 1852 1853 |
# File 'lib/google/apis/run_v2/classes.rb', line 1851 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/google/apis/run_v2/classes.rb', line 1858 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization) @client = args[:client] if args.key?(:client) @client_version = args[:client_version] if args.key?(:client_version) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @delete_time = args[:delete_time] if args.key?(:delete_time) @etag = args[:etag] if args.key?(:etag) @execution_count = args[:execution_count] if args.key?(:execution_count) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @labels = args[:labels] if args.key?(:labels) @last_modifier = args[:last_modifier] if args.key?(:last_modifier) @latest_created_execution = args[:latest_created_execution] if args.key?(:latest_created_execution) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @run_execution_token = args[:run_execution_token] if args.key?(:run_execution_token) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_execution_token = args[:start_execution_token] if args.key?(:start_execution_token) @template = args[:template] if args.key?(:template) @terminal_condition = args[:terminal_condition] if args.key?(:terminal_condition) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |