Class: Google::Apis::RunV2::GoogleCloudRunV2ListServicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Response message containing a list of Services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2ListServicesResponse

Returns a new instance of GoogleCloudRunV2ListServicesResponse.



1607
1608
1609
# File 'lib/google/apis/run_v2/classes.rb', line 1607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token indicating there are more items than page_size. Use it in the next ListServices request to continue. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1594
1595
1596
# File 'lib/google/apis/run_v2/classes.rb', line 1594

def next_page_token
  @next_page_token
end

#servicesArray<Google::Apis::RunV2::GoogleCloudRunV2Service>

The resulting list of Services. Corresponds to the JSON property services



1599
1600
1601
# File 'lib/google/apis/run_v2/classes.rb', line 1599

def services
  @services
end

#unreachableArray<String>

Output only. For global requests, returns the list of regions that could not be reached within the deadline. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1605
1606
1607
# File 'lib/google/apis/run_v2/classes.rb', line 1605

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1612
1613
1614
1615
1616
# File 'lib/google/apis/run_v2/classes.rb', line 1612

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @services = args[:services] if args.key?(:services)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end