Class: Google::Apis::RunV2::GoogleCloudRunV2NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Direct VPC egress settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2NetworkInterface

Returns a new instance of GoogleCloudRunV2NetworkInterface.



2186
2187
2188
# File 'lib/google/apis/run_v2/classes.rb', line 2186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Optional. The VPC network that the Cloud Run resource will be able to send traffic to. At least one of network or subnetwork must be specified. If both network and subnetwork are specified, the given VPC subnetwork must belong to the given VPC network. If network is not specified, it will be looked up from the subnetwork. Corresponds to the JSON property network

Returns:

  • (String)


2170
2171
2172
# File 'lib/google/apis/run_v2/classes.rb', line 2170

def network
  @network
end

#subnetworkString

Optional. The VPC subnetwork that the Cloud Run resource will get IPs from. At least one of network or subnetwork must be specified. If both network and subnetwork are specified, the given VPC subnetwork must belong to the given VPC network. If subnetwork is not specified, the subnetwork with the same name with the network will be used. Corresponds to the JSON property subnetwork

Returns:

  • (String)


2179
2180
2181
# File 'lib/google/apis/run_v2/classes.rb', line 2179

def subnetwork
  @subnetwork
end

#tagsArray<String>

Optional. Network tags applied to this Cloud Run resource. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


2184
2185
2186
# File 'lib/google/apis/run_v2/classes.rb', line 2184

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2191
2192
2193
2194
2195
# File 'lib/google/apis/run_v2/classes.rb', line 2191

def update!(**args)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @tags = args[:tags] if args.key?(:tags)
end