Class: Google::Apis::RunV2::GoogleCloudRunV2NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2NetworkInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Direct VPC egress settings.
Instance Attribute Summary collapse
-
#network ⇒ String
Optional.
-
#subnetwork ⇒ String
Optional.
-
#tags ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2NetworkInterface
constructor
A new instance of GoogleCloudRunV2NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2NetworkInterface
Returns a new instance of GoogleCloudRunV2NetworkInterface.
1774 1775 1776 |
# File 'lib/google/apis/run_v2/classes.rb', line 1774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network ⇒ String
Optional. The VPC network that the Cloud Run resource will be able to send
traffic to. At least one of network or subnetwork must be specified. If both
network and subnetwork are specified, the given VPC subnetwork must belong to
the given VPC network. If network is not specified, it will be looked up from
the subnetwork.
Corresponds to the JSON property network
1758 1759 1760 |
# File 'lib/google/apis/run_v2/classes.rb', line 1758 def network @network end |
#subnetwork ⇒ String
Optional. The VPC subnetwork that the Cloud Run resource will get IPs from. At
least one of network or subnetwork must be specified. If both network and
subnetwork are specified, the given VPC subnetwork must belong to the given
VPC network. If subnetwork is not specified, the subnetwork with the same name
with the network will be used.
Corresponds to the JSON property subnetwork
1767 1768 1769 |
# File 'lib/google/apis/run_v2/classes.rb', line 1767 def subnetwork @subnetwork end |
#tags ⇒ Array<String>
Optional. Network tags applied to this Cloud Run resource.
Corresponds to the JSON property tags
1772 1773 1774 |
# File 'lib/google/apis/run_v2/classes.rb', line 1772 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1779 1780 1781 1782 1783 |
# File 'lib/google/apis/run_v2/classes.rb', line 1779 def update!(**args) @network = args[:network] if args.key?(:network) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @tags = args[:tags] if args.key?(:tags) end |