Class: Google::Apis::RunV2::GoogleCloudRunV2Overrides
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Overrides
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
RunJob Overrides that contains Execution fields to be overridden.
Instance Attribute Summary collapse
-
#container_overrides ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerOverride>
Per container override specification.
-
#task_count ⇒ Fixnum
Optional.
-
#timeout ⇒ String
Duration in seconds the task may be active before the system will actively try to mark it failed and kill associated containers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Overrides
constructor
A new instance of GoogleCloudRunV2Overrides.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Overrides
Returns a new instance of GoogleCloudRunV2Overrides.
2226 2227 2228 |
# File 'lib/google/apis/run_v2/classes.rb', line 2226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_overrides ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2ContainerOverride>
Per container override specification.
Corresponds to the JSON property containerOverrides
2211 2212 2213 |
# File 'lib/google/apis/run_v2/classes.rb', line 2211 def container_overrides @container_overrides end |
#task_count ⇒ Fixnum
Optional. The desired number of tasks the execution should run. Will replace
existing task_count value.
Corresponds to the JSON property taskCount
2217 2218 2219 |
# File 'lib/google/apis/run_v2/classes.rb', line 2217 def task_count @task_count end |
#timeout ⇒ String
Duration in seconds the task may be active before the system will actively try
to mark it failed and kill associated containers. Will replace existing
timeout_seconds value.
Corresponds to the JSON property timeout
2224 2225 2226 |
# File 'lib/google/apis/run_v2/classes.rb', line 2224 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2231 2232 2233 2234 2235 |
# File 'lib/google/apis/run_v2/classes.rb', line 2231 def update!(**args) @container_overrides = args[:container_overrides] if args.key?(:container_overrides) @task_count = args[:task_count] if args.key?(:task_count) @timeout = args[:timeout] if args.key?(:timeout) end |