Class: Google::Apis::RunV2::GoogleCloudRunV2Probe
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Probe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
Instance Attribute Summary collapse
-
#failure_threshold ⇒ Fixnum
Optional.
-
#grpc ⇒ Google::Apis::RunV2::GoogleCloudRunV2GrpcAction
GRPCAction describes an action involving a GRPC port.
-
#http_get ⇒ Google::Apis::RunV2::GoogleCloudRunV2HttpGetAction
HTTPGetAction describes an action based on HTTP Get requests.
-
#initial_delay_seconds ⇒ Fixnum
Optional.
-
#period_seconds ⇒ Fixnum
Optional.
-
#tcp_socket ⇒ Google::Apis::RunV2::GoogleCloudRunV2TcpSocketAction
TCPSocketAction describes an action based on opening a socket Corresponds to the JSON property
tcpSocket. -
#timeout_seconds ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Probe
constructor
A new instance of GoogleCloudRunV2Probe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Probe
Returns a new instance of GoogleCloudRunV2Probe.
2285 2286 2287 |
# File 'lib/google/apis/run_v2/classes.rb', line 2285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_threshold ⇒ Fixnum
Optional. Minimum consecutive failures for the probe to be considered failed
after having succeeded. Defaults to 3. Minimum value is 1.
Corresponds to the JSON property failureThreshold
2247 2248 2249 |
# File 'lib/google/apis/run_v2/classes.rb', line 2247 def failure_threshold @failure_threshold end |
#grpc ⇒ Google::Apis::RunV2::GoogleCloudRunV2GrpcAction
GRPCAction describes an action involving a GRPC port.
Corresponds to the JSON property grpc
2252 2253 2254 |
# File 'lib/google/apis/run_v2/classes.rb', line 2252 def grpc @grpc end |
#http_get ⇒ Google::Apis::RunV2::GoogleCloudRunV2HttpGetAction
HTTPGetAction describes an action based on HTTP Get requests.
Corresponds to the JSON property httpGet
2257 2258 2259 |
# File 'lib/google/apis/run_v2/classes.rb', line 2257 def http_get @http_get end |
#initial_delay_seconds ⇒ Fixnum
Optional. Number of seconds after the container has started before the probe
is initiated. Defaults to 0 seconds. Minimum value is 0. Maximum value for
liveness probe is 3600. Maximum value for startup probe is 240.
Corresponds to the JSON property initialDelaySeconds
2264 2265 2266 |
# File 'lib/google/apis/run_v2/classes.rb', line 2264 def initial_delay_seconds @initial_delay_seconds end |
#period_seconds ⇒ Fixnum
Optional. How often (in seconds) to perform the probe. Default to 10 seconds.
Minimum value is 1. Maximum value for liveness probe is 3600. Maximum value
for startup probe is 240. Must be greater or equal than timeout_seconds.
Corresponds to the JSON property periodSeconds
2271 2272 2273 |
# File 'lib/google/apis/run_v2/classes.rb', line 2271 def period_seconds @period_seconds end |
#tcp_socket ⇒ Google::Apis::RunV2::GoogleCloudRunV2TcpSocketAction
TCPSocketAction describes an action based on opening a socket
Corresponds to the JSON property tcpSocket
2276 2277 2278 |
# File 'lib/google/apis/run_v2/classes.rb', line 2276 def tcp_socket @tcp_socket end |
#timeout_seconds ⇒ Fixnum
Optional. Number of seconds after which the probe times out. Defaults to 1
second. Minimum value is 1. Maximum value is 3600. Must be smaller than
period_seconds.
Corresponds to the JSON property timeoutSeconds
2283 2284 2285 |
# File 'lib/google/apis/run_v2/classes.rb', line 2283 def timeout_seconds @timeout_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2290 2291 2292 2293 2294 2295 2296 2297 2298 |
# File 'lib/google/apis/run_v2/classes.rb', line 2290 def update!(**args) @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold) @grpc = args[:grpc] if args.key?(:grpc) @http_get = args[:http_get] if args.key?(:http_get) @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds) @period_seconds = args[:period_seconds] if args.key?(:period_seconds) @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) end |