Class: Google::Apis::RunV2::GoogleCloudRunV2Revision
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Revision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A Revision is an immutable snapshot of code and configuration. A Revision references a container image. Revisions are only created by updates to its parent Service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Output only.
-
#client ⇒ String
Output only.
-
#client_version ⇒ String
Output only.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Holds the list which define the units of execution for this Revision.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#encryption_key ⇒ String
A reference to a customer managed encryption key (CMEK) to use to encrypt this container image.
-
#encryption_key_revocation_action ⇒ String
The action to take if the encryption key is revoked.
-
#encryption_key_shutdown_duration ⇒ String
If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances.
-
#etag ⇒ String
Output only.
-
#execution_environment ⇒ String
The execution environment being used to host this Revision.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#gpu_zonal_redundancy_disabled ⇒ Boolean
(also: #gpu_zonal_redundancy_disabled?)
Optional.
-
#labels ⇒ Hash<String,String>
Output only.
-
#launch_stage ⇒ String
The least stable launch stage needed to create this resource, as defined by Google Cloud Platform Launch Stages.
-
#log_uri ⇒ String
Output only.
-
#max_instance_request_concurrency ⇒ Fixnum
Sets the maximum number of requests that each serving instance can receive.
-
#name ⇒ String
Output only.
-
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#sandboxes ⇒ Google::Apis::RunV2::GoogleCloudRunV2SandboxConfiguration
Configuration for sandboxes.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scaling ⇒ Google::Apis::RunV2::GoogleCloudRunV2RevisionScaling
Settings for revision-level scaling settings.
-
#scaling_status ⇒ Google::Apis::RunV2::GoogleCloudRunV2RevisionScalingStatus
Effective settings for the current revision Corresponds to the JSON property
scalingStatus. -
#service ⇒ String
Output only.
-
#service_account ⇒ String
Email address of the IAM service account associated with the revision of the service.
-
#service_mesh ⇒ Google::Apis::RunV2::GoogleCloudRunV2ServiceMesh
Settings for Cloud Service Mesh.
-
#session_affinity ⇒ Boolean
(also: #session_affinity?)
Enable session affinity.
-
#timeout ⇒ String
Max allowed time for an instance to respond to a request.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
-
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Revision
constructor
A new instance of GoogleCloudRunV2Revision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Revision
Returns a new instance of GoogleCloudRunV2Revision.
2583 2584 2585 |
# File 'lib/google/apis/run_v2/classes.rb', line 2583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Output only. Unstructured key value map that may be set by external tools to
store and arbitrary metadata. They are not queryable and should be preserved
when modifying objects.
Corresponds to the JSON property annotations
2368 2369 2370 |
# File 'lib/google/apis/run_v2/classes.rb', line 2368 def annotations @annotations end |
#client ⇒ String
Output only. Arbitrary identifier for the API client.
Corresponds to the JSON property client
2373 2374 2375 |
# File 'lib/google/apis/run_v2/classes.rb', line 2373 def client @client end |
#client_version ⇒ String
Output only. Arbitrary version identifier for the API client.
Corresponds to the JSON property clientVersion
2378 2379 2380 |
# File 'lib/google/apis/run_v2/classes.rb', line 2378 def client_version @client_version end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Condition of this Revision, containing its readiness status,
and detailed error information in case it did not reach a serving state.
Corresponds to the JSON property conditions
2384 2385 2386 |
# File 'lib/google/apis/run_v2/classes.rb', line 2384 def conditions @conditions end |
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Holds the list which define the units of execution for this Revision.
Corresponds to the JSON property containers
2389 2390 2391 |
# File 'lib/google/apis/run_v2/classes.rb', line 2389 def containers @containers end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
2394 2395 2396 |
# File 'lib/google/apis/run_v2/classes.rb', line 2394 def create_time @create_time end |
#creator ⇒ String
Output only. Email address of the authenticated creator.
Corresponds to the JSON property creator
2399 2400 2401 |
# File 'lib/google/apis/run_v2/classes.rb', line 2399 def creator @creator end |
#delete_time ⇒ String
Output only. For a deleted resource, the deletion time. It is only populated
as a response to a Delete request.
Corresponds to the JSON property deleteTime
2405 2406 2407 |
# File 'lib/google/apis/run_v2/classes.rb', line 2405 def delete_time @delete_time end |
#encryption_key ⇒ String
A reference to a customer managed encryption key (CMEK) to use to encrypt this
container image. For more information, go to https://cloud.google.com/run/docs/
securing/using-cmek
Corresponds to the JSON property encryptionKey
2412 2413 2414 |
# File 'lib/google/apis/run_v2/classes.rb', line 2412 def encryption_key @encryption_key end |
#encryption_key_revocation_action ⇒ String
The action to take if the encryption key is revoked.
Corresponds to the JSON property encryptionKeyRevocationAction
2417 2418 2419 |
# File 'lib/google/apis/run_v2/classes.rb', line 2417 def encryption_key_revocation_action @encryption_key_revocation_action end |
#encryption_key_shutdown_duration ⇒ String
If encryption_key_revocation_action is SHUTDOWN, the duration before shutting
down all instances. The minimum increment is 1 hour.
Corresponds to the JSON property encryptionKeyShutdownDuration
2423 2424 2425 |
# File 'lib/google/apis/run_v2/classes.rb', line 2423 def encryption_key_shutdown_duration @encryption_key_shutdown_duration end |
#etag ⇒ String
Output only. A system-generated fingerprint for this version of the resource.
May be used to detect modification conflict during updates.
Corresponds to the JSON property etag
2429 2430 2431 |
# File 'lib/google/apis/run_v2/classes.rb', line 2429 def etag @etag end |
#execution_environment ⇒ String
The execution environment being used to host this Revision.
Corresponds to the JSON property executionEnvironment
2434 2435 2436 |
# File 'lib/google/apis/run_v2/classes.rb', line 2434 def execution_environment @execution_environment end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permamently deleted. It is only populated as a response to a Delete request.
Corresponds to the JSON property expireTime
2440 2441 2442 |
# File 'lib/google/apis/run_v2/classes.rb', line 2440 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state.
Corresponds to the JSON property generation
2446 2447 2448 |
# File 'lib/google/apis/run_v2/classes.rb', line 2446 def generation @generation end |
#gpu_zonal_redundancy_disabled ⇒ Boolean Also known as: gpu_zonal_redundancy_disabled?
Optional. Output only. True if GPU zonal redundancy is disabled on this
revision.
Corresponds to the JSON property gpuZonalRedundancyDisabled
2452 2453 2454 |
# File 'lib/google/apis/run_v2/classes.rb', line 2452 def gpu_zonal_redundancy_disabled @gpu_zonal_redundancy_disabled end |
#labels ⇒ Hash<String,String>
Output only. Unstructured key value map that can be used to organize and
categorize objects. User-provided labels are shared with Google's billing
system, so they can be used to filter, or break down billing charges by team,
component, environment, state, etc. For more information, visit https://cloud.
google.com/resource-manager/docs/creating-managing-labels or https://cloud.
google.com/run/docs/configuring/labels.
Corresponds to the JSON property labels
2463 2464 2465 |
# File 'lib/google/apis/run_v2/classes.rb', line 2463 def labels @labels end |
#launch_stage ⇒ String
The least stable launch stage needed to create this resource, as defined by
Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and GA. Note that this value
might not be what was used as input. For example, if ALPHA was provided as
input in the parent resource, but only BETA and GA-level features are used,
this field will be BETA.
Corresponds to the JSON property launchStage
2473 2474 2475 |
# File 'lib/google/apis/run_v2/classes.rb', line 2473 def launch_stage @launch_stage end |
#log_uri ⇒ String
Output only. The Google Console URI to obtain logs for the Revision.
Corresponds to the JSON property logUri
2478 2479 2480 |
# File 'lib/google/apis/run_v2/classes.rb', line 2478 def log_uri @log_uri end |
#max_instance_request_concurrency ⇒ Fixnum
Sets the maximum number of requests that each serving instance can receive.
Corresponds to the JSON property maxInstanceRequestConcurrency
2483 2484 2485 |
# File 'lib/google/apis/run_v2/classes.rb', line 2483 def max_instance_request_concurrency @max_instance_request_concurrency end |
#name ⇒ String
Output only. The unique name of this Revision.
Corresponds to the JSON property name
2488 2489 2490 |
# File 'lib/google/apis/run_v2/classes.rb', line 2488 def name @name end |
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
Corresponds to the JSON property nodeSelector
2493 2494 2495 |
# File 'lib/google/apis/run_v2/classes.rb', line 2493 def node_selector @node_selector end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Revision currently serving traffic. See
comments in reconciling for additional information on reconciliation process
in Cloud Run.
Corresponds to the JSON property observedGeneration
2500 2501 2502 |
# File 'lib/google/apis/run_v2/classes.rb', line 2500 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether the resource's reconciliation is still in
progress. See comments in Service.reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property reconciling
2507 2508 2509 |
# File 'lib/google/apis/run_v2/classes.rb', line 2507 def reconciling @reconciling end |
#sandboxes ⇒ Google::Apis::RunV2::GoogleCloudRunV2SandboxConfiguration
Configuration for sandboxes.
Corresponds to the JSON property sandboxes
2513 2514 2515 |
# File 'lib/google/apis/run_v2/classes.rb', line 2513 def sandboxes @sandboxes end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2518 2519 2520 |
# File 'lib/google/apis/run_v2/classes.rb', line 2518 def satisfies_pzs @satisfies_pzs end |
#scaling ⇒ Google::Apis::RunV2::GoogleCloudRunV2RevisionScaling
Settings for revision-level scaling settings.
Corresponds to the JSON property scaling
2524 2525 2526 |
# File 'lib/google/apis/run_v2/classes.rb', line 2524 def scaling @scaling end |
#scaling_status ⇒ Google::Apis::RunV2::GoogleCloudRunV2RevisionScalingStatus
Effective settings for the current revision
Corresponds to the JSON property scalingStatus
2529 2530 2531 |
# File 'lib/google/apis/run_v2/classes.rb', line 2529 def scaling_status @scaling_status end |
#service ⇒ String
Output only. The name of the parent service.
Corresponds to the JSON property service
2534 2535 2536 |
# File 'lib/google/apis/run_v2/classes.rb', line 2534 def service @service end |
#service_account ⇒ String
Email address of the IAM service account associated with the revision of the
service. The service account represents the identity of the running revision,
and determines what permissions the revision has.
Corresponds to the JSON property serviceAccount
2541 2542 2543 |
# File 'lib/google/apis/run_v2/classes.rb', line 2541 def service_account @service_account end |
#service_mesh ⇒ Google::Apis::RunV2::GoogleCloudRunV2ServiceMesh
Settings for Cloud Service Mesh. For more information see https://cloud.google.
com/service-mesh/docs/overview.
Corresponds to the JSON property serviceMesh
2547 2548 2549 |
# File 'lib/google/apis/run_v2/classes.rb', line 2547 def service_mesh @service_mesh end |
#session_affinity ⇒ Boolean Also known as: session_affinity?
Enable session affinity.
Corresponds to the JSON property sessionAffinity
2552 2553 2554 |
# File 'lib/google/apis/run_v2/classes.rb', line 2552 def session_affinity @session_affinity end |
#timeout ⇒ String
Max allowed time for an instance to respond to a request.
Corresponds to the JSON property timeout
2558 2559 2560 |
# File 'lib/google/apis/run_v2/classes.rb', line 2558 def timeout @timeout end |
#uid ⇒ String
Output only. Server assigned unique identifier for the Revision. The value is
a UUID4 string and guaranteed to remain unchanged until the resource is
deleted.
Corresponds to the JSON property uid
2565 2566 2567 |
# File 'lib/google/apis/run_v2/classes.rb', line 2565 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
2570 2571 2572 |
# File 'lib/google/apis/run_v2/classes.rb', line 2570 def update_time @update_time end |
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
Corresponds to the JSON property volumes
2575 2576 2577 |
# File 'lib/google/apis/run_v2/classes.rb', line 2575 def volumes @volumes end |
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings. For more information on sending traffic to a VPC network,
visit https://cloud.google.com/run/docs/configuring/connecting-vpc.
Corresponds to the JSON property vpcAccess
2581 2582 2583 |
# File 'lib/google/apis/run_v2/classes.rb', line 2581 def vpc_access @vpc_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 |
# File 'lib/google/apis/run_v2/classes.rb', line 2588 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @client = args[:client] if args.key?(:client) @client_version = args[:client_version] if args.key?(:client_version) @conditions = args[:conditions] if args.key?(:conditions) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @delete_time = args[:delete_time] if args.key?(:delete_time) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action) @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration) @etag = args[:etag] if args.key?(:etag) @execution_environment = args[:execution_environment] if args.key?(:execution_environment) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled) @labels = args[:labels] if args.key?(:labels) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @log_uri = args[:log_uri] if args.key?(:log_uri) @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency) @name = args[:name] if args.key?(:name) @node_selector = args[:node_selector] if args.key?(:node_selector) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @sandboxes = args[:sandboxes] if args.key?(:sandboxes) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scaling = args[:scaling] if args.key?(:scaling) @scaling_status = args[:scaling_status] if args.key?(:scaling_status) @service = args[:service] if args.key?(:service) @service_account = args[:service_account] if args.key?(:service_account) @service_mesh = args[:service_mesh] if args.key?(:service_mesh) @session_affinity = args[:session_affinity] if args.key?(:session_affinity) @timeout = args[:timeout] if args.key?(:timeout) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @volumes = args[:volumes] if args.key?(:volumes) @vpc_access = args[:vpc_access] if args.key?(:vpc_access) end |