Class: Google::Apis::RunV2::GoogleCloudRunV2Revision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Revision is an immutable snapshot of code and configuration. A Revision references a container image. Revisions are only created by updates to its parent Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Revision

Returns a new instance of GoogleCloudRunV2Revision.



2564
2565
2566
# File 'lib/google/apis/run_v2/classes.rb', line 2564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Output only. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2354
2355
2356
# File 'lib/google/apis/run_v2/classes.rb', line 2354

def annotations
  @annotations
end

#clientString

Output only. Arbitrary identifier for the API client. Corresponds to the JSON property client

Returns:

  • (String)


2359
2360
2361
# File 'lib/google/apis/run_v2/classes.rb', line 2359

def client
  @client
end

#client_versionString

Output only. Arbitrary version identifier for the API client. Corresponds to the JSON property clientVersion

Returns:

  • (String)


2364
2365
2366
# File 'lib/google/apis/run_v2/classes.rb', line 2364

def client_version
  @client_version
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Condition of this Revision, containing its readiness status, and detailed error information in case it did not reach a serving state. Corresponds to the JSON property conditions



2370
2371
2372
# File 'lib/google/apis/run_v2/classes.rb', line 2370

def conditions
  @conditions
end

#containersArray<Google::Apis::RunV2::GoogleCloudRunV2Container>

Holds the list which define the units of execution for this Revision. Corresponds to the JSON property containers



2375
2376
2377
# File 'lib/google/apis/run_v2/classes.rb', line 2375

def containers
  @containers
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


2380
2381
2382
# File 'lib/google/apis/run_v2/classes.rb', line 2380

def create_time
  @create_time
end

#creatorString

Output only. Email address of the authenticated creator. Corresponds to the JSON property creator

Returns:

  • (String)


2385
2386
2387
# File 'lib/google/apis/run_v2/classes.rb', line 2385

def creator
  @creator
end

#delete_timeString

Output only. For a deleted resource, the deletion time. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


2391
2392
2393
# File 'lib/google/apis/run_v2/classes.rb', line 2391

def delete_time
  @delete_time
end

#encryption_keyString

A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google.com/run/docs/ securing/using-cmek Corresponds to the JSON property encryptionKey

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/run_v2/classes.rb', line 2398

def encryption_key
  @encryption_key
end

#encryption_key_revocation_actionString

The action to take if the encryption key is revoked. Corresponds to the JSON property encryptionKeyRevocationAction

Returns:

  • (String)


2403
2404
2405
# File 'lib/google/apis/run_v2/classes.rb', line 2403

def encryption_key_revocation_action
  @encryption_key_revocation_action
end

#encryption_key_shutdown_durationString

If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances. The minimum increment is 1 hour. Corresponds to the JSON property encryptionKeyShutdownDuration

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/run_v2/classes.rb', line 2409

def encryption_key_shutdown_duration
  @encryption_key_shutdown_duration
end

#etagString

Output only. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


2415
2416
2417
# File 'lib/google/apis/run_v2/classes.rb', line 2415

def etag
  @etag
end

#execution_environmentString

The execution environment being used to host this Revision. Corresponds to the JSON property executionEnvironment

Returns:

  • (String)


2420
2421
2422
# File 'lib/google/apis/run_v2/classes.rb', line 2420

def execution_environment
  @execution_environment
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permamently deleted. It is only populated as a response to a Delete request. Corresponds to the JSON property expireTime

Returns:

  • (String)


2426
2427
2428
# File 'lib/google/apis/run_v2/classes.rb', line 2426

def expire_time
  @expire_time
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


2432
2433
2434
# File 'lib/google/apis/run_v2/classes.rb', line 2432

def generation
  @generation
end

#gpu_zonal_redundancy_disabledBoolean Also known as: gpu_zonal_redundancy_disabled?

Optional. Output only. True if GPU zonal redundancy is disabled on this revision. Corresponds to the JSON property gpuZonalRedundancyDisabled

Returns:

  • (Boolean)


2438
2439
2440
# File 'lib/google/apis/run_v2/classes.rb', line 2438

def gpu_zonal_redundancy_disabled
  @gpu_zonal_redundancy_disabled
end

#labelsHash<String,String>

Output only. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2449
2450
2451
# File 'lib/google/apis/run_v2/classes.rb', line 2449

def labels
  @labels
end

#launch_stageString

The least stable launch stage needed to create this resource, as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and GA. Note that this value might not be what was used as input. For example, if ALPHA was provided as input in the parent resource, but only BETA and GA-level features are used, this field will be BETA. Corresponds to the JSON property launchStage

Returns:

  • (String)


2459
2460
2461
# File 'lib/google/apis/run_v2/classes.rb', line 2459

def launch_stage
  @launch_stage
end

#log_uriString

Output only. The Google Console URI to obtain logs for the Revision. Corresponds to the JSON property logUri

Returns:

  • (String)


2464
2465
2466
# File 'lib/google/apis/run_v2/classes.rb', line 2464

def log_uri
  @log_uri
end

#max_instance_request_concurrencyFixnum

Sets the maximum number of requests that each serving instance can receive. Corresponds to the JSON property maxInstanceRequestConcurrency

Returns:

  • (Fixnum)


2469
2470
2471
# File 'lib/google/apis/run_v2/classes.rb', line 2469

def max_instance_request_concurrency
  @max_instance_request_concurrency
end

#nameString

Output only. The unique name of this Revision. Corresponds to the JSON property name

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/run_v2/classes.rb', line 2474

def name
  @name
end

#node_selectorGoogle::Apis::RunV2::GoogleCloudRunV2NodeSelector

Hardware constraints configuration. Corresponds to the JSON property nodeSelector



2479
2480
2481
# File 'lib/google/apis/run_v2/classes.rb', line 2479

def node_selector
  @node_selector
end

#observed_generationFixnum

Output only. The generation of this Revision currently serving traffic. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


2486
2487
2488
# File 'lib/google/apis/run_v2/classes.rb', line 2486

def observed_generation
  @observed_generation
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether the resource's reconciliation is still in progress. See comments in Service.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2493
2494
2495
# File 'lib/google/apis/run_v2/classes.rb', line 2493

def reconciling
  @reconciling
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2499
2500
2501
# File 'lib/google/apis/run_v2/classes.rb', line 2499

def satisfies_pzs
  @satisfies_pzs
end

#scalingGoogle::Apis::RunV2::GoogleCloudRunV2RevisionScaling

Settings for revision-level scaling settings. Corresponds to the JSON property scaling



2505
2506
2507
# File 'lib/google/apis/run_v2/classes.rb', line 2505

def scaling
  @scaling
end

#scaling_statusGoogle::Apis::RunV2::GoogleCloudRunV2RevisionScalingStatus

Effective settings for the current revision Corresponds to the JSON property scalingStatus



2510
2511
2512
# File 'lib/google/apis/run_v2/classes.rb', line 2510

def scaling_status
  @scaling_status
end

#serviceString

Output only. The name of the parent service. Corresponds to the JSON property service

Returns:

  • (String)


2515
2516
2517
# File 'lib/google/apis/run_v2/classes.rb', line 2515

def service
  @service
end

#service_accountString

Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2522
2523
2524
# File 'lib/google/apis/run_v2/classes.rb', line 2522

def 
  @service_account
end

#service_meshGoogle::Apis::RunV2::GoogleCloudRunV2ServiceMesh

Settings for Cloud Service Mesh. For more information see https://cloud.google. com/service-mesh/docs/overview. Corresponds to the JSON property serviceMesh



2528
2529
2530
# File 'lib/google/apis/run_v2/classes.rb', line 2528

def service_mesh
  @service_mesh
end

#session_affinityBoolean Also known as: session_affinity?

Enable session affinity. Corresponds to the JSON property sessionAffinity

Returns:

  • (Boolean)


2533
2534
2535
# File 'lib/google/apis/run_v2/classes.rb', line 2533

def session_affinity
  @session_affinity
end

#timeoutString

Max allowed time for an instance to respond to a request. Corresponds to the JSON property timeout

Returns:

  • (String)


2539
2540
2541
# File 'lib/google/apis/run_v2/classes.rb', line 2539

def timeout
  @timeout
end

#uidString

Output only. Server assigned unique identifier for the Revision. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/run_v2/classes.rb', line 2546

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2551
2552
2553
# File 'lib/google/apis/run_v2/classes.rb', line 2551

def update_time
  @update_time
end

#volumesArray<Google::Apis::RunV2::GoogleCloudRunV2Volume>

A list of Volumes to make available to containers. Corresponds to the JSON property volumes



2556
2557
2558
# File 'lib/google/apis/run_v2/classes.rb', line 2556

def volumes
  @volumes
end

#vpc_accessGoogle::Apis::RunV2::GoogleCloudRunV2VpcAccess

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc. Corresponds to the JSON property vpcAccess



2562
2563
2564
# File 'lib/google/apis/run_v2/classes.rb', line 2562

def vpc_access
  @vpc_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
2603
2604
2605
2606
# File 'lib/google/apis/run_v2/classes.rb', line 2569

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client = args[:client] if args.key?(:client)
  @client_version = args[:client_version] if args.key?(:client_version)
  @conditions = args[:conditions] if args.key?(:conditions)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action)
  @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration)
  @etag = args[:etag] if args.key?(:etag)
  @execution_environment = args[:execution_environment] if args.key?(:execution_environment)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled)
  @labels = args[:labels] if args.key?(:labels)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency)
  @name = args[:name] if args.key?(:name)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scaling = args[:scaling] if args.key?(:scaling)
  @scaling_status = args[:scaling_status] if args.key?(:scaling_status)
  @service = args[:service] if args.key?(:service)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_mesh = args[:service_mesh] if args.key?(:service_mesh)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @timeout = args[:timeout] if args.key?(:timeout)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volumes = args[:volumes] if args.key?(:volumes)
  @vpc_access = args[:vpc_access] if args.key?(:vpc_access)
end