Class: Google::Apis::RunV2::GoogleCloudRunV2RevisionTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

RevisionTemplate describes the data a revision should have when created from a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2RevisionTemplate

Returns a new instance of GoogleCloudRunV2RevisionTemplate.



2825
2826
2827
# File 'lib/google/apis/run_v2/classes.rb', line 2825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Cloud Run API v2 does not support annotations with run.googleapis.com, cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev namespaces, and they will be rejected. All system annotations in v1 now have a corresponding field in v2 RevisionTemplate. This field follows Kubernetes annotations' namespacing, limits, and rules. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2701
2702
2703
# File 'lib/google/apis/run_v2/classes.rb', line 2701

def annotations
  @annotations
end

#clientString

Optional. Arbitrary identifier for the API client. Corresponds to the JSON property client

Returns:

  • (String)


2706
2707
2708
# File 'lib/google/apis/run_v2/classes.rb', line 2706

def client
  @client
end

#client_versionString

Optional. Arbitrary version identifier for the API client. Corresponds to the JSON property clientVersion

Returns:

  • (String)


2711
2712
2713
# File 'lib/google/apis/run_v2/classes.rb', line 2711

def client_version
  @client_version
end

#containersArray<Google::Apis::RunV2::GoogleCloudRunV2Container>

Holds the list which define the units of execution for this Revision. Corresponds to the JSON property containers



2716
2717
2718
# File 'lib/google/apis/run_v2/classes.rb', line 2716

def containers
  @containers
end

#encryption_keyString

A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google.com/run/docs/ securing/using-cmek Corresponds to the JSON property encryptionKey

Returns:

  • (String)


2723
2724
2725
# File 'lib/google/apis/run_v2/classes.rb', line 2723

def encryption_key
  @encryption_key
end

#encryption_key_revocation_actionString

Optional. The action to take if the encryption key is revoked. Corresponds to the JSON property encryptionKeyRevocationAction

Returns:

  • (String)


2728
2729
2730
# File 'lib/google/apis/run_v2/classes.rb', line 2728

def encryption_key_revocation_action
  @encryption_key_revocation_action
end

#encryption_key_shutdown_durationString

Optional. If encryption_key_revocation_action is SHUTDOWN, the duration before shutting down all instances. The minimum increment is 1 hour. Corresponds to the JSON property encryptionKeyShutdownDuration

Returns:

  • (String)


2734
2735
2736
# File 'lib/google/apis/run_v2/classes.rb', line 2734

def encryption_key_shutdown_duration
  @encryption_key_shutdown_duration
end

#execution_environmentString

Optional. The sandbox environment to host this Revision. Corresponds to the JSON property executionEnvironment

Returns:

  • (String)


2739
2740
2741
# File 'lib/google/apis/run_v2/classes.rb', line 2739

def execution_environment
  @execution_environment
end

#gpu_zonal_redundancy_disabledBoolean Also known as: gpu_zonal_redundancy_disabled?

Optional. True if GPU zonal redundancy is disabled on this revision. Corresponds to the JSON property gpuZonalRedundancyDisabled

Returns:

  • (Boolean)


2744
2745
2746
# File 'lib/google/apis/run_v2/classes.rb', line 2744

def gpu_zonal_redundancy_disabled
  @gpu_zonal_redundancy_disabled
end

#health_check_disabledBoolean Also known as: health_check_disabled?

Optional. Disables health checking containers during deployment. Corresponds to the JSON property healthCheckDisabled

Returns:

  • (Boolean)


2750
2751
2752
# File 'lib/google/apis/run_v2/classes.rb', line 2750

def health_check_disabled
  @health_check_disabled
end

#labelsHash<String,String>

Optional. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels. Cloud Run API v2 does not support labels with run.googleapis.com, cloud.googleapis.com, serving.knative.dev , or autoscaling.knative.dev namespaces, and they will be rejected. All system labels in v1 now have a corresponding field in v2 RevisionTemplate. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2764
2765
2766
# File 'lib/google/apis/run_v2/classes.rb', line 2764

def labels
  @labels
end

#max_instance_request_concurrencyFixnum

Optional. Sets the maximum number of requests that each serving instance can receive. If not specified or 0, concurrency defaults to 80 when requested `CPU

= 1and defaults to 1 when requestedCPU < 1. Corresponds to the JSON propertymaxInstanceRequestConcurrency`

Returns:

  • (Fixnum)


2771
2772
2773
# File 'lib/google/apis/run_v2/classes.rb', line 2771

def max_instance_request_concurrency
  @max_instance_request_concurrency
end

#node_selectorGoogle::Apis::RunV2::GoogleCloudRunV2NodeSelector

Hardware constraints configuration. Corresponds to the JSON property nodeSelector



2776
2777
2778
# File 'lib/google/apis/run_v2/classes.rb', line 2776

def node_selector
  @node_selector
end

#revisionString

Optional. The unique name for the revision. If this field is omitted, it will be automatically generated based on the Service name. Corresponds to the JSON property revision

Returns:

  • (String)


2782
2783
2784
# File 'lib/google/apis/run_v2/classes.rb', line 2782

def revision
  @revision
end

#scalingGoogle::Apis::RunV2::GoogleCloudRunV2RevisionScaling

Settings for revision-level scaling settings. Corresponds to the JSON property scaling



2787
2788
2789
# File 'lib/google/apis/run_v2/classes.rb', line 2787

def scaling
  @scaling
end

#service_accountString

Optional. Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. If not provided, the revision will use the project's default service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2795
2796
2797
# File 'lib/google/apis/run_v2/classes.rb', line 2795

def 
  @service_account
end

#service_meshGoogle::Apis::RunV2::GoogleCloudRunV2ServiceMesh

Settings for Cloud Service Mesh. For more information see https://cloud.google. com/service-mesh/docs/overview. Corresponds to the JSON property serviceMesh



2801
2802
2803
# File 'lib/google/apis/run_v2/classes.rb', line 2801

def service_mesh
  @service_mesh
end

#session_affinityBoolean Also known as: session_affinity?

Optional. Enable session affinity. Corresponds to the JSON property sessionAffinity

Returns:

  • (Boolean)


2806
2807
2808
# File 'lib/google/apis/run_v2/classes.rb', line 2806

def session_affinity
  @session_affinity
end

#timeoutString

Optional. Max allowed time for an instance to respond to a request. Corresponds to the JSON property timeout

Returns:

  • (String)


2812
2813
2814
# File 'lib/google/apis/run_v2/classes.rb', line 2812

def timeout
  @timeout
end

#volumesArray<Google::Apis::RunV2::GoogleCloudRunV2Volume>

Optional. A list of Volumes to make available to containers. Corresponds to the JSON property volumes



2817
2818
2819
# File 'lib/google/apis/run_v2/classes.rb', line 2817

def volumes
  @volumes
end

#vpc_accessGoogle::Apis::RunV2::GoogleCloudRunV2VpcAccess

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc. Corresponds to the JSON property vpcAccess



2823
2824
2825
# File 'lib/google/apis/run_v2/classes.rb', line 2823

def vpc_access
  @vpc_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
# File 'lib/google/apis/run_v2/classes.rb', line 2830

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client = args[:client] if args.key?(:client)
  @client_version = args[:client_version] if args.key?(:client_version)
  @containers = args[:containers] if args.key?(:containers)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @encryption_key_revocation_action = args[:encryption_key_revocation_action] if args.key?(:encryption_key_revocation_action)
  @encryption_key_shutdown_duration = args[:encryption_key_shutdown_duration] if args.key?(:encryption_key_shutdown_duration)
  @execution_environment = args[:execution_environment] if args.key?(:execution_environment)
  @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled)
  @health_check_disabled = args[:health_check_disabled] if args.key?(:health_check_disabled)
  @labels = args[:labels] if args.key?(:labels)
  @max_instance_request_concurrency = args[:max_instance_request_concurrency] if args.key?(:max_instance_request_concurrency)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @revision = args[:revision] if args.key?(:revision)
  @scaling = args[:scaling] if args.key?(:scaling)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_mesh = args[:service_mesh] if args.key?(:service_mesh)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @timeout = args[:timeout] if args.key?(:timeout)
  @volumes = args[:volumes] if args.key?(:volumes)
  @vpc_access = args[:vpc_access] if args.key?(:vpc_access)
end