Class: Google::Apis::RunV2::GoogleCloudRunV2RunJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2RunJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Request message to create a new Execution of a Job.
Instance Attribute Summary collapse
-
#etag ⇒ String
A system-generated fingerprint for this version of the resource.
-
#overrides ⇒ Google::Apis::RunV2::GoogleCloudRunV2Overrides
RunJob Overrides that contains Execution fields to be overridden.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Indicates that the request should be validated without actually deleting any resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2RunJobRequest
constructor
A new instance of GoogleCloudRunV2RunJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2RunJobRequest
Returns a new instance of GoogleCloudRunV2RunJobRequest.
2871 2872 2873 |
# File 'lib/google/apis/run_v2/classes.rb', line 2871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
A system-generated fingerprint for this version of the resource. May be used
to detect modification conflict during updates.
Corresponds to the JSON property etag
2857 2858 2859 |
# File 'lib/google/apis/run_v2/classes.rb', line 2857 def etag @etag end |
#overrides ⇒ Google::Apis::RunV2::GoogleCloudRunV2Overrides
RunJob Overrides that contains Execution fields to be overridden.
Corresponds to the JSON property overrides
2862 2863 2864 |
# File 'lib/google/apis/run_v2/classes.rb', line 2862 def overrides @overrides end |
#validate_only ⇒ Boolean Also known as: validate_only?
Indicates that the request should be validated without actually deleting any
resources.
Corresponds to the JSON property validateOnly
2868 2869 2870 |
# File 'lib/google/apis/run_v2/classes.rb', line 2868 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2876 2877 2878 2879 2880 |
# File 'lib/google/apis/run_v2/classes.rb', line 2876 def update!(**args) @etag = args[:etag] if args.key?(:etag) @overrides = args[:overrides] if args.key?(:overrides) @validate_only = args[:validate_only] if args.key?(:validate_only) end |