Class: Google::Apis::RunV2::GoogleCloudRunV2Service
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Service acts as a top-level container that manages a set of configurations and revision templates which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
-
#build_config ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildConfig
Describes the Build step of the function that builds a container from the given source.
-
#client ⇒ String
Arbitrary identifier for the API client.
-
#client_version ⇒ String
Arbitrary version identifier for the API client.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#custom_audiences ⇒ Array<String>
One or more custom audiences that you want this service to support.
-
#default_uri_disabled ⇒ Boolean
(also: #default_uri_disabled?)
Optional.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
User-provided description of the Service.
-
#etag ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#iap_enabled ⇒ Boolean
(also: #iap_enabled?)
Optional.
-
#ingress ⇒ String
Optional.
-
#invoker_iam_disabled ⇒ Boolean
(also: #invoker_iam_disabled?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#last_modifier ⇒ String
Output only.
-
#latest_created_revision ⇒ String
Output only.
-
#latest_ready_revision ⇒ String
Output only.
-
#launch_stage ⇒ String
Optional.
-
#multi_region_settings ⇒ Google::Apis::RunV2::GoogleCloudRunV2MultiRegionSettings
Settings for multi-region deployment.
-
#name ⇒ String
Identifier.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scaling ⇒ Google::Apis::RunV2::GoogleCloudRunV2ServiceScaling
Scaling settings applied at the service level rather than at the revision level.
-
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2RevisionTemplate
RevisionTemplate describes the data a revision should have when created from a template.
-
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
-
#threat_detection_enabled ⇒ Boolean
(also: #threat_detection_enabled?)
Output only.
-
#traffic ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2TrafficTarget>
Optional.
-
#traffic_statuses ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2TrafficTargetStatus>
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#uri ⇒ String
Output only.
-
#urls ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Service
constructor
A new instance of GoogleCloudRunV2Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Service
Returns a new instance of GoogleCloudRunV2Service.
3231 3232 3233 |
# File 'lib/google/apis/run_v2/classes.rb', line 3231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Unstructured key value map that may be set by external tools to
store and arbitrary metadata. They are not queryable and should be preserved
when modifying objects. Cloud Run API v2 does not support annotations with
run.googleapis.com, cloud.googleapis.com, serving.knative.dev, or
autoscaling.knative.dev namespaces, and they will be rejected in new
resources. All system annotations in v1 now have a corresponding field in v2
Service. This field follows Kubernetes annotations' namespacing, limits, and
rules.
Corresponds to the JSON property annotations
2972 2973 2974 |
# File 'lib/google/apis/run_v2/classes.rb', line 2972 def annotations @annotations end |
#binary_authorization ⇒ Google::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization
Settings for Binary Authorization feature.
Corresponds to the JSON property binaryAuthorization
2977 2978 2979 |
# File 'lib/google/apis/run_v2/classes.rb', line 2977 def @binary_authorization end |
#build_config ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildConfig
Describes the Build step of the function that builds a container from the
given source.
Corresponds to the JSON property buildConfig
2983 2984 2985 |
# File 'lib/google/apis/run_v2/classes.rb', line 2983 def build_config @build_config end |
#client ⇒ String
Arbitrary identifier for the API client.
Corresponds to the JSON property client
2988 2989 2990 |
# File 'lib/google/apis/run_v2/classes.rb', line 2988 def client @client end |
#client_version ⇒ String
Arbitrary version identifier for the API client.
Corresponds to the JSON property clientVersion
2993 2994 2995 |
# File 'lib/google/apis/run_v2/classes.rb', line 2993 def client_version @client_version end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Conditions of all other associated sub-resources. They
contain additional diagnostics information in case the Service does not reach
its Serving state. See comments in reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property conditions
3001 3002 3003 |
# File 'lib/google/apis/run_v2/classes.rb', line 3001 def conditions @conditions end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
3006 3007 3008 |
# File 'lib/google/apis/run_v2/classes.rb', line 3006 def create_time @create_time end |
#creator ⇒ String
Output only. Email address of the authenticated creator.
Corresponds to the JSON property creator
3011 3012 3013 |
# File 'lib/google/apis/run_v2/classes.rb', line 3011 def creator @creator end |
#custom_audiences ⇒ Array<String>
One or more custom audiences that you want this service to support. Specify
each custom audience as the full URL in a string. The custom audiences are
encoded in the token and used to authenticate requests. For more information,
see https://cloud.google.com/run/docs/configuring/custom-audiences.
Corresponds to the JSON property customAudiences
3019 3020 3021 |
# File 'lib/google/apis/run_v2/classes.rb', line 3019 def custom_audiences @custom_audiences end |
#default_uri_disabled ⇒ Boolean Also known as: default_uri_disabled?
Optional. Disables public resolution of the default URI of this service.
Corresponds to the JSON property defaultUriDisabled
3024 3025 3026 |
# File 'lib/google/apis/run_v2/classes.rb', line 3024 def default_uri_disabled @default_uri_disabled end |
#delete_time ⇒ String
Output only. The deletion time. It is only populated as a response to a Delete
request.
Corresponds to the JSON property deleteTime
3031 3032 3033 |
# File 'lib/google/apis/run_v2/classes.rb', line 3031 def delete_time @delete_time end |
#description ⇒ String
User-provided description of the Service. This field currently has a 512-
character limit.
Corresponds to the JSON property description
3037 3038 3039 |
# File 'lib/google/apis/run_v2/classes.rb', line 3037 def description @description end |
#etag ⇒ String
Optional. A system-generated fingerprint for this version of the resource. May
be used to detect modification conflict during updates.
Corresponds to the JSON property etag
3043 3044 3045 |
# File 'lib/google/apis/run_v2/classes.rb', line 3043 def etag @etag end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permanently deleted.
Corresponds to the JSON property expireTime
3049 3050 3051 |
# File 'lib/google/apis/run_v2/classes.rb', line 3049 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state. Please note that unlike v1, this is an int64 value.
As with most Google APIs, its JSON representation will be a string instead
of an integer.
Corresponds to the JSON property generation
3057 3058 3059 |
# File 'lib/google/apis/run_v2/classes.rb', line 3057 def generation @generation end |
#iap_enabled ⇒ Boolean Also known as: iap_enabled?
Optional. IAP settings on the Service.
Corresponds to the JSON property iapEnabled
3062 3063 3064 |
# File 'lib/google/apis/run_v2/classes.rb', line 3062 def iap_enabled @iap_enabled end |
#ingress ⇒ String
Optional. Provides the ingress settings for this Service. On output, returns
the currently observed ingress settings, or INGRESS_TRAFFIC_UNSPECIFIED if no
revision is active.
Corresponds to the JSON property ingress
3070 3071 3072 |
# File 'lib/google/apis/run_v2/classes.rb', line 3070 def ingress @ingress end |
#invoker_iam_disabled ⇒ Boolean Also known as: invoker_iam_disabled?
Optional. Disables IAM permission check for run.routes.invoke for callers of
this service. For more information, visit https://cloud.google.com/run/docs/
securing/managing-access#invoker_check.
Corresponds to the JSON property invokerIamDisabled
3077 3078 3079 |
# File 'lib/google/apis/run_v2/classes.rb', line 3077 def invoker_iam_disabled @invoker_iam_disabled end |
#labels ⇒ Hash<String,String>
Optional. Unstructured key value map that can be used to organize and
categorize objects. User-provided labels are shared with Google's billing
system, so they can be used to filter, or break down billing charges by team,
component, environment, state, etc. For more information, visit https://cloud.
google.com/resource-manager/docs/creating-managing-labels or https://cloud.
google.com/run/docs/configuring/labels. Cloud Run API v2 does not support
labels with run.googleapis.com, cloud.googleapis.com, serving.knative.dev
, or autoscaling.knative.dev namespaces, and they will be rejected. All
system labels in v1 now have a corresponding field in v2 Service.
Corresponds to the JSON property labels
3091 3092 3093 |
# File 'lib/google/apis/run_v2/classes.rb', line 3091 def labels @labels end |
#last_modifier ⇒ String
Output only. Email address of the last authenticated modifier.
Corresponds to the JSON property lastModifier
3096 3097 3098 |
# File 'lib/google/apis/run_v2/classes.rb', line 3096 def last_modifier @last_modifier end |
#latest_created_revision ⇒ String
Output only. Name of the last created revision. See comments in reconciling
for additional information on reconciliation process in Cloud Run.
Corresponds to the JSON property latestCreatedRevision
3102 3103 3104 |
# File 'lib/google/apis/run_v2/classes.rb', line 3102 def latest_created_revision @latest_created_revision end |
#latest_ready_revision ⇒ String
Output only. Name of the latest revision that is serving traffic. See comments
in reconciling for additional information on reconciliation process in Cloud
Run.
Corresponds to the JSON property latestReadyRevision
3109 3110 3111 |
# File 'lib/google/apis/run_v2/classes.rb', line 3109 def latest_ready_revision @latest_ready_revision end |
#launch_stage ⇒ String
Optional. The launch stage as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA,
BETA, and GA. If no value is specified, GA is assumed. Set the launch stage
to a preview stage on input to allow use of preview features in that stage. On
read (or output), describes whether the resource uses preview features. For
example, if ALPHA is provided as input, but only BETA and GA-level features
are used, this field will be BETA on output.
Corresponds to the JSON property launchStage
3120 3121 3122 |
# File 'lib/google/apis/run_v2/classes.rb', line 3120 def launch_stage @launch_stage end |
#multi_region_settings ⇒ Google::Apis::RunV2::GoogleCloudRunV2MultiRegionSettings
Settings for multi-region deployment.
Corresponds to the JSON property multiRegionSettings
3125 3126 3127 |
# File 'lib/google/apis/run_v2/classes.rb', line 3125 def multi_region_settings @multi_region_settings end |
#name ⇒ String
Identifier. The fully qualified name of this Service. In CreateServiceRequest,
this field is ignored, and instead composed from CreateServiceRequest.parent
and CreateServiceRequest.service_id. Format: projects/project/locations/
location/services/service_id
Corresponds to the JSON property name
3133 3134 3135 |
# File 'lib/google/apis/run_v2/classes.rb', line 3133 def name @name end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Service currently serving traffic. See
comments in reconciling for additional information on reconciliation process
in Cloud Run. Please note that unlike v1, this is an int64 value. As with most
Google APIs, its JSON representation will be a string instead of an integer
.
Corresponds to the JSON property observedGeneration
3142 3143 3144 |
# File 'lib/google/apis/run_v2/classes.rb', line 3142 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Returns true if the Service is currently being acted upon by the
system to bring it into the desired state. When a new Service is created, or
an existing one is updated, Cloud Run will asynchronously perform all
necessary steps to bring the Service to the desired serving state. This
process is called reconciliation. While reconciliation is in process,
observed_generation, latest_ready_revision, traffic_statuses, and uri
will have transient values that might mismatch the intended state: Once
reconciliation is over (and this field is false), there are two possible
outcomes: reconciliation succeeded and the serving state matches the Service,
or there was an error, and reconciliation failed. This state can be found in
terminal_condition.state. If reconciliation succeeded, the following fields
will match: traffic and traffic_statuses, observed_generation and
generation, latest_ready_revision and latest_created_revision. If
reconciliation failed, traffic_statuses, observed_generation, and
latest_ready_revision will have the state of the last serving revision, or
empty for newly created Services. Additional information on the failure can be
found in terminal_condition and conditions.
Corresponds to the JSON property reconciling
3163 3164 3165 |
# File 'lib/google/apis/run_v2/classes.rb', line 3163 def reconciling @reconciling end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
3169 3170 3171 |
# File 'lib/google/apis/run_v2/classes.rb', line 3169 def satisfies_pzs @satisfies_pzs end |
#scaling ⇒ Google::Apis::RunV2::GoogleCloudRunV2ServiceScaling
Scaling settings applied at the service level rather than at the revision
level.
Corresponds to the JSON property scaling
3176 3177 3178 |
# File 'lib/google/apis/run_v2/classes.rb', line 3176 def scaling @scaling end |
#template ⇒ Google::Apis::RunV2::GoogleCloudRunV2RevisionTemplate
RevisionTemplate describes the data a revision should have when created from a
template.
Corresponds to the JSON property template
3182 3183 3184 |
# File 'lib/google/apis/run_v2/classes.rb', line 3182 def template @template end |
#terminal_condition ⇒ Google::Apis::RunV2::GoogleCloudRunV2Condition
Defines a status condition for a resource.
Corresponds to the JSON property terminalCondition
3187 3188 3189 |
# File 'lib/google/apis/run_v2/classes.rb', line 3187 def terminal_condition @terminal_condition end |
#threat_detection_enabled ⇒ Boolean Also known as: threat_detection_enabled?
Output only. True if Cloud Run Threat Detection monitoring is enabled for the
parent project of this Service.
Corresponds to the JSON property threatDetectionEnabled
3193 3194 3195 |
# File 'lib/google/apis/run_v2/classes.rb', line 3193 def threat_detection_enabled @threat_detection_enabled end |
#traffic ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2TrafficTarget>
Optional. Specifies how to distribute traffic over a collection of Revisions
belonging to the Service. If traffic is empty or not provided, defaults to 100%
traffic to the latest Ready Revision.
Corresponds to the JSON property traffic
3201 3202 3203 |
# File 'lib/google/apis/run_v2/classes.rb', line 3201 def traffic @traffic end |
#traffic_statuses ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2TrafficTargetStatus>
Output only. Detailed status information for corresponding traffic targets.
See comments in reconciling for additional information on reconciliation
process in Cloud Run.
Corresponds to the JSON property trafficStatuses
3208 3209 3210 |
# File 'lib/google/apis/run_v2/classes.rb', line 3208 def traffic_statuses @traffic_statuses end |
#uid ⇒ String
Output only. Server assigned unique identifier for the trigger. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
3214 3215 3216 |
# File 'lib/google/apis/run_v2/classes.rb', line 3214 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
3219 3220 3221 |
# File 'lib/google/apis/run_v2/classes.rb', line 3219 def update_time @update_time end |
#uri ⇒ String
Output only. The main URI in which this Service is serving traffic.
Corresponds to the JSON property uri
3224 3225 3226 |
# File 'lib/google/apis/run_v2/classes.rb', line 3224 def uri @uri end |
#urls ⇒ Array<String>
Output only. All URLs serving traffic for this Service.
Corresponds to the JSON property urls
3229 3230 3231 |
# File 'lib/google/apis/run_v2/classes.rb', line 3229 def urls @urls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 |
# File 'lib/google/apis/run_v2/classes.rb', line 3236 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization) @build_config = args[:build_config] if args.key?(:build_config) @client = args[:client] if args.key?(:client) @client_version = args[:client_version] if args.key?(:client_version) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @custom_audiences = args[:custom_audiences] if args.key?(:custom_audiences) @default_uri_disabled = args[:default_uri_disabled] if args.key?(:default_uri_disabled) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @iap_enabled = args[:iap_enabled] if args.key?(:iap_enabled) @ingress = args[:ingress] if args.key?(:ingress) @invoker_iam_disabled = args[:invoker_iam_disabled] if args.key?(:invoker_iam_disabled) @labels = args[:labels] if args.key?(:labels) @last_modifier = args[:last_modifier] if args.key?(:last_modifier) @latest_created_revision = args[:latest_created_revision] if args.key?(:latest_created_revision) @latest_ready_revision = args[:latest_ready_revision] if args.key?(:latest_ready_revision) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @multi_region_settings = args[:multi_region_settings] if args.key?(:multi_region_settings) @name = args[:name] if args.key?(:name) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scaling = args[:scaling] if args.key?(:scaling) @template = args[:template] if args.key?(:template) @terminal_condition = args[:terminal_condition] if args.key?(:terminal_condition) @threat_detection_enabled = args[:threat_detection_enabled] if args.key?(:threat_detection_enabled) @traffic = args[:traffic] if args.key?(:traffic) @traffic_statuses = args[:traffic_statuses] if args.key?(:traffic_statuses) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) @urls = args[:urls] if args.key?(:urls) end |