Class: Google::Apis::RunV2::GoogleCloudRunV2Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Service acts as a top-level container that manages a set of configurations and revision templates which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Service

Returns a new instance of GoogleCloudRunV2Service.



2792
2793
2794
# File 'lib/google/apis/run_v2/classes.rb', line 2792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Cloud Run API v2 does not support annotations with run.googleapis.com, cloud.googleapis.com, serving.knative.dev, or autoscaling.knative.dev namespaces, and they will be rejected in new resources. All system annotations in v1 now have a corresponding field in v2 Service. This field follows Kubernetes annotations' namespacing, limits, and rules. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2533
2534
2535
# File 'lib/google/apis/run_v2/classes.rb', line 2533

def annotations
  @annotations
end

#binary_authorizationGoogle::Apis::RunV2::GoogleCloudRunV2BinaryAuthorization

Settings for Binary Authorization feature. Corresponds to the JSON property binaryAuthorization



2538
2539
2540
# File 'lib/google/apis/run_v2/classes.rb', line 2538

def binary_authorization
  @binary_authorization
end

#build_configGoogle::Apis::RunV2::GoogleCloudRunV2BuildConfig

Describes the Build step of the function that builds a container from the given source. Corresponds to the JSON property buildConfig



2544
2545
2546
# File 'lib/google/apis/run_v2/classes.rb', line 2544

def build_config
  @build_config
end

#clientString

Arbitrary identifier for the API client. Corresponds to the JSON property client

Returns:

  • (String)


2549
2550
2551
# File 'lib/google/apis/run_v2/classes.rb', line 2549

def client
  @client
end

#client_versionString

Arbitrary version identifier for the API client. Corresponds to the JSON property clientVersion

Returns:

  • (String)


2554
2555
2556
# File 'lib/google/apis/run_v2/classes.rb', line 2554

def client_version
  @client_version
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Conditions of all other associated sub-resources. They contain additional diagnostics information in case the Service does not reach its Serving state. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property conditions



2562
2563
2564
# File 'lib/google/apis/run_v2/classes.rb', line 2562

def conditions
  @conditions
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


2567
2568
2569
# File 'lib/google/apis/run_v2/classes.rb', line 2567

def create_time
  @create_time
end

#creatorString

Output only. Email address of the authenticated creator. Corresponds to the JSON property creator

Returns:

  • (String)


2572
2573
2574
# File 'lib/google/apis/run_v2/classes.rb', line 2572

def creator
  @creator
end

#custom_audiencesArray<String>

One or more custom audiences that you want this service to support. Specify each custom audience as the full URL in a string. The custom audiences are encoded in the token and used to authenticate requests. For more information, see https://cloud.google.com/run/docs/configuring/custom-audiences. Corresponds to the JSON property customAudiences

Returns:

  • (Array<String>)


2580
2581
2582
# File 'lib/google/apis/run_v2/classes.rb', line 2580

def custom_audiences
  @custom_audiences
end

#default_uri_disabledBoolean Also known as: default_uri_disabled?

Optional. Disables public resolution of the default URI of this service. Corresponds to the JSON property defaultUriDisabled

Returns:

  • (Boolean)


2585
2586
2587
# File 'lib/google/apis/run_v2/classes.rb', line 2585

def default_uri_disabled
  @default_uri_disabled
end

#delete_timeString

Output only. The deletion time. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


2592
2593
2594
# File 'lib/google/apis/run_v2/classes.rb', line 2592

def delete_time
  @delete_time
end

#descriptionString

User-provided description of the Service. This field currently has a 512- character limit. Corresponds to the JSON property description

Returns:

  • (String)


2598
2599
2600
# File 'lib/google/apis/run_v2/classes.rb', line 2598

def description
  @description
end

#etagString

Optional. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


2604
2605
2606
# File 'lib/google/apis/run_v2/classes.rb', line 2604

def etag
  @etag
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permanently deleted. Corresponds to the JSON property expireTime

Returns:

  • (String)


2610
2611
2612
# File 'lib/google/apis/run_v2/classes.rb', line 2610

def expire_time
  @expire_time
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Please note that unlike v1, this is an int64 value. As with most Google APIs, its JSON representation will be a string instead of an integer. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


2618
2619
2620
# File 'lib/google/apis/run_v2/classes.rb', line 2618

def generation
  @generation
end

#iap_enabledBoolean Also known as: iap_enabled?

Optional. IAP settings on the Service. Corresponds to the JSON property iapEnabled

Returns:

  • (Boolean)


2623
2624
2625
# File 'lib/google/apis/run_v2/classes.rb', line 2623

def iap_enabled
  @iap_enabled
end

#ingressString

Optional. Provides the ingress settings for this Service. On output, returns the currently observed ingress settings, or INGRESS_TRAFFIC_UNSPECIFIED if no revision is active. Corresponds to the JSON property ingress

Returns:

  • (String)


2631
2632
2633
# File 'lib/google/apis/run_v2/classes.rb', line 2631

def ingress
  @ingress
end

#invoker_iam_disabledBoolean Also known as: invoker_iam_disabled?

Optional. Disables IAM permission check for run.routes.invoke for callers of this service. For more information, visit https://cloud.google.com/run/docs/ securing/managing-access#invoker_check. Corresponds to the JSON property invokerIamDisabled

Returns:

  • (Boolean)


2638
2639
2640
# File 'lib/google/apis/run_v2/classes.rb', line 2638

def invoker_iam_disabled
  @invoker_iam_disabled
end

#labelsHash<String,String>

Optional. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels. Cloud Run API v2 does not support labels with run.googleapis.com, cloud.googleapis.com, serving.knative.dev , or autoscaling.knative.dev namespaces, and they will be rejected. All system labels in v1 now have a corresponding field in v2 Service. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2652
2653
2654
# File 'lib/google/apis/run_v2/classes.rb', line 2652

def labels
  @labels
end

#last_modifierString

Output only. Email address of the last authenticated modifier. Corresponds to the JSON property lastModifier

Returns:

  • (String)


2657
2658
2659
# File 'lib/google/apis/run_v2/classes.rb', line 2657

def last_modifier
  @last_modifier
end

#latest_created_revisionString

Output only. Name of the last created revision. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property latestCreatedRevision

Returns:

  • (String)


2663
2664
2665
# File 'lib/google/apis/run_v2/classes.rb', line 2663

def latest_created_revision
  @latest_created_revision
end

#latest_ready_revisionString

Output only. Name of the latest revision that is serving traffic. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property latestReadyRevision

Returns:

  • (String)


2670
2671
2672
# File 'lib/google/apis/run_v2/classes.rb', line 2670

def latest_ready_revision
  @latest_ready_revision
end

#launch_stageString

Optional. The launch stage as defined by Google Cloud Platform Launch Stages. Cloud Run supports ALPHA, BETA, and GA. If no value is specified, GA is assumed. Set the launch stage to a preview stage on input to allow use of preview features in that stage. On read (or output), describes whether the resource uses preview features. For example, if ALPHA is provided as input, but only BETA and GA-level features are used, this field will be BETA on output. Corresponds to the JSON property launchStage

Returns:

  • (String)


2681
2682
2683
# File 'lib/google/apis/run_v2/classes.rb', line 2681

def launch_stage
  @launch_stage
end

#multi_region_settingsGoogle::Apis::RunV2::GoogleCloudRunV2MultiRegionSettings

Settings for multi-region deployment. Corresponds to the JSON property multiRegionSettings



2686
2687
2688
# File 'lib/google/apis/run_v2/classes.rb', line 2686

def multi_region_settings
  @multi_region_settings
end

#nameString

Identifier. The fully qualified name of this Service. In CreateServiceRequest, this field is ignored, and instead composed from CreateServiceRequest.parent and CreateServiceRequest.service_id. Format: projects/project/locations/ location/services/service_id Corresponds to the JSON property name

Returns:

  • (String)


2694
2695
2696
# File 'lib/google/apis/run_v2/classes.rb', line 2694

def name
  @name
end

#observed_generationFixnum

Output only. The generation of this Service currently serving traffic. See comments in reconciling for additional information on reconciliation process in Cloud Run. Please note that unlike v1, this is an int64 value. As with most Google APIs, its JSON representation will be a string instead of an integer . Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


2703
2704
2705
# File 'lib/google/apis/run_v2/classes.rb', line 2703

def observed_generation
  @observed_generation
end

#reconcilingBoolean Also known as: reconciling?

Output only. Returns true if the Service is currently being acted upon by the system to bring it into the desired state. When a new Service is created, or an existing one is updated, Cloud Run will asynchronously perform all necessary steps to bring the Service to the desired serving state. This process is called reconciliation. While reconciliation is in process, observed_generation, latest_ready_revision, traffic_statuses, and uri will have transient values that might mismatch the intended state: Once reconciliation is over (and this field is false), there are two possible outcomes: reconciliation succeeded and the serving state matches the Service, or there was an error, and reconciliation failed. This state can be found in terminal_condition.state. If reconciliation succeeded, the following fields will match: traffic and traffic_statuses, observed_generation and generation, latest_ready_revision and latest_created_revision. If reconciliation failed, traffic_statuses, observed_generation, and latest_ready_revision will have the state of the last serving revision, or empty for newly created Services. Additional information on the failure can be found in terminal_condition and conditions. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2724
2725
2726
# File 'lib/google/apis/run_v2/classes.rb', line 2724

def reconciling
  @reconciling
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2730
2731
2732
# File 'lib/google/apis/run_v2/classes.rb', line 2730

def satisfies_pzs
  @satisfies_pzs
end

#scalingGoogle::Apis::RunV2::GoogleCloudRunV2ServiceScaling

Scaling settings applied at the service level rather than at the revision level. Corresponds to the JSON property scaling



2737
2738
2739
# File 'lib/google/apis/run_v2/classes.rb', line 2737

def scaling
  @scaling
end

#templateGoogle::Apis::RunV2::GoogleCloudRunV2RevisionTemplate

RevisionTemplate describes the data a revision should have when created from a template. Corresponds to the JSON property template



2743
2744
2745
# File 'lib/google/apis/run_v2/classes.rb', line 2743

def template
  @template
end

#terminal_conditionGoogle::Apis::RunV2::GoogleCloudRunV2Condition

Defines a status condition for a resource. Corresponds to the JSON property terminalCondition



2748
2749
2750
# File 'lib/google/apis/run_v2/classes.rb', line 2748

def terminal_condition
  @terminal_condition
end

#threat_detection_enabledBoolean Also known as: threat_detection_enabled?

Output only. True if Cloud Run Threat Detection monitoring is enabled for the parent project of this Service. Corresponds to the JSON property threatDetectionEnabled

Returns:

  • (Boolean)


2754
2755
2756
# File 'lib/google/apis/run_v2/classes.rb', line 2754

def threat_detection_enabled
  @threat_detection_enabled
end

#trafficArray<Google::Apis::RunV2::GoogleCloudRunV2TrafficTarget>

Optional. Specifies how to distribute traffic over a collection of Revisions belonging to the Service. If traffic is empty or not provided, defaults to 100% traffic to the latest Ready Revision. Corresponds to the JSON property traffic



2762
2763
2764
# File 'lib/google/apis/run_v2/classes.rb', line 2762

def traffic
  @traffic
end

#traffic_statusesArray<Google::Apis::RunV2::GoogleCloudRunV2TrafficTargetStatus>

Output only. Detailed status information for corresponding traffic targets. See comments in reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property trafficStatuses



2769
2770
2771
# File 'lib/google/apis/run_v2/classes.rb', line 2769

def traffic_statuses
  @traffic_statuses
end

#uidString

Output only. Server assigned unique identifier for the trigger. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


2775
2776
2777
# File 'lib/google/apis/run_v2/classes.rb', line 2775

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2780
2781
2782
# File 'lib/google/apis/run_v2/classes.rb', line 2780

def update_time
  @update_time
end

#uriString

Output only. The main URI in which this Service is serving traffic. Corresponds to the JSON property uri

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/run_v2/classes.rb', line 2785

def uri
  @uri
end

#urlsArray<String>

Output only. All URLs serving traffic for this Service. Corresponds to the JSON property urls

Returns:

  • (Array<String>)


2790
2791
2792
# File 'lib/google/apis/run_v2/classes.rb', line 2790

def urls
  @urls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
# File 'lib/google/apis/run_v2/classes.rb', line 2797

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @binary_authorization = args[:binary_authorization] if args.key?(:binary_authorization)
  @build_config = args[:build_config] if args.key?(:build_config)
  @client = args[:client] if args.key?(:client)
  @client_version = args[:client_version] if args.key?(:client_version)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @custom_audiences = args[:custom_audiences] if args.key?(:custom_audiences)
  @default_uri_disabled = args[:default_uri_disabled] if args.key?(:default_uri_disabled)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @iap_enabled = args[:iap_enabled] if args.key?(:iap_enabled)
  @ingress = args[:ingress] if args.key?(:ingress)
  @invoker_iam_disabled = args[:invoker_iam_disabled] if args.key?(:invoker_iam_disabled)
  @labels = args[:labels] if args.key?(:labels)
  @last_modifier = args[:last_modifier] if args.key?(:last_modifier)
  @latest_created_revision = args[:latest_created_revision] if args.key?(:latest_created_revision)
  @latest_ready_revision = args[:latest_ready_revision] if args.key?(:latest_ready_revision)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @multi_region_settings = args[:multi_region_settings] if args.key?(:multi_region_settings)
  @name = args[:name] if args.key?(:name)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scaling = args[:scaling] if args.key?(:scaling)
  @template = args[:template] if args.key?(:template)
  @terminal_condition = args[:terminal_condition] if args.key?(:terminal_condition)
  @threat_detection_enabled = args[:threat_detection_enabled] if args.key?(:threat_detection_enabled)
  @traffic = args[:traffic] if args.key?(:traffic)
  @traffic_statuses = args[:traffic_statuses] if args.key?(:traffic_statuses)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
  @urls = args[:urls] if args.key?(:urls)
end