Class: Google::Apis::RunV2::GoogleCloudRunV2ServiceScaling
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2ServiceScaling
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Scaling settings applied at the service level rather than at the revision level.
Instance Attribute Summary collapse
-
#manual_instance_count ⇒ Fixnum
Optional.
-
#max_instance_count ⇒ Fixnum
Optional.
-
#min_instance_count ⇒ Fixnum
Optional.
-
#scaling_mode ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2ServiceScaling
constructor
A new instance of GoogleCloudRunV2ServiceScaling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2ServiceScaling
Returns a new instance of GoogleCloudRunV2ServiceScaling.
3343 3344 3345 |
# File 'lib/google/apis/run_v2/classes.rb', line 3343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#manual_instance_count ⇒ Fixnum
Optional. total instance count for the service in manual scaling mode. This
number of instances is divided among all revisions with specified traffic
based on the percent of traffic they are receiving.
Corresponds to the JSON property manualInstanceCount
3322 3323 3324 |
# File 'lib/google/apis/run_v2/classes.rb', line 3322 def manual_instance_count @manual_instance_count end |
#max_instance_count ⇒ Fixnum
Optional. total max instances for the service. This number of instances is
divided among all revisions with specified traffic based on the percent of
traffic they are receiving.
Corresponds to the JSON property maxInstanceCount
3329 3330 3331 |
# File 'lib/google/apis/run_v2/classes.rb', line 3329 def max_instance_count @max_instance_count end |
#min_instance_count ⇒ Fixnum
Optional. total min instances for the service. This number of instances is
divided among all revisions with specified traffic based on the percent of
traffic they are receiving.
Corresponds to the JSON property minInstanceCount
3336 3337 3338 |
# File 'lib/google/apis/run_v2/classes.rb', line 3336 def min_instance_count @min_instance_count end |
#scaling_mode ⇒ String
Optional. The scaling mode for the service.
Corresponds to the JSON property scalingMode
3341 3342 3343 |
# File 'lib/google/apis/run_v2/classes.rb', line 3341 def scaling_mode @scaling_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3348 3349 3350 3351 3352 3353 |
# File 'lib/google/apis/run_v2/classes.rb', line 3348 def update!(**args) @manual_instance_count = args[:manual_instance_count] if args.key?(:manual_instance_count) @max_instance_count = args[:max_instance_count] if args.key?(:max_instance_count) @min_instance_count = args[:min_instance_count] if args.key?(:min_instance_count) @scaling_mode = args[:scaling_mode] if args.key?(:scaling_mode) end |