Class: Google::Apis::RunV2::GoogleCloudRunV2StartInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2StartInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Request message for starting an Instance.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2StartInstanceRequest
constructor
A new instance of GoogleCloudRunV2StartInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2StartInstanceRequest
Returns a new instance of GoogleCloudRunV2StartInstanceRequest.
3417 3418 3419 |
# File 'lib/google/apis/run_v2/classes.rb', line 3417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. A system-generated fingerprint for this version of the resource.
This may be used to detect modification conflict during updates.
Corresponds to the JSON property etag
3408 3409 3410 |
# File 'lib/google/apis/run_v2/classes.rb', line 3408 def etag @etag end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. Indicates that the request should be validated without actually
stopping any resources.
Corresponds to the JSON property validateOnly
3414 3415 3416 |
# File 'lib/google/apis/run_v2/classes.rb', line 3414 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3422 3423 3424 3425 |
# File 'lib/google/apis/run_v2/classes.rb', line 3422 def update!(**args) @etag = args[:etag] if args.key?(:etag) @validate_only = args[:validate_only] if args.key?(:validate_only) end |