Class: Google::Apis::RunV2::GoogleCloudRunV2StopInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2StopInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Request message for deleting an Instance.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#validate_only ⇒ Boolean
(also: #validate_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2StopInstanceRequest
constructor
A new instance of GoogleCloudRunV2StopInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2StopInstanceRequest
Returns a new instance of GoogleCloudRunV2StopInstanceRequest.
3445 3446 3447 |
# File 'lib/google/apis/run_v2/classes.rb', line 3445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. A system-generated fingerprint for this version of the resource.
This may be used to detect modification conflict during updates.
Corresponds to the JSON property etag
3436 3437 3438 |
# File 'lib/google/apis/run_v2/classes.rb', line 3436 def etag @etag end |
#validate_only ⇒ Boolean Also known as: validate_only?
Optional. Indicates that the request should be validated without actually
stopping any resources.
Corresponds to the JSON property validateOnly
3442 3443 3444 |
# File 'lib/google/apis/run_v2/classes.rb', line 3442 def validate_only @validate_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3450 3451 3452 3453 |
# File 'lib/google/apis/run_v2/classes.rb', line 3450 def update!(**args) @etag = args[:etag] if args.key?(:etag) @validate_only = args[:validate_only] if args.key?(:validate_only) end |