Class: Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Request message for submitting a Build.
Instance Attribute Summary collapse
-
#buildpack_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildpacksBuild
Build the source using Buildpacks.
-
#client ⇒ String
Optional.
-
#docker_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2DockerBuild
Build the source using Docker.
-
#image_uri ⇒ String
Required.
-
#machine_type ⇒ String
Optional.
-
#release_track ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
-
#storage_source ⇒ Google::Apis::RunV2::GoogleCloudRunV2StorageSource
Location of the source in an archive file in Google Cloud Storage.
-
#tags ⇒ Array<String>
Optional.
-
#worker_pool ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildRequest
constructor
A new instance of GoogleCloudRunV2SubmitBuildRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildRequest
Returns a new instance of GoogleCloudRunV2SubmitBuildRequest.
3559 3560 3561 |
# File 'lib/google/apis/run_v2/classes.rb', line 3559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buildpack_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildpacksBuild
Build the source using Buildpacks.
Corresponds to the JSON property buildpackBuild
3505 3506 3507 |
# File 'lib/google/apis/run_v2/classes.rb', line 3505 def buildpack_build @buildpack_build end |
#client ⇒ String
Optional. The client that initiated the build request.
Corresponds to the JSON property client
3510 3511 3512 |
# File 'lib/google/apis/run_v2/classes.rb', line 3510 def client @client end |
#docker_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2DockerBuild
Build the source using Docker. This means the source has a Dockerfile.
Corresponds to the JSON property dockerBuild
3515 3516 3517 |
# File 'lib/google/apis/run_v2/classes.rb', line 3515 def docker_build @docker_build end |
#image_uri ⇒ String
Required. Artifact Registry URI to store the built image.
Corresponds to the JSON property imageUri
3520 3521 3522 |
# File 'lib/google/apis/run_v2/classes.rb', line 3520 def image_uri @image_uri end |
#machine_type ⇒ String
Optional. The machine type from default pool to use for the build. If left
blank, cloudbuild will use a sensible default. Currently only E2_HIGHCPU_8 is
supported. If worker_pool is set, this field will be ignored.
Corresponds to the JSON property machineType
3527 3528 3529 |
# File 'lib/google/apis/run_v2/classes.rb', line 3527 def machine_type @machine_type end |
#release_track ⇒ String
Optional. The release track of the client that initiated the build request.
Corresponds to the JSON property releaseTrack
3532 3533 3534 |
# File 'lib/google/apis/run_v2/classes.rb', line 3532 def release_track @release_track end |
#service_account ⇒ String
Optional. The service account to use for the build. If not set, the default
Cloud Build service account for the project will be used.
Corresponds to the JSON property serviceAccount
3538 3539 3540 |
# File 'lib/google/apis/run_v2/classes.rb', line 3538 def service_account @service_account end |
#storage_source ⇒ Google::Apis::RunV2::GoogleCloudRunV2StorageSource
Location of the source in an archive file in Google Cloud Storage.
Corresponds to the JSON property storageSource
3543 3544 3545 |
# File 'lib/google/apis/run_v2/classes.rb', line 3543 def storage_source @storage_source end |
#tags ⇒ Array<String>
Optional. Additional tags to annotate the build.
Corresponds to the JSON property tags
3548 3549 3550 |
# File 'lib/google/apis/run_v2/classes.rb', line 3548 def @tags end |
#worker_pool ⇒ String
Optional. Name of the Cloud Build Custom Worker Pool that should be used to
build the function. The format of this field is projects/project/locations/
region/workerPools/workerPoolwhereprojectandregionare the
project id and region respectively where the worker pool is defined and
workerPool`is the short name of the worker pool.
Corresponds to the JSON propertyworkerPool`
3557 3558 3559 |
# File 'lib/google/apis/run_v2/classes.rb', line 3557 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 |
# File 'lib/google/apis/run_v2/classes.rb', line 3564 def update!(**args) @buildpack_build = args[:buildpack_build] if args.key?(:buildpack_build) @client = args[:client] if args.key?(:client) @docker_build = args[:docker_build] if args.key?(:docker_build) @image_uri = args[:image_uri] if args.key?(:image_uri) @machine_type = args[:machine_type] if args.key?(:machine_type) @release_track = args[:release_track] if args.key?(:release_track) @service_account = args[:service_account] if args.key?(:service_account) @storage_source = args[:storage_source] if args.key?(:storage_source) @tags = args[:tags] if args.key?(:tags) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |