Class: Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildRequest
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Request message for submitting a Build.
Instance Attribute Summary collapse
-
#buildpack_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildpacksBuild
Build the source using Buildpacks.
-
#client ⇒ String
Optional.
-
#docker_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2DockerBuild
Build the source using Docker.
-
#image_uri ⇒ String
Required.
-
#machine_type ⇒ String
Optional.
-
#release_track ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
-
#storage_source ⇒ Google::Apis::RunV2::GoogleCloudRunV2StorageSource
Location of the source in an archive file in Google Cloud Storage.
-
#tags ⇒ Array<String>
Optional.
-
#worker_pool ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildRequest
constructor
A new instance of GoogleCloudRunV2SubmitBuildRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildRequest
Returns a new instance of GoogleCloudRunV2SubmitBuildRequest.
3019 3020 3021 |
# File 'lib/google/apis/run_v2/classes.rb', line 3019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buildpack_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2BuildpacksBuild
Build the source using Buildpacks.
Corresponds to the JSON property buildpackBuild
2965 2966 2967 |
# File 'lib/google/apis/run_v2/classes.rb', line 2965 def buildpack_build @buildpack_build end |
#client ⇒ String
Optional. The client that initiated the build request.
Corresponds to the JSON property client
2970 2971 2972 |
# File 'lib/google/apis/run_v2/classes.rb', line 2970 def client @client end |
#docker_build ⇒ Google::Apis::RunV2::GoogleCloudRunV2DockerBuild
Build the source using Docker. This means the source has a Dockerfile.
Corresponds to the JSON property dockerBuild
2975 2976 2977 |
# File 'lib/google/apis/run_v2/classes.rb', line 2975 def docker_build @docker_build end |
#image_uri ⇒ String
Required. Artifact Registry URI to store the built image.
Corresponds to the JSON property imageUri
2980 2981 2982 |
# File 'lib/google/apis/run_v2/classes.rb', line 2980 def image_uri @image_uri end |
#machine_type ⇒ String
Optional. The machine type from default pool to use for the build. If left
blank, cloudbuild will use a sensible default. Currently only E2_HIGHCPU_8 is
supported. If worker_pool is set, this field will be ignored.
Corresponds to the JSON property machineType
2987 2988 2989 |
# File 'lib/google/apis/run_v2/classes.rb', line 2987 def machine_type @machine_type end |
#release_track ⇒ String
Optional. The release track of the client that initiated the build request.
Corresponds to the JSON property releaseTrack
2992 2993 2994 |
# File 'lib/google/apis/run_v2/classes.rb', line 2992 def release_track @release_track end |
#service_account ⇒ String
Optional. The service account to use for the build. If not set, the default
Cloud Build service account for the project will be used.
Corresponds to the JSON property serviceAccount
2998 2999 3000 |
# File 'lib/google/apis/run_v2/classes.rb', line 2998 def service_account @service_account end |
#storage_source ⇒ Google::Apis::RunV2::GoogleCloudRunV2StorageSource
Location of the source in an archive file in Google Cloud Storage.
Corresponds to the JSON property storageSource
3003 3004 3005 |
# File 'lib/google/apis/run_v2/classes.rb', line 3003 def storage_source @storage_source end |
#tags ⇒ Array<String>
Optional. Additional tags to annotate the build.
Corresponds to the JSON property tags
3008 3009 3010 |
# File 'lib/google/apis/run_v2/classes.rb', line 3008 def @tags end |
#worker_pool ⇒ String
Optional. Name of the Cloud Build Custom Worker Pool that should be used to
build the function. The format of this field is projects/project/locations/
region/workerPools/workerPoolwhereprojectandregionare the
project id and region respectively where the worker pool is defined and
workerPool`is the short name of the worker pool.
Corresponds to the JSON propertyworkerPool`
3017 3018 3019 |
# File 'lib/google/apis/run_v2/classes.rb', line 3017 def worker_pool @worker_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 |
# File 'lib/google/apis/run_v2/classes.rb', line 3024 def update!(**args) @buildpack_build = args[:buildpack_build] if args.key?(:buildpack_build) @client = args[:client] if args.key?(:client) @docker_build = args[:docker_build] if args.key?(:docker_build) @image_uri = args[:image_uri] if args.key?(:image_uri) @machine_type = args[:machine_type] if args.key?(:machine_type) @release_track = args[:release_track] if args.key?(:release_track) @service_account = args[:service_account] if args.key?(:service_account) @storage_source = args[:storage_source] if args.key?(:storage_source) @tags = args[:tags] if args.key?(:tags) @worker_pool = args[:worker_pool] if args.key?(:worker_pool) end |