Class: Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2SubmitBuildResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Response message for submitting a Build.
Instance Attribute Summary collapse
-
#base_image_uri ⇒ String
URI of the base builder image in Artifact Registry being used in the build.
-
#base_image_warning ⇒ String
Warning message for the base image.
-
#build_operation ⇒ Google::Apis::RunV2::GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a network API call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildResponse
constructor
A new instance of GoogleCloudRunV2SubmitBuildResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2SubmitBuildResponse
Returns a new instance of GoogleCloudRunV2SubmitBuildResponse.
3592 3593 3594 |
# File 'lib/google/apis/run_v2/classes.rb', line 3592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_image_uri ⇒ String
URI of the base builder image in Artifact Registry being used in the build.
Used to opt into automatic base image updates.
Corresponds to the JSON property baseImageUri
3579 3580 3581 |
# File 'lib/google/apis/run_v2/classes.rb', line 3579 def base_image_uri @base_image_uri end |
#base_image_warning ⇒ String
Warning message for the base image.
Corresponds to the JSON property baseImageWarning
3584 3585 3586 |
# File 'lib/google/apis/run_v2/classes.rb', line 3584 def base_image_warning @base_image_warning end |
#build_operation ⇒ Google::Apis::RunV2::GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a
network API call.
Corresponds to the JSON property buildOperation
3590 3591 3592 |
# File 'lib/google/apis/run_v2/classes.rb', line 3590 def build_operation @build_operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3597 3598 3599 3600 3601 |
# File 'lib/google/apis/run_v2/classes.rb', line 3597 def update!(**args) @base_image_uri = args[:base_image_uri] if args.key?(:base_image_uri) @base_image_warning = args[:base_image_warning] if args.key?(:base_image_warning) @build_operation = args[:build_operation] if args.key?(:build_operation) end |