Class: Google::Apis::RunV2::GoogleCloudRunV2Task
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Task
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Task represents a single run of a container to completion.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Output only.
-
#completion_time ⇒ String
Output only.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Holds the single container that defines the unit of execution for this task.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#encryption_key ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#execution ⇒ String
Output only.
-
#execution_environment ⇒ String
The execution environment being used to host this Task.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#gpu_zonal_redundancy_disabled ⇒ Boolean
(also: #gpu_zonal_redundancy_disabled?)
Optional.
-
#index ⇒ Fixnum
Output only.
-
#job ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#last_attempt_result ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult
Result of a task attempt.
-
#log_uri ⇒ String
Output only.
-
#max_retries ⇒ Fixnum
Number of retries allowed per Task, before marking this Task failed.
-
#name ⇒ String
Output only.
-
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#retried ⇒ Fixnum
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduled_time ⇒ String
Output only.
-
#service_account ⇒ String
Email address of the IAM service account associated with the Task of a Job.
-
#start_time ⇒ String
Output only.
-
#timeout ⇒ String
Max allowed time duration the Task may be active before the system will actively try to mark it failed and kill associated containers.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
-
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Task
constructor
A new instance of GoogleCloudRunV2Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Task
Returns a new instance of GoogleCloudRunV2Task.
3840 3841 3842 |
# File 'lib/google/apis/run_v2/classes.rb', line 3840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Output only. Unstructured key value map that may be set by external tools to
store and arbitrary metadata. They are not queryable and should be preserved
when modifying objects.
Corresponds to the JSON property annotations
3647 3648 3649 |
# File 'lib/google/apis/run_v2/classes.rb', line 3647 def annotations @annotations end |
#completion_time ⇒ String
Output only. Represents time when the Task was completed. It is not guaranteed
to be set in happens-before order across separate operations.
Corresponds to the JSON property completionTime
3653 3654 3655 |
# File 'lib/google/apis/run_v2/classes.rb', line 3653 def completion_time @completion_time end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Condition of this Task, containing its readiness status, and
detailed error information in case it did not reach the desired state.
Corresponds to the JSON property conditions
3659 3660 3661 |
# File 'lib/google/apis/run_v2/classes.rb', line 3659 def conditions @conditions end |
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Holds the single container that defines the unit of execution for this task.
Corresponds to the JSON property containers
3664 3665 3666 |
# File 'lib/google/apis/run_v2/classes.rb', line 3664 def containers @containers end |
#create_time ⇒ String
Output only. Represents time when the task was created by the system. It is
not guaranteed to be set in happens-before order across separate operations.
Corresponds to the JSON property createTime
3670 3671 3672 |
# File 'lib/google/apis/run_v2/classes.rb', line 3670 def create_time @create_time end |
#delete_time ⇒ String
Output only. For a deleted resource, the deletion time. It is only populated
as a response to a Delete request.
Corresponds to the JSON property deleteTime
3676 3677 3678 |
# File 'lib/google/apis/run_v2/classes.rb', line 3676 def delete_time @delete_time end |
#encryption_key ⇒ String
Output only. A reference to a customer managed encryption key (CMEK) to use to
encrypt this container image. For more information, go to https://cloud.google.
com/run/docs/securing/using-cmek
Corresponds to the JSON property encryptionKey
3683 3684 3685 |
# File 'lib/google/apis/run_v2/classes.rb', line 3683 def encryption_key @encryption_key end |
#etag ⇒ String
Output only. A system-generated fingerprint for this version of the resource.
May be used to detect modification conflict during updates.
Corresponds to the JSON property etag
3689 3690 3691 |
# File 'lib/google/apis/run_v2/classes.rb', line 3689 def etag @etag end |
#execution ⇒ String
Output only. The name of the parent Execution.
Corresponds to the JSON property execution
3694 3695 3696 |
# File 'lib/google/apis/run_v2/classes.rb', line 3694 def execution @execution end |
#execution_environment ⇒ String
The execution environment being used to host this Task.
Corresponds to the JSON property executionEnvironment
3699 3700 3701 |
# File 'lib/google/apis/run_v2/classes.rb', line 3699 def execution_environment @execution_environment end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permamently deleted. It is only populated as a response to a Delete request.
Corresponds to the JSON property expireTime
3705 3706 3707 |
# File 'lib/google/apis/run_v2/classes.rb', line 3705 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state.
Corresponds to the JSON property generation
3711 3712 3713 |
# File 'lib/google/apis/run_v2/classes.rb', line 3711 def generation @generation end |
#gpu_zonal_redundancy_disabled ⇒ Boolean Also known as: gpu_zonal_redundancy_disabled?
Optional. Output only. True if GPU zonal redundancy is disabled on this task.
Corresponds to the JSON property gpuZonalRedundancyDisabled
3716 3717 3718 |
# File 'lib/google/apis/run_v2/classes.rb', line 3716 def gpu_zonal_redundancy_disabled @gpu_zonal_redundancy_disabled end |
#index ⇒ Fixnum
Output only. Index of the Task, unique per execution, and beginning at 0.
Corresponds to the JSON property index
3722 3723 3724 |
# File 'lib/google/apis/run_v2/classes.rb', line 3722 def index @index end |
#job ⇒ String
Output only. The name of the parent Job.
Corresponds to the JSON property job
3727 3728 3729 |
# File 'lib/google/apis/run_v2/classes.rb', line 3727 def job @job end |
#labels ⇒ Hash<String,String>
Output only. Unstructured key value map that can be used to organize and
categorize objects. User-provided labels are shared with Google's billing
system, so they can be used to filter, or break down billing charges by team,
component, environment, state, etc. For more information, visit https://cloud.
google.com/resource-manager/docs/creating-managing-labels or https://cloud.
google.com/run/docs/configuring/labels
Corresponds to the JSON property labels
3737 3738 3739 |
# File 'lib/google/apis/run_v2/classes.rb', line 3737 def labels @labels end |
#last_attempt_result ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult
Result of a task attempt.
Corresponds to the JSON property lastAttemptResult
3742 3743 3744 |
# File 'lib/google/apis/run_v2/classes.rb', line 3742 def last_attempt_result @last_attempt_result end |
#log_uri ⇒ String
Output only. URI where logs for this execution can be found in Cloud Console.
Corresponds to the JSON property logUri
3747 3748 3749 |
# File 'lib/google/apis/run_v2/classes.rb', line 3747 def log_uri @log_uri end |
#max_retries ⇒ Fixnum
Number of retries allowed per Task, before marking this Task failed.
Corresponds to the JSON property maxRetries
3752 3753 3754 |
# File 'lib/google/apis/run_v2/classes.rb', line 3752 def max_retries @max_retries end |
#name ⇒ String
Output only. The unique name of this Task.
Corresponds to the JSON property name
3757 3758 3759 |
# File 'lib/google/apis/run_v2/classes.rb', line 3757 def name @name end |
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
Corresponds to the JSON property nodeSelector
3762 3763 3764 |
# File 'lib/google/apis/run_v2/classes.rb', line 3762 def node_selector @node_selector end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Task. See comments in Job.reconciling
for additional information on reconciliation process in Cloud Run.
Corresponds to the JSON property observedGeneration
3768 3769 3770 |
# File 'lib/google/apis/run_v2/classes.rb', line 3768 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether the resource's reconciliation is still in
progress. See comments in Job.reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property reconciling
3775 3776 3777 |
# File 'lib/google/apis/run_v2/classes.rb', line 3775 def reconciling @reconciling end |
#retried ⇒ Fixnum
Output only. The number of times this Task was retried. Tasks are retried when
they fail up to the maxRetries limit.
Corresponds to the JSON property retried
3782 3783 3784 |
# File 'lib/google/apis/run_v2/classes.rb', line 3782 def retried @retried end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
3787 3788 3789 |
# File 'lib/google/apis/run_v2/classes.rb', line 3787 def satisfies_pzs @satisfies_pzs end |
#scheduled_time ⇒ String
Output only. Represents time when the task was scheduled to run by the system.
It is not guaranteed to be set in happens-before order across separate
operations.
Corresponds to the JSON property scheduledTime
3795 3796 3797 |
# File 'lib/google/apis/run_v2/classes.rb', line 3795 def scheduled_time @scheduled_time end |
#service_account ⇒ String
Email address of the IAM service account associated with the Task of a Job.
The service account represents the identity of the running task, and
determines what permissions the task has. If not provided, the task will use
the project's default service account.
Corresponds to the JSON property serviceAccount
3803 3804 3805 |
# File 'lib/google/apis/run_v2/classes.rb', line 3803 def service_account @service_account end |
#start_time ⇒ String
Output only. Represents time when the task started to run. It is not
guaranteed to be set in happens-before order across separate operations.
Corresponds to the JSON property startTime
3809 3810 3811 |
# File 'lib/google/apis/run_v2/classes.rb', line 3809 def start_time @start_time end |
#timeout ⇒ String
Max allowed time duration the Task may be active before the system will
actively try to mark it failed and kill associated containers. This applies
per attempt of a task, meaning each retry can run for the full timeout.
Corresponds to the JSON property timeout
3816 3817 3818 |
# File 'lib/google/apis/run_v2/classes.rb', line 3816 def timeout @timeout end |
#uid ⇒ String
Output only. Server assigned unique identifier for the Task. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
3822 3823 3824 |
# File 'lib/google/apis/run_v2/classes.rb', line 3822 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
3827 3828 3829 |
# File 'lib/google/apis/run_v2/classes.rb', line 3827 def update_time @update_time end |
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
Corresponds to the JSON property volumes
3832 3833 3834 |
# File 'lib/google/apis/run_v2/classes.rb', line 3832 def volumes @volumes end |
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings. For more information on sending traffic to a VPC network,
visit https://cloud.google.com/run/docs/configuring/connecting-vpc.
Corresponds to the JSON property vpcAccess
3838 3839 3840 |
# File 'lib/google/apis/run_v2/classes.rb', line 3838 def vpc_access @vpc_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3845 3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/google/apis/run_v2/classes.rb', line 3845 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @completion_time = args[:completion_time] if args.key?(:completion_time) @conditions = args[:conditions] if args.key?(:conditions) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @etag = args[:etag] if args.key?(:etag) @execution = args[:execution] if args.key?(:execution) @execution_environment = args[:execution_environment] if args.key?(:execution_environment) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled) @index = args[:index] if args.key?(:index) @job = args[:job] if args.key?(:job) @labels = args[:labels] if args.key?(:labels) @last_attempt_result = args[:last_attempt_result] if args.key?(:last_attempt_result) @log_uri = args[:log_uri] if args.key?(:log_uri) @max_retries = args[:max_retries] if args.key?(:max_retries) @name = args[:name] if args.key?(:name) @node_selector = args[:node_selector] if args.key?(:node_selector) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @retried = args[:retried] if args.key?(:retried) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @timeout = args[:timeout] if args.key?(:timeout) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @volumes = args[:volumes] if args.key?(:volumes) @vpc_access = args[:vpc_access] if args.key?(:vpc_access) end |