Class: Google::Apis::RunV2::GoogleCloudRunV2Task

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Task represents a single run of a container to completion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Task

Returns a new instance of GoogleCloudRunV2Task.



3872
3873
3874
# File 'lib/google/apis/run_v2/classes.rb', line 3872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Output only. Unstructured key value map that may be set by external tools to store and arbitrary metadata. They are not queryable and should be preserved when modifying objects. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


3679
3680
3681
# File 'lib/google/apis/run_v2/classes.rb', line 3679

def annotations
  @annotations
end

#completion_timeString

Output only. Represents time when the Task was completed. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property completionTime

Returns:

  • (String)


3685
3686
3687
# File 'lib/google/apis/run_v2/classes.rb', line 3685

def completion_time
  @completion_time
end

#conditionsArray<Google::Apis::RunV2::GoogleCloudRunV2Condition>

Output only. The Condition of this Task, containing its readiness status, and detailed error information in case it did not reach the desired state. Corresponds to the JSON property conditions



3691
3692
3693
# File 'lib/google/apis/run_v2/classes.rb', line 3691

def conditions
  @conditions
end

#containersArray<Google::Apis::RunV2::GoogleCloudRunV2Container>

Holds the single container that defines the unit of execution for this task. Corresponds to the JSON property containers



3696
3697
3698
# File 'lib/google/apis/run_v2/classes.rb', line 3696

def containers
  @containers
end

#create_timeString

Output only. Represents time when the task was created by the system. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property createTime

Returns:

  • (String)


3702
3703
3704
# File 'lib/google/apis/run_v2/classes.rb', line 3702

def create_time
  @create_time
end

#delete_timeString

Output only. For a deleted resource, the deletion time. It is only populated as a response to a Delete request. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3708
3709
3710
# File 'lib/google/apis/run_v2/classes.rb', line 3708

def delete_time
  @delete_time
end

#encryption_keyString

Output only. A reference to a customer managed encryption key (CMEK) to use to encrypt this container image. For more information, go to https://cloud.google. com/run/docs/securing/using-cmek Corresponds to the JSON property encryptionKey

Returns:

  • (String)


3715
3716
3717
# File 'lib/google/apis/run_v2/classes.rb', line 3715

def encryption_key
  @encryption_key
end

#etagString

Output only. A system-generated fingerprint for this version of the resource. May be used to detect modification conflict during updates. Corresponds to the JSON property etag

Returns:

  • (String)


3721
3722
3723
# File 'lib/google/apis/run_v2/classes.rb', line 3721

def etag
  @etag
end

#executionString

Output only. The name of the parent Execution. Corresponds to the JSON property execution

Returns:

  • (String)


3726
3727
3728
# File 'lib/google/apis/run_v2/classes.rb', line 3726

def execution
  @execution
end

#execution_environmentString

The execution environment being used to host this Task. Corresponds to the JSON property executionEnvironment

Returns:

  • (String)


3731
3732
3733
# File 'lib/google/apis/run_v2/classes.rb', line 3731

def execution_environment
  @execution_environment
end

#expire_timeString

Output only. For a deleted resource, the time after which it will be permamently deleted. It is only populated as a response to a Delete request. Corresponds to the JSON property expireTime

Returns:

  • (String)


3737
3738
3739
# File 'lib/google/apis/run_v2/classes.rb', line 3737

def expire_time
  @expire_time
end

#generationFixnum

Output only. A number that monotonically increases every time the user modifies the desired state. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


3743
3744
3745
# File 'lib/google/apis/run_v2/classes.rb', line 3743

def generation
  @generation
end

#gpu_zonal_redundancy_disabledBoolean Also known as: gpu_zonal_redundancy_disabled?

Optional. Output only. True if GPU zonal redundancy is disabled on this task. Corresponds to the JSON property gpuZonalRedundancyDisabled

Returns:

  • (Boolean)


3748
3749
3750
# File 'lib/google/apis/run_v2/classes.rb', line 3748

def gpu_zonal_redundancy_disabled
  @gpu_zonal_redundancy_disabled
end

#indexFixnum

Output only. Index of the Task, unique per execution, and beginning at 0. Corresponds to the JSON property index

Returns:

  • (Fixnum)


3754
3755
3756
# File 'lib/google/apis/run_v2/classes.rb', line 3754

def index
  @index
end

#jobString

Output only. The name of the parent Job. Corresponds to the JSON property job

Returns:

  • (String)


3759
3760
3761
# File 'lib/google/apis/run_v2/classes.rb', line 3759

def job
  @job
end

#labelsHash<String,String>

Output only. Unstructured key value map that can be used to organize and categorize objects. User-provided labels are shared with Google's billing system, so they can be used to filter, or break down billing charges by team, component, environment, state, etc. For more information, visit https://cloud. google.com/resource-manager/docs/creating-managing-labels or https://cloud. google.com/run/docs/configuring/labels Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3769
3770
3771
# File 'lib/google/apis/run_v2/classes.rb', line 3769

def labels
  @labels
end

#last_attempt_resultGoogle::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult

Result of a task attempt. Corresponds to the JSON property lastAttemptResult



3774
3775
3776
# File 'lib/google/apis/run_v2/classes.rb', line 3774

def last_attempt_result
  @last_attempt_result
end

#log_uriString

Output only. URI where logs for this execution can be found in Cloud Console. Corresponds to the JSON property logUri

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/run_v2/classes.rb', line 3779

def log_uri
  @log_uri
end

#max_retriesFixnum

Number of retries allowed per Task, before marking this Task failed. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


3784
3785
3786
# File 'lib/google/apis/run_v2/classes.rb', line 3784

def max_retries
  @max_retries
end

#nameString

Output only. The unique name of this Task. Corresponds to the JSON property name

Returns:

  • (String)


3789
3790
3791
# File 'lib/google/apis/run_v2/classes.rb', line 3789

def name
  @name
end

#node_selectorGoogle::Apis::RunV2::GoogleCloudRunV2NodeSelector

Hardware constraints configuration. Corresponds to the JSON property nodeSelector



3794
3795
3796
# File 'lib/google/apis/run_v2/classes.rb', line 3794

def node_selector
  @node_selector
end

#observed_generationFixnum

Output only. The generation of this Task. See comments in Job.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property observedGeneration

Returns:

  • (Fixnum)


3800
3801
3802
# File 'lib/google/apis/run_v2/classes.rb', line 3800

def observed_generation
  @observed_generation
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether the resource's reconciliation is still in progress. See comments in Job.reconciling for additional information on reconciliation process in Cloud Run. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3807
3808
3809
# File 'lib/google/apis/run_v2/classes.rb', line 3807

def reconciling
  @reconciling
end

#retriedFixnum

Output only. The number of times this Task was retried. Tasks are retried when they fail up to the maxRetries limit. Corresponds to the JSON property retried

Returns:

  • (Fixnum)


3814
3815
3816
# File 'lib/google/apis/run_v2/classes.rb', line 3814

def retried
  @retried
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


3819
3820
3821
# File 'lib/google/apis/run_v2/classes.rb', line 3819

def satisfies_pzs
  @satisfies_pzs
end

#scheduled_timeString

Output only. Represents time when the task was scheduled to run by the system. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property scheduledTime

Returns:

  • (String)


3827
3828
3829
# File 'lib/google/apis/run_v2/classes.rb', line 3827

def scheduled_time
  @scheduled_time
end

#service_accountString

Email address of the IAM service account associated with the Task of a Job. The service account represents the identity of the running task, and determines what permissions the task has. If not provided, the task will use the project's default service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3835
3836
3837
# File 'lib/google/apis/run_v2/classes.rb', line 3835

def 
  @service_account
end

#start_timeString

Output only. Represents time when the task started to run. It is not guaranteed to be set in happens-before order across separate operations. Corresponds to the JSON property startTime

Returns:

  • (String)


3841
3842
3843
# File 'lib/google/apis/run_v2/classes.rb', line 3841

def start_time
  @start_time
end

#timeoutString

Max allowed time duration the Task may be active before the system will actively try to mark it failed and kill associated containers. This applies per attempt of a task, meaning each retry can run for the full timeout. Corresponds to the JSON property timeout

Returns:

  • (String)


3848
3849
3850
# File 'lib/google/apis/run_v2/classes.rb', line 3848

def timeout
  @timeout
end

#uidString

Output only. Server assigned unique identifier for the Task. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


3854
3855
3856
# File 'lib/google/apis/run_v2/classes.rb', line 3854

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


3859
3860
3861
# File 'lib/google/apis/run_v2/classes.rb', line 3859

def update_time
  @update_time
end

#volumesArray<Google::Apis::RunV2::GoogleCloudRunV2Volume>

A list of Volumes to make available to containers. Corresponds to the JSON property volumes



3864
3865
3866
# File 'lib/google/apis/run_v2/classes.rb', line 3864

def volumes
  @volumes
end

#vpc_accessGoogle::Apis::RunV2::GoogleCloudRunV2VpcAccess

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc. Corresponds to the JSON property vpcAccess



3870
3871
3872
# File 'lib/google/apis/run_v2/classes.rb', line 3870

def vpc_access
  @vpc_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3877
3878
3879
3880
3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
3908
3909
3910
3911
# File 'lib/google/apis/run_v2/classes.rb', line 3877

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @conditions = args[:conditions] if args.key?(:conditions)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @encryption_key = args[:encryption_key] if args.key?(:encryption_key)
  @etag = args[:etag] if args.key?(:etag)
  @execution = args[:execution] if args.key?(:execution)
  @execution_environment = args[:execution_environment] if args.key?(:execution_environment)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @generation = args[:generation] if args.key?(:generation)
  @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled)
  @index = args[:index] if args.key?(:index)
  @job = args[:job] if args.key?(:job)
  @labels = args[:labels] if args.key?(:labels)
  @last_attempt_result = args[:last_attempt_result] if args.key?(:last_attempt_result)
  @log_uri = args[:log_uri] if args.key?(:log_uri)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
  @name = args[:name] if args.key?(:name)
  @node_selector = args[:node_selector] if args.key?(:node_selector)
  @observed_generation = args[:observed_generation] if args.key?(:observed_generation)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @retried = args[:retried] if args.key?(:retried)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @timeout = args[:timeout] if args.key?(:timeout)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @volumes = args[:volumes] if args.key?(:volumes)
  @vpc_access = args[:vpc_access] if args.key?(:vpc_access)
end