Class: Google::Apis::RunV2::GoogleCloudRunV2Task
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Task
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Task represents a single run of a container to completion.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Output only.
-
#completion_time ⇒ String
Output only.
-
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only.
-
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Holds the single container that defines the unit of execution for this task.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#encryption_key ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#execution ⇒ String
Output only.
-
#execution_environment ⇒ String
The execution environment being used to host this Task.
-
#expire_time ⇒ String
Output only.
-
#generation ⇒ Fixnum
Output only.
-
#gpu_zonal_redundancy_disabled ⇒ Boolean
(also: #gpu_zonal_redundancy_disabled?)
Optional.
-
#index ⇒ Fixnum
Output only.
-
#job ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#last_attempt_result ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult
Result of a task attempt.
-
#log_uri ⇒ String
Output only.
-
#max_retries ⇒ Fixnum
Number of retries allowed per Task, before marking this Task failed.
-
#name ⇒ String
Output only.
-
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
-
#observed_generation ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#retried ⇒ Fixnum
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduled_time ⇒ String
Output only.
-
#service_account ⇒ String
Email address of the IAM service account associated with the Task of a Job.
-
#start_time ⇒ String
Output only.
-
#timeout ⇒ String
Max allowed time duration the Task may be active before the system will actively try to mark it failed and kill associated containers.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
-
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Task
constructor
A new instance of GoogleCloudRunV2Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Task
Returns a new instance of GoogleCloudRunV2Task.
3294 3295 3296 |
# File 'lib/google/apis/run_v2/classes.rb', line 3294 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Output only. Unstructured key value map that may be set by external tools to
store and arbitrary metadata. They are not queryable and should be preserved
when modifying objects.
Corresponds to the JSON property annotations
3101 3102 3103 |
# File 'lib/google/apis/run_v2/classes.rb', line 3101 def annotations @annotations end |
#completion_time ⇒ String
Output only. Represents time when the Task was completed. It is not guaranteed
to be set in happens-before order across separate operations.
Corresponds to the JSON property completionTime
3107 3108 3109 |
# File 'lib/google/apis/run_v2/classes.rb', line 3107 def completion_time @completion_time end |
#conditions ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Condition>
Output only. The Condition of this Task, containing its readiness status, and
detailed error information in case it did not reach the desired state.
Corresponds to the JSON property conditions
3113 3114 3115 |
# File 'lib/google/apis/run_v2/classes.rb', line 3113 def conditions @conditions end |
#containers ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Container>
Holds the single container that defines the unit of execution for this task.
Corresponds to the JSON property containers
3118 3119 3120 |
# File 'lib/google/apis/run_v2/classes.rb', line 3118 def containers @containers end |
#create_time ⇒ String
Output only. Represents time when the task was created by the system. It is
not guaranteed to be set in happens-before order across separate operations.
Corresponds to the JSON property createTime
3124 3125 3126 |
# File 'lib/google/apis/run_v2/classes.rb', line 3124 def create_time @create_time end |
#delete_time ⇒ String
Output only. For a deleted resource, the deletion time. It is only populated
as a response to a Delete request.
Corresponds to the JSON property deleteTime
3130 3131 3132 |
# File 'lib/google/apis/run_v2/classes.rb', line 3130 def delete_time @delete_time end |
#encryption_key ⇒ String
Output only. A reference to a customer managed encryption key (CMEK) to use to
encrypt this container image. For more information, go to https://cloud.google.
com/run/docs/securing/using-cmek
Corresponds to the JSON property encryptionKey
3137 3138 3139 |
# File 'lib/google/apis/run_v2/classes.rb', line 3137 def encryption_key @encryption_key end |
#etag ⇒ String
Output only. A system-generated fingerprint for this version of the resource.
May be used to detect modification conflict during updates.
Corresponds to the JSON property etag
3143 3144 3145 |
# File 'lib/google/apis/run_v2/classes.rb', line 3143 def etag @etag end |
#execution ⇒ String
Output only. The name of the parent Execution.
Corresponds to the JSON property execution
3148 3149 3150 |
# File 'lib/google/apis/run_v2/classes.rb', line 3148 def execution @execution end |
#execution_environment ⇒ String
The execution environment being used to host this Task.
Corresponds to the JSON property executionEnvironment
3153 3154 3155 |
# File 'lib/google/apis/run_v2/classes.rb', line 3153 def execution_environment @execution_environment end |
#expire_time ⇒ String
Output only. For a deleted resource, the time after which it will be
permamently deleted. It is only populated as a response to a Delete request.
Corresponds to the JSON property expireTime
3159 3160 3161 |
# File 'lib/google/apis/run_v2/classes.rb', line 3159 def expire_time @expire_time end |
#generation ⇒ Fixnum
Output only. A number that monotonically increases every time the user
modifies the desired state.
Corresponds to the JSON property generation
3165 3166 3167 |
# File 'lib/google/apis/run_v2/classes.rb', line 3165 def generation @generation end |
#gpu_zonal_redundancy_disabled ⇒ Boolean Also known as: gpu_zonal_redundancy_disabled?
Optional. Output only. True if GPU zonal redundancy is disabled on this task.
Corresponds to the JSON property gpuZonalRedundancyDisabled
3170 3171 3172 |
# File 'lib/google/apis/run_v2/classes.rb', line 3170 def gpu_zonal_redundancy_disabled @gpu_zonal_redundancy_disabled end |
#index ⇒ Fixnum
Output only. Index of the Task, unique per execution, and beginning at 0.
Corresponds to the JSON property index
3176 3177 3178 |
# File 'lib/google/apis/run_v2/classes.rb', line 3176 def index @index end |
#job ⇒ String
Output only. The name of the parent Job.
Corresponds to the JSON property job
3181 3182 3183 |
# File 'lib/google/apis/run_v2/classes.rb', line 3181 def job @job end |
#labels ⇒ Hash<String,String>
Output only. Unstructured key value map that can be used to organize and
categorize objects. User-provided labels are shared with Google's billing
system, so they can be used to filter, or break down billing charges by team,
component, environment, state, etc. For more information, visit https://cloud.
google.com/resource-manager/docs/creating-managing-labels or https://cloud.
google.com/run/docs/configuring/labels
Corresponds to the JSON property labels
3191 3192 3193 |
# File 'lib/google/apis/run_v2/classes.rb', line 3191 def labels @labels end |
#last_attempt_result ⇒ Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult
Result of a task attempt.
Corresponds to the JSON property lastAttemptResult
3196 3197 3198 |
# File 'lib/google/apis/run_v2/classes.rb', line 3196 def last_attempt_result @last_attempt_result end |
#log_uri ⇒ String
Output only. URI where logs for this execution can be found in Cloud Console.
Corresponds to the JSON property logUri
3201 3202 3203 |
# File 'lib/google/apis/run_v2/classes.rb', line 3201 def log_uri @log_uri end |
#max_retries ⇒ Fixnum
Number of retries allowed per Task, before marking this Task failed.
Corresponds to the JSON property maxRetries
3206 3207 3208 |
# File 'lib/google/apis/run_v2/classes.rb', line 3206 def max_retries @max_retries end |
#name ⇒ String
Output only. The unique name of this Task.
Corresponds to the JSON property name
3211 3212 3213 |
# File 'lib/google/apis/run_v2/classes.rb', line 3211 def name @name end |
#node_selector ⇒ Google::Apis::RunV2::GoogleCloudRunV2NodeSelector
Hardware constraints configuration.
Corresponds to the JSON property nodeSelector
3216 3217 3218 |
# File 'lib/google/apis/run_v2/classes.rb', line 3216 def node_selector @node_selector end |
#observed_generation ⇒ Fixnum
Output only. The generation of this Task. See comments in Job.reconciling
for additional information on reconciliation process in Cloud Run.
Corresponds to the JSON property observedGeneration
3222 3223 3224 |
# File 'lib/google/apis/run_v2/classes.rb', line 3222 def observed_generation @observed_generation end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Indicates whether the resource's reconciliation is still in
progress. See comments in Job.reconciling for additional information on
reconciliation process in Cloud Run.
Corresponds to the JSON property reconciling
3229 3230 3231 |
# File 'lib/google/apis/run_v2/classes.rb', line 3229 def reconciling @reconciling end |
#retried ⇒ Fixnum
Output only. The number of times this Task was retried. Tasks are retried when
they fail up to the maxRetries limit.
Corresponds to the JSON property retried
3236 3237 3238 |
# File 'lib/google/apis/run_v2/classes.rb', line 3236 def retried @retried end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
3241 3242 3243 |
# File 'lib/google/apis/run_v2/classes.rb', line 3241 def satisfies_pzs @satisfies_pzs end |
#scheduled_time ⇒ String
Output only. Represents time when the task was scheduled to run by the system.
It is not guaranteed to be set in happens-before order across separate
operations.
Corresponds to the JSON property scheduledTime
3249 3250 3251 |
# File 'lib/google/apis/run_v2/classes.rb', line 3249 def scheduled_time @scheduled_time end |
#service_account ⇒ String
Email address of the IAM service account associated with the Task of a Job.
The service account represents the identity of the running task, and
determines what permissions the task has. If not provided, the task will use
the project's default service account.
Corresponds to the JSON property serviceAccount
3257 3258 3259 |
# File 'lib/google/apis/run_v2/classes.rb', line 3257 def service_account @service_account end |
#start_time ⇒ String
Output only. Represents time when the task started to run. It is not
guaranteed to be set in happens-before order across separate operations.
Corresponds to the JSON property startTime
3263 3264 3265 |
# File 'lib/google/apis/run_v2/classes.rb', line 3263 def start_time @start_time end |
#timeout ⇒ String
Max allowed time duration the Task may be active before the system will
actively try to mark it failed and kill associated containers. This applies
per attempt of a task, meaning each retry can run for the full timeout.
Corresponds to the JSON property timeout
3270 3271 3272 |
# File 'lib/google/apis/run_v2/classes.rb', line 3270 def timeout @timeout end |
#uid ⇒ String
Output only. Server assigned unique identifier for the Task. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
3276 3277 3278 |
# File 'lib/google/apis/run_v2/classes.rb', line 3276 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
3281 3282 3283 |
# File 'lib/google/apis/run_v2/classes.rb', line 3281 def update_time @update_time end |
#volumes ⇒ Array<Google::Apis::RunV2::GoogleCloudRunV2Volume>
A list of Volumes to make available to containers.
Corresponds to the JSON property volumes
3286 3287 3288 |
# File 'lib/google/apis/run_v2/classes.rb', line 3286 def volumes @volumes end |
#vpc_access ⇒ Google::Apis::RunV2::GoogleCloudRunV2VpcAccess
VPC Access settings. For more information on sending traffic to a VPC network,
visit https://cloud.google.com/run/docs/configuring/connecting-vpc.
Corresponds to the JSON property vpcAccess
3292 3293 3294 |
# File 'lib/google/apis/run_v2/classes.rb', line 3292 def vpc_access @vpc_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/google/apis/run_v2/classes.rb', line 3299 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @completion_time = args[:completion_time] if args.key?(:completion_time) @conditions = args[:conditions] if args.key?(:conditions) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @encryption_key = args[:encryption_key] if args.key?(:encryption_key) @etag = args[:etag] if args.key?(:etag) @execution = args[:execution] if args.key?(:execution) @execution_environment = args[:execution_environment] if args.key?(:execution_environment) @expire_time = args[:expire_time] if args.key?(:expire_time) @generation = args[:generation] if args.key?(:generation) @gpu_zonal_redundancy_disabled = args[:gpu_zonal_redundancy_disabled] if args.key?(:gpu_zonal_redundancy_disabled) @index = args[:index] if args.key?(:index) @job = args[:job] if args.key?(:job) @labels = args[:labels] if args.key?(:labels) @last_attempt_result = args[:last_attempt_result] if args.key?(:last_attempt_result) @log_uri = args[:log_uri] if args.key?(:log_uri) @max_retries = args[:max_retries] if args.key?(:max_retries) @name = args[:name] if args.key?(:name) @node_selector = args[:node_selector] if args.key?(:node_selector) @observed_generation = args[:observed_generation] if args.key?(:observed_generation) @reconciling = args[:reconciling] if args.key?(:reconciling) @retried = args[:retried] if args.key?(:retried) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduled_time = args[:scheduled_time] if args.key?(:scheduled_time) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @timeout = args[:timeout] if args.key?(:timeout) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @volumes = args[:volumes] if args.key?(:volumes) @vpc_access = args[:vpc_access] if args.key?(:vpc_access) end |