Class: Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Result of a task attempt.
Instance Attribute Summary collapse
-
#exit_code ⇒ Fixnum
Output only.
-
#status ⇒ Google::Apis::RunV2::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#term_signal ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2TaskAttemptResult
constructor
A new instance of GoogleCloudRunV2TaskAttemptResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2TaskAttemptResult
Returns a new instance of GoogleCloudRunV2TaskAttemptResult.
3898 3899 3900 |
# File 'lib/google/apis/run_v2/classes.rb', line 3898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exit_code ⇒ Fixnum
Output only. The exit code of this attempt. This may be unset if the container
was unable to exit cleanly with a code due to some other failure. See status
field for possible failure details. At most one of exit_code or term_signal
will be set.
Corresponds to the JSON property exitCode
3879 3880 3881 |
# File 'lib/google/apis/run_v2/classes.rb', line 3879 def exit_code @exit_code end |
#status ⇒ Google::Apis::RunV2::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
3889 3890 3891 |
# File 'lib/google/apis/run_v2/classes.rb', line 3889 def status @status end |
#term_signal ⇒ Fixnum
Output only. Termination signal of the container. This is set to non-zero if
the container is terminated by the system. At most one of exit_code or
term_signal will be set.
Corresponds to the JSON property termSignal
3896 3897 3898 |
# File 'lib/google/apis/run_v2/classes.rb', line 3896 def term_signal @term_signal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3903 3904 3905 3906 3907 |
# File 'lib/google/apis/run_v2/classes.rb', line 3903 def update!(**args) @exit_code = args[:exit_code] if args.key?(:exit_code) @status = args[:status] if args.key?(:status) @term_signal = args[:term_signal] if args.key?(:term_signal) end |