Class: Google::Apis::RunV2::GoogleCloudRunV2TaskAttemptResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Result of a task attempt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2TaskAttemptResult

Returns a new instance of GoogleCloudRunV2TaskAttemptResult.



3365
3366
3367
# File 'lib/google/apis/run_v2/classes.rb', line 3365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exit_codeFixnum

Output only. The exit code of this attempt. This may be unset if the container was unable to exit cleanly with a code due to some other failure. See status field for possible failure details. At most one of exit_code or term_signal will be set. Corresponds to the JSON property exitCode

Returns:

  • (Fixnum)


3346
3347
3348
# File 'lib/google/apis/run_v2/classes.rb', line 3346

def exit_code
  @exit_code
end

#statusGoogle::Apis::RunV2::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



3356
3357
3358
# File 'lib/google/apis/run_v2/classes.rb', line 3356

def status
  @status
end

#term_signalFixnum

Output only. Termination signal of the container. This is set to non-zero if the container is terminated by the system. At most one of exit_code or term_signal will be set. Corresponds to the JSON property termSignal

Returns:

  • (Fixnum)


3363
3364
3365
# File 'lib/google/apis/run_v2/classes.rb', line 3363

def term_signal
  @term_signal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3370
3371
3372
3373
3374
# File 'lib/google/apis/run_v2/classes.rb', line 3370

def update!(**args)
  @exit_code = args[:exit_code] if args.key?(:exit_code)
  @status = args[:status] if args.key?(:status)
  @term_signal = args[:term_signal] if args.key?(:term_signal)
end