Class: Google::Apis::RunV2::GoogleCloudRunV2TrafficTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Holds a single traffic routing entry for the Service. Allocations can be done to a specific Revision name, or pointing to the latest Ready Revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2TrafficTarget

Returns a new instance of GoogleCloudRunV2TrafficTarget.



4022
4023
4024
# File 'lib/google/apis/run_v2/classes.rb', line 4022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentFixnum

Specifies percent of the traffic to this Revision. This defaults to zero if unspecified. Corresponds to the JSON property percent

Returns:

  • (Fixnum)


4004
4005
4006
# File 'lib/google/apis/run_v2/classes.rb', line 4004

def percent
  @percent
end

#revisionString

Revision to which to send this portion of traffic, if traffic allocation is by revision. Corresponds to the JSON property revision

Returns:

  • (String)


4010
4011
4012
# File 'lib/google/apis/run_v2/classes.rb', line 4010

def revision
  @revision
end

#tagString

Indicates a string to be part of the URI to exclusively reference this target. Corresponds to the JSON property tag

Returns:

  • (String)


4015
4016
4017
# File 'lib/google/apis/run_v2/classes.rb', line 4015

def tag
  @tag
end

#typeString

The allocation type for this traffic target. Corresponds to the JSON property type

Returns:

  • (String)


4020
4021
4022
# File 'lib/google/apis/run_v2/classes.rb', line 4020

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4027
4028
4029
4030
4031
4032
# File 'lib/google/apis/run_v2/classes.rb', line 4027

def update!(**args)
  @percent = args[:percent] if args.key?(:percent)
  @revision = args[:revision] if args.key?(:revision)
  @tag = args[:tag] if args.key?(:tag)
  @type = args[:type] if args.key?(:type)
end