Class: Google::Apis::RunV2::GoogleCloudRunV2TrafficTarget
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2TrafficTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Holds a single traffic routing entry for the Service. Allocations can be done to a specific Revision name, or pointing to the latest Ready Revision.
Instance Attribute Summary collapse
-
#percent ⇒ Fixnum
Specifies percent of the traffic to this Revision.
-
#revision ⇒ String
Revision to which to send this portion of traffic, if traffic allocation is by revision.
-
#tag ⇒ String
Indicates a string to be part of the URI to exclusively reference this target.
-
#type ⇒ String
The allocation type for this traffic target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2TrafficTarget
constructor
A new instance of GoogleCloudRunV2TrafficTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2TrafficTarget
Returns a new instance of GoogleCloudRunV2TrafficTarget.
3489 3490 3491 |
# File 'lib/google/apis/run_v2/classes.rb', line 3489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#percent ⇒ Fixnum
Specifies percent of the traffic to this Revision. This defaults to zero if
unspecified.
Corresponds to the JSON property percent
3471 3472 3473 |
# File 'lib/google/apis/run_v2/classes.rb', line 3471 def percent @percent end |
#revision ⇒ String
Revision to which to send this portion of traffic, if traffic allocation is by
revision.
Corresponds to the JSON property revision
3477 3478 3479 |
# File 'lib/google/apis/run_v2/classes.rb', line 3477 def revision @revision end |
#tag ⇒ String
Indicates a string to be part of the URI to exclusively reference this target.
Corresponds to the JSON property tag
3482 3483 3484 |
# File 'lib/google/apis/run_v2/classes.rb', line 3482 def tag @tag end |
#type ⇒ String
The allocation type for this traffic target.
Corresponds to the JSON property type
3487 3488 3489 |
# File 'lib/google/apis/run_v2/classes.rb', line 3487 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3494 3495 3496 3497 3498 3499 |
# File 'lib/google/apis/run_v2/classes.rb', line 3494 def update!(**args) @percent = args[:percent] if args.key?(:percent) @revision = args[:revision] if args.key?(:revision) @tag = args[:tag] if args.key?(:tag) @type = args[:type] if args.key?(:type) end |