Class: Google::Apis::RunV2::GoogleCloudRunV2VersionToPath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

VersionToPath maps a specific version of a secret to a relative file to mount to, relative to VolumeMount's mount_path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2VersionToPath

Returns a new instance of GoogleCloudRunV2VersionToPath.



4107
4108
4109
# File 'lib/google/apis/run_v2/classes.rb', line 4107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modeFixnum

Integer octal mode bits to use on this file, must be a value between 01 and 0777 (octal). If 0 or not set, the Volume's default mode will be used. Notes * Internally, a umask of 0222 will be applied to any non-zero value. * This is an integer representation of the mode bits. So, the octal integer value should look exactly as the chmod numeric notation with a leading zero. Some examples: for chmod 640 (u=rw,g=r), set to 0640 (octal) or 416 (base-10). For chmod 755 ( u=rwx,g=rx,o=rx), set to 0755 (octal) or 493 (base-10). * This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. Corresponds to the JSON property mode

Returns:

  • (Fixnum)


4094
4095
4096
# File 'lib/google/apis/run_v2/classes.rb', line 4094

def mode
  @mode
end

#pathString

Required. The relative path of the secret in the container. Corresponds to the JSON property path

Returns:

  • (String)


4099
4100
4101
# File 'lib/google/apis/run_v2/classes.rb', line 4099

def path
  @path
end

#versionString

The Cloud Secret Manager secret version. Can be 'latest' for the latest value, or an integer or a secret alias for a specific version. Corresponds to the JSON property version

Returns:

  • (String)


4105
4106
4107
# File 'lib/google/apis/run_v2/classes.rb', line 4105

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4112
4113
4114
4115
4116
# File 'lib/google/apis/run_v2/classes.rb', line 4112

def update!(**args)
  @mode = args[:mode] if args.key?(:mode)
  @path = args[:path] if args.key?(:path)
  @version = args[:version] if args.key?(:version)
end