Class: Google::Apis::RunV2::GoogleCloudRunV2Volume
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2Volume
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Volume represents a named volume in a container.
Instance Attribute Summary collapse
-
#cloud_sql_instance ⇒ Google::Apis::RunV2::GoogleCloudRunV2CloudSqlInstance
Represents a set of Cloud SQL instances.
-
#empty_dir ⇒ Google::Apis::RunV2::GoogleCloudRunV2EmptyDirVolumeSource
In memory (tmpfs) ephemeral storage.
-
#gcs ⇒ Google::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource
Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE.
-
#name ⇒ String
Required.
-
#nfs ⇒ Google::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource
Represents an NFS mount.
-
#secret ⇒ Google::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource
The secret's value will be presented as the content of a file whose name is defined in the item path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2Volume
constructor
A new instance of GoogleCloudRunV2Volume.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2Volume
Returns a new instance of GoogleCloudRunV2Volume.
4223 4224 4225 |
# File 'lib/google/apis/run_v2/classes.rb', line 4223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql_instance ⇒ Google::Apis::RunV2::GoogleCloudRunV2CloudSqlInstance
Represents a set of Cloud SQL instances. Each one will be available under /
cloudsql/[instance]. Visit https://cloud.google.com/sql/docs/mysql/connect-run
for more information on how to connect Cloud SQL and Cloud Run.
Corresponds to the JSON property cloudSqlInstance
4192 4193 4194 |
# File 'lib/google/apis/run_v2/classes.rb', line 4192 def cloud_sql_instance @cloud_sql_instance end |
#empty_dir ⇒ Google::Apis::RunV2::GoogleCloudRunV2EmptyDirVolumeSource
In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when
the sandbox is taken down, the data is destroyed with it (it does not persist
across sandbox runs).
Corresponds to the JSON property emptyDir
4199 4200 4201 |
# File 'lib/google/apis/run_v2/classes.rb', line 4199 def empty_dir @empty_dir end |
#gcs ⇒ Google::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource
Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE.
Corresponds to the JSON property gcs
4204 4205 4206 |
# File 'lib/google/apis/run_v2/classes.rb', line 4204 def gcs @gcs end |
#name ⇒ String
Required. Volume's name.
Corresponds to the JSON property name
4209 4210 4211 |
# File 'lib/google/apis/run_v2/classes.rb', line 4209 def name @name end |
#nfs ⇒ Google::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource
Represents an NFS mount.
Corresponds to the JSON property nfs
4214 4215 4216 |
# File 'lib/google/apis/run_v2/classes.rb', line 4214 def nfs @nfs end |
#secret ⇒ Google::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource
The secret's value will be presented as the content of a file whose name is
defined in the item path. If no items are defined, the name of the file is the
secret.
Corresponds to the JSON property secret
4221 4222 4223 |
# File 'lib/google/apis/run_v2/classes.rb', line 4221 def secret @secret end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/google/apis/run_v2/classes.rb', line 4228 def update!(**args) @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance) @empty_dir = args[:empty_dir] if args.key?(:empty_dir) @gcs = args[:gcs] if args.key?(:gcs) @name = args[:name] if args.key?(:name) @nfs = args[:nfs] if args.key?(:nfs) @secret = args[:secret] if args.key?(:secret) end |