Class: Google::Apis::RunV2::GoogleCloudRunV2Volume

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Volume represents a named volume in a container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Volume

Returns a new instance of GoogleCloudRunV2Volume.



4204
4205
4206
# File 'lib/google/apis/run_v2/classes.rb', line 4204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_instanceGoogle::Apis::RunV2::GoogleCloudRunV2CloudSqlInstance

Represents a set of Cloud SQL instances. Each one will be available under / cloudsql/[instance]. Visit https://cloud.google.com/sql/docs/mysql/connect-run for more information on how to connect Cloud SQL and Cloud Run. Corresponds to the JSON property cloudSqlInstance



4173
4174
4175
# File 'lib/google/apis/run_v2/classes.rb', line 4173

def cloud_sql_instance
  @cloud_sql_instance
end

#empty_dirGoogle::Apis::RunV2::GoogleCloudRunV2EmptyDirVolumeSource

In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when the sandbox is taken down, the data is destroyed with it (it does not persist across sandbox runs). Corresponds to the JSON property emptyDir



4180
4181
4182
# File 'lib/google/apis/run_v2/classes.rb', line 4180

def empty_dir
  @empty_dir
end

#gcsGoogle::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource

Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE. Corresponds to the JSON property gcs



4185
4186
4187
# File 'lib/google/apis/run_v2/classes.rb', line 4185

def gcs
  @gcs
end

#nameString

Required. Volume's name. Corresponds to the JSON property name

Returns:

  • (String)


4190
4191
4192
# File 'lib/google/apis/run_v2/classes.rb', line 4190

def name
  @name
end

#nfsGoogle::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource

Represents an NFS mount. Corresponds to the JSON property nfs



4195
4196
4197
# File 'lib/google/apis/run_v2/classes.rb', line 4195

def nfs
  @nfs
end

#secretGoogle::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource

The secret's value will be presented as the content of a file whose name is defined in the item path. If no items are defined, the name of the file is the secret. Corresponds to the JSON property secret



4202
4203
4204
# File 'lib/google/apis/run_v2/classes.rb', line 4202

def secret
  @secret
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/google/apis/run_v2/classes.rb', line 4209

def update!(**args)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @empty_dir = args[:empty_dir] if args.key?(:empty_dir)
  @gcs = args[:gcs] if args.key?(:gcs)
  @name = args[:name] if args.key?(:name)
  @nfs = args[:nfs] if args.key?(:nfs)
  @secret = args[:secret] if args.key?(:secret)
end