Class: Google::Apis::RunV2::GoogleCloudRunV2Volume

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Volume represents a named volume in a container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Volume

Returns a new instance of GoogleCloudRunV2Volume.



4166
4167
4168
# File 'lib/google/apis/run_v2/classes.rb', line 4166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_instanceGoogle::Apis::RunV2::GoogleCloudRunV2CloudSqlInstance

Represents a set of Cloud SQL instances. Each one will be available under / cloudsql/[instance]. Visit https://cloud.google.com/sql/docs/mysql/connect-run for more information on how to connect Cloud SQL and Cloud Run. Corresponds to the JSON property cloudSqlInstance



4135
4136
4137
# File 'lib/google/apis/run_v2/classes.rb', line 4135

def cloud_sql_instance
  @cloud_sql_instance
end

#empty_dirGoogle::Apis::RunV2::GoogleCloudRunV2EmptyDirVolumeSource

In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when the sandbox is taken down, the data is destroyed with it (it does not persist across sandbox runs). Corresponds to the JSON property emptyDir



4142
4143
4144
# File 'lib/google/apis/run_v2/classes.rb', line 4142

def empty_dir
  @empty_dir
end

#gcsGoogle::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource

Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE. Corresponds to the JSON property gcs



4147
4148
4149
# File 'lib/google/apis/run_v2/classes.rb', line 4147

def gcs
  @gcs
end

#nameString

Required. Volume's name. Corresponds to the JSON property name

Returns:

  • (String)


4152
4153
4154
# File 'lib/google/apis/run_v2/classes.rb', line 4152

def name
  @name
end

#nfsGoogle::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource

Represents an NFS mount. Corresponds to the JSON property nfs



4157
4158
4159
# File 'lib/google/apis/run_v2/classes.rb', line 4157

def nfs
  @nfs
end

#secretGoogle::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource

The secret's value will be presented as the content of a file whose name is defined in the item path. If no items are defined, the name of the file is the secret. Corresponds to the JSON property secret



4164
4165
4166
# File 'lib/google/apis/run_v2/classes.rb', line 4164

def secret
  @secret
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4171
4172
4173
4174
4175
4176
4177
4178
# File 'lib/google/apis/run_v2/classes.rb', line 4171

def update!(**args)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @empty_dir = args[:empty_dir] if args.key?(:empty_dir)
  @gcs = args[:gcs] if args.key?(:gcs)
  @name = args[:name] if args.key?(:name)
  @nfs = args[:nfs] if args.key?(:nfs)
  @secret = args[:secret] if args.key?(:secret)
end