Class: Google::Apis::RunV2::GoogleCloudRunV2Volume

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Volume represents a named volume in a container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2Volume

Returns a new instance of GoogleCloudRunV2Volume.



3626
3627
3628
# File 'lib/google/apis/run_v2/classes.rb', line 3626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_instanceGoogle::Apis::RunV2::GoogleCloudRunV2CloudSqlInstance

Represents a set of Cloud SQL instances. Each one will be available under / cloudsql/[instance]. Visit https://cloud.google.com/sql/docs/mysql/connect-run for more information on how to connect Cloud SQL and Cloud Run. Corresponds to the JSON property cloudSqlInstance



3595
3596
3597
# File 'lib/google/apis/run_v2/classes.rb', line 3595

def cloud_sql_instance
  @cloud_sql_instance
end

#empty_dirGoogle::Apis::RunV2::GoogleCloudRunV2EmptyDirVolumeSource

In memory (tmpfs) ephemeral storage. It is ephemeral in the sense that when the sandbox is taken down, the data is destroyed with it (it does not persist across sandbox runs). Corresponds to the JSON property emptyDir



3602
3603
3604
# File 'lib/google/apis/run_v2/classes.rb', line 3602

def empty_dir
  @empty_dir
end

#gcsGoogle::Apis::RunV2::GoogleCloudRunV2GcsVolumeSource

Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE. Corresponds to the JSON property gcs



3607
3608
3609
# File 'lib/google/apis/run_v2/classes.rb', line 3607

def gcs
  @gcs
end

#nameString

Required. Volume's name. Corresponds to the JSON property name

Returns:

  • (String)


3612
3613
3614
# File 'lib/google/apis/run_v2/classes.rb', line 3612

def name
  @name
end

#nfsGoogle::Apis::RunV2::GoogleCloudRunV2NfsVolumeSource

Represents an NFS mount. Corresponds to the JSON property nfs



3617
3618
3619
# File 'lib/google/apis/run_v2/classes.rb', line 3617

def nfs
  @nfs
end

#secretGoogle::Apis::RunV2::GoogleCloudRunV2SecretVolumeSource

The secret's value will be presented as the content of a file whose name is defined in the item path. If no items are defined, the name of the file is the secret. Corresponds to the JSON property secret



3624
3625
3626
# File 'lib/google/apis/run_v2/classes.rb', line 3624

def secret
  @secret
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3631
3632
3633
3634
3635
3636
3637
3638
# File 'lib/google/apis/run_v2/classes.rb', line 3631

def update!(**args)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @empty_dir = args[:empty_dir] if args.key?(:empty_dir)
  @gcs = args[:gcs] if args.key?(:gcs)
  @name = args[:name] if args.key?(:name)
  @nfs = args[:nfs] if args.key?(:nfs)
  @secret = args[:secret] if args.key?(:secret)
end