Class: Google::Apis::RunV2::GoogleCloudRunV2VolumeMount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

VolumeMount describes a mounting of a Volume within a container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2VolumeMount

Returns a new instance of GoogleCloudRunV2VolumeMount.



4199
4200
4201
# File 'lib/google/apis/run_v2/classes.rb', line 4199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mount_pathString

Required. Path within the container at which the volume should be mounted. Must not contain ':'. For Cloud SQL volumes, it can be left empty, or must otherwise be /cloudsql. All instances defined in the Volume will be available as /cloudsql/[instance]. For more information on Cloud SQL volumes, visit https://cloud.google.com/sql/docs/mysql/connect-run Corresponds to the JSON property mountPath

Returns:

  • (String)


4185
4186
4187
# File 'lib/google/apis/run_v2/classes.rb', line 4185

def mount_path
  @mount_path
end

#nameString

Required. This must match the Name of a Volume. Corresponds to the JSON property name

Returns:

  • (String)


4190
4191
4192
# File 'lib/google/apis/run_v2/classes.rb', line 4190

def name
  @name
end

#sub_pathString

Optional. Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root). This field is currently rejected in Secret volume mounts. Corresponds to the JSON property subPath

Returns:

  • (String)


4197
4198
4199
# File 'lib/google/apis/run_v2/classes.rb', line 4197

def sub_path
  @sub_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4204
4205
4206
4207
4208
# File 'lib/google/apis/run_v2/classes.rb', line 4204

def update!(**args)
  @mount_path = args[:mount_path] if args.key?(:mount_path)
  @name = args[:name] if args.key?(:name)
  @sub_path = args[:sub_path] if args.key?(:sub_path)
end