Class: Google::Apis::RunV2::GoogleCloudRunV2VolumeMount
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleCloudRunV2VolumeMount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
VolumeMount describes a mounting of a Volume within a container.
Instance Attribute Summary collapse
-
#mount_path ⇒ String
Required.
-
#name ⇒ String
Required.
-
#sub_path ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRunV2VolumeMount
constructor
A new instance of GoogleCloudRunV2VolumeMount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRunV2VolumeMount
Returns a new instance of GoogleCloudRunV2VolumeMount.
3665 3666 3667 |
# File 'lib/google/apis/run_v2/classes.rb', line 3665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mount_path ⇒ String
Required. Path within the container at which the volume should be mounted.
Must not contain ':'. For Cloud SQL volumes, it can be left empty, or must
otherwise be /cloudsql. All instances defined in the Volume will be
available as /cloudsql/[instance]. For more information on Cloud SQL volumes,
visit https://cloud.google.com/sql/docs/mysql/connect-run
Corresponds to the JSON property mountPath
3652 3653 3654 |
# File 'lib/google/apis/run_v2/classes.rb', line 3652 def mount_path @mount_path end |
#name ⇒ String
Required. This must match the Name of a Volume.
Corresponds to the JSON property name
3657 3658 3659 |
# File 'lib/google/apis/run_v2/classes.rb', line 3657 def name @name end |
#sub_path ⇒ String
Optional. Path within the volume from which the container's volume should be
mounted. Defaults to "" (volume's root).
Corresponds to the JSON property subPath
3663 3664 3665 |
# File 'lib/google/apis/run_v2/classes.rb', line 3663 def sub_path @sub_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3670 3671 3672 3673 3674 |
# File 'lib/google/apis/run_v2/classes.rb', line 3670 def update!(**args) @mount_path = args[:mount_path] if args.key?(:mount_path) @name = args[:name] if args.key?(:name) @sub_path = args[:sub_path] if args.key?(:sub_path) end |