Class: Google::Apis::RunV2::GoogleCloudRunV2VpcAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

VPC Access settings. For more information on sending traffic to a VPC network, visit https://cloud.google.com/run/docs/configuring/connecting-vpc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRunV2VpcAccess

Returns a new instance of GoogleCloudRunV2VpcAccess.



3702
3703
3704
# File 'lib/google/apis/run_v2/classes.rb', line 3702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectorString

VPC Access connector name. Format: projects/project/locations/location/ connectors/connector, whereproject`can be project id or number. For more information on sending traffic to a VPC network via a connector, visit https://cloud.google.com/run/docs/configuring/vpc-connectors. Corresponds to the JSON propertyconnector`

Returns:

  • (String)


3688
3689
3690
# File 'lib/google/apis/run_v2/classes.rb', line 3688

def connector
  @connector
end

#egressString

Optional. Traffic VPC egress settings. If not provided, it defaults to PRIVATE_RANGES_ONLY. Corresponds to the JSON property egress

Returns:

  • (String)


3694
3695
3696
# File 'lib/google/apis/run_v2/classes.rb', line 3694

def egress
  @egress
end

#network_interfacesArray<Google::Apis::RunV2::GoogleCloudRunV2NetworkInterface>

Optional. Direct VPC egress settings. Currently only single network interface is supported. Corresponds to the JSON property networkInterfaces



3700
3701
3702
# File 'lib/google/apis/run_v2/classes.rb', line 3700

def network_interfaces
  @network_interfaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3707
3708
3709
3710
3711
# File 'lib/google/apis/run_v2/classes.rb', line 3707

def update!(**args)
  @connector = args[:connector] if args.key?(:connector)
  @egress = args[:egress] if args.key?(:egress)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
end