Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalResult
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
ApprovalResult describes the decision and associated metadata of a manual approval of a build.
Instance Attribute Summary collapse
-
#approval_time ⇒ String
Output only.
-
#approver_account ⇒ String
Output only.
-
#comment ⇒ String
Optional.
-
#decision ⇒ String
Required.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ApprovalResult
constructor
A new instance of GoogleDevtoolsCloudbuildV1ApprovalResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ApprovalResult
Returns a new instance of GoogleDevtoolsCloudbuildV1ApprovalResult.
4763 4764 4765 |
# File 'lib/google/apis/run_v2/classes.rb', line 4763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_time ⇒ String
Output only. The time when the approval decision was made.
Corresponds to the JSON property approvalTime
4737 4738 4739 |
# File 'lib/google/apis/run_v2/classes.rb', line 4737 def approval_time @approval_time end |
#approver_account ⇒ String
Output only. Email of the user that called the ApproveBuild API to approve or
reject a build at the time that the API was called.
Corresponds to the JSON property approverAccount
4743 4744 4745 |
# File 'lib/google/apis/run_v2/classes.rb', line 4743 def approver_account @approver_account end |
#comment ⇒ String
Optional. An optional comment for this manual approval result.
Corresponds to the JSON property comment
4748 4749 4750 |
# File 'lib/google/apis/run_v2/classes.rb', line 4748 def comment @comment end |
#decision ⇒ String
Required. The decision of this manual approval.
Corresponds to the JSON property decision
4753 4754 4755 |
# File 'lib/google/apis/run_v2/classes.rb', line 4753 def decision @decision end |
#url ⇒ String
Optional. An optional URL tied to this manual approval result. This field is
essentially the same as comment, except that it will be rendered by the UI
differently. An example use case is a link to an external job that approved
this Build.
Corresponds to the JSON property url
4761 4762 4763 |
# File 'lib/google/apis/run_v2/classes.rb', line 4761 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4768 4769 4770 4771 4772 4773 4774 |
# File 'lib/google/apis/run_v2/classes.rb', line 4768 def update!(**args) @approval_time = args[:approval_time] if args.key?(:approval_time) @approver_account = args[:approver_account] if args.key?(:approver_account) @comment = args[:comment] if args.key?(:comment) @decision = args[:decision] if args.key?(:decision) @url = args[:url] if args.key?(:url) end |