Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

ApprovalResult describes the decision and associated metadata of a manual approval of a build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ApprovalResult

Returns a new instance of GoogleDevtoolsCloudbuildV1ApprovalResult.



4172
4173
4174
# File 'lib/google/apis/run_v2/classes.rb', line 4172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approval_timeString

Output only. The time when the approval decision was made. Corresponds to the JSON property approvalTime

Returns:

  • (String)


4146
4147
4148
# File 'lib/google/apis/run_v2/classes.rb', line 4146

def approval_time
  @approval_time
end

#approver_accountString

Output only. Email of the user that called the ApproveBuild API to approve or reject a build at the time that the API was called. Corresponds to the JSON property approverAccount

Returns:

  • (String)


4152
4153
4154
# File 'lib/google/apis/run_v2/classes.rb', line 4152

def 
  @approver_account
end

#commentString

Optional. An optional comment for this manual approval result. Corresponds to the JSON property comment

Returns:

  • (String)


4157
4158
4159
# File 'lib/google/apis/run_v2/classes.rb', line 4157

def comment
  @comment
end

#decisionString

Required. The decision of this manual approval. Corresponds to the JSON property decision

Returns:

  • (String)


4162
4163
4164
# File 'lib/google/apis/run_v2/classes.rb', line 4162

def decision
  @decision
end

#urlString

Optional. An optional URL tied to this manual approval result. This field is essentially the same as comment, except that it will be rendered by the UI differently. An example use case is a link to an external job that approved this Build. Corresponds to the JSON property url

Returns:

  • (String)


4170
4171
4172
# File 'lib/google/apis/run_v2/classes.rb', line 4170

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4177
4178
4179
4180
4181
4182
4183
# File 'lib/google/apis/run_v2/classes.rb', line 4177

def update!(**args)
  @approval_time = args[:approval_time] if args.key?(:approval_time)
  @approver_account = args[:approver_account] if args.key?(:approver_account)
  @comment = args[:comment] if args.key?(:comment)
  @decision = args[:decision] if args.key?(:decision)
  @url = args[:url] if args.key?(:url)
end