Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts

Returns a new instance of GoogleDevtoolsCloudbuildV1Artifacts.



4849
4850
4851
# File 'lib/google/apis/run_v2/classes.rb', line 4849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generic_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifact>

Optional. A list of generic artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property genericArtifacts



4790
4791
4792
# File 'lib/google/apis/run_v2/classes.rb', line 4790

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



4797
4798
4799
# File 'lib/google/apis/run_v2/classes.rb', line 4797

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


4806
4807
4808
# File 'lib/google/apis/run_v2/classes.rb', line 4806

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



4815
4816
4817
# File 'lib/google/apis/run_v2/classes.rb', line 4815

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



4824
4825
4826
# File 'lib/google/apis/run_v2/classes.rb', line 4824

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



4830
4831
4832
# File 'lib/google/apis/run_v2/classes.rb', line 4830

def objects
  @objects
end

#ociArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Oci>

Optional. A list of OCI images to be uploaded to Artifact Registry upon successful completion of all build steps. OCI images in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property oci



4839
4840
4841
# File 'lib/google/apis/run_v2/classes.rb', line 4839

def oci
  @oci
end

#python_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1PythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



4847
4848
4849
# File 'lib/google/apis/run_v2/classes.rb', line 4847

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/google/apis/run_v2/classes.rb', line 4854

def update!(**args)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @oci = args[:oci] if args.key?(:oci)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end