Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#generic_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifact>
Optional.
-
#go_modules ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GoModule>
Optional.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#maven_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#npm_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps.
-
#objects ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion of all build steps.
-
#oci ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Oci>
Optional.
-
#python_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1PythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts
constructor
A new instance of GoogleDevtoolsCloudbuildV1Artifacts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts
Returns a new instance of GoogleDevtoolsCloudbuildV1Artifacts.
4843 4844 4845 |
# File 'lib/google/apis/run_v2/classes.rb', line 4843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generic_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifact>
Optional. A list of generic artifacts to be uploaded to Artifact Registry upon
successful completion of all build steps. If any artifacts fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property genericArtifacts
4784 4785 4786 |
# File 'lib/google/apis/run_v2/classes.rb', line 4784 def generic_artifacts @generic_artifacts end |
#go_modules ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GoModule>
Optional. A list of Go modules to be uploaded to Artifact Registry upon
successful completion of all build steps. If any objects fail to be pushed,
the build is marked FAILURE.
Corresponds to the JSON property goModules
4791 4792 4793 |
# File 'lib/google/apis/run_v2/classes.rb', line 4791 def go_modules @go_modules end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images will be pushed using the builder service account's
credentials. The digests of the pushed images will be stored in the Build
resource's results field. If any of the images fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property images
4800 4801 4802 |
# File 'lib/google/apis/run_v2/classes.rb', line 4800 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact>
A list of Maven artifacts to be uploaded to Artifact Registry upon successful
completion of all build steps. Artifacts in the workspace matching specified
paths globs will be uploaded to the specified Artifact Registry repository
using the builder service account's credentials. If any artifacts fail to be
pushed, the build is marked FAILURE.
Corresponds to the JSON property mavenArtifacts
4809 4810 4811 |
# File 'lib/google/apis/run_v2/classes.rb', line 4809 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage>
A list of npm packages to be uploaded to Artifact Registry upon successful
completion of all build steps. Npm packages in the specified paths will be
uploaded to the specified Artifact Registry repository using the builder
service account's credentials. If any packages fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property npmPackages
4818 4819 4820 |
# File 'lib/google/apis/run_v2/classes.rb', line 4818 def npm_packages @npm_packages end |
#objects ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ArtifactObjects
Files in the workspace to upload to Cloud Storage upon successful completion
of all build steps.
Corresponds to the JSON property objects
4824 4825 4826 |
# File 'lib/google/apis/run_v2/classes.rb', line 4824 def objects @objects end |
#oci ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Oci>
Optional. A list of OCI images to be uploaded to Artifact Registry upon
successful completion of all build steps. OCI images in the specified paths
will be uploaded to the specified Artifact Registry repository using the
builder service account's credentials. If any images fail to be pushed, the
build is marked FAILURE.
Corresponds to the JSON property oci
4833 4834 4835 |
# File 'lib/google/apis/run_v2/classes.rb', line 4833 def oci @oci end |
#python_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1PythonPackage>
A list of Python packages to be uploaded to Artifact Registry upon successful
completion of all build steps. The build service account credentials will be
used to perform the upload. If any objects fail to be pushed, the build is
marked FAILURE.
Corresponds to the JSON property pythonPackages
4841 4842 4843 |
# File 'lib/google/apis/run_v2/classes.rb', line 4841 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4848 4849 4850 4851 4852 4853 4854 4855 4856 4857 |
# File 'lib/google/apis/run_v2/classes.rb', line 4848 def update!(**args) @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @objects = args[:objects] if args.key?(:objects) @oci = args[:oci] if args.key?(:oci) @python_packages = args[:python_packages] if args.key?(:python_packages) end |