Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts

Returns a new instance of GoogleDevtoolsCloudbuildV1Artifacts.



4836
4837
4838
# File 'lib/google/apis/run_v2/classes.rb', line 4836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generic_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifact>

Optional. A list of generic artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property genericArtifacts



4777
4778
4779
# File 'lib/google/apis/run_v2/classes.rb', line 4777

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



4784
4785
4786
# File 'lib/google/apis/run_v2/classes.rb', line 4784

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


4793
4794
4795
# File 'lib/google/apis/run_v2/classes.rb', line 4793

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



4802
4803
4804
# File 'lib/google/apis/run_v2/classes.rb', line 4802

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



4811
4812
4813
# File 'lib/google/apis/run_v2/classes.rb', line 4811

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



4817
4818
4819
# File 'lib/google/apis/run_v2/classes.rb', line 4817

def objects
  @objects
end

#ociArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Oci>

Optional. A list of OCI images to be uploaded to Artifact Registry upon successful completion of all build steps. OCI images in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property oci



4826
4827
4828
# File 'lib/google/apis/run_v2/classes.rb', line 4826

def oci
  @oci
end

#python_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1PythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



4834
4835
4836
# File 'lib/google/apis/run_v2/classes.rb', line 4834

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
# File 'lib/google/apis/run_v2/classes.rb', line 4841

def update!(**args)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @oci = args[:oci] if args.key?(:oci)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end