Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifacts produced by a build that should be uploaded upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Artifacts

Returns a new instance of GoogleDevtoolsCloudbuildV1Artifacts.



4274
4275
4276
# File 'lib/google/apis/run_v2/classes.rb', line 4274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#go_modulesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GoModule>

Optional. A list of Go modules to be uploaded to Artifact Registry upon successful completion of all build steps. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property goModules



4231
4232
4233
# File 'lib/google/apis/run_v2/classes.rb', line 4231

def go_modules
  @go_modules
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images will be pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


4240
4241
4242
# File 'lib/google/apis/run_v2/classes.rb', line 4240

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact>

A list of Maven artifacts to be uploaded to Artifact Registry upon successful completion of all build steps. Artifacts in the workspace matching specified paths globs will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any artifacts fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property mavenArtifacts



4249
4250
4251
# File 'lib/google/apis/run_v2/classes.rb', line 4249

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1NpmPackage>

A list of npm packages to be uploaded to Artifact Registry upon successful completion of all build steps. Npm packages in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any packages fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property npmPackages



4258
4259
4260
# File 'lib/google/apis/run_v2/classes.rb', line 4258

def npm_packages
  @npm_packages
end

#objectsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ArtifactObjects

Files in the workspace to upload to Cloud Storage upon successful completion of all build steps. Corresponds to the JSON property objects



4264
4265
4266
# File 'lib/google/apis/run_v2/classes.rb', line 4264

def objects
  @objects
end

#python_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1PythonPackage>

A list of Python packages to be uploaded to Artifact Registry upon successful completion of all build steps. The build service account credentials will be used to perform the upload. If any objects fail to be pushed, the build is marked FAILURE. Corresponds to the JSON property pythonPackages



4272
4273
4274
# File 'lib/google/apis/run_v2/classes.rb', line 4272

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4279
4280
4281
4282
4283
4284
4285
4286
# File 'lib/google/apis/run_v2/classes.rb', line 4279

def update!(**args)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @objects = args[:objects] if args.key?(:objects)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end