Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Build

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A build resource in the Cloud Build API. At a high level, a Build describes where to find source code, how to build it (for example, the builder image to run on the source), and where to store the built artifacts. Fields can include the following variables, which will be expanded when the build is created: - $ PROJECT_ID: the project ID of the build. - $PROJECT_NUMBER: the project number of the build. - $LOCATION: the location/region of the build. - $BUILD_ID: the autogenerated ID of the build. - $REPO_NAME: the source repository name specified by RepoSource. - $BRANCH_NAME: the branch name specified by RepoSource. - $TAG_NAME: the tag name specified by RepoSource. - $REVISION_ID or $COMMIT_SHA: the commit SHA specified by RepoSource or resolved from the specified branch or tag. - $SHORT_SHA: first 7 characters of $REVISION_ID or $ COMMIT_SHA.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Build

Returns a new instance of GoogleDevtoolsCloudbuildV1Build.



5064
5065
5066
# File 'lib/google/apis/run_v2/classes.rb', line 5064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approvalGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildApproval

BuildApproval describes a build's approval configuration, state, and result. Corresponds to the JSON property approval



4884
4885
4886
# File 'lib/google/apis/run_v2/classes.rb', line 4884

def approval
  @approval
end

#artifactsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts

Artifacts produced by a build that should be uploaded upon successful completion of all build steps. Corresponds to the JSON property artifacts



4890
4891
4892
# File 'lib/google/apis/run_v2/classes.rb', line 4890

def artifacts
  @artifacts
end

#available_secretsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1Secrets

Secrets and secret environment variables. Corresponds to the JSON property availableSecrets



4895
4896
4897
# File 'lib/google/apis/run_v2/classes.rb', line 4895

def available_secrets
  @available_secrets
end

#build_trigger_idString

Output only. The ID of the BuildTrigger that triggered this build, if it was triggered automatically. Corresponds to the JSON property buildTriggerId

Returns:

  • (String)


4901
4902
4903
# File 'lib/google/apis/run_v2/classes.rb', line 4901

def build_trigger_id
  @build_trigger_id
end

#create_timeString

Output only. Time at which the request to create the build was received. Corresponds to the JSON property createTime

Returns:

  • (String)


4906
4907
4908
# File 'lib/google/apis/run_v2/classes.rb', line 4906

def create_time
  @create_time
end

#dependenciesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency>

Optional. Dependencies that the Cloud Build worker will fetch before executing user steps. Corresponds to the JSON property dependencies



4912
4913
4914
# File 'lib/google/apis/run_v2/classes.rb', line 4912

def dependencies
  @dependencies
end

#failure_infoGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FailureInfo

A fatal problem encountered during the execution of the build. Corresponds to the JSON property failureInfo



4917
4918
4919
# File 'lib/google/apis/run_v2/classes.rb', line 4917

def failure_info
  @failure_info
end

#finish_timeString

Output only. Time at which execution of the build was finished. The difference between finish_time and start_time is the duration of the build's execution. Corresponds to the JSON property finishTime

Returns:

  • (String)


4923
4924
4925
# File 'lib/google/apis/run_v2/classes.rb', line 4923

def finish_time
  @finish_time
end

#git_configGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitConfig

GitConfig is a configuration for git operations. Corresponds to the JSON property gitConfig



4928
4929
4930
# File 'lib/google/apis/run_v2/classes.rb', line 4928

def git_config
  @git_config
end

#idString

Output only. Unique identifier of the build. Corresponds to the JSON property id

Returns:

  • (String)


4933
4934
4935
# File 'lib/google/apis/run_v2/classes.rb', line 4933

def id
  @id
end

#imagesArray<String>

A list of images to be pushed upon the successful completion of all build steps. The images are pushed using the builder service account's credentials. The digests of the pushed images will be stored in the Build resource's results field. If any of the images fail to be pushed, the build status is marked FAILURE. Corresponds to the JSON property images

Returns:

  • (Array<String>)


4942
4943
4944
# File 'lib/google/apis/run_v2/classes.rb', line 4942

def images
  @images
end

#log_urlString

Output only. URL to logs for this build in Google Cloud Console. Corresponds to the JSON property logUrl

Returns:

  • (String)


4947
4948
4949
# File 'lib/google/apis/run_v2/classes.rb', line 4947

def log_url
  @log_url
end

#logs_bucketString

Cloud Storage bucket where logs should be written (see Bucket Name Requirements ). Logs file names will be of the format $logs_bucket/log-$build_id.txt. Corresponds to the JSON property logsBucket

Returns:

  • (String)


4954
4955
4956
# File 'lib/google/apis/run_v2/classes.rb', line 4954

def logs_bucket
  @logs_bucket
end

#nameString

Output only. The 'Build' name with format: projects/project/locations/ location/builds/build`, wherebuildis a unique identifier generated by the service. Corresponds to the JSON propertyname`

Returns:

  • (String)


4961
4962
4963
# File 'lib/google/apis/run_v2/classes.rb', line 4961

def name
  @name
end

#optionsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildOptions

Optional arguments to enable specific features of builds. Corresponds to the JSON property options



4966
4967
4968
# File 'lib/google/apis/run_v2/classes.rb', line 4966

def options
  @options
end

#project_idString

Output only. ID of the project. Corresponds to the JSON property projectId

Returns:

  • (String)


4971
4972
4973
# File 'lib/google/apis/run_v2/classes.rb', line 4971

def project_id
  @project_id
end

#queue_ttlString

TTL in queue for this build. If provided and the build is enqueued longer than this value, the build will expire and the build status will be EXPIRED. The TTL starts ticking from create_time. Corresponds to the JSON property queueTtl

Returns:

  • (String)


4978
4979
4980
# File 'lib/google/apis/run_v2/classes.rb', line 4978

def queue_ttl
  @queue_ttl
end

#resultsGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results

Artifacts created by the build pipeline. Corresponds to the JSON property results



4983
4984
4985
# File 'lib/google/apis/run_v2/classes.rb', line 4983

def results
  @results
end

#secretsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Secret>

Secrets to decrypt using Cloud Key Management Service. Note: Secret Manager is the recommended technique for managing sensitive data with Cloud Build. Use available_secrets to configure builds to access secrets from Secret Manager. For instructions, see: https://cloud.google.com/cloud-build/docs/securing- builds/use-secrets Corresponds to the JSON property secrets



4992
4993
4994
# File 'lib/google/apis/run_v2/classes.rb', line 4992

def secrets
  @secrets
end

#service_accountString

IAM service account whose credentials will be used at build runtime. Must be of the format projects/PROJECT_ID/serviceAccounts/ACCOUNT`. ACCOUNT can be email address or uniqueId of the service account. Corresponds to the JSON propertyserviceAccount`

Returns:

  • (String)


4999
5000
5001
# File 'lib/google/apis/run_v2/classes.rb', line 4999

def 
  @service_account
end

#sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source

Location of the source in a supported storage service. Corresponds to the JSON property source



5004
5005
5006
# File 'lib/google/apis/run_v2/classes.rb', line 5004

def source
  @source
end

#source_provenanceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1SourceProvenance

Provenance of the source. Ways to find the original source, or verify that some source was used for this build. Corresponds to the JSON property sourceProvenance



5010
5011
5012
# File 'lib/google/apis/run_v2/classes.rb', line 5010

def source_provenance
  @source_provenance
end

#start_timeString

Output only. Time at which execution of the build was started. Corresponds to the JSON property startTime

Returns:

  • (String)


5015
5016
5017
# File 'lib/google/apis/run_v2/classes.rb', line 5015

def start_time
  @start_time
end

#statusString

Output only. Status of the build. Corresponds to the JSON property status

Returns:

  • (String)


5020
5021
5022
# File 'lib/google/apis/run_v2/classes.rb', line 5020

def status
  @status
end

#status_detailString

Output only. Customer-readable message about the current status. Corresponds to the JSON property statusDetail

Returns:

  • (String)


5025
5026
5027
# File 'lib/google/apis/run_v2/classes.rb', line 5025

def status_detail
  @status_detail
end

#stepsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStep>

Required. The operations to be performed on the workspace. Corresponds to the JSON property steps



5030
5031
5032
# File 'lib/google/apis/run_v2/classes.rb', line 5030

def steps
  @steps
end

#substitutionsHash<String,String>

Substitutions data for Build resource. Corresponds to the JSON property substitutions

Returns:

  • (Hash<String,String>)


5035
5036
5037
# File 'lib/google/apis/run_v2/classes.rb', line 5035

def substitutions
  @substitutions
end

#tagsArray<String>

Tags for annotation of a Build. These are not docker tags. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


5040
5041
5042
# File 'lib/google/apis/run_v2/classes.rb', line 5040

def tags
  @tags
end

#timeoutString

Amount of time that this build should be allowed to run, to second granularity. If this amount of time elapses, work on the build will cease and the build status will be TIMEOUT. timeout starts ticking from startTime. Default time is 60 minutes. Corresponds to the JSON property timeout

Returns:

  • (String)


5048
5049
5050
# File 'lib/google/apis/run_v2/classes.rb', line 5048

def timeout
  @timeout
end

#timingHash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan>

Output only. Stores timing information for phases of the build. Valid keys are:

  • BUILD: time to execute all build steps. * PUSH: time to push all artifacts including docker images and non docker artifacts. * FETCHSOURCE: time to fetch source. * SETUPBUILD: time to set up build. If the build does not specify source or images, these keys will not be included. Corresponds to the JSON property timing


5057
5058
5059
# File 'lib/google/apis/run_v2/classes.rb', line 5057

def timing
  @timing
end

#warningsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Warning>

Output only. Non-fatal problems encountered during the execution of the build. Corresponds to the JSON property warnings



5062
5063
5064
# File 'lib/google/apis/run_v2/classes.rb', line 5062

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
5095
5096
5097
5098
5099
5100
5101
# File 'lib/google/apis/run_v2/classes.rb', line 5069

def update!(**args)
  @approval = args[:approval] if args.key?(:approval)
  @artifacts = args[:artifacts] if args.key?(:artifacts)
  @available_secrets = args[:available_secrets] if args.key?(:available_secrets)
  @build_trigger_id = args[:build_trigger_id] if args.key?(:build_trigger_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @failure_info = args[:failure_info] if args.key?(:failure_info)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @git_config = args[:git_config] if args.key?(:git_config)
  @id = args[:id] if args.key?(:id)
  @images = args[:images] if args.key?(:images)
  @log_url = args[:log_url] if args.key?(:log_url)
  @logs_bucket = args[:logs_bucket] if args.key?(:logs_bucket)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @project_id = args[:project_id] if args.key?(:project_id)
  @queue_ttl = args[:queue_ttl] if args.key?(:queue_ttl)
  @results = args[:results] if args.key?(:results)
  @secrets = args[:secrets] if args.key?(:secrets)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source = args[:source] if args.key?(:source)
  @source_provenance = args[:source_provenance] if args.key?(:source_provenance)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @steps = args[:steps] if args.key?(:steps)
  @substitutions = args[:substitutions] if args.key?(:substitutions)
  @tags = args[:tags] if args.key?(:tags)
  @timeout = args[:timeout] if args.key?(:timeout)
  @timing = args[:timing] if args.key?(:timing)
  @warnings = args[:warnings] if args.key?(:warnings)
end