Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Build
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Build
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A build resource in the Cloud Build API. At a high level, a Build describes
where to find source code, how to build it (for example, the builder image to
run on the source), and where to store the built artifacts. Fields can include
the following variables, which will be expanded when the build is created: - $
PROJECT_ID: the project ID of the build. - $PROJECT_NUMBER: the project number
of the build. - $LOCATION: the location/region of the build. - $BUILD_ID: the
autogenerated ID of the build. - $REPO_NAME: the source repository name
specified by RepoSource. - $BRANCH_NAME: the branch name specified by
RepoSource. - $TAG_NAME: the tag name specified by RepoSource. - $REVISION_ID
or $COMMIT_SHA: the commit SHA specified by RepoSource or resolved from the
specified branch or tag. - $SHORT_SHA: first 7 characters of $REVISION_ID or $
COMMIT_SHA.
Instance Attribute Summary collapse
-
#approval ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildApproval
BuildApproval describes a build's approval configuration, state, and result.
-
#artifacts ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts
Artifacts produced by a build that should be uploaded upon successful completion of all build steps.
-
#available_secrets ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Secrets
Secrets and secret environment variables.
-
#build_trigger_id ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#dependencies ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency>
Optional.
-
#failure_info ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FailureInfo
A fatal problem encountered during the execution of the build.
-
#finish_time ⇒ String
Output only.
-
#git_config ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitConfig
GitConfig is a configuration for git operations.
-
#id ⇒ String
Output only.
-
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build steps.
-
#log_url ⇒ String
Output only.
-
#logs_bucket ⇒ String
Cloud Storage bucket where logs should be written (see Bucket Name Requirements ).
-
#name ⇒ String
Output only.
-
#options ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildOptions
Optional arguments to enable specific features of builds.
-
#project_id ⇒ String
Output only.
-
#queue_ttl ⇒ String
TTL in queue for this build.
-
#results ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results
Artifacts created by the build pipeline.
-
#secrets ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Secret>
Secrets to decrypt using Cloud Key Management Service.
-
#service_account ⇒ String
IAM service account whose credentials will be used at build runtime.
-
#source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source
Location of the source in a supported storage service.
-
#source_provenance ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1SourceProvenance
Provenance of the source.
-
#start_time ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#steps ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStep>
Required.
-
#substitutions ⇒ Hash<String,String>
Substitutions data for
Buildresource. -
#tags ⇒ Array<String>
Tags for annotation of a
Build. -
#timeout ⇒ String
Amount of time that this build should be allowed to run, to second granularity.
-
#timing ⇒ Hash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan>
Output only.
-
#warnings ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Build
constructor
A new instance of GoogleDevtoolsCloudbuildV1Build.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Build
Returns a new instance of GoogleDevtoolsCloudbuildV1Build.
5051 5052 5053 |
# File 'lib/google/apis/run_v2/classes.rb', line 5051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildApproval
BuildApproval describes a build's approval configuration, state, and result.
Corresponds to the JSON property approval
4871 4872 4873 |
# File 'lib/google/apis/run_v2/classes.rb', line 4871 def approval @approval end |
#artifacts ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Artifacts
Artifacts produced by a build that should be uploaded upon successful
completion of all build steps.
Corresponds to the JSON property artifacts
4877 4878 4879 |
# File 'lib/google/apis/run_v2/classes.rb', line 4877 def artifacts @artifacts end |
#available_secrets ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Secrets
Secrets and secret environment variables.
Corresponds to the JSON property availableSecrets
4882 4883 4884 |
# File 'lib/google/apis/run_v2/classes.rb', line 4882 def available_secrets @available_secrets end |
#build_trigger_id ⇒ String
Output only. The ID of the BuildTrigger that triggered this build, if it was
triggered automatically.
Corresponds to the JSON property buildTriggerId
4888 4889 4890 |
# File 'lib/google/apis/run_v2/classes.rb', line 4888 def build_trigger_id @build_trigger_id end |
#create_time ⇒ String
Output only. Time at which the request to create the build was received.
Corresponds to the JSON property createTime
4893 4894 4895 |
# File 'lib/google/apis/run_v2/classes.rb', line 4893 def create_time @create_time end |
#dependencies ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency>
Optional. Dependencies that the Cloud Build worker will fetch before executing
user steps.
Corresponds to the JSON property dependencies
4899 4900 4901 |
# File 'lib/google/apis/run_v2/classes.rb', line 4899 def dependencies @dependencies end |
#failure_info ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FailureInfo
A fatal problem encountered during the execution of the build.
Corresponds to the JSON property failureInfo
4904 4905 4906 |
# File 'lib/google/apis/run_v2/classes.rb', line 4904 def failure_info @failure_info end |
#finish_time ⇒ String
Output only. Time at which execution of the build was finished. The difference
between finish_time and start_time is the duration of the build's execution.
Corresponds to the JSON property finishTime
4910 4911 4912 |
# File 'lib/google/apis/run_v2/classes.rb', line 4910 def finish_time @finish_time end |
#git_config ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitConfig
GitConfig is a configuration for git operations.
Corresponds to the JSON property gitConfig
4915 4916 4917 |
# File 'lib/google/apis/run_v2/classes.rb', line 4915 def git_config @git_config end |
#id ⇒ String
Output only. Unique identifier of the build.
Corresponds to the JSON property id
4920 4921 4922 |
# File 'lib/google/apis/run_v2/classes.rb', line 4920 def id @id end |
#images ⇒ Array<String>
A list of images to be pushed upon the successful completion of all build
steps. The images are pushed using the builder service account's credentials.
The digests of the pushed images will be stored in the Build resource's
results field. If any of the images fail to be pushed, the build status is
marked FAILURE.
Corresponds to the JSON property images
4929 4930 4931 |
# File 'lib/google/apis/run_v2/classes.rb', line 4929 def images @images end |
#log_url ⇒ String
Output only. URL to logs for this build in Google Cloud Console.
Corresponds to the JSON property logUrl
4934 4935 4936 |
# File 'lib/google/apis/run_v2/classes.rb', line 4934 def log_url @log_url end |
#logs_bucket ⇒ String
Cloud Storage bucket where logs should be written (see Bucket Name
Requirements
). Logs file names will be of the format $logs_bucket/log-$build_id.txt.
Corresponds to the JSON property logsBucket
4941 4942 4943 |
# File 'lib/google/apis/run_v2/classes.rb', line 4941 def logs_bucket @logs_bucket end |
#name ⇒ String
Output only. The 'Build' name with format: projects/project/locations/
location/builds/build`, wherebuildis a unique identifier generated by
the service.
Corresponds to the JSON propertyname`
4948 4949 4950 |
# File 'lib/google/apis/run_v2/classes.rb', line 4948 def name @name end |
#options ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildOptions
Optional arguments to enable specific features of builds.
Corresponds to the JSON property options
4953 4954 4955 |
# File 'lib/google/apis/run_v2/classes.rb', line 4953 def @options end |
#project_id ⇒ String
Output only. ID of the project.
Corresponds to the JSON property projectId
4958 4959 4960 |
# File 'lib/google/apis/run_v2/classes.rb', line 4958 def project_id @project_id end |
#queue_ttl ⇒ String
TTL in queue for this build. If provided and the build is enqueued longer than
this value, the build will expire and the build status will be EXPIRED. The
TTL starts ticking from create_time.
Corresponds to the JSON property queueTtl
4965 4966 4967 |
# File 'lib/google/apis/run_v2/classes.rb', line 4965 def queue_ttl @queue_ttl end |
#results ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results
Artifacts created by the build pipeline.
Corresponds to the JSON property results
4970 4971 4972 |
# File 'lib/google/apis/run_v2/classes.rb', line 4970 def results @results end |
#secrets ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Secret>
Secrets to decrypt using Cloud Key Management Service. Note: Secret Manager is
the recommended technique for managing sensitive data with Cloud Build. Use
available_secrets to configure builds to access secrets from Secret Manager.
For instructions, see: https://cloud.google.com/cloud-build/docs/securing-
builds/use-secrets
Corresponds to the JSON property secrets
4979 4980 4981 |
# File 'lib/google/apis/run_v2/classes.rb', line 4979 def secrets @secrets end |
#service_account ⇒ String
IAM service account whose credentials will be used at build runtime. Must be
of the format projects/PROJECT_ID/serviceAccounts/ACCOUNT`. ACCOUNT can
be email address or uniqueId of the service account.
Corresponds to the JSON propertyserviceAccount`
4986 4987 4988 |
# File 'lib/google/apis/run_v2/classes.rb', line 4986 def service_account @service_account end |
#source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source
Location of the source in a supported storage service.
Corresponds to the JSON property source
4991 4992 4993 |
# File 'lib/google/apis/run_v2/classes.rb', line 4991 def source @source end |
#source_provenance ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1SourceProvenance
Provenance of the source. Ways to find the original source, or verify that
some source was used for this build.
Corresponds to the JSON property sourceProvenance
4997 4998 4999 |
# File 'lib/google/apis/run_v2/classes.rb', line 4997 def source_provenance @source_provenance end |
#start_time ⇒ String
Output only. Time at which execution of the build was started.
Corresponds to the JSON property startTime
5002 5003 5004 |
# File 'lib/google/apis/run_v2/classes.rb', line 5002 def start_time @start_time end |
#status ⇒ String
Output only. Status of the build.
Corresponds to the JSON property status
5007 5008 5009 |
# File 'lib/google/apis/run_v2/classes.rb', line 5007 def status @status end |
#status_detail ⇒ String
Output only. Customer-readable message about the current status.
Corresponds to the JSON property statusDetail
5012 5013 5014 |
# File 'lib/google/apis/run_v2/classes.rb', line 5012 def status_detail @status_detail end |
#steps ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStep>
Required. The operations to be performed on the workspace.
Corresponds to the JSON property steps
5017 5018 5019 |
# File 'lib/google/apis/run_v2/classes.rb', line 5017 def steps @steps end |
#substitutions ⇒ Hash<String,String>
Substitutions data for Build resource.
Corresponds to the JSON property substitutions
5022 5023 5024 |
# File 'lib/google/apis/run_v2/classes.rb', line 5022 def substitutions @substitutions end |
#tags ⇒ Array<String>
Tags for annotation of a Build. These are not docker tags.
Corresponds to the JSON property tags
5027 5028 5029 |
# File 'lib/google/apis/run_v2/classes.rb', line 5027 def @tags end |
#timeout ⇒ String
Amount of time that this build should be allowed to run, to second granularity.
If this amount of time elapses, work on the build will cease and the build
status will be TIMEOUT. timeout starts ticking from startTime. Default
time is 60 minutes.
Corresponds to the JSON property timeout
5035 5036 5037 |
# File 'lib/google/apis/run_v2/classes.rb', line 5035 def timeout @timeout end |
#timing ⇒ Hash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan>
Output only. Stores timing information for phases of the build. Valid keys are:
- BUILD: time to execute all build steps. * PUSH: time to push all artifacts
including docker images and non docker artifacts. * FETCHSOURCE: time to fetch
source. * SETUPBUILD: time to set up build. If the build does not specify
source or images, these keys will not be included.
Corresponds to the JSON property
timing
5044 5045 5046 |
# File 'lib/google/apis/run_v2/classes.rb', line 5044 def timing @timing end |
#warnings ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Warning>
Output only. Non-fatal problems encountered during the execution of the build.
Corresponds to the JSON property warnings
5049 5050 5051 |
# File 'lib/google/apis/run_v2/classes.rb', line 5049 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 |
# File 'lib/google/apis/run_v2/classes.rb', line 5056 def update!(**args) @approval = args[:approval] if args.key?(:approval) @artifacts = args[:artifacts] if args.key?(:artifacts) @available_secrets = args[:available_secrets] if args.key?(:available_secrets) @build_trigger_id = args[:build_trigger_id] if args.key?(:build_trigger_id) @create_time = args[:create_time] if args.key?(:create_time) @dependencies = args[:dependencies] if args.key?(:dependencies) @failure_info = args[:failure_info] if args.key?(:failure_info) @finish_time = args[:finish_time] if args.key?(:finish_time) @git_config = args[:git_config] if args.key?(:git_config) @id = args[:id] if args.key?(:id) @images = args[:images] if args.key?(:images) @log_url = args[:log_url] if args.key?(:log_url) @logs_bucket = args[:logs_bucket] if args.key?(:logs_bucket) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @project_id = args[:project_id] if args.key?(:project_id) @queue_ttl = args[:queue_ttl] if args.key?(:queue_ttl) @results = args[:results] if args.key?(:results) @secrets = args[:secrets] if args.key?(:secrets) @service_account = args[:service_account] if args.key?(:service_account) @source = args[:source] if args.key?(:source) @source_provenance = args[:source_provenance] if args.key?(:source_provenance) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_detail = args[:status_detail] if args.key?(:status_detail) @steps = args[:steps] if args.key?(:steps) @substitutions = args[:substitutions] if args.key?(:substitutions) @tags = args[:tags] if args.key?(:tags) @timeout = args[:timeout] if args.key?(:timeout) @timing = args[:timing] if args.key?(:timing) @warnings = args[:warnings] if args.key?(:warnings) end |