Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildApproval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

BuildApproval describes a build's approval configuration, state, and result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuildApproval

Returns a new instance of GoogleDevtoolsCloudbuildV1BuildApproval.



4547
4548
4549
# File 'lib/google/apis/run_v2/classes.rb', line 4547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalConfig

ApprovalConfig describes configuration for manual approval of a build. Corresponds to the JSON property config



4534
4535
4536
# File 'lib/google/apis/run_v2/classes.rb', line 4534

def config
  @config
end

#resultGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ApprovalResult

ApprovalResult describes the decision and associated metadata of a manual approval of a build. Corresponds to the JSON property result



4540
4541
4542
# File 'lib/google/apis/run_v2/classes.rb', line 4540

def result
  @result
end

#stateString

Output only. The state of this build's approval. Corresponds to the JSON property state

Returns:

  • (String)


4545
4546
4547
# File 'lib/google/apis/run_v2/classes.rb', line 4545

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4552
4553
4554
4555
4556
# File 'lib/google/apis/run_v2/classes.rb', line 4552

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @result = args[:result] if args.key?(:result)
  @state = args[:state] if args.key?(:state)
end