Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

An image built by the pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1BuiltImage

Returns a new instance of GoogleDevtoolsCloudbuildV1BuiltImage.



5526
5527
5528
# File 'lib/google/apis/run_v2/classes.rb', line 5526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


5502
5503
5504
# File 'lib/google/apis/run_v2/classes.rb', line 5502

def artifact_registry_package
  @artifact_registry_package
end

#digestString

Docker Registry 2.0 digest. Corresponds to the JSON property digest

Returns:

  • (String)


5507
5508
5509
# File 'lib/google/apis/run_v2/classes.rb', line 5507

def digest
  @digest
end

#nameString

Name used to push the container image to Google Container Registry, as presented to docker push. Corresponds to the JSON property name

Returns:

  • (String)


5513
5514
5515
# File 'lib/google/apis/run_v2/classes.rb', line 5513

def name
  @name
end

#oci_media_typeString

Output only. The OCI media type of the artifact. Non-OCI images, such as Docker images, will have an unspecified value. Corresponds to the JSON property ociMediaType

Returns:

  • (String)


5519
5520
5521
# File 'lib/google/apis/run_v2/classes.rb', line 5519

def oci_media_type
  @oci_media_type
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



5524
5525
5526
# File 'lib/google/apis/run_v2/classes.rb', line 5524

def push_timing
  @push_timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5531
5532
5533
5534
5535
5536
5537
# File 'lib/google/apis/run_v2/classes.rb', line 5531

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @digest = args[:digest] if args.key?(:digest)
  @name = args[:name] if args.key?(:name)
  @oci_media_type = args[:oci_media_type] if args.key?(:oci_media_type)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
end