Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Instance Attribute Summary collapse
-
#dir ⇒ String
Optional.
-
#repository ⇒ String
Required.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ConnectedRepository
constructor
A new instance of GoogleDevtoolsCloudbuildV1ConnectedRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1ConnectedRepository
Returns a new instance of GoogleDevtoolsCloudbuildV1ConnectedRepository.
4958 4959 4960 |
# File 'lib/google/apis/run_v2/classes.rb', line 4958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dir ⇒ String
Optional. Directory, relative to the source root, in which to run the build.
Corresponds to the JSON property dir
4944 4945 4946 |
# File 'lib/google/apis/run_v2/classes.rb', line 4944 def dir @dir end |
#repository ⇒ String
Required. Name of the Google Cloud Build repository, formatted as projects/*/
locations/*/connections/*/repositories/*.
Corresponds to the JSON property repository
4950 4951 4952 |
# File 'lib/google/apis/run_v2/classes.rb', line 4950 def repository @repository end |
#revision ⇒ String
Required. The revision to fetch from the Git repository such as a branch, a
tag, a commit SHA, or any Git ref.
Corresponds to the JSON property revision
4956 4957 4958 |
# File 'lib/google/apis/run_v2/classes.rb', line 4956 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4963 4964 4965 4966 4967 |
# File 'lib/google/apis/run_v2/classes.rb', line 4963 def update!(**args) @dir = args[:dir] if args.key?(:dir) @repository = args[:repository] if args.key?(:repository) @revision = args[:revision] if args.key?(:revision) end |