Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A dependency that the Cloud Build worker will fetch before executing user steps.
Instance Attribute Summary collapse
-
#empty ⇒ Boolean
(also: #empty?)
If set to true disable all dependency fetching (ignoring the default source as well).
-
#generic_artifact ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifactDependency
Represents a generic artifact as a build dependency.
-
#git_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency
Represents a git repository as a build dependency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency
constructor
A new instance of GoogleDevtoolsCloudbuildV1Dependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency
Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.
5601 5602 5603 |
# File 'lib/google/apis/run_v2/classes.rb', line 5601 def initialize(**args) update!(**args) end |
Instance Attribute Details
#empty ⇒ Boolean Also known as: empty?
If set to true disable all dependency fetching (ignoring the default source as
well).
Corresponds to the JSON property empty
5588 5589 5590 |
# File 'lib/google/apis/run_v2/classes.rb', line 5588 def empty @empty end |
#generic_artifact ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifactDependency
Represents a generic artifact as a build dependency.
Corresponds to the JSON property genericArtifact
5594 5595 5596 |
# File 'lib/google/apis/run_v2/classes.rb', line 5594 def generic_artifact @generic_artifact end |
#git_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency
Represents a git repository as a build dependency.
Corresponds to the JSON property gitSource
5599 5600 5601 |
# File 'lib/google/apis/run_v2/classes.rb', line 5599 def git_source @git_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5606 5607 5608 5609 5610 |
# File 'lib/google/apis/run_v2/classes.rb', line 5606 def update!(**args) @empty = args[:empty] if args.key?(:empty) @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact) @git_source = args[:git_source] if args.key?(:git_source) end |