Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.



5633
5634
5635
# File 'lib/google/apis/run_v2/classes.rb', line 5633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


5620
5621
5622
# File 'lib/google/apis/run_v2/classes.rb', line 5620

def empty
  @empty
end

#generic_artifactGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifactDependency

Represents a generic artifact as a build dependency. Corresponds to the JSON property genericArtifact



5626
5627
5628
# File 'lib/google/apis/run_v2/classes.rb', line 5626

def generic_artifact
  @generic_artifact
end

#git_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



5631
5632
5633
# File 'lib/google/apis/run_v2/classes.rb', line 5631

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5638
5639
5640
5641
5642
# File 'lib/google/apis/run_v2/classes.rb', line 5638

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact)
  @git_source = args[:git_source] if args.key?(:git_source)
end