Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A dependency that the Cloud Build worker will fetch before executing user steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Dependency

Returns a new instance of GoogleDevtoolsCloudbuildV1Dependency.



5595
5596
5597
# File 'lib/google/apis/run_v2/classes.rb', line 5595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emptyBoolean Also known as: empty?

If set to true disable all dependency fetching (ignoring the default source as well). Corresponds to the JSON property empty

Returns:

  • (Boolean)


5582
5583
5584
# File 'lib/google/apis/run_v2/classes.rb', line 5582

def empty
  @empty
end

#generic_artifactGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifactDependency

Represents a generic artifact as a build dependency. Corresponds to the JSON property genericArtifact



5588
5589
5590
# File 'lib/google/apis/run_v2/classes.rb', line 5588

def generic_artifact
  @generic_artifact
end

#git_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency

Represents a git repository as a build dependency. Corresponds to the JSON property gitSource



5593
5594
5595
# File 'lib/google/apis/run_v2/classes.rb', line 5593

def git_source
  @git_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5600
5601
5602
5603
5604
# File 'lib/google/apis/run_v2/classes.rb', line 5600

def update!(**args)
  @empty = args[:empty] if args.key?(:empty)
  @generic_artifact = args[:generic_artifact] if args.key?(:generic_artifact)
  @git_source = args[:git_source] if args.key?(:git_source)
end