Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
This config defines the location of a source through Developer Connect.
Instance Attribute Summary collapse
-
#dir ⇒ String
Required.
-
#git_repository_link ⇒ String
Required.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1DeveloperConnectConfig
constructor
A new instance of GoogleDevtoolsCloudbuildV1DeveloperConnectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1DeveloperConnectConfig
Returns a new instance of GoogleDevtoolsCloudbuildV1DeveloperConnectConfig.
5628 5629 5630 |
# File 'lib/google/apis/run_v2/classes.rb', line 5628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dir ⇒ String
Required. Directory, relative to the source root, in which to run the build.
Corresponds to the JSON property dir
5614 5615 5616 |
# File 'lib/google/apis/run_v2/classes.rb', line 5614 def dir @dir end |
#git_repository_link ⇒ String
Required. The Developer Connect Git repository link, formatted as projects/*/
locations/*/connections/*/gitRepositoryLink/*.
Corresponds to the JSON property gitRepositoryLink
5620 5621 5622 |
# File 'lib/google/apis/run_v2/classes.rb', line 5620 def git_repository_link @git_repository_link end |
#revision ⇒ String
Required. The revision to fetch from the Git repository such as a branch, a
tag, a commit SHA, or any Git ref.
Corresponds to the JSON property revision
5626 5627 5628 |
# File 'lib/google/apis/run_v2/classes.rb', line 5626 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5633 5634 5635 5636 5637 |
# File 'lib/google/apis/run_v2/classes.rb', line 5633 def update!(**args) @dir = args[:dir] if args.key?(:dir) @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link) @revision = args[:revision] if args.key?(:revision) end |