Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FailureInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FailureInfo

Returns a new instance of GoogleDevtoolsCloudbuildV1FailureInfo.



5654
5655
5656
# File 'lib/google/apis/run_v2/classes.rb', line 5654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


5647
5648
5649
# File 'lib/google/apis/run_v2/classes.rb', line 5647

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/run_v2/classes.rb', line 5652

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5659
5660
5661
5662
# File 'lib/google/apis/run_v2/classes.rb', line 5659

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end