Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FailureInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A fatal problem encountered during the execution of the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FailureInfo

Returns a new instance of GoogleDevtoolsCloudbuildV1FailureInfo.



5622
5623
5624
# File 'lib/google/apis/run_v2/classes.rb', line 5622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

Explains the failure issue in more detail using hard-coded text. Corresponds to the JSON property detail

Returns:

  • (String)


5615
5616
5617
# File 'lib/google/apis/run_v2/classes.rb', line 5615

def detail
  @detail
end

#typeString

The name of the failure. Corresponds to the JSON property type

Returns:

  • (String)


5620
5621
5622
# File 'lib/google/apis/run_v2/classes.rb', line 5620

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5627
5628
5629
5630
# File 'lib/google/apis/run_v2/classes.rb', line 5627

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @type = args[:type] if args.key?(:type)
end