Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FileHashes

Returns a new instance of GoogleDevtoolsCloudbuildV1FileHashes.



5681
5682
5683
# File 'lib/google/apis/run_v2/classes.rb', line 5681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Hash>

Collection of file hashes. Corresponds to the JSON property fileHash



5679
5680
5681
# File 'lib/google/apis/run_v2/classes.rb', line 5679

def file_hash
  @file_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5686
5687
5688
# File 'lib/google/apis/run_v2/classes.rb', line 5686

def update!(**args)
  @file_hash = args[:file_hash] if args.key?(:file_hash)
end