Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
Instance Attribute Summary collapse
-
#file_hash ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Hash>
Collection of file hashes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FileHashes
constructor
A new instance of GoogleDevtoolsCloudbuildV1FileHashes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1FileHashes
Returns a new instance of GoogleDevtoolsCloudbuildV1FileHashes.
5066 5067 5068 |
# File 'lib/google/apis/run_v2/classes.rb', line 5066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hash ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Hash>
Collection of file hashes.
Corresponds to the JSON property fileHash
5064 5065 5066 |
# File 'lib/google/apis/run_v2/classes.rb', line 5064 def file_hash @file_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5071 5072 5073 |
# File 'lib/google/apis/run_v2/classes.rb', line 5071 def update!(**args) @file_hash = args[:file_hash] if args.key?(:file_hash) end |