Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifact
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GenericArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Generic artifact to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#folder ⇒ String
Required.
-
#registry_path ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GenericArtifact
constructor
A new instance of GoogleDevtoolsCloudbuildV1GenericArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GenericArtifact
Returns a new instance of GoogleDevtoolsCloudbuildV1GenericArtifact.
5671 5672 5673 |
# File 'lib/google/apis/run_v2/classes.rb', line 5671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folder ⇒ String
Required. Path to the generic artifact in the build's workspace to be uploaded
to Artifact Registry.
Corresponds to the JSON property folder
5662 5663 5664 |
# File 'lib/google/apis/run_v2/classes.rb', line 5662 def folder @folder end |
#registry_path ⇒ String
Required. Registry path to upload the generic artifact to, in the form
projects/$PROJECT/locations/$LOCATION/repositories/$REPO/packages/$PACKAGE/
versions/$VERSION
Corresponds to the JSON property registryPath
5669 5670 5671 |
# File 'lib/google/apis/run_v2/classes.rb', line 5669 def registry_path @registry_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5676 5677 5678 5679 |
# File 'lib/google/apis/run_v2/classes.rb', line 5676 def update!(**args) @folder = args[:folder] if args.key?(:folder) @registry_path = args[:registry_path] if args.key?(:registry_path) end |