Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Represents a git repository as a build dependency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency

Returns a new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.



5868
5869
5870
# File 'lib/google/apis/run_v2/classes.rb', line 5868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#depthFixnum

Optional. How much history should be fetched for the build (default 1, -1 for all history). Corresponds to the JSON property depth

Returns:

  • (Fixnum)


5845
5846
5847
# File 'lib/google/apis/run_v2/classes.rb', line 5845

def depth
  @depth
end

#dest_pathString

Required. Where should the files be placed on the worker. Corresponds to the JSON property destPath

Returns:

  • (String)


5850
5851
5852
# File 'lib/google/apis/run_v2/classes.rb', line 5850

def dest_path
  @dest_path
end

#recurse_submodulesBoolean Also known as: recurse_submodules?

Optional. True if submodules should be fetched too (default false). Corresponds to the JSON property recurseSubmodules

Returns:

  • (Boolean)


5855
5856
5857
# File 'lib/google/apis/run_v2/classes.rb', line 5855

def recurse_submodules
  @recurse_submodules
end

#repositoryGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceRepository

A repository for a git source. Corresponds to the JSON property repository



5861
5862
5863
# File 'lib/google/apis/run_v2/classes.rb', line 5861

def repository
  @repository
end

#revisionString

Required. The revision that we will fetch the repo at. Corresponds to the JSON property revision

Returns:

  • (String)


5866
5867
5868
# File 'lib/google/apis/run_v2/classes.rb', line 5866

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5873
5874
5875
5876
5877
5878
5879
# File 'lib/google/apis/run_v2/classes.rb', line 5873

def update!(**args)
  @depth = args[:depth] if args.key?(:depth)
  @dest_path = args[:dest_path] if args.key?(:dest_path)
  @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules)
  @repository = args[:repository] if args.key?(:repository)
  @revision = args[:revision] if args.key?(:revision)
end