Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceDependency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Represents a git repository as a build dependency.
Instance Attribute Summary collapse
-
#depth ⇒ Fixnum
Optional.
-
#dest_path ⇒ String
Required.
-
#recurse_submodules ⇒ Boolean
(also: #recurse_submodules?)
Optional.
-
#repository ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceRepository
A repository for a git source.
-
#revision ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency
constructor
A new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GitSourceDependency
Returns a new instance of GoogleDevtoolsCloudbuildV1GitSourceDependency.
5868 5869 5870 |
# File 'lib/google/apis/run_v2/classes.rb', line 5868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#depth ⇒ Fixnum
Optional. How much history should be fetched for the build (default 1, -1 for
all history).
Corresponds to the JSON property depth
5845 5846 5847 |
# File 'lib/google/apis/run_v2/classes.rb', line 5845 def depth @depth end |
#dest_path ⇒ String
Required. Where should the files be placed on the worker.
Corresponds to the JSON property destPath
5850 5851 5852 |
# File 'lib/google/apis/run_v2/classes.rb', line 5850 def dest_path @dest_path end |
#recurse_submodules ⇒ Boolean Also known as: recurse_submodules?
Optional. True if submodules should be fetched too (default false).
Corresponds to the JSON property recurseSubmodules
5855 5856 5857 |
# File 'lib/google/apis/run_v2/classes.rb', line 5855 def recurse_submodules @recurse_submodules end |
#repository ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSourceRepository
A repository for a git source.
Corresponds to the JSON property repository
5861 5862 5863 |
# File 'lib/google/apis/run_v2/classes.rb', line 5861 def repository @repository end |
#revision ⇒ String
Required. The revision that we will fetch the repo at.
Corresponds to the JSON property revision
5866 5867 5868 |
# File 'lib/google/apis/run_v2/classes.rb', line 5866 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5873 5874 5875 5876 5877 5878 5879 |
# File 'lib/google/apis/run_v2/classes.rb', line 5873 def update!(**args) @depth = args[:depth] if args.key?(:depth) @dest_path = args[:dest_path] if args.key?(:dest_path) @recurse_submodules = args[:recurse_submodules] if args.key?(:recurse_submodules) @repository = args[:repository] if args.key?(:repository) @revision = args[:revision] if args.key?(:revision) end |