Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GoModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Go module to upload to Artifact Registry upon successful completion of all build steps. A module refers to all dependencies in a go.mod file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1GoModule

Returns a new instance of GoogleDevtoolsCloudbuildV1GoModule.



5881
5882
5883
# File 'lib/google/apis/run_v2/classes.rb', line 5881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#module_pathString

Optional. The Go module's "module path". e.g. example.com/foo/v2 Corresponds to the JSON property modulePath

Returns:

  • (String)


5846
5847
5848
# File 'lib/google/apis/run_v2/classes.rb', line 5846

def module_path
  @module_path
end

#module_versionString

Optional. The Go module's semantic version in the form vX.Y.Z. e.g. v0.1.1 Pre- release identifiers can also be added by appending a dash and dot separated ASCII alphanumeric characters and hyphens. e.g. v0.2.3-alpha.x.12m.5 Corresponds to the JSON property moduleVersion

Returns:

  • (String)


5853
5854
5855
# File 'lib/google/apis/run_v2/classes.rb', line 5853

def module_version
  @module_version
end

#repository_locationString

Optional. Location of the Artifact Registry repository. i.e. us-east1 Defaults to the build’s location. Corresponds to the JSON property repositoryLocation

Returns:

  • (String)


5859
5860
5861
# File 'lib/google/apis/run_v2/classes.rb', line 5859

def repository_location
  @repository_location
end

#repository_nameString

Optional. Artifact Registry repository name. Specified Go modules will be zipped and uploaded to Artifact Registry with this location as a prefix. e.g. my-go-repo Corresponds to the JSON property repositoryName

Returns:

  • (String)


5866
5867
5868
# File 'lib/google/apis/run_v2/classes.rb', line 5866

def repository_name
  @repository_name
end

#repository_project_idString

Optional. Project ID of the Artifact Registry repository. Defaults to the build project. Corresponds to the JSON property repositoryProjectId

Returns:

  • (String)


5872
5873
5874
# File 'lib/google/apis/run_v2/classes.rb', line 5872

def repository_project_id
  @repository_project_id
end

#source_pathString

Optional. Source path of the go.mod file in the build's workspace. If not specified, this will default to the current directory. e.g. ~/code/go/ mypackage Corresponds to the JSON property sourcePath

Returns:

  • (String)


5879
5880
5881
# File 'lib/google/apis/run_v2/classes.rb', line 5879

def source_path
  @source_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5886
5887
5888
5889
5890
5891
5892
5893
# File 'lib/google/apis/run_v2/classes.rb', line 5886

def update!(**args)
  @module_path = args[:module_path] if args.key?(:module_path)
  @module_version = args[:module_version] if args.key?(:module_version)
  @repository_location = args[:repository_location] if args.key?(:repository_location)
  @repository_name = args[:repository_name] if args.key?(:repository_name)
  @repository_project_id = args[:repository_project_id] if args.key?(:repository_project_id)
  @source_path = args[:source_path] if args.key?(:source_path)
end