Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1MavenArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1MavenArtifact.



6049
6050
6051
# File 'lib/google/apis/run_v2/classes.rb', line 6049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Maven artifactId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property artifactId

Returns:

  • (String)


6014
6015
6016
# File 'lib/google/apis/run_v2/classes.rb', line 6014

def artifact_id
  @artifact_id
end

#deploy_folderString

Optional. Path to a folder containing the files to upload to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/target/, or a relative path from /workspace, e.g. my-app/target/. This field is mutually exclusive with the path field. Corresponds to the JSON property deployFolder

Returns:

  • (String)


6022
6023
6024
# File 'lib/google/apis/run_v2/classes.rb', line 6022

def deploy_folder
  @deploy_folder
end

#group_idString

Maven groupId value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property groupId

Returns:

  • (String)


6027
6028
6029
# File 'lib/google/apis/run_v2/classes.rb', line 6027

def group_id
  @group_id
end

#pathString

Optional. Path to an artifact in the build's workspace to be uploaded to Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/ target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/ target/my-app-1.0.SNAPSHOT.jar. Corresponds to the JSON property path

Returns:

  • (String)


6035
6036
6037
# File 'lib/google/apis/run_v2/classes.rb', line 6035

def path
  @path
end

#repositoryString

Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix. Corresponds to the JSON property repository

Returns:

  • (String)


6042
6043
6044
# File 'lib/google/apis/run_v2/classes.rb', line 6042

def repository
  @repository
end

#versionString

Maven version value used when uploading the artifact to Artifact Registry. Corresponds to the JSON property version

Returns:

  • (String)


6047
6048
6049
# File 'lib/google/apis/run_v2/classes.rb', line 6047

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6054
6055
6056
6057
6058
6059
6060
6061
# File 'lib/google/apis/run_v2/classes.rb', line 6054

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder)
  @group_id = args[:group_id] if args.key?(:group_id)
  @path = args[:path] if args.key?(:path)
  @repository = args[:repository] if args.key?(:repository)
  @version = args[:version] if args.key?(:version)
end