Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1MavenArtifact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A Maven artifact to upload to Artifact Registry upon successful completion of all build steps.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Maven
artifactIdvalue used when uploading the artifact to Artifact Registry. -
#deploy_folder ⇒ String
Optional.
-
#group_id ⇒ String
Maven
groupIdvalue used when uploading the artifact to Artifact Registry. -
#path ⇒ String
Optional.
-
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$ PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be uploaded to Artifact Registry with this location as a prefix.
-
#version ⇒ String
Maven
versionvalue used when uploading the artifact to Artifact Registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1MavenArtifact
constructor
A new instance of GoogleDevtoolsCloudbuildV1MavenArtifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1MavenArtifact
Returns a new instance of GoogleDevtoolsCloudbuildV1MavenArtifact.
6017 6018 6019 |
# File 'lib/google/apis/run_v2/classes.rb', line 6017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Maven artifactId value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property artifactId
5982 5983 5984 |
# File 'lib/google/apis/run_v2/classes.rb', line 5982 def artifact_id @artifact_id end |
#deploy_folder ⇒ String
Optional. Path to a folder containing the files to upload to Artifact Registry.
This can be either an absolute path, e.g. /workspace/my-app/target/, or a
relative path from /workspace, e.g. my-app/target/. This field is mutually
exclusive with the path field.
Corresponds to the JSON property deployFolder
5990 5991 5992 |
# File 'lib/google/apis/run_v2/classes.rb', line 5990 def deploy_folder @deploy_folder end |
#group_id ⇒ String
Maven groupId value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property groupId
5995 5996 5997 |
# File 'lib/google/apis/run_v2/classes.rb', line 5995 def group_id @group_id end |
#path ⇒ String
Optional. Path to an artifact in the build's workspace to be uploaded to
Artifact Registry. This can be either an absolute path, e.g. /workspace/my-app/
target/my-app-1.0.SNAPSHOT.jar or a relative path from /workspace, e.g. my-app/
target/my-app-1.0.SNAPSHOT.jar.
Corresponds to the JSON property path
6003 6004 6005 |
# File 'lib/google/apis/run_v2/classes.rb', line 6003 def path @path end |
#repository ⇒ String
Artifact Registry repository, in the form "https://$REGION-maven.pkg.dev/$
PROJECT/$REPOSITORY" Artifact in the workspace specified by path will be
uploaded to Artifact Registry with this location as a prefix.
Corresponds to the JSON property repository
6010 6011 6012 |
# File 'lib/google/apis/run_v2/classes.rb', line 6010 def repository @repository end |
#version ⇒ String
Maven version value used when uploading the artifact to Artifact Registry.
Corresponds to the JSON property version
6015 6016 6017 |
# File 'lib/google/apis/run_v2/classes.rb', line 6015 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6022 6023 6024 6025 6026 6027 6028 6029 |
# File 'lib/google/apis/run_v2/classes.rb', line 6022 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @deploy_folder = args[:deploy_folder] if args.key?(:deploy_folder) @group_id = args[:group_id] if args.key?(:group_id) @path = args[:path] if args.key?(:path) @repository = args[:repository] if args.key?(:repository) @version = args[:version] if args.key?(:version) end |