Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results

Returns a new instance of GoogleDevtoolsCloudbuildV1Results.



6361
6362
6363
# File 'lib/google/apis/run_v2/classes.rb', line 6361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


6297
6298
6299
# File 'lib/google/apis/run_v2/classes.rb', line 6297

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



6302
6303
6304
# File 'lib/google/apis/run_v2/classes.rb', line 6302

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


6307
6308
6309
# File 'lib/google/apis/run_v2/classes.rb', line 6307

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


6316
6317
6318
# File 'lib/google/apis/run_v2/classes.rb', line 6316

def build_step_outputs
  @build_step_outputs
end

#build_step_resultsHash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuildStepResults>

Results for build steps. step_id -> Corresponds to the JSON property buildStepResults



6321
6322
6323
# File 'lib/google/apis/run_v2/classes.rb', line 6321

def build_step_results
  @build_step_results
end

#generic_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>

Output only. Generic artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property genericArtifacts



6327
6328
6329
# File 'lib/google/apis/run_v2/classes.rb', line 6327

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



6333
6334
6335
# File 'lib/google/apis/run_v2/classes.rb', line 6333

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



6338
6339
6340
# File 'lib/google/apis/run_v2/classes.rb', line 6338

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



6343
6344
6345
# File 'lib/google/apis/run_v2/classes.rb', line 6343

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



6348
6349
6350
# File 'lib/google/apis/run_v2/classes.rb', line 6348

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


6354
6355
6356
# File 'lib/google/apis/run_v2/classes.rb', line 6354

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



6359
6360
6361
# File 'lib/google/apis/run_v2/classes.rb', line 6359

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
# File 'lib/google/apis/run_v2/classes.rb', line 6366

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @build_step_results = args[:build_step_results] if args.key?(:build_step_results)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end