Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifacts created by the build pipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results

Returns a new instance of GoogleDevtoolsCloudbuildV1Results.



6286
6287
6288
# File 'lib/google/apis/run_v2/classes.rb', line 6286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_manifestString

Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property artifactManifest

Returns:

  • (String)


6227
6228
6229
# File 'lib/google/apis/run_v2/classes.rb', line 6227

def artifact_manifest
  @artifact_manifest
end

#artifact_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property artifactTiming



6232
6233
6234
# File 'lib/google/apis/run_v2/classes.rb', line 6232

def artifact_timing
  @artifact_timing
end

#build_step_imagesArray<String>

List of build step digests, in the order corresponding to build step indices. Corresponds to the JSON property buildStepImages

Returns:

  • (Array<String>)


6237
6238
6239
# File 'lib/google/apis/run_v2/classes.rb', line 6237

def build_step_images
  @build_step_images
end

#build_step_outputsArray<String>

List of build step outputs, produced by builder images, in the order corresponding to build step indices. Cloud Builders can produce this output by writing to $ BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $ BUILDER_OUTPUT variable is read-only and can't be substituted. Corresponds to the JSON property buildStepOutputs

Returns:

  • (Array<String>)


6246
6247
6248
# File 'lib/google/apis/run_v2/classes.rb', line 6246

def build_step_outputs
  @build_step_outputs
end

#generic_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact>

Output only. Generic artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property genericArtifacts



6252
6253
6254
# File 'lib/google/apis/run_v2/classes.rb', line 6252

def generic_artifacts
  @generic_artifacts
end

#go_modulesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule>

Optional. Go module artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property goModules



6258
6259
6260
# File 'lib/google/apis/run_v2/classes.rb', line 6258

def go_modules
  @go_modules
end

#imagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage>

Container images that were built as a part of the build. Corresponds to the JSON property images



6263
6264
6265
# File 'lib/google/apis/run_v2/classes.rb', line 6263

def images
  @images
end

#maven_artifactsArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>

Maven artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property mavenArtifacts



6268
6269
6270
# File 'lib/google/apis/run_v2/classes.rb', line 6268

def maven_artifacts
  @maven_artifacts
end

#npm_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>

Npm packages uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property npmPackages



6273
6274
6275
# File 'lib/google/apis/run_v2/classes.rb', line 6273

def npm_packages
  @npm_packages
end

#num_artifactsFixnum

Number of non-container artifacts uploaded to Cloud Storage. Only populated when artifacts are uploaded to Cloud Storage. Corresponds to the JSON property numArtifacts

Returns:

  • (Fixnum)


6279
6280
6281
# File 'lib/google/apis/run_v2/classes.rb', line 6279

def num_artifacts
  @num_artifacts
end

#python_packagesArray<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>

Python artifacts uploaded to Artifact Registry at the end of the build. Corresponds to the JSON property pythonPackages



6284
6285
6286
# File 'lib/google/apis/run_v2/classes.rb', line 6284

def python_packages
  @python_packages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6291
6292
6293
6294
6295
6296
6297
6298
6299
6300
6301
6302
6303
# File 'lib/google/apis/run_v2/classes.rb', line 6291

def update!(**args)
  @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest)
  @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing)
  @build_step_images = args[:build_step_images] if args.key?(:build_step_images)
  @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs)
  @generic_artifacts = args[:generic_artifacts] if args.key?(:generic_artifacts)
  @go_modules = args[:go_modules] if args.key?(:go_modules)
  @images = args[:images] if args.key?(:images)
  @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts)
  @npm_packages = args[:npm_packages] if args.key?(:npm_packages)
  @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts)
  @python_packages = args[:python_packages] if args.key?(:python_packages)
end