Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Results
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Artifacts created by the build pipeline.
Instance Attribute Summary collapse
-
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud Storage.
-
#artifact_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
-
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order corresponding to build step indices.
-
#go_modules ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional.
-
#images ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
-
#maven_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
-
#npm_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
-
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage.
-
#python_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
constructor
A new instance of GoogleDevtoolsCloudbuildV1Results.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Results
Returns a new instance of GoogleDevtoolsCloudbuildV1Results.
5614 5615 5616 |
# File 'lib/google/apis/run_v2/classes.rb', line 5614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_manifest ⇒ String
Path to the artifact manifest for non-container artifacts uploaded to Cloud
Storage. Only populated when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property artifactManifest
5561 5562 5563 |
# File 'lib/google/apis/run_v2/classes.rb', line 5561 def artifact_manifest @artifact_manifest end |
#artifact_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property artifactTiming
5566 5567 5568 |
# File 'lib/google/apis/run_v2/classes.rb', line 5566 def artifact_timing @artifact_timing end |
#build_step_images ⇒ Array<String>
List of build step digests, in the order corresponding to build step indices.
Corresponds to the JSON property buildStepImages
5571 5572 5573 |
# File 'lib/google/apis/run_v2/classes.rb', line 5571 def build_step_images @build_step_images end |
#build_step_outputs ⇒ Array<String>
List of build step outputs, produced by builder images, in the order
corresponding to build step indices. Cloud Builders can produce this output by writing to $
BUILDER_OUTPUT/output. Only the first 50KB of data is stored. Note that the $
BUILDER_OUTPUT variable is read-only and can't be substituted.
Corresponds to the JSON property buildStepOutputs
5580 5581 5582 |
# File 'lib/google/apis/run_v2/classes.rb', line 5580 def build_step_outputs @build_step_outputs end |
#go_modules ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule>
Optional. Go module artifacts uploaded to Artifact Registry at the end of the
build.
Corresponds to the JSON property goModules
5586 5587 5588 |
# File 'lib/google/apis/run_v2/classes.rb', line 5586 def go_modules @go_modules end |
#images ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1BuiltImage>
Container images that were built as a part of the build.
Corresponds to the JSON property images
5591 5592 5593 |
# File 'lib/google/apis/run_v2/classes.rb', line 5591 def images @images end |
#maven_artifacts ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact>
Maven artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property mavenArtifacts
5596 5597 5598 |
# File 'lib/google/apis/run_v2/classes.rb', line 5596 def maven_artifacts @maven_artifacts end |
#npm_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage>
Npm packages uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property npmPackages
5601 5602 5603 |
# File 'lib/google/apis/run_v2/classes.rb', line 5601 def npm_packages @npm_packages end |
#num_artifacts ⇒ Fixnum
Number of non-container artifacts uploaded to Cloud Storage. Only populated
when artifacts are uploaded to Cloud Storage.
Corresponds to the JSON property numArtifacts
5607 5608 5609 |
# File 'lib/google/apis/run_v2/classes.rb', line 5607 def num_artifacts @num_artifacts end |
#python_packages ⇒ Array<Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage>
Python artifacts uploaded to Artifact Registry at the end of the build.
Corresponds to the JSON property pythonPackages
5612 5613 5614 |
# File 'lib/google/apis/run_v2/classes.rb', line 5612 def python_packages @python_packages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5619 5620 5621 5622 5623 5624 5625 5626 5627 5628 5629 5630 |
# File 'lib/google/apis/run_v2/classes.rb', line 5619 def update!(**args) @artifact_manifest = args[:artifact_manifest] if args.key?(:artifact_manifest) @artifact_timing = args[:artifact_timing] if args.key?(:artifact_timing) @build_step_images = args[:build_step_images] if args.key?(:build_step_images) @build_step_outputs = args[:build_step_outputs] if args.key?(:build_step_outputs) @go_modules = args[:go_modules] if args.key?(:go_modules) @images = args[:images] if args.key?(:images) @maven_artifacts = args[:maven_artifacts] if args.key?(:maven_artifacts) @npm_packages = args[:npm_packages] if args.key?(:npm_packages) @num_artifacts = args[:num_artifacts] if args.key?(:num_artifacts) @python_packages = args[:python_packages] if args.key?(:python_packages) end |