Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1SecretManagerSecret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Pairs a secret environment variable with a SecretVersion in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1SecretManagerSecret

Returns a new instance of GoogleDevtoolsCloudbuildV1SecretManagerSecret.



5681
5682
5683
# File 'lib/google/apis/run_v2/classes.rb', line 5681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#envString

Environment variable name to associate with the secret. Secret environment variables must be unique across all of a build's secrets, and must be used by at least one build step. Corresponds to the JSON property env

Returns:

  • (String)


5674
5675
5676
# File 'lib/google/apis/run_v2/classes.rb', line 5674

def env
  @env
end

#version_nameString

Resource name of the SecretVersion. In format: projects//secrets//versions/* Corresponds to the JSON property versionName

Returns:

  • (String)


5679
5680
5681
# File 'lib/google/apis/run_v2/classes.rb', line 5679

def version_name
  @version_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5686
5687
5688
5689
# File 'lib/google/apis/run_v2/classes.rb', line 5686

def update!(**args)
  @env = args[:env] if args.key?(:env)
  @version_name = args[:version_name] if args.key?(:version_name)
end