Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Location of the source in a supported storage service.
Instance Attribute Summary collapse
-
#connected_repository ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#developer_connect_config ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig
This config defines the location of a source through Developer Connect.
-
#git_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
-
#repo_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
-
#storage_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
-
#storage_source_manifest ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Source
constructor
A new instance of GoogleDevtoolsCloudbuildV1Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Source
Returns a new instance of GoogleDevtoolsCloudbuildV1Source.
6470 6471 6472 |
# File 'lib/google/apis/run_v2/classes.rb', line 6470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_repository ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property connectedRepository
6441 6442 6443 |
# File 'lib/google/apis/run_v2/classes.rb', line 6441 def connected_repository @connected_repository end |
#developer_connect_config ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig
This config defines the location of a source through Developer Connect.
Corresponds to the JSON property developerConnectConfig
6446 6447 6448 |
# File 'lib/google/apis/run_v2/classes.rb', line 6446 def developer_connect_config @developer_connect_config end |
#git_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property gitSource
6451 6452 6453 |
# File 'lib/google/apis/run_v2/classes.rb', line 6451 def git_source @git_source end |
#repo_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property repoSource
6456 6457 6458 |
# File 'lib/google/apis/run_v2/classes.rb', line 6456 def repo_source @repo_source end |
#storage_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property storageSource
6461 6462 6463 |
# File 'lib/google/apis/run_v2/classes.rb', line 6461 def storage_source @storage_source end |
#storage_source_manifest ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property storageSourceManifest
6468 6469 6470 |
# File 'lib/google/apis/run_v2/classes.rb', line 6468 def storage_source_manifest @storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6475 6476 6477 6478 6479 6480 6481 6482 |
# File 'lib/google/apis/run_v2/classes.rb', line 6475 def update!(**args) @connected_repository = args[:connected_repository] if args.key?(:connected_repository) @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config) @git_source = args[:git_source] if args.key?(:git_source) @repo_source = args[:repo_source] if args.key?(:repo_source) @storage_source = args[:storage_source] if args.key?(:storage_source) @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest) end |