Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Location of the source in a supported storage service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Source

Returns a new instance of GoogleDevtoolsCloudbuildV1Source.



6502
6503
6504
# File 'lib/google/apis/run_v2/classes.rb', line 6502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_repositoryGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property connectedRepository



6473
6474
6475
# File 'lib/google/apis/run_v2/classes.rb', line 6473

def connected_repository
  @connected_repository
end

#developer_connect_configGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

This config defines the location of a source through Developer Connect. Corresponds to the JSON property developerConnectConfig



6478
6479
6480
# File 'lib/google/apis/run_v2/classes.rb', line 6478

def developer_connect_config
  @developer_connect_config
end

#git_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property gitSource



6483
6484
6485
# File 'lib/google/apis/run_v2/classes.rb', line 6483

def git_source
  @git_source
end

#repo_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property repoSource



6488
6489
6490
# File 'lib/google/apis/run_v2/classes.rb', line 6488

def repo_source
  @repo_source
end

#storage_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property storageSource



6493
6494
6495
# File 'lib/google/apis/run_v2/classes.rb', line 6493

def storage_source
  @storage_source
end

#storage_source_manifestGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property storageSourceManifest



6500
6501
6502
# File 'lib/google/apis/run_v2/classes.rb', line 6500

def storage_source_manifest
  @storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6507
6508
6509
6510
6511
6512
6513
6514
# File 'lib/google/apis/run_v2/classes.rb', line 6507

def update!(**args)
  @connected_repository = args[:connected_repository] if args.key?(:connected_repository)
  @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config)
  @git_source = args[:git_source] if args.key?(:git_source)
  @repo_source = args[:repo_source] if args.key?(:repo_source)
  @storage_source = args[:storage_source] if args.key?(:storage_source)
  @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest)
end