Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Location of the source in a supported storage service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Source

Returns a new instance of GoogleDevtoolsCloudbuildV1Source.



5753
5754
5755
# File 'lib/google/apis/run_v2/classes.rb', line 5753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_repositoryGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property connectedRepository



5724
5725
5726
# File 'lib/google/apis/run_v2/classes.rb', line 5724

def connected_repository
  @connected_repository
end

#developer_connect_configGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1DeveloperConnectConfig

This config defines the location of a source through Developer Connect. Corresponds to the JSON property developerConnectConfig



5729
5730
5731
# File 'lib/google/apis/run_v2/classes.rb', line 5729

def developer_connect_config
  @developer_connect_config
end

#git_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property gitSource



5734
5735
5736
# File 'lib/google/apis/run_v2/classes.rb', line 5734

def git_source
  @git_source
end

#repo_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property repoSource



5739
5740
5741
# File 'lib/google/apis/run_v2/classes.rb', line 5739

def repo_source
  @repo_source
end

#storage_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property storageSource



5744
5745
5746
# File 'lib/google/apis/run_v2/classes.rb', line 5744

def storage_source
  @storage_source
end

#storage_source_manifestGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property storageSourceManifest



5751
5752
5753
# File 'lib/google/apis/run_v2/classes.rb', line 5751

def storage_source_manifest
  @storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5758
5759
5760
5761
5762
5763
5764
5765
# File 'lib/google/apis/run_v2/classes.rb', line 5758

def update!(**args)
  @connected_repository = args[:connected_repository] if args.key?(:connected_repository)
  @developer_connect_config = args[:developer_connect_config] if args.key?(:developer_connect_config)
  @git_source = args[:git_source] if args.key?(:git_source)
  @repo_source = args[:repo_source] if args.key?(:repo_source)
  @storage_source = args[:storage_source] if args.key?(:storage_source)
  @storage_source_manifest = args[:storage_source_manifest] if args.key?(:storage_source_manifest)
end