Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1SourceProvenance
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1SourceProvenance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Provenance of the source. Ways to find the original source, or verify that some source was used for this build.
Instance Attribute Summary collapse
-
#file_hashes ⇒ Hash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes>
Output only.
-
#resolved_connected_repository ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
-
#resolved_git_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
-
#resolved_repo_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
-
#resolved_storage_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
-
#resolved_storage_source_manifest ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1SourceProvenance
constructor
A new instance of GoogleDevtoolsCloudbuildV1SourceProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1SourceProvenance
Returns a new instance of GoogleDevtoolsCloudbuildV1SourceProvenance.
6522 6523 6524 |
# File 'lib/google/apis/run_v2/classes.rb', line 6522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_hashes ⇒ Hash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes>
Output only. Hash(es) of the build source, which can be used to verify that
the original source integrity was maintained in the build. Note that
FileHashes will only be populated if BuildOptions has requested a
SourceProvenanceHash. The keys to this map are file paths used as build
source and the values contain the hash values for those files. If the build
source came in a single package such as a gzipped tarfile (.tar.gz), the
FileHash will be for the single path to that file.
Corresponds to the JSON property fileHashes
6493 6494 6495 |
# File 'lib/google/apis/run_v2/classes.rb', line 6493 def file_hashes @file_hashes end |
#resolved_connected_repository ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository
Location of the source in a 2nd-gen Google Cloud Build repository resource.
Corresponds to the JSON property resolvedConnectedRepository
6498 6499 6500 |
# File 'lib/google/apis/run_v2/classes.rb', line 6498 def resolved_connected_repository @resolved_connected_repository end |
#resolved_git_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource
Location of the source in any accessible Git repository.
Corresponds to the JSON property resolvedGitSource
6503 6504 6505 |
# File 'lib/google/apis/run_v2/classes.rb', line 6503 def resolved_git_source @resolved_git_source end |
#resolved_repo_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource
Location of the source in a Google Cloud Source Repository.
Corresponds to the JSON property resolvedRepoSource
6508 6509 6510 |
# File 'lib/google/apis/run_v2/classes.rb', line 6508 def resolved_repo_source @resolved_repo_source end |
#resolved_storage_source ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource
Location of the source in an archive file in Cloud Storage.
Corresponds to the JSON property resolvedStorageSource
6513 6514 6515 |
# File 'lib/google/apis/run_v2/classes.rb', line 6513 def resolved_storage_source @resolved_storage_source end |
#resolved_storage_source_manifest ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest
Location of the source manifest in Cloud Storage. This feature is in Preview;
see description here.
Corresponds to the JSON property resolvedStorageSourceManifest
6520 6521 6522 |
# File 'lib/google/apis/run_v2/classes.rb', line 6520 def resolved_storage_source_manifest @resolved_storage_source_manifest end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6527 6528 6529 6530 6531 6532 6533 6534 |
# File 'lib/google/apis/run_v2/classes.rb', line 6527 def update!(**args) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @resolved_connected_repository = args[:resolved_connected_repository] if args.key?(:resolved_connected_repository) @resolved_git_source = args[:resolved_git_source] if args.key?(:resolved_git_source) @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source) @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source) @resolved_storage_source_manifest = args[:resolved_storage_source_manifest] if args.key?(:resolved_storage_source_manifest) end |