Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1SourceProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Provenance of the source. Ways to find the original source, or verify that some source was used for this build.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1SourceProvenance

Returns a new instance of GoogleDevtoolsCloudbuildV1SourceProvenance.



6484
6485
6486
# File 'lib/google/apis/run_v2/classes.rb', line 6484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_hashesHash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes>

Output only. Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build. Note that FileHashes will only be populated if BuildOptions has requested a SourceProvenanceHash. The keys to this map are file paths used as build source and the values contain the hash values for those files. If the build source came in a single package such as a gzipped tarfile (.tar.gz), the FileHash will be for the single path to that file. Corresponds to the JSON property fileHashes



6455
6456
6457
# File 'lib/google/apis/run_v2/classes.rb', line 6455

def file_hashes
  @file_hashes
end

#resolved_connected_repositoryGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1ConnectedRepository

Location of the source in a 2nd-gen Google Cloud Build repository resource. Corresponds to the JSON property resolvedConnectedRepository



6460
6461
6462
# File 'lib/google/apis/run_v2/classes.rb', line 6460

def resolved_connected_repository
  @resolved_connected_repository
end

#resolved_git_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1GitSource

Location of the source in any accessible Git repository. Corresponds to the JSON property resolvedGitSource



6465
6466
6467
# File 'lib/google/apis/run_v2/classes.rb', line 6465

def resolved_git_source
  @resolved_git_source
end

#resolved_repo_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1RepoSource

Location of the source in a Google Cloud Source Repository. Corresponds to the JSON property resolvedRepoSource



6470
6471
6472
# File 'lib/google/apis/run_v2/classes.rb', line 6470

def resolved_repo_source
  @resolved_repo_source
end

#resolved_storage_sourceGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource

Location of the source in an archive file in Cloud Storage. Corresponds to the JSON property resolvedStorageSource



6475
6476
6477
# File 'lib/google/apis/run_v2/classes.rb', line 6475

def resolved_storage_source
  @resolved_storage_source
end

#resolved_storage_source_manifestGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSourceManifest

Location of the source manifest in Cloud Storage. This feature is in Preview; see description here. Corresponds to the JSON property resolvedStorageSourceManifest



6482
6483
6484
# File 'lib/google/apis/run_v2/classes.rb', line 6482

def resolved_storage_source_manifest
  @resolved_storage_source_manifest
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6489
6490
6491
6492
6493
6494
6495
6496
# File 'lib/google/apis/run_v2/classes.rb', line 6489

def update!(**args)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @resolved_connected_repository = args[:resolved_connected_repository] if args.key?(:resolved_connected_repository)
  @resolved_git_source = args[:resolved_git_source] if args.key?(:resolved_git_source)
  @resolved_repo_source = args[:resolved_repo_source] if args.key?(:resolved_repo_source)
  @resolved_storage_source = args[:resolved_storage_source] if args.key?(:resolved_storage_source)
  @resolved_storage_source_manifest = args[:resolved_storage_source_manifest] if args.key?(:resolved_storage_source_manifest)
end