Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1StorageSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Location of the source in an archive file in Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1StorageSource

Returns a new instance of GoogleDevtoolsCloudbuildV1StorageSource.



6595
6596
6597
# File 'lib/google/apis/run_v2/classes.rb', line 6595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketString

Cloud Storage bucket containing the source (see Bucket Name Requirements). Corresponds to the JSON property bucket

Returns:

  • (String)


6576
6577
6578
# File 'lib/google/apis/run_v2/classes.rb', line 6576

def bucket
  @bucket
end

#generationFixnum

Optional. Cloud Storage generation for the object. If the generation is omitted, the latest generation will be used. Corresponds to the JSON property generation

Returns:

  • (Fixnum)


6582
6583
6584
# File 'lib/google/apis/run_v2/classes.rb', line 6582

def generation
  @generation
end

#objectString

Required. Cloud Storage object containing the source. This object must be a zipped (.zip) or gzipped archive file (.tar.gz) containing source to build. Corresponds to the JSON property object

Returns:

  • (String)


6588
6589
6590
# File 'lib/google/apis/run_v2/classes.rb', line 6588

def object
  @object
end

#source_fetcherString

Optional. Option to specify the tool to fetch the source file for the build. Corresponds to the JSON property sourceFetcher

Returns:

  • (String)


6593
6594
6595
# File 'lib/google/apis/run_v2/classes.rb', line 6593

def source_fetcher
  @source_fetcher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6600
6601
6602
6603
6604
6605
# File 'lib/google/apis/run_v2/classes.rb', line 6600

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @generation = args[:generation] if args.key?(:generation)
  @object = args[:object] if args.key?(:object)
  @source_fetcher = args[:source_fetcher] if args.key?(:source_fetcher)
end