Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGenericArtifact.



6721
6722
6723
# File 'lib/google/apis/run_v2/classes.rb', line 6721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_fingerprintGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property artifactFingerprint



6698
6699
6700
# File 'lib/google/apis/run_v2/classes.rb', line 6698

def artifact_fingerprint
  @artifact_fingerprint
end

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6703
6704
6705
# File 'lib/google/apis/run_v2/classes.rb', line 6703

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesHash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes>

Output only. The file hashes that make up the generic artifact. Corresponds to the JSON property fileHashes



6708
6709
6710
# File 'lib/google/apis/run_v2/classes.rb', line 6708

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6713
6714
6715
# File 'lib/google/apis/run_v2/classes.rb', line 6713

def push_timing
  @push_timing
end

#uriString

Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/ repositories/r1/packages/p1/versions/v1 Corresponds to the JSON property uri

Returns:

  • (String)


6719
6720
6721
# File 'lib/google/apis/run_v2/classes.rb', line 6719

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6726
6727
6728
6729
6730
6731
6732
# File 'lib/google/apis/run_v2/classes.rb', line 6726

def update!(**args)
  @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end