Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGenericArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGenericArtifact.



6695
6696
6697
# File 'lib/google/apis/run_v2/classes.rb', line 6695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_fingerprintGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property artifactFingerprint



6672
6673
6674
# File 'lib/google/apis/run_v2/classes.rb', line 6672

def artifact_fingerprint
  @artifact_fingerprint
end

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6677
6678
6679
# File 'lib/google/apis/run_v2/classes.rb', line 6677

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesHash<String,Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes>

Output only. The file hashes that make up the generic artifact. Corresponds to the JSON property fileHashes



6682
6683
6684
# File 'lib/google/apis/run_v2/classes.rb', line 6682

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6687
6688
6689
# File 'lib/google/apis/run_v2/classes.rb', line 6687

def push_timing
  @push_timing
end

#uriString

Output only. URI of the uploaded artifact. Ex: projects/p1/locations/us/ repositories/r1/packages/p1/versions/v1 Corresponds to the JSON property uri

Returns:

  • (String)


6693
6694
6695
# File 'lib/google/apis/run_v2/classes.rb', line 6693

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6700
6701
6702
6703
6704
6705
6706
# File 'lib/google/apis/run_v2/classes.rb', line 6700

def update!(**args)
  @artifact_fingerprint = args[:artifact_fingerprint] if args.key?(:artifact_fingerprint)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end