Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A Go module artifact uploaded to Artifact Registry using the GoModule directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGoModule
constructor
A new instance of GoogleDevtoolsCloudbuildV1UploadedGoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGoModule
Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGoModule.
6748 6749 6750 |
# File 'lib/google/apis/run_v2/classes.rb', line 6748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
6730 6731 6732 |
# File 'lib/google/apis/run_v2/classes.rb', line 6730 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
6736 6737 6738 |
# File 'lib/google/apis/run_v2/classes.rb', line 6736 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
6741 6742 6743 |
# File 'lib/google/apis/run_v2/classes.rb', line 6741 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
6746 6747 6748 |
# File 'lib/google/apis/run_v2/classes.rb', line 6746 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6753 6754 6755 6756 6757 6758 |
# File 'lib/google/apis/run_v2/classes.rb', line 6753 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |