Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedGoModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
A Go module artifact uploaded to Artifact Registry using the GoModule directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded artifact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGoModule
constructor
A new instance of GoogleDevtoolsCloudbuildV1UploadedGoModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedGoModule
Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedGoModule.
5954 5955 5956 |
# File 'lib/google/apis/run_v2/classes.rb', line 5954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
5936 5937 5938 |
# File 'lib/google/apis/run_v2/classes.rb', line 5936 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
5942 5943 5944 |
# File 'lib/google/apis/run_v2/classes.rb', line 5942 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
5947 5948 5949 |
# File 'lib/google/apis/run_v2/classes.rb', line 5947 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded artifact.
Corresponds to the JSON property uri
5952 5953 5954 |
# File 'lib/google/apis/run_v2/classes.rb', line 5952 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5959 5960 5961 5962 5963 5964 |
# File 'lib/google/apis/run_v2/classes.rb', line 5959 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |