Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Maven artifact uploaded using the MavenArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedMavenArtifact.



6773
6774
6775
# File 'lib/google/apis/run_v2/classes.rb', line 6773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6755
6756
6757
# File 'lib/google/apis/run_v2/classes.rb', line 6755

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



6761
6762
6763
# File 'lib/google/apis/run_v2/classes.rb', line 6761

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6766
6767
6768
# File 'lib/google/apis/run_v2/classes.rb', line 6766

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


6771
6772
6773
# File 'lib/google/apis/run_v2/classes.rb', line 6771

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6778
6779
6780
6781
6782
6783
# File 'lib/google/apis/run_v2/classes.rb', line 6778

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end