Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Maven artifact uploaded using the MavenArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedMavenArtifact.



6711
6712
6713
# File 'lib/google/apis/run_v2/classes.rb', line 6711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6693
6694
6695
# File 'lib/google/apis/run_v2/classes.rb', line 6693

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



6699
6700
6701
# File 'lib/google/apis/run_v2/classes.rb', line 6699

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6704
6705
6706
# File 'lib/google/apis/run_v2/classes.rb', line 6704

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


6709
6710
6711
# File 'lib/google/apis/run_v2/classes.rb', line 6709

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6716
6717
6718
6719
6720
6721
# File 'lib/google/apis/run_v2/classes.rb', line 6716

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end