Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

A Maven artifact uploaded using the MavenArtifact directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedMavenArtifact

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedMavenArtifact.



5992
5993
5994
# File 'lib/google/apis/run_v2/classes.rb', line 5992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


5974
5975
5976
# File 'lib/google/apis/run_v2/classes.rb', line 5974

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



5980
5981
5982
# File 'lib/google/apis/run_v2/classes.rb', line 5980

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



5985
5986
5987
# File 'lib/google/apis/run_v2/classes.rb', line 5985

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


5990
5991
5992
# File 'lib/google/apis/run_v2/classes.rb', line 5990

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5997
5998
5999
6000
6001
6002
# File 'lib/google/apis/run_v2/classes.rb', line 5997

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end