Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
An npm package uploaded to Artifact Registry using the NpmPackage directive.
Instance Attribute Summary collapse
-
#artifact_registry_package ⇒ String
Output only.
-
#file_hashes ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build.
-
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
-
#uri ⇒ String
URI of the uploaded npm package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage
constructor
A new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage
Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.
6818 6819 6820 |
# File 'lib/google/apis/run_v2/classes.rb', line 6818 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_registry_package ⇒ String
Output only. Path to the artifact in Artifact Registry.
Corresponds to the JSON property artifactRegistryPackage
6800 6801 6802 |
# File 'lib/google/apis/run_v2/classes.rb', line 6800 def artifact_registry_package @artifact_registry_package end |
#file_hashes ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes
Container message for hashes of byte content of files, used in
SourceProvenance messages to verify integrity of source input to the build.
Corresponds to the JSON property fileHashes
6806 6807 6808 |
# File 'lib/google/apis/run_v2/classes.rb', line 6806 def file_hashes @file_hashes end |
#push_timing ⇒ Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan
Start and end times for a build execution phase.
Corresponds to the JSON property pushTiming
6811 6812 6813 |
# File 'lib/google/apis/run_v2/classes.rb', line 6811 def push_timing @push_timing end |
#uri ⇒ String
URI of the uploaded npm package.
Corresponds to the JSON property uri
6816 6817 6818 |
# File 'lib/google/apis/run_v2/classes.rb', line 6816 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6823 6824 6825 6826 6827 6828 |
# File 'lib/google/apis/run_v2/classes.rb', line 6823 def update!(**args) @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package) @file_hashes = args[:file_hashes] if args.key?(:file_hashes) @push_timing = args[:push_timing] if args.key?(:push_timing) @uri = args[:uri] if args.key?(:uri) end |