Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

An npm package uploaded to Artifact Registry using the NpmPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.



6749
6750
6751
# File 'lib/google/apis/run_v2/classes.rb', line 6749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6731
6732
6733
# File 'lib/google/apis/run_v2/classes.rb', line 6731

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



6737
6738
6739
# File 'lib/google/apis/run_v2/classes.rb', line 6737

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6742
6743
6744
# File 'lib/google/apis/run_v2/classes.rb', line 6742

def push_timing
  @push_timing
end

#uriString

URI of the uploaded npm package. Corresponds to the JSON property uri

Returns:

  • (String)


6747
6748
6749
# File 'lib/google/apis/run_v2/classes.rb', line 6747

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6754
6755
6756
6757
6758
6759
# File 'lib/google/apis/run_v2/classes.rb', line 6754

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end