Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedNpmPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

An npm package uploaded to Artifact Registry using the NpmPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedNpmPackage

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedNpmPackage.



6030
6031
6032
# File 'lib/google/apis/run_v2/classes.rb', line 6030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6012
6013
6014
# File 'lib/google/apis/run_v2/classes.rb', line 6012

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



6018
6019
6020
# File 'lib/google/apis/run_v2/classes.rb', line 6018

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6023
6024
6025
# File 'lib/google/apis/run_v2/classes.rb', line 6023

def push_timing
  @push_timing
end

#uriString

URI of the uploaded npm package. Corresponds to the JSON property uri

Returns:

  • (String)


6028
6029
6030
# File 'lib/google/apis/run_v2/classes.rb', line 6028

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6035
6036
6037
6038
6039
6040
# File 'lib/google/apis/run_v2/classes.rb', line 6035

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end