Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifact uploaded using the PythonPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedPythonPackage

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedPythonPackage.



6894
6895
6896
# File 'lib/google/apis/run_v2/classes.rb', line 6894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6876
6877
6878
# File 'lib/google/apis/run_v2/classes.rb', line 6876

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



6882
6883
6884
# File 'lib/google/apis/run_v2/classes.rb', line 6882

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6887
6888
6889
# File 'lib/google/apis/run_v2/classes.rb', line 6887

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


6892
6893
6894
# File 'lib/google/apis/run_v2/classes.rb', line 6892

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6899
6900
6901
6902
6903
6904
# File 'lib/google/apis/run_v2/classes.rb', line 6899

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end