Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1UploadedPythonPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Artifact uploaded using the PythonPackage directive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1UploadedPythonPackage

Returns a new instance of GoogleDevtoolsCloudbuildV1UploadedPythonPackage.



6068
6069
6070
# File 'lib/google/apis/run_v2/classes.rb', line 6068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_registry_packageString

Output only. Path to the artifact in Artifact Registry. Corresponds to the JSON property artifactRegistryPackage

Returns:

  • (String)


6050
6051
6052
# File 'lib/google/apis/run_v2/classes.rb', line 6050

def artifact_registry_package
  @artifact_registry_package
end

#file_hashesGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1FileHashes

Container message for hashes of byte content of files, used in SourceProvenance messages to verify integrity of source input to the build. Corresponds to the JSON property fileHashes



6056
6057
6058
# File 'lib/google/apis/run_v2/classes.rb', line 6056

def file_hashes
  @file_hashes
end

#push_timingGoogle::Apis::RunV2::GoogleDevtoolsCloudbuildV1TimeSpan

Start and end times for a build execution phase. Corresponds to the JSON property pushTiming



6061
6062
6063
# File 'lib/google/apis/run_v2/classes.rb', line 6061

def push_timing
  @push_timing
end

#uriString

URI of the uploaded artifact. Corresponds to the JSON property uri

Returns:

  • (String)


6066
6067
6068
# File 'lib/google/apis/run_v2/classes.rb', line 6066

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6073
6074
6075
6076
6077
6078
# File 'lib/google/apis/run_v2/classes.rb', line 6073

def update!(**args)
  @artifact_registry_package = args[:artifact_registry_package] if args.key?(:artifact_registry_package)
  @file_hashes = args[:file_hashes] if args.key?(:file_hashes)
  @push_timing = args[:push_timing] if args.key?(:push_timing)
  @uri = args[:uri] if args.key?(:uri)
end