Class: Google::Apis::RunV2::GoogleDevtoolsCloudbuildV1Volume

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb

Overview

Volume describes a Docker container volume which is mounted into build steps in order to persist files across build step execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleDevtoolsCloudbuildV1Volume

Returns a new instance of GoogleDevtoolsCloudbuildV1Volume.



6819
6820
6821
# File 'lib/google/apis/run_v2/classes.rb', line 6819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the volume to mount. Volume names must be unique per build step and must be valid names for Docker volumes. Each named volume must be used by at least two build steps. Corresponds to the JSON property name

Returns:

  • (String)


6810
6811
6812
# File 'lib/google/apis/run_v2/classes.rb', line 6810

def name
  @name
end

#pathString

Path at which to mount the volume. Paths must be absolute and cannot conflict with other volume paths on the same build step or with certain reserved volume paths. Corresponds to the JSON property path

Returns:

  • (String)


6817
6818
6819
# File 'lib/google/apis/run_v2/classes.rb', line 6817

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6824
6825
6826
6827
# File 'lib/google/apis/run_v2/classes.rb', line 6824

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
end