Class: Google::Apis::RunV2::GoogleLongrunningListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::GoogleLongrunningListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::RunV2::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
constructor
A new instance of GoogleLongrunningListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse
Returns a new instance of GoogleLongrunningListOperationsResponse.
6518 6519 6520 |
# File 'lib/google/apis/run_v2/classes.rb', line 6518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
6503 6504 6505 |
# File 'lib/google/apis/run_v2/classes.rb', line 6503 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::RunV2::GoogleLongrunningOperation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
6508 6509 6510 |
# File 'lib/google/apis/run_v2/classes.rb', line 6508 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
6516 6517 6518 |
# File 'lib/google/apis/run_v2/classes.rb', line 6516 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6523 6524 6525 6526 6527 |
# File 'lib/google/apis/run_v2/classes.rb', line 6523 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |