Class: Google::Apis::RunV2::UtilStatusProto
- Inherits:
-
Object
- Object
- Google::Apis::RunV2::UtilStatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/run_v2/classes.rb,
lib/google/apis/run_v2/representations.rb,
lib/google/apis/run_v2/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property
canonicalCode. -
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::RunV2::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
-
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UtilStatusProto
constructor
A new instance of UtilStatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UtilStatusProto
Returns a new instance of UtilStatusProto.
6787 6788 6789 |
# File 'lib/google/apis/run_v2/classes.rb', line 6787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 canonical_code = 6;
Corresponds to the JSON property canonicalCode
6751 6752 6753 |
# File 'lib/google/apis/run_v2/classes.rb', line 6751 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 code = 1;
Corresponds to the JSON property code
6759 6760 6761 |
# File 'lib/google/apis/run_v2/classes.rb', line 6759 def code @code end |
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara:
strip_end_and_replace optional string message = 3;
Corresponds to the JSON property message
6765 6766 6767 |
# File 'lib/google/apis/run_v2/classes.rb', line 6765 def @message end |
#message_set ⇒ Google::Apis::RunV2::Proto2BridgeMessageSet
This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS.
If you are using editions or proto2, please make your own extendable messages
for your use case. If you are using proto3, please use Any instead.
MessageSet was the implementation of extensions for proto1. When proto2 was
introduced, extensions were implemented as a first-class feature. This schema
for MessageSet was meant to be a "bridge" solution to migrate MessageSet-
bearing messages from proto1 to proto2. This schema has been open-sourced only
to facilitate the migration of Google products with MessageSet-bearing
messages to open-source environments.
Corresponds to the JSON property messageSet
6778 6779 6780 |
# File 'lib/google/apis/run_v2/classes.rb', line 6778 def @message_set end |
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara:
strip_end_and_replace optional string space = 2; // Space to which this status
belongs
Corresponds to the JSON property space
6785 6786 6787 |
# File 'lib/google/apis/run_v2/classes.rb', line 6785 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6792 6793 6794 6795 6796 6797 6798 |
# File 'lib/google/apis/run_v2/classes.rb', line 6792 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |